/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(xb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function vb(wb){var r=wb.a;var s=r.buffer;r.grow=tb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=wb.abort;var M=NaN;var N=Infinity;var O=wb.b;var P=wb.c;var Q=wb.d;var R=wb.e;var S=wb.f;var T=wb.g;var U=wb.h;var V=wb.i;var W=wb.j;var X=wb.k;var Y=wb.l;var Z=wb.m;var _=wb.n;var $=wb.o;var aa=wb.p;var ba=wb.q;var ca=wb.r;var da=wb.s;var ea=wb.t;var fa=wb.u;var ga=wb.v;var ha=wb.w;var ia=wb.x;var ja=wb.y;var ka=wb.z;var la=wb.A;var ma=wb.B;var na=wb.C;var oa=wb.D;var pa=wb.E;var qa=wb.F;var ra=wb.G;var sa=wb.H;var ta=wb.I;var ua=wb.J;var va=wb.K;var wa=wb.L;var xa=wb.M;var ya=wb.N;var za=wb.O;var Aa=wb.P;var Ba=wb.Q;var Ca=wb.R;var Da=wb.S;var Ea=wb.T;var Fa=wb.U;var Ga=wb.V;var Ha=wb.W;var Ia=wb.X;var Ja=wb.Y;var Ka=wb.Z;var La=wb._;var Ma=wb.$;var Na=wb.aa;var Oa=wb.ba;var Pa=wb.ca;var Qa=wb.da;var Ra=wb.ea;var Sa=wb.fa;var Ta=wb.ga;var Ua=wb.ha;var Va=wb.ia;var Wa=wb.ja;var Xa=wb.ka;var Ya=wb.la;var Za=wb.ma;var _a=wb.na;var $a=wb.oa;var ab=wb.pa;var bb=wb.qa;var cb=wb.ra;var db=wb.sa;var eb=wb.ta;var fb=wb.ua;var gb=wb.va;var hb=wb.wa;var ib=wb.xa;var jb=5706928;var kb=0;var lb=0;var mb=0;
// EMSCRIPTEN_START_FUNCS
function Uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0),aa=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=C(0),wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=C(0),Ma=0;aa=jb-32|0;jb=aa;a:{b:{na=a+24604|0;e=na;if(!v[e+16>>2]){break b}g=v[e+20>>2];if(g>>>0>4|!(1<<g&22)){break b}e=v[e+28>>2];if(e>>>0>4){break b}e=23>>>e&1;break a}e=0}if(!e){EL(aa+16|0,20656,20676,207);m=aa+16|0;e=jb-160|0;jb=e;g=Ub(e+120|0,38211);v[114578]=0;U(6,e+104|0,1,20681);h=v[114578];v[114578]=0;c:{d:{e:{f:{g:{if((h|0)!=1){v[114578]=0;U(3,e+136|0,g|0,e+104|0);h=v[114578];v[114578]=0;if((h|0)==1){break g}v[114578]=0;fa(2118,e+88|0,m|0,1,38204,e+136|0);m=v[114578];v[114578]=0;if((m|0)==1){break f}yb(e+136|0);yb(e+104|0);break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(e+136|0)}yb(e+104|0)}yb(g);S(a|0);L()}yb(g);jb=e+160|0}e=v[a+480208>>2];h:{if(!b|e&512){break h}xa=a+8204|0;ya=a+1074332|0;za=a+393352|0;ia=a+12|0;oa=a+1304392|0;m=v[a+1074380>>2];while(1){i:{if(m){break i}V=a;g=e|512;j:{if(e&256){break j}m=0;q=jb-32|0;jb=q;R=jb-16|0;jb=R;F=a;f=F;g=f+1074392|0;e=v[g>>2]+1|0;v[g>>2]=e;k:{l:{m:{n:{if(vl(f)>>>0>e>>>0){break n}o=f+1074984|0;p=f+1074312|0;h=f+1304360|0;n=f+484344|0;j=f+484360|0;l=f+1074438|0;k=f+1074424|0;G=f+480210|0;while(1){i=0;o:{if(!v[f+1074396>>2]){break o}i=0;if(!(w[G|0]&8)){break o}i=v[f+480180>>2]==1}p:{if(v[f+480180>>2]!=2|(w[G|0]&8?0:v[f+1074428>>2])){break p}g=0;if(!x[f+480188>>1]){break p}while(1){v[(f+B(g,896)|0)+1075788>>2]=0;g=g+1|0;if(g>>>0<x[f+480188>>1]){continue}break}}v[f+1074400>>2]=0;v[f+1074392>>2]=0;v[f+1074396>>2]=0;v[f+1074424>>2]=v[f+1074428>>2];g=x[f+1074440>>1];u[f+1074438>>1]=g;if(!(w[f+480208|0]&32)){e=f;q:{if(oc(Vb(j))>>>0>g>>>0){g=x[rc(Vb(j),x[l>>1])>>1];break q}g=65535}u[e+1074436>>1]=g;r:{if(Ce(n)>>>0<=(g&65535)>>>0){break r}if(mh(_b(n,x[f+1074436>>1]))){break r}u[f+1074436>>1]=65534}if(x[f+1074436>>1]>=Ce(n)>>>0){while(1){s:{t:{u:{v:{if(x[f+1074436>>1]!=65535){e=x[l>>1];if(oc(Vb(j))>>>0>e>>>0){break v}}e=x[Vb(j)+28>>1];if(e){break t}e=x[l>>1];if(oc(Vb(j))>>>0<e>>>0){break u}g=x[l>>1];if(!g){break u}while(1){e=g;g=e-1|0;if(!g){break u}if(x[rc(Vb(j),g)>>1]!=65535){continue}break}break t}g=x[l>>1]+1|0;u[l>>1]=g;break s}e=0}u[f+1074438>>1]=e;v[f+480208>>2]=v[f+480208>>2]&-524289;w:{if(oc(Vb(j))>>>0<=(e&65535)>>>0){break w}while(1){if(x[rc(Vb(j),x[l>>1])>>1]!=65534){break w}e=x[l>>1]+1|0;u[l>>1]=e;if(oc(Vb(j))>>>0>(e&65535)>>>0){continue}break}}e=x[l>>1];x:{if(oc(Vb(j))>>>0<=e>>>0){break x}if(!np(Vb(j),x[l>>1])){break x}g=x[l>>1];break s}qj(h,1);break l}e=f;y:{if(oc(Vb(j))>>>0>(g&65535)>>>0){g=x[rc(Vb(j),x[l>>1])>>1];break y}g=65535}u[e+1074436>>1]=g;z:{if(Ce(n)>>>0<=(g&65535)>>>0){break z}if(mh(_b(n,x[f+1074436>>1]))){break z}u[f+1074436>>1]=65534}if(x[f+1074436>>1]>=Ce(n)>>>0){continue}break}}u[f+1074440>>1]=x[f+1074438>>1]}if(!dg(n,x[f+1074436>>1])){break l}if(y[f+1074424>>2]>=y[_b(n,x[f+1074436>>1])+12>>2]){v[k>>2]=0}A=v[f+480272>>2]==-1?0:(w[f+480208|0]&32)>>>5|0;if(i){g=h+12|0;if(md(g)){e=-1}else{e=v[pj(g)>>2]}e=(e|0)!=v[k>>2]}else{e=0}A:{if(A|e){break A}if(!aN(h,x[l>>1],v[k>>2],1)){break A}e=v[f+480272>>2];if(e){if((e|0)>=1){v[f+480272>>2]=e-1}qj(h,1);bL(h,x[l>>1],v[k>>2]);break A}if(!(w[G|0]&64)){break m}if(!$M(h,l,k,1)){u[f+1074438>>1]=0;u[f+1074440>>1]=0;v[f+1074424>>2]=0;v[f+1074428>>2]=0;e=w[j+16|0];if((e|0)>=(Mh(j)-1|0)){mp(j,0);qj(h,1);e=0;break k}mp(j,w[j+16|0]+1&255);qj(h,1)}g=0;while(1){qn((f+B(g,896)|0)+1074984|0,f,g&65535);g=g+1|0;if((g|0)!=256){continue}break}xL(f);v[f+1074416>>2]=v[f+480196>>2];v[f+1074420>>2]=v[f+480204>>2];v[f+1074444>>2]=v[f+480200>>2];u[f+1074440>>1]=x[f+1074438>>1];v[f+1074428>>2]=v[f+1074424>>2];g=h;A=oc(Vb(j));e=x[f+1074438>>1];if(A>>>0>e>>>0){Ja=f,Ka=x[rc(Vb(j),x[f+1074438>>1])>>1],u[Ja+1074436>>1]=Ka;e=x[f+1074438>>1]}bL(g,e&65535,v[f+1074424>>2]);if(!dg(n,x[f+1074436>>1])){break l}}e=v[f+1074424>>2]+1|0;v[f+1074428>>2]=e;B:{if(e>>>0<y[_b(n,x[f+1074436>>1])+12>>2]){break B}if(!(w[f+480208|0]&32)){u[f+1074440>>1]=x[f+1074438>>1]+1}v[f+1074428>>2]=0;Eb(R+8|0,p,63);if(!Cb(R+8|0)){break B}e=v[f+1074432>>2];v[f+1074432>>2]=0;v[f+1074428>>2]=e}e=Xe(_b(n,x[f+1074436>>1]),v[f+1074424>>2],0);g=x[f+480188>>1];if(g){H=(f+B(g,896)|0)+1074984|0;g=o;while(1){Eb(R+8|0,p,82);C:{if(!Cb(R+8|0)|w[g+827|0]!=1){break C}A=w[e+3|0];if((A|0)!=3?(A|0)!=2:0){break C}Ja=g,Ka=ag(f,w[g+822|0],v[g+768>>2],v[g+704>>2]),v[Ja+700>>2]=Ka}Eb(R+8|0,p,91);D:{if(!Cb(R+8|0)){break D}if(Tf(e)){break D}if(!Tf(g+810|0)|w[g+813|0]!=19){break D}A=w[g+815|0];if((A&240)!=208|y[f+1074416>>2]>(A&15)>>>0){break D}Ja=g,Ka=ag(f,w[g+810|0],v[g+768>>2],0),v[Ja+700>>2]=Ka}Eb(R+8|0,p,92);E:{if(!Cb(R+8|0)){break E}Eb(R,p,5);if(Cb(R)|v[f+1074416>>2]!=1|w[g+813|0]!=17){break E}v[f+1074420>>2]=B(w[g+815|0],1e4)}A=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[g+810|0]=A;t[g+811|0]=A>>>8;t[g+812|0]=A>>>16;t[g+813|0]=A>>>24;A=w[e+4|0]|w[e+5|0]<<8;t[g+814|0]=A;t[g+815|0]=A>>>8;A=v[g+676>>2];v[g+20>>2]=v[g+672>>2];v[g+24>>2]=A;v[g+88>>2]=v[g+88>>2]&-393217;Eb(R+8|0,p,21);if(!Cb(R+8|0)){t[g+851|0]=0}v[g+884>>2]=0;t[g+827|0]=0;e=e+6|0;g=g+896|0;if((H|0)!=(g|0)){continue}break}}e=f;A=e+1074412|0;F:{G:{g=e+484344|0;if(Kn(g,x[e+1074436>>1])){if(FM(_b(g,x[e+1074436>>1]))){break G}}v[e+1074408>>2]=v[e+480216>>2];e=v[e+480220>>2];break F}Ja=e+1074408|0,Ka=v[_b(g,x[e+1074436>>1])+16>>2],v[Ja>>2]=Ka;e=v[_b(g,x[e+1074436>>1])+20>>2]}v[A>>2]=e;if(!i){break n}e=v[f+1074416>>2]+1|0;v[f+1074392>>2]=e;if(vl(f)>>>0<=e>>>0){continue}break}}if(!v[f+1074416>>2]){v[f+1074416>>2]=1}g=v[f+480208>>2];e=f;H:{I:{if(v[f+1074392>>2]){v[f+480208>>2]=g&-4097;if(v[f+480180>>2]&1048580|(w[f+480210|0]&32?0:v[f+480180>>2]==1)){break H}if(y[f+1074392>>2]>=vl(f)>>>0|y[f+1074392>>2]%(v[f+1074400>>2]+v[f+1074416>>2]>>>0)){break H}g=v[f+480208>>2];break I}g=g&-528385}v[e+480208>>2]=g|4096}s=0;r=jb-32|0;jb=r;I=f+1074312|0;T=f+480208|0;A=-1;K=65535;J:{if(!x[f+480188>>1]){n=-1;break J}ga=f+1075821|0;X=f+1304392|0;_=f+1074376|0;n=-1;while(1){E=f+B(s,896)|0;o=E+1075799|0;h=w[o|0];l=E+1075797|0;G=w[l|0];H=E+1075798|0;J=w[H|0];ca=E+1075796|0;p=w[ca|0];ba=E+1075795|0;i=w[ba|0];e=v[f+1074392>>2];g=v[f+1074400>>2];k=v[f+1074416>>2];W=E+1075794|0;j=Ds(W);N=E+1075856|0;t[N|0]=v[f+480208>>2]>>>12&1|w[N|0]&254;Y=(e>>>0)%(g+k>>>0)|0;e=w[W|0];if((e|0)==252){e=w[ba|0];g=iy(W);k=Bs(W);K:{if(!e|e-251>>>0<5){break K}e=v[(f+B(e,160)|0)+906140>>2];if(!e){break K}nb[v[v[e>>2]+44>>2]](e,g,C(C(k>>>0)*C(.0010010009864345193)))}e=w[W|0]}L:{if(G&255|z[E+1075868>>2]==C(0)?(e&255)!=251:0){break L}M=v[T>>2]&4096;M:{if(!M){k=w[E+1075878|0];break M}k=w[ba|0];t[E+1075878|0]=k}e=k&255;if(e-251>>>0<5|!e){break L}g=(f+B(e,160)|0)+906140|0;if(!v[g>>2]){break L}N:{if(!M){e=x[E+1075876>>1];break N}e=zs(w[ca|0],w[H|0]);u[E+1075876>>1]=e;$=C(C(zs(w[l|0],w[o|0])>>>0)*C(.0010010009864345193));z[E+1075872>>2]=$;o=v[g>>2];Ja=E+1075868|0,La=C(C($-C(nb[v[v[o>>2]+48>>2]](o,e)))/C(vl(f)>>>0)),z[Ja>>2]=La}o=v[f+1074392>>2];l=vl(f);g=v[g>>2];k=e;e=(l|0)==(o+1|0);nb[v[v[g>>2]+(e?44:100)>>2]](g,k,z[(e?E+1075872|0:E+1075868|0)>>2])}l=E+1074984|0;O:{P:{Q:{R:{S:{if(!AM(w[W|0])){if(w[T+1|0]&16){break S}break R}e=jb-16|0;jb=e;u[e+12>>1]=0;v[e+8>>2]=0;Qh(e+8|0);g=x[e+12>>1];t[l+814|0]=g;t[l+815|0]=g>>>8;g=v[e+8>>2];t[l+810|0]=g;t[l+811|0]=g>>>8;t[l+812|0]=g>>>16;t[l+813|0]=g>>>24;jb=e+16|0;i=0;p=0;J=0;G=0;h=0;j=0;if(!(w[T+1|0]&16)){break R}k=0;break P}if(!i){i=0;break Q}v[E+1075768>>2]=0;break Q}rM(f,l)}o=G&255;if((o|0)==33){Eb(r+24|0,I,30);k=h>>>4|0;dy(f,s&65535,k+(h&15)|0,Cb(r+24|0));G=33;break P}k=0;if((G-19&255)>>>0>1){break P}T:{if(!(!(v[f+480180>>2]&16777250)|h)){h=w[E+1075837|0];break T}t[E+1075837|0]=h}g=h&240;if((g|0)==208){e=h&15;if(!e){if(v[f+480180>>2]&16777248){k=1;break P}if(v[f+480180>>2]!=2){break P}break O}U:{if(e>>>0<v[f+1074400>>2]+v[f+1074416>>2]>>>0){break U}Eb(r+24|0,I,14);if(!Cb(r+24|0)){break U}if(!i){break O}t[E+1075809|0]=i;break O}k=e;break P}if(!(w[T+1|0]&16)){break P}V:{W:{X:{Y:{if((g|0)==96){e=19;if((o|0)==19){break Y}}if((g|0)!=176){break W}e=20;if((o|0)!=20){break X}}Eb(r+24|0,I,77);if(!(!Cb(r+24|0)|!(v[(f+(s<<5)|0)+480280>>2]&1024))){G=e;break P}g=f;G=l;M=0;H=jb-16|0;jb=H;Q=h&15;Z:{_:{if(Q){o=w[G+861|0];$:{if(o){o=o-1|0;t[G+861|0]=o;if(o&255){break $}Eb(H+8|0,g+1074312|0,16);if(!Cb(H+8|0)){o=-1;if(v[g+480180>>2]!=2){break Z}}v[G+804>>2]=v[g+1074424>>2]+1;break _}Eb(H+8|0,g+1074312|0,17);if(!(Cb(H+8|0)|v[g+480180>>2]&3|!x[g+480188>>1])){o=g+1074984|0;while(1){if(w[o+861|0]?(o|0)!=(G|0):0){break _}o=o+896|0;M=M+1|0;if(x[g+480188>>1]>(M&65535)>>>0){continue}break}}t[G+861|0]=Q}o=v[G+804>>2];v[g+1074432>>2]=o;break Z}v[G+804>>2]=v[g+1074424>>2]}o=-1}jb=H+16|0;g=o;aa:{if((g|0)==-1){g=n;break aa}ba:{if((A|0)!=-1){Eb(r+24|0,I,68);A=Cb(r+24|0)?g:A;break ba}A=-1}Eb(r+24|0,I,103);K=Cb(r+24|0)?-1:K}if(!x[f+480188>>1]|v[f+480180>>2]!=2){break V}o=E+1075845|0;n=E+1075788|0;G=0;while(1){H=f+B(G,896)|0;v[H+1075788>>2]=v[n>>2];t[H+1075845|0]=w[o|0];G=G+1|0;if(G>>>0<x[f+480188>>1]){continue}break}break V}G=19;break P}if((g|0)!=224|(v[f+1074396>>2]?v[f+480180>>2]&16777250:0)){break P}e=h&15;if(e?0:v[f+480180>>2]&2){break P}v[f+1074396>>2]=e+1;break P}G=e;n=g}da=G&255;g=v[f+480180>>2]==16&(da|0)==19&(h&240)==208;Q=g?0:k;ca:{if(!Q|w[W|0]!=255|w[ca|0]!=2){break ca}Eb(r+24|0,I,74);if(!Cb(r+24|0)){break ca}t[ca|0]=0}e=v[f+1074392>>2];Eb(r+24|0,I,72);da:{if(Cb(r+24|0)){M=0;if(Q>>>0>=y[f+1074416>>2]){break da}}Eb(r+24|0,I,88);M=(Q|0)==(Y|0)|(e|0)==(Q|0);if(!(!Cb(r+24|0)|!Q)){break da}M=(e|0)==(Q|0)}Eb(r+24|0,I,44);if(Cb(r+24|0)){t[N|0]=w[N|0]&254|(Q|0)==(Y|0)}ea=h&15;o=g?ea|144:h;Eb(r+24|0,I,66);j=(!Q|Cb(r+24|0)^-1)&j;ea:{fa:{if(!(v[f+1074392>>2]|(!(w[T+2|0]&32)|!i))){v[E+1075644>>2]=0;if(M){break fa}if(!Kh(l)){break ea}t[E+1075809|0]=i;if(x[f+480190>>1]<i>>>0){break ea}e=f+B(i,104)|0;v[E+1075672>>2]=x[e+484410>>1];v[E+1075752>>2]=t[e+484417|0];break ea}if(!M){break ea}}h=w[W|0];if(i){t[E+1075809|0]=i}ga:{ha:{if(!be(h)){break ha}Eb(r+24|0,I,67);if(!Cb(r+24|0)){break ha}e=v[E+1075756>>2];ia:{if(!i|j){break ia}ja:{if(x[f+480192>>1]){g=65535;if(x[f+480192>>1]<i>>>0){break ja}k=v[(f+(i<<2)|0)+900380>>2];if(!k){break ja}g=x[dd(k+236|0,h-1|0)>>1];break ja}g=i}g=g&65535;if(g>>>0>x[f+480190>>1]){break ia}e=t[vp(f,g)+36|0]}h=(e+h|0)-12>>>0>119?0:h;break ga}if(!(v[f+480180>>2]&25165856)|!x[f+480192>>1]){break ga}e=h;if(e){e=be(e)}else{e=1}if(!e){break ga}e=i;if(!e){e=w[E+1075810|0]}if(!e|(v[(f+(e<<2)|0)+900380>>2]?x[f+480192>>1]>=e>>>0:0)){break ga}h=0;i=0}if(!((da|0)!=25|o)){Eb(r+24|0,I,55);e=Cb(r+24|0);i=e?0:i;h=e?0:h}Eb(r+24|0,I,65);e=(i|0)!=0;g=!h;k=Cb(r+24|0);Y=1;ka:{if(v[f+480180>>2]&16777248){break ka}Eb(r+24|0,I,107);if(Cb(r+24|0)){break ka}Eb(r+16|0,I,85);Y=0;if(!Cb(r+16|0)){break ka}if(Kh(l)){break ka}Y=1;H=v[E+1075088>>2];if(!H){break ka}Y=De(H)^1}H=e&g;N=e&k;la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{if(!(v[f+480180>>2]&1048580)){break sa}ta:{if((h|0)!=255){break ta}if((da|0)!=13?(p|0)==1|i:1){Eb(r+24|0,I,55);if(Cb(r+24|0)){break ta}}e=v[E+1075640>>2];if(t[e+60|0]&1?e:0){break ta}v[E+1075672>>2]=0;e=E+1075072|0;v[e>>2]=v[e>>2]|2097152;ua:{if(!(v[f+480208>>2]&4096)){break ua}Eb(r+24|0,I,86);if(!Cb(r+24|0)){break ua}v[e>>2]=v[e>>2]|4096}i=0;h=0;g=0;e=0;k=0;H=1;if(N){break ma}break la}Eb(r+24|0,I,59);if(!Cb(r+24|0)|v[T>>2]&4096){break sa}g=w[E+1075803|0]-w[E+1075756|0]|0;if(!h){break qa}if(h>>>0>250){Y=0;N=1;g=0;break qa}if(!i){Eb(r+24|0,I,98);if(Cb(r+24|0)){break ra}}Y=1;N=1;break ra}g=0;k=0;if(!H){break oa}break pa}g=h}j=0}Eb(r+24|0,I,65);if(!Cb(r+24|0)){break na}h=g;k=1}e=h;g=k;H=1;if(N){break ma}break la}h=g;g=1;H=N}va:{wa:{if(!x[f+480192>>1]){if(x[f+480190>>1]<i>>>0){break va}e=(f+B(i,104)|0)+484380|0;break wa}e=v[E+1075088>>2];if(!e){break va}}xa:{if(u[e+34>>1]<0){break xa}if(v[f+480180>>2]==2){if(!De(e)){break xa}}v[E+1075672>>2]=x[e+30>>1]}if(!H){break va}Ys(l,x[e+28>>1],f)}e=h;k=g}Eb(r+24|0,I,71);if(!(!Cb(r+24|0)|!i)){t[E+1075843|0]=32}ya:{if(!x[f+480192>>1]){break ya}Eb(r+24|0,I,100);if(!Cb(r+24|0)|!i){break ya}if(be(e&255)){break ya}g=v[T>>2];za:{if(j){if(g&8){break za}break ya}if(!(g&4)){break ya}}yl(l);v[E+1075680>>2]=65536;g=E+1075072|0;v[g>>2]=v[g>>2]|2097152}if(k){Eb(r+24|0,I,11);Aa:{if(!(Ja=Cb(r+24|0),Ka=1,Ma=v[f+480180>>2]!=268435456,Ma?Ja:Ka)){break Aa}Eb(r+24|0,I,87);h=0;if(Cb(r+24|0)){h=Kh(l)^1}Ba:{if(x[f+480192>>1]){if(x[f+480192>>1]<i>>>0){break Aa}if(v[E+1075640>>2]!=v[(f+(i<<2)|0)+900380>>2]|h){break Ba}break Aa}if((v[E+1075088>>2]!=((f+B(i,104)|0)+484380|0)|h)!=1|i>>>0>3999){break Aa}}e=w[E+1075803|0]}Ca:{if(!x[f+480192>>1]|!(v[f+480180>>2]&1048588)){break Ca}yl(l);t[E+1075822|0]=0;v[E+1075764>>2]=0;v[E+1075680>>2]=65536;g=E+1075072|0;v[g>>2]=v[g>>2]&-2101249|2097152;Eb(r+24|0,I,86);if(!Cb(r+24|0)){break Ca}v[g>>2]=v[g>>2]&-2049}i=Y?i:0}k=e&255;Da:{if(k>>>0<251){break Da}Eb(r+24|0,I,50);Ea:{if(!Cb(r+24|0)|!i){break Ea}if(x[f+480192>>1]){if(x[f+480192>>1]<i>>>0){break Ea}g=(f+(i<<2)|0)+900380|0;if(!v[g>>2]){break Ea}h=E+1075805|0;if(!be(w[h|0])){break Ea}g=x[dd(v[g>>2]+236|0,w[h|0]-1|0)>>1]}else{g=i}g=g&65535;if(!g|g>>>0>x[f+480190>>1]){break Ea}g=f+B(g,104)|0;if(u[g+484414>>1]<0){break Ea}v[E+1075672>>2]=x[g+484410>>1]}Eb(r+24|0,I,100);if(Ja=Cb(r+24|0),Ka=0,Ma=v[T>>2]&4,Ma?Ja:Ka){break Da}i=0}Fa:{if(!be(k)){break Fa}t[E+1075808|0]=e;t[E+1075805|0]=e;if(!j){uM(f,s&65535,i,k,0)}g=E+1075780|0;e=u[g>>1];if(e){v[E+1075676>>2]=(e&32767)-1;if((e|0)<=-1){e=E+1075072|0;v[e>>2]=v[e>>2]|256}u[g>>1]=0}e=E+1075801|0;g=w[e|0];if(g){t[E+1075842|0]=g-1;t[e|0]=0}e=E+1075802|0;g=w[e|0];if(!g){break Fa}t[E+1075841|0]=g-1;t[e|0]=0}Ga:{Ha:{Ia:{Ja:{Ka:{if(i){g=E+1075088|0;h=v[g>>2];dp(f,l,i,j,1,1);e=v[g>>2];La:{if(!e|!(w[e+35|0]&2)){break La}if(!sd(X)){break La}xy(v[X>>2],s&65535,v[g>>2]+68|0)}Ma:{Na:{if(v[f+480180>>2]==1){if(!j){break Na}Eb(r+24|0,I,85);if(!Cb(r+24|0)){break Na}break Ma}Eb(r+24|0,I,50);if(!Cb(r+24|0)){break Na}if(!be(k)){break Ma}}t[E+1075809|0]=0}Eb(r+24|0,I,42);if(Cb(r+24|0)){if(!be(k)|(h|0)==v[g>>2]){break Ja}break Ka}if(!(!(v[f+480180>>2]&16777248)|(h|0)==v[g>>2])){e=0;if(be(k)){break Ia}}Eb(r+24|0,I,107);Oa:{if(!Cb(r+24|0)|(h|0)==v[g>>2]){break Oa}if(!j){if(be(k)){break Oa}}e=E+1075060|0;if(y[e>>2]>=y[l+4>>2]){break Oa}v[e>>2]=0;break Ja}Eb(r+24|0,I,85);if(!Cb(r+24|0)){break Ja}if(!Kh(l)){break Ka}break Ja}if(!k){e=j;break Ga}g=0;H=E+1075809|0;Pa:{if(!w[H|0]){break Pa}if(!be(k)){break Pa}dp(f,l,w[H|0],j,!(v[E+1075088>>2]?1:v[E+1075640>>2]),!(v[f+480180>>2]&1048580));t[H|0]=0;g=1}e=j;break Ha}v[l>>2]=0;v[l+4>>2]=0}e=j}g=0;if(!k){break Ga}}h=E+1075088|0;j=v[h>>2];Qa:{if(!j|!(w[j+35|0]&2)){break Qa}if(!sd(X)){break Qa}if(!g){if(vM(v[X>>2],s&65535)){break Qa}}xy(v[X>>2],s&65535,v[h>>2]+68|0)}g=s&65535;As(f,l,k,e,!(v[f+480180>>2]&1048580),0,g);if(!(!e|(!(v[f+480180>>2]&1048580)|!i))){h=E+1075072|0;v[h>>2]=v[h>>2]|2097152;yl(l);t[E+1075822|0]=0;v[E+1075764>>2]=0}if(!(v[E+1075072>>2]&512)){break Ga}if(!sd(X)){break Ga}Ra:{switch(k-253|0){case 0:Eb(r+24|0,I,99);if(Cb(r+24|0)){break Ga}break;case 1:case 2:break Ra;default:break Ga}}tk(v[X>>2],g)}Sa:{Ta:{switch(p-1|0){case 0:J=J>>>0<64?J:64;v[E+1075672>>2]=J<<2;g=E+1075072|0;v[g>>2]=v[g>>2]|2097152;break Sa;case 1:break Ta;default:break Sa}}zl(f,l,J,6)}if(x[f+480192>>1]){_K(f,s&65535)}j=e}Eb(r+24|0,I,77);if(Ja=Cb(r+24|0),Ka=0,Ma=v[(f+(s<<5)|0)+480280>>2]&1024,Ma?Ja:Ka){break O}e=v[f+1074392>>2];Eb(r+24|0,I,75);Ua:{Va:{Wa:{h=e>>>0>=Q>>>0;Xa:{if(!Cb(r+24|0)|!Q){break Xa}g=v[f+1074392>>2];if(!g){break Wa}h=1;if((g|0)!=(Q|0)){break Xa}h=!w[ba|0]&(p|0)!=11}e=p;if(!h|e>>>0<3){break Wa}if((e|0)==11){hy(r+24|0,f,W,Q);e=w[hc(r+24|0)|0];bn(f,l,v[r+24>>2]);if(e){break Ua}i=11;break Va}Eb(r+24|0,I,62);Ya:{if(!(!Cb(r+24|0)|J)){J=0;i=0;Za:{switch(e-8|0){case 0:break Ya;case 1:break Za;default:break Va}}if(w[T+1|0]&16){break Va}v[E+1075676>>2]=0;break Va}Eb(r+24|0,I,41);if(Cb(r+24|0)){break Ya}if(J){t[E+1075838|0]=J;break Ya}J=w[E+1075838|0]}i=p;_a:{switch(e-3|0){case 0:case 1:$a:{ab:{if(J){break ab}Eb(r+24|0,I,41);if(!Cb(r+24|0)){break ab}J=w[E+1075838|0];if(J){break $a}J=0;break Wa}t[E+1075838|0]=J}en(f,l,((e|0)==3?J<<4:J)&255);break Wa;case 2:if((Q|0)!=v[f+1074392>>2]){Eb(r+24|0,I,41);i=5;if(Cb(r+24|0)){break Va}}Eb(r+24|0,I,41);bp(f,l,J,Cb(r+24|0));i=5;break Va;case 3:if((Q|0)!=v[f+1074392>>2]){Eb(r+24|0,I,41);i=6;if(Cb(r+24|0)){break Va}}Eb(r+24|0,I,41);ap(f,l,J,Cb(r+24|0));i=6;break Va;case 4:Eb(r+24|0,I,53);if(Cb(r+24|0)){t[E+1075827|0]=J&15;i=7;break Va}qk(l,J<<4);i=7;break Va;case 5:qk(l,J);i=8;break Va;case 6:Eb(r+24|0,I,62);cy(f,l,J,Cb(r+24|0)^1);i=9;break Va;case 7:Eb(r+24|0,I,62);cy(f,l,J<<4&240,Cb(r+24|0)^1);i=10;break Va;case 9:i=12;Eb(r+24|0,I,12);qM(f,s&65535,J<<2&252,Cb(r+24|0));break Va;case 10:Eb(r+24|0,I,12);pM(f,s&65535,J<<2&252,Cb(r+24|0));i=13;break Va;case 12:break _a;default:break Va}}i=15;if(!M){break Va}e=v[E+1075088>>2];if(!e|J>>>0>9){break Va}bb:{if(!J){k=v[E+1075648>>2];break bb}k=v[(e+(J<<2)|0)- -64>>2];v[E+1075648>>2]=k}cp(f,l,k);break Va}i=p}cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{switch(da-1|0){case 12:if(!(w[T+1|0]&16)){break Ua}e=f+B(s,896)|0;v[e+1075672>>2]=o>>>0<64?o<<2:256;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Ua;case 1:if(!(v[f+480180>>2]&1?o:1)){break Ab}qM(f,s&65535,o,0);break Ua;case 2:if(!(v[f+480180>>2]&1?o:1)){break Ab}pM(f,s&65535,o,0);break Ua;case 10:if(!(v[f+480180>>2]==1?o:1)){break Ab}en(f,l,o);break Ua;case 3:bn(f,l,o);break Ua;case 5:if(v[f+480180>>2]==1?o:1){en(f,l,o)}bn(f,l,0);break Ua;case 4:qk(l,o);break Ua;case 6:if(v[f+480180>>2]==1?o:1){en(f,l,o)}qk(l,0);break Ua;case 15:if(!(w[T+1|0]&16)){break Ua}break cb;case 16:Eb(r+24|0,I,5);if(Cb(r+24|0)){if(!(w[T+1|0]&16)){break Ua}if(o){break cb}break Ua}o=ep(f,x[f+1074436>>1],v[f+1074424>>2],s&65535,0);Cb:{if(!(v[f+480180>>2]&16777250)){break Cb}if(o){t[(f+B(s,896)|0)+1075839|0]=o;break Cb}o=w[(f+B(s,896)|0)+1075839|0]}v[r+24>>2]=B(o,1e4);Cc(r+24|0,B(v[v[f+8>>2]+24>>2],1e4));g=jb-16|0;jb=g;i=v[r+24>>2];v[g+8>>2]=i;e=f;h=v[e+8>>2];Db:{if(i>>>0>=(v[e+480180>>2]&16392?1e4:32e4)>>>0){i=v[e+480208>>2];Eb(g,e+1074312|0,92);if((Cb(g)|0)==((i&4096)>>>12|0)){break Db}v[g>>2]=B(v[h+24>>2],1e4);Ja=e+1074420|0,Ka=v[Lb(g+8|0,g)>>2],v[Ja>>2]=Ka;break Db}if(w[e+480209|0]&16){break Db}j=e+1074420|0;i=(i>>>0)/1e4|0;p=B(i&15,1e4);v[j>>2]=v[j>>2]+((i&240)==16?p:0-p|0);i=v[h+20>>2];h=v[h+24>>2];Eb(g,e+1074312|0,8);Yn(j,B(i,1e4),Cb(g)?255e4:B(h,1e4))}jb=g+16|0;break Ua;case 9:if(!M|(v[f+480180>>2]==4?j:0)){break Ua}t[r+24|0]=0;e=ep(f,x[f+1074436>>1],v[f+1074424>>2],s&65535,r+24|0);g=f;h=l;if(!w[r+24|0]){j=(f+B(s,896)|0)+1075648|0;i=e<<8;Eb:{if(i){v[j>>2]=i;break Eb}i=v[j>>2]}e=(w[(f+B(s,896)|0)+1075840|0]<<16)+i|0}cp(g,h,e);break Ua;case 40:if(!M){break Ua}g=Hma(v[(f+B(s,896)|0)+1075060>>2],0,o,0);e=mb;j=e>>>8|0;cp(f,l,hd((e&255)<<24|g>>>8,j));break Ua;case 0:if(v[f+1074392>>2]){break Ua}e=f+B(s,896)|0;Fb:{if(w[e+1075803|0]?v[e+1075684>>2]:0){break Fb}e=v[e+1075640>>2];if(e){if(zi(e)){break Fb}}Eb(r+24|0,I,13);if(Cb(r+24|0)){break Fb}if(v[f+480180>>2]&16777248){break Ua}}if(!o){o=0;if(v[f+480180>>2]&5){break Ua}t[(f+B(s,896)|0)+1075811|0]=1;break Ua}e=f+B(s,896)|0;t[e+1075812|0]=o;t[e+1075811|0]=1;break Ua;case 14:if(v[f+480180>>2]&1048580){o=o&240?o:x[(f+B(s,896)|0)+1075784>>1]&240|o;if(!(o&15)){o=x[(f+B(s,896)|0)+1075784>>1]&15|o}o=o|256}Eb(r+24|0,I,23);if(Cb(r+24|0)){Gb:{if(!o){k=x[(f+B(s,896)|0)+1075784>>1];break Gb}k=o&255;u[(f+B(s,896)|0)+1075784>>1]=k}by(f,s&65535,k<<16>>16,(i&255)==15?J+1|0:0);break Ua}Hb:{if(o){u[(f+B(s,896)|0)+1075784>>1]=o&255;break Hb}o=u[(f+B(s,896)|0)+1075784>>1]}by(f,s&65535,o,(i&255)==15?J+1|0:0);break Ua;case 39:break gb;case 38:break hb;case 34:case 35:case 36:case 37:break ib;case 13:break jb;case 11:break kb;case 29:break lb;case 26:break mb;case 21:break nb;case 20:break ob;case 27:break pb;case 24:break qb;case 19:break rb;case 18:break sb;case 25:break tb;case 7:break ub;case 28:break vb;case 8:break wb;case 23:break xb;case 22:break yb;case 17:break Bb;default:break Ua}}if(!(w[T+1|0]&16)){break Ua}Eb(r+24|0,I,22);Ib:{Jb:{if(Cb(r+24|0)){if(!o){o=0;break Jb}if(w[T|0]&4){break Jb}e=o&240?o-16|0:o;o=e-((e&15)!=0)|0;break Jb}Eb(r+24|0,I,71);if(!Cb(r+24|0)){break Ib}}e=(f+B(s,896)|0)+1075843|0;t[e|0]=w[e|0]|128}e=f+B(s,896)|0;t[e+1075811|0]=18;if(o){break zb}}o=0;break Ua}t[e+1075844|0]=o;break Ua}if(!(w[T+1|0]&16)){break Ua}o=o<<!(v[f+480180>>2]&59593760);if(o>>>0<=128){v[f+1074444>>2]=o<<1;break Ua}if(v[f+480180>>2]&16777250){break Ua}v[f+1074444>>2]=256;break Ua}Eb(r+24|0,I,9);if(Cb(r+24|0)){oM(f,o,(f+B(s,896)|0)+1075821|0);break Ua}oM(f,o,ga);break Ua}if(!(w[T+1|0]&16)){break Ua}zl(f,l,o,8);break Ua}cy(f,l,o,1);break Ua}HM(l,o);break Ua}IM(f,l,o);break Ua}g=o;h=g&15;e=f;i=s&65535;p=e+B(i,896)|0;j=p+1074984|0;Kb:{Lb:{switch(g>>>4|0){case 0:if(!x[e+480188>>1]){break Kb}g=(g&1)<<14;i=0;while(1){h=(e+B(i,896)|0)+1075072|0;v[h>>2]=(g|v[h>>2]&-16385)^16384;i=i+1|0;if(i>>>0<x[e+480188>>1]){continue}break};break Kb;case 1:if(!(v[e+480180>>2]&1048580?1:h)){break Kb}fM(e,j,h);break Kb;case 2:if(!(v[e+480180>>2]&1048580?1:h)){break Kb}dM(e,j,h);break Kb;case 3:e=p+1075072|0;v[e>>2]=v[e>>2]&-1048577|((h|0)!=0)<<20;break Kb;case 4:t[p+1075826|0]=g&7;break Kb;case 5:if(!(w[e+480209|0]&16)){break Kb}if(v[e+480180>>2]&69206025){g=e+B(i,896)|0;j=g+1075752|0;v[j>>2]=h<<28>>24;h=g+1075684|0;if(!v[h>>2]){break Kb}if(!Tf(g+1075794|0)){break Kb}g=e;e=e+B(i,896)|0;Ja=h,Ka=ag(g,w[e+1075803|0],v[j>>2],v[e+1075688>>2]),v[Ja>>2]=Ka;break Kb}p=v[e+480180>>2];j=Tf((e+B(i,896)|0)+1075794|0);if((p|0)==16){if(!j){break Kb}g=e+B(i,896)|0;j=v[g+1075088>>2];if(!j){break Kb}t[j+37|0]=h;v[g+1075752>>2]=h;g=g+1075684|0;if(!v[g>>2]){break Kb}j=e;e=e+B(i,896)|0;Ja=g,Ka=ag(j,w[e+1075803|0],h,v[e+1075688>>2]),v[Ja>>2]=Ka;break Kb}if(!j){break Kb}h=e+B(i,896)|0;g=g<<28>>24^-128;v[h+1075752>>2]=g;i=h+1075684|0;if(!v[i>>2]){break Kb}Ja=i,Ka=ag(e,w[h+1075803|0],g,v[h+1075688>>2]),v[Ja>>2]=Ka;break Kb;case 7:t[p+1075829|0]=g&7;break Kb;case 8:if(!(w[e+480209|0]&16)){break Kb}zl(e,j,h,4);break Kb;case 9:by(e,i,h,0);break Kb;case 10:if(!(v[e+480180>>2]&1048580?1:h)){break Kb}bp(e,j,h,0);break Kb;case 11:if(!(v[e+480180>>2]&1048580?1:h)){break Kb}ap(e,j,h,0);break Kb;case 12:dy(e,i,h,0);break Kb;case 15:break Lb;default:break Kb}}if(v[e+480180>>2]==1){t[(e+B(i,896)|0)+1075850|0]=h;if(!(w[e+480209|0]&16)){break Kb}rM(e,j);break Kb}t[(e+B(i,896)|0)+1075848|0]=h}break Ua}Eb(r+24|0,I,78);e=f;g=s&65535;if(!(!Cb(r+24|0)|o)){o=w[(f+B(s,896)|0)+1075812|0]}mM(e,g,o);break Ua}Eb(r+24|0,I,55);if(Cb(r+24|0)){if(v[f+1074392>>2]!=(o|0)){break Ua}e=v[(f+B(s,896)|0)+1075640>>2];if(t[e+60|0]&1?e:0){break db}if(!(!(w[ca|0]?1:w[ba|0])|o)){e=(f+B(s,896)|0)+1075072|0;v[e>>2]=v[e>>2]|4096;break db}e=f+B(s,896)|0;v[e+1075672>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break db}if(w[T+1|0]&16){break db}break Ua}e=(o&240)-16>>>4|0;if(e>>>0>9){break Ua}if(!(1<<e&880)){if(!e){break fb}if((e|0)!=1){break Ua}lM(f,l,o&15);break Ua}Eb(r+24|0,I,58);if(Cb(r+24|0)){break Ua}mM(f,s&65535,o);break Ua}if(!(w[T+1|0]&16)|o>>>0>64){break Ua}e=f+B(s,896)|0;v[e+1075744>>2]=o;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Ua}g=f;e=l;h=o;Mb:{if(h){t[e+836|0]=h;break Mb}h=w[e+836|0]}i=h&255;j=h&240;h=h&15;Nb:{Ob:{if(!(!j|(h|0)!=15)){if(!(w[g+480209|0]&16)){break Nb}h=i>>>4|0;break Ob}p=v[g+480208>>2]&4096;if(!(!h|(j|0)!=240)){if(!p){break Nb}h=0-h|0;break Ob}if(p){break Nb}if(h){h=0-h|0;if(!(v[g+480180>>2]&25690144)|!j){break Ob}break Nb}h=i>>>4|0;if(!h){break Nb}}Ja=e,Ka=Yb(v[e+760>>2]+h|0,0,64),v[Ja+760>>2]=Ka}break Ua}GM(l,o);break Ua}if(!(w[T+1|0]&16)){break Ua}e=f+B(s,896)|0;v[e+1075712>>2]=o;Eb(r+24|0,I,60);if(Ja=0,Ka=Cb(r+24|0),Ma=w[e+1075708|0]&4,Ma?Ja:Ka){break Ua}e=f+B(s,896)|0;v[e+1075736>>2]=o;v[e+1075724>>2]=o;break Ua}v[f+1074432>>2]=0;K=ep(f,x[f+1074436>>1],v[f+1074424>>2],s&65535,0);A=v[f+480180>>2]&5?(A|0)!=-1?0:A:A;break Ua}e=JM(f,_,s&65535,o);if((e|0)==-1){break Ua}if(!(w[T|0]&32)){break eb}K=x[f+1074438>>1];break eb}e=l;g=o;h=G&255;i=(h|0)==35|(h|0)==37;j=(G-37&255)>>>0<2;h=f;Pb:{if(w[f+480209|0]&16){if((g&255)>>>0>=16){t[e+869|0]=(g&240)>>>4}g=g&15;if(g){t[e+870|0]=g}t[e+868|0]=w[e+869|0];break Pb}g=w[e+868|0]-1|0;t[e+868|0]=g;Qb:{if(g&255){break Qb}t[e+868|0]=w[e+869|0];g=w[e+870|0];g=i?g:0-g|0;Rb:{if(uj(e)){v[e+876>>2]=v[e+876>>2]+B(g,v[v[v[e+656>>2]+44>>2]+36>>2]);break Rb}Ja=e,Ka=ag(h,us(h,v[e+700>>2],0,0)+g|0,8363,0),v[Ja+700>>2]=Ka}if(!j){break Qb}v[e>>2]=0;v[e+4>>2]=0}}break Ua}EM(r,l,o);break Ua}if(v[f+1074392>>2]|ea>>>0>2|o>>>0>31){break Ua}i=s;G=i;if((o&240)==16){G=x[f+480188>>1]-1|0;i=0}e=((ea|0)==1)<<26;while(1){g=i&65535;h=(f+(g<<5)|0)+480280|0;v[h>>2]=e|v[h>>2]&-67108865;g=(f+B(g,896)|0)+1075072|0;v[g>>2]=e|v[g>>2]&-67108865;i=i+1|0;if((i&65535)>>>0<=(G&65535)>>>0){continue}break}break Ua}kM(f,l,o&15);break Ua}A=e;break Ua}dn(f,l);break Ua}KM(f,_,o)}Eb(r+24|0,I,78);if(!(!Cb(r+24|0)|!o)){e=o&255;t[l+860|0]=e;t[l+832|0]=e;t[l+831|0]=e;t[l+829|0]=e;t[l+828|0]=e;u[l+800>>1]=e;t[l+846|0]=e>>>4;t[l+847|0]=e<<2&60}e=w[ba|0];if(!e){break O}t[E+1075810|0]=e}s=s+1|0;if(s>>>0<x[f+480188>>1]){continue}break}}Sb:{if(!(w[T+1|0]&16)){break Sb}Tb:{if(!((A|0)!=-1|(K&65535)!=65535)){if((n|0)==-1){break Sb}break Tb}Ub:{if((n|0)==-1){break Ub}Eb(r+24|0,I,68);if(Cb(r+24|0)){break Ub}Eb(r+16|0,I,103);if(Ja=Cb(r+16|0),Ka=0,Ma=(K&65535)!=65535,Ma?Ja:Ka){break Ub}Eb(r+8|0,I,49);if(!Cb(r+8|0)|(K&65535)==65535){break Tb}}K=(K&65535)==65535?x[f+1074438>>1]+1|0:K;v[f+480208>>2]=v[f+480208>>2]|524288;e=f+484360|0;if(oc(Vb(e))>>>0<=(K&65535)>>>0){K=x[Vb(e)+28>>1]}g=(A|0)==-1?0:A;Vb:{if(x[f+1074438>>1]==(K&65535)){break Vb}Eb(r+24|0,I,26);if(Cb(r+24|0)){break Vb}Eb(r+16|0,I,68);if(Cb(r+16|0)|v[f+480180>>2]==1|!x[f+480188>>1]){break Vb}e=0;while(1){t[(f+B(e,896)|0)+1075845|0]=0;e=e+1|0;if(e>>>0<x[f+480188>>1]){continue}break}}v[f+1074428>>2]=g;if(w[f+480208|0]&32){break Sb}u[f+1074440>>1]=K;break Sb}u[f+1074440>>1]=x[f+1074438>>1];v[f+1074428>>2]=n;Wb:{if(!v[f+1074396>>2]){break Wb}if(v[f+480180>>2]==32){Eb(r+24|0,I,103);if(Cb(r+24|0)){break Wb}}if(v[f+480180>>2]==2){break Wb}v[f+1074428>>2]=v[f+1074428>>2]+1}if(y[_b(f+484344|0,x[f+1074436>>1])+12>>2]<=n>>>0){v[f+1074428>>2]=0;u[f+1074440>>1]=x[f+1074440>>1]+1}i=x[f+1074438>>1];e=jb-16|0;jb=e;f=f+1304360|0;h=f+12|0;XN(e+8|0,h);ZM(e,h);Xb:{if(!Ts(e+8|0,e)|(n|0)==-1){break Xb}while(1){g=jb-16|0;jb=g;v[g+8>>2]=v[e+12>>2];o=v[YM(g+8|0)>>2];jb=g+16|0;o=v[o>>2];ry(f,i,o,0);g=e+8|0;j=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=j;YM(g+4|0);ZM(e,h);if(!Ts(e+8|0,e)){break Xb}if((o|0)!=(n|0)){continue}break}}jb=e+16|0}jb=r+32|0;e=1;break k}qj(h,1)}e=0}jb=R+16|0;Yb:{if(!e|!v[F+1074420>>2]){break Yb}e=tL(F,F+1074376|0);v[F+1074380>>2]=e;v[F+1074404>>2]=e;g=Fd(x[F+480188>>1],1,31);E=F+1074332|0;Zb:{if(w[E+37|0]){e=v[F+24628>>2];if((e|0)>=129){e=((B(e-128|0,g+4|0)|0)/16|0)+128|0}J=B(v[F+480228>>2],e)>>>6|0;break Zb}J=v[F+480228>>2]}J=w[E+37|0]?(J<<7>>>0)/w[(g>>>1|0)+20752|0]|0:J;u[F+480212>>1]=0;s=F+1304392|0;H=F+1074312|0;R=F+480210|0;K=F+480209|0;G=0;while(1){k=F+B(G,896)|0;A=k+1075072|0;_b:{if(!(v[A>>2]&4096)|(v[k+1075008>>2]|(v[k+1075004>>2]|v[k+1075680>>2]))){break _b}Eb(q+24|0,H,64);if(Cb(q+24|0)){break _b}v[k+1075060>>2]=0;e=k+1075076|0;v[e>>2]=0;v[e+4>>2]=0}g=x[F+480188>>1];$b:{ac:{e=v[A>>2];if(!(e&1024)){h=g>>>0>G>>>0;if(h|v[k+1075060>>2]){break ac}}if(g>>>0>G>>>0){hL(F,G&65535)}u[k+1075846>>1]=0;break $b}m=0;W=k+1075704|0;v[W>>2]=0;N=k+1075664|0;v[N>>2]=0;o=k+1074992|0;g=o;v[g>>2]=0;v[g+4>>2]=0;v[k+1075084>>2]=0;v[q+20>>2]=1065353216;u[q+18>>1]=0;r=k+1075684|0;m=v[r>>2]?v[k+1075060>>2]!=0:m;g=k+1074984|0;Q=k+1075640|0;I=v[Q>>2];bc:{cc:{dc:{ec:{if(!h){break ec}if(w[(F+(G<<5)|0)+480288|0]){break cc}if(!I){break ec}h=w[I+34|0]!=0|m;break dc}h=0-m|0}if(!(h&1)){break bc}}v[q+8>>2]=v[k+1075672>>2];v[q+4>>2]=v[k+1075748>>2];Eb(q+24|0,H,28);e=g;h=Cb(q+24|0)?q+4|0:q+8|0;f=jb-16|0;jb=f;i=F+1074312|0;Eb(f+8|0,i,28);fc:{if(Cb(f+8|0)){v[h>>2]=v[h>>2]+u[e+788>>1];ce(h,0,64);break fc}Eb(f+8|0,i,1);j=Cb(f+8|0);i=u[e+788>>1];if(j){v[h>>2]=i+v[h>>2];ce(h,0,256);break fc}v[e+688>>2]=i+v[e+688>>2];ce(e+688|0,0,256);v[h>>2]=v[e+688>>2];u[e+788>>1]=0}jb=f+16|0;h=jb-16|0;jb=h;f=F+1074312|0;Eb(h+8|0,f,28);gc:{hc:{if(!Cb(h+8|0)){Eb(h,f,1);if(!Cb(h)){break hc}}v[e+684>>2]=v[e+692>>2]+u[e+790>>1];ce(e+684|0,0,256);break gc}v[e+692>>2]=v[e+692>>2]+u[e+790>>1];ce(e+692|0,0,256);u[e+790>>1]=0;v[e+684>>2]=v[e+692>>2]}jb=h+16|0;l=jb-16|0;jb=l;f=g;e=F;ic:{if(!(w[f+90|0]&4)|(v[e+480208>>2]&2101248)==2101248){break ic}jc:{if(v[q+8>>2]<=0){Eb(l+8|0,e+1074312|0,21);if(!Cb(l+8|0)){break jc}}j=5;if(!(v[e+480180>>2]&5)){Eb(l+8|0,e+1074312|0,21);j=Cb(l+8|0)?5:6}h=Ix(e,w[f+845|0],w[f+840|0]);kc:{if((w[f+845|0]&3)!=1){break kc}Eb(l+8|0,e+1074312|0,89);if(!Cb(l+8|0)){break kc}h=w[f+839|0];n=w[f+840|0];i=n<<2&124;h=(!(w[f+90|0]&2)|w[e+480209|0]&16?h:w[f+843|0]+h|0)&32?i^127:i;h=n&32?0-h|0:h}i=q;if(v[e+480180>>2]!=131072){h=v[q+8>>2]+((B(w[f+847|0],h)|0)/(1<<j)|0)|0}else{j=64-h|0;h=v[q+8>>2];h=((B(w[f+847|0],B(j,h))|0)/-8192|0)+h|0}v[i+8>>2]=h}if(!(v[e+480180>>2]&16777248)|w[e+480208|0]&4?w[e+480209|0]&16:0){break ic}Eb(l+8|0,e+1074312|0,21);e=Cb(l+8|0);j=f;h=w[f+846|0];f=w[f+840|0];t[j+840|0]=(e?h<<2:f)+(e?f:h)}jb=l+16|0;i=G&65535;j=i;l=jb-16|0;jb=l;e=F;h=e+1074312|0;Eb(l+8|0,h,71);lc:{if(Cb(l+8|0)){f=(e+B(j,896)|0)+1075843|0;h=t[f|0];if((h|0)>-1){break lc}if(!(w[e+480209|0]&16|w[(e+B(j,896)|0)+1075811|0]!=18)){n=h&-33;t[f|0]=n;mc:{nc:{if((n|0)!=-64){h=h&223;if((h|0)!=128){break nc}h=w[(e+B(j,896)|0)+1075844|0]>>>4|-64;break mc}h=w[(e+B(j,896)|0)+1075844|0]&15|-128;break mc}h=h-1|0}t[f|0]=h;f=(e+B(j,896)|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}if((h&224)!=128){break lc}v[q+8>>2]=0;break lc}if(w[(e+B(j,896)|0)+1075811|0]!=18){break lc}Eb(l+8|0,h,22);oc:{if(Cb(l+8|0)){p=e+B(j,896)|0;f=p+1075843|0;n=w[f|0];h=n<<24>>24;if(!((h|0)>-1|!v[p+1075060>>2])){pc:{qc:{if((n|0)!=192){if((n|0)!=128){break qc}h=w[(e+B(j,896)|0)+1075844|0]>>>4|-64;break pc}h=w[(e+B(j,896)|0)+1075844|0]&15|-128;break pc}h=h-1|0}t[f|0]=h}if((h&192)!=128){break oc}v[q+8>>2]=0;break oc}h=w[(e+B(j,896)|0)+1075844|0];p=h>>>4|0;n=p+(h&15)|0;if(!(w[e+480208|0]&4?0:v[e+480180>>2]&16777248)){p=p+1|0;n=n+2|0}f=(e+B(j,896)|0)+1075843|0;h=w[f|0];if(!(v[e+480180>>2]&4)){h=(h&255)>>>0<n>>>0?h:0;if((h&255)>>>0>=p>>>0){v[q+8>>2]=0}t[f|0]=h+1;break oc}rc:{if(w[e+480209|0]&16){h=h&255?h-1|0:0;break rc}t[f|0]=h+1}if(((h&255)>>>0)%(n>>>0)>>>0<p>>>0){break oc}v[q+8>>2]=0}h=(e+B(j,896)|0)+1075072|0;v[h>>2]=v[h>>2]|2097152}h=e+B(j,896)|0;sc:{if(w[h+1075811|0]!=18){break sc}n=h+1075640|0;h=v[n>>2];if(!h|!w[h+34|0]|w[h+15|0]&2){break sc}h=e+B(j,896)|0;if(v[h+1075072>>2]&134218752){break sc}f=h+1075805|0;if(!be(w[f|0])){break sc}n=v[n>>2];h=v[(e+B(w[n+34|0],160)|0)+906140>>2];if(!h){break sc}p=nb[v[v[h>>2]+96>>2]](h,w[f|0],j)|0;M=v[q+8>>2];if(!(!p|M)){nb[v[v[h>>2]+88>>2]](h,n,w[f|0]+255|0,0,j);break sc}if(p|!M){break sc}nb[v[v[h>>2]+88>>2]](h,n,w[f|0],x[(e+B(j,896)|0)+1075672>>1],j)}jb=l+16|0;ce(q+8|0,0,256);e=v[q+8>>2]<<6;v[q+8>>2]=e;tc:{uc:{if(I){Eb(q+24|0,H,31);if(Cb(q+24|0)){ms(F,g)}f=jb-16|0;jb=f;h=F;e=g;vc:{if(!Hx(h,e,0)){break vc}j=v[e+656>>2];h=h+1074312|0;Eb(f+8|0,h,31);wc:{if(Cb(f+8|0)){l=v[e+728>>2];if(l){break wc}break vc}l=v[e+728>>2]}Eb(f+8|0,h,31);n=j+48|0;M=l-Cb(f+8|0)|0;l=qp(n,M,256,64);p=w[j+65|0];xc:{if((p|0)==255){break xc}e=v[e+732>>2];if((e|0)==-1){break xc}p=w[Pb(n,p)+2|0];j=x[Pb(n,w[j+65|0])>>1];Eb(f+8|0,h,94);h=p<<2;j=(j|0)==(M|0)?h:l;if(Cb(f+8|0)){l=e+(j-h<<1)|0;break xc}if(!p){l=0;break xc}l=(B(e,j)|0)/(h|0)|0}Ja=q,Ka=(B(v[q+8>>2],Yb(l,0,512))|0)/256|0,v[Ja+8>>2]=Ka}jb=f+16|0;gL(g,q+8|0);f=jb-16|0;jb=f;h=F;e=g;yc:{if(!Hx(h,e,1)){break yc}j=v[e+656>>2];h=h+1074312|0;Eb(f+8|0,h,31);zc:{if(Cb(f+8|0)){l=v[e+740>>2];if(l){break zc}break yc}l=v[e+740>>2]}Eb(f+8|0,h,31);h=e;j=qp(j+68|0,l-Cb(f+8|0)|0,64,64)-32|0;e=v[e+684>>2];Ja=h,Ka=Yb(((B(j,(e|0)>127?256-e|0:e)|0)/32|0)+e|0,0,256),v[Ja+684>>2]=Ka}jb=f+16|0;e=g;h=v[e+656>>2];f=t[h+26|0];Ac:{if(!f){break Ac}j=w[e+819|0];if(!j){break Ac}Ja=e,Ka=Yb(v[e+684>>2]+((B(f,j+(w[h+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ja+684>>2]=Ka}e=v[q+8>>2];break uc}if(!(w[A+1|0]&16)){break uc}v[k+1075680>>2]=0;v[q+8>>2]=0;break tc}if(!e){break tc}if(w[A+3|0]&8){v[N>>2]=0;break tc}e=v[q+8>>2];if(w[E+36|0]){h=B(v[q+4>>2],v[k+1075744>>2]);e=e<<8;Ja=N,Ka=Ac(Ima(Hma(h,h>>31,e,e>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;break tc}h=B(v[q+4>>2],v[k+1075744>>2]);e=B(e,v[F+1074444>>2]);Ja=N,Ka=Ac(Ima(Hma(h,h>>31,e,e>>31),mb,1048576,0),mb),v[Ja>>2]=Ka}v[W>>2]=v[q+8>>2];Bc:{if(v[F+480180>>2]==2|v[r>>2]>=v[F+480260>>2]){break Bc}if(Zo(F)){break Bc}v[r>>2]=v[F+480260>>2]}Eb(q+24|0,H,73);if(Cb(q+24|0)){Yb(v[r>>2],1,31999)}e=v[r>>2];v[q+12>>2]=e;Cc:{if((v[A>>2]&1572864)!=1572864){break Cc}if(w[R|0]&32){if(!Ds(k+1075794|0)|w[K|0]&16){break Cc}e=v[q+12>>2]}h=k+1075696|0;Dc:{if(v[h>>2]==(e|0)){e=v[k+1075700>>2];break Dc}v[h>>2]=e;f=e;e=k+1075752|0;h=k+1075688|0;e=ag(F,us(F,f,v[e>>2],v[h>>2]),v[e>>2],v[h>>2]);v[k+1075700>>2]=e}v[q+12>>2]=e}n=jb-16|0;jb=n;e=F;M=e+B(i,896)|0;h=v[M+1075640>>2];Ec:{if(!h){break Ec}f=w[h+34|0];if(!f|w[h+15|0]&2|(!v[(e+B(f,160)|0)+906140>>2]|v[(e+B(i,896)|0)+1075072>>2]&134218752)){break Ec}f=e+B(i,896)|0;X=f+1075797|0;T=w[X|0];l=0;j=f+1075805|0;if(be(w[j|0])){l=w[fc(h+108|0,w[j|0]-1|0)|0]}p=f+1075794|0;Fc:{Gc:{if((T|0)==1){j=0;Hc:{Ic:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:j=w[(e+B(i,896)|0)+1075812|0]>>>4|0;break Hc;case 1:break Ic;default:break Hc}}j=w[(e+B(i,896)|0)+1075812|0]&15}h=e+B(i,896)|0;t[h+1075807|0]=l;if(w[h+1075806|0]==(j+l|0)){break Fc}if(!(w[e+480209|0]&16)){break Gc}if(!Tf(p)){break Gc}break Fc}j=0;if(w[p|0]|!w[(e+B(i,896)|0)+1075806|0]){break Fc}}h=e+B(i,896)|0;xl(e,i,w[h+1075807|0]+j|0,x[h+1075672>>1])}f=(e+B(i,896)|0)+1075806|0;h=w[f|0];Jc:{if(!h){if(!(w[e+480209|0]&16)|(T|0)!=1){break Jc}if(Tf(p)){break Jc}h=l;if(!be(h)){break Jc}}xl(e,i,(h&255)+255|0,0)}t[f|0]=w[X|0]==1?w[(e+B(i,896)|0)+1075807|0]+j|0:0}Kc:{if(w[M+1075811|0]!=1){break Kc}if(uj(M+1074984|0)){l=0;Lc:{Mc:{Nc:{switch(y[e+1074392>>2]%3|0){case 1:l=w[(e+B(i,896)|0)+1075812|0]>>>4|0;break Mc;case 0:break Mc;case 2:break Nc;default:break Lc}}l=w[(e+B(i,896)|0)+1075812|0]&15}u[q+18>>1]=l}e=(e+B(i,896)|0)+1075856|0;t[e|0]=w[e|0]|12;break Kc}if(!(!(w[e+480209|0]&16)|v[e+480180>>2]!=1048576)){h=e+B(i,896)|0;f=ag(e,w[h+1075803|0],v[h+1075752>>2],v[h+1075688>>2]);v[q+12>>2]=f;v[h+1075684>>2]=f}l=e+1074312|0;Eb(n+8|0,l,13);if(Cb(n+8|0)){l=w[(e+B(i,896)|0)+1075812|0];if(!l){break Kc}i=65536;Oc:{switch(((y[e+1074392>>2]%(v[e+1074400>>2]+v[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:l=l<<4;case 0:i=v[((l&240)<<2)+25312>>2];break;default:break Oc}}j=Zo(e);e=v[q+12>>2];f=e;e=e>>31;h=q;if(j){e=Hma(f,e,i,i>>31)+32768|0;l=mb;e=Ima(e,e>>>0<32768?l+1|0:l,65536,0)}else{j=(i|0)/2|0;l=j;p=j>>31;j=e<<16|f>>>16;f=f<<16;e=f+l|0;l=j+p|0;e=Ima(e,e>>>0<f>>>0?l+1|0:l,i,i>>31)}f=mb;Ja=h,Ka=Ac(e,f),v[Ja+12>>2]=Ka;break Kc}Eb(n+8|0,l,51);if(Cb(n+8|0)){if(w[e+480209|0]&16){break Kc}Pc:{Qc:{h=v[e+1074416>>2];h=h-(y[e+1074392>>2]%(h>>>0)|0)|0;if((h|0)>16){break Qc}if((h|0)==16){break Kc}j=0;Rc:{switch((h|0)%3|0){case 0:break Kc;case 2:break Qc;case 1:break Rc;default:break Pc}}j=w[(e+B(i,896)|0)+1075812|0]>>>4|0;break Pc}j=w[(e+B(i,896)|0)+1075812|0]&15}h=e+B(i,896)|0;f=h+1075752|0;h=h+1075688|0;i=us(e,v[q+12>>2],v[f>>2],v[h>>2])+j|0;f=ag(e,i,v[f>>2],v[h>>2]);v[q+12>>2]=f;if(i>>>0<109){break Kc}v[n+8>>2]=f;Ja=n,Ka=ag(e,109,0,v[h>>2]),v[Ja+4>>2]=Ka;Ja=q,Ka=v[bd(n+8|0,n+4|0)>>2],v[Ja+12>>2]=Ka;break Kc}h=v[e+1074392>>2];if(v[e+480180>>2]!=1){j=w[(e+B(i,896)|0)+1075803|0]}else{f=e+B(i,896)|0;j=us(e,v[q+12>>2],v[f+1075752>>2],v[f+1075688>>2])}Sc:{Tc:{switch((((v[e+480180>>2]&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:j=(w[(e+B(i,896)|0)+1075812|0]>>>4|0)+j|0;break Sc;case 1:break Tc;default:break Sc}}j=(w[(e+B(i,896)|0)+1075812|0]&15)+j|0}if(!(v[e+480180>>2]&67633408|w[(e+B(i,896)|0)+1075803|0]!=(j&255))){Eb(n+8|0,l,82);if(!Cb(n+8|0)){break Kc}}f=q;Z=e;if(w[e+480210|0]&32){p=j&255;if((p|0)==85){v[q+12>>2]=2147483647;break Kc}j=p>>>0>85?j-37|0:j}h=e+B(i,896)|0;Ja=f,Ka=ag(Z,j&255,v[h+1075752>>2],v[h+1075688>>2]),v[Ja+12>>2]=Ka;if(v[e+480180>>2]&71827712){v[h+1075684>>2]=v[q+12>>2];break Kc}Eb(n+8|0,l,82);if(!Cb(n+8|0)){break Kc}t[(e+B(i,896)|0)+1075806|0]=j}jb=n+16|0;if(!(!(w[R|0]&33)|v[q+12>>2]==2147483647)){Uc:{if(v[F+480180>>2]==2){e=452;h=3424;break Uc}h=B(v[k+1075752>>2]>>>4&15,24)+21024|0;e=x[h+22>>1];e=e>>>0<904?452:e>>>1|0;h=x[h>>1]<<1}ce(q+12|0,e,h);ce(r,e,h)}fL(F,g);e=v[A>>2]}Vc:{if(!(e&256)|w[K|0]&64){break Vc}Eb(q+24|0,H,37);if(!Cb(q+24|0)){break Vc}v[k+1075668>>2]=128}h=G&65535;hL(F,h);Wc:{if(!m){break Wc}e=eL(F,g,q+12|0);if((e|0)<0|!(w[A+1|0]&2)){break Wc}if(!sd(s)){break Wc}lp(v[s>>2],h,e>>>2&255,1)}Xc:{if(w[k+1075796|0]!=8){break Xc}Yc:{Zc:{e=w[k+1075797|0];switch(e-5|0){case 1:break Xc;case 0:case 2:break Yc;default:break Zc}}if((e|0)!=26){break Xc}}if(v[F+480180>>2]==4){if(w[K|0]&16){break Xc}e=k+1075823|0;t[e|0]=w[e|0]+w[k+1075827|0];break Xc}if(!(v[F+480180>>2]&16777248)){break Xc}qk(g,w[k+1075798|0]);dL(F,h,q+12|0,q+20|0)}dL(F,h,q+12|0,q+20|0);if(m){v[q+8>>2]=0;f=F;m=q+12|0;M=jb-16|0;jb=M;e=g;p=v[e+104>>2];_c:{if(!p|!w[p+40|0]){break _c}Y=uj(e);n=Zo(f);Eb(M+8|0,f+1074312|0,21);l=n?26336:25312;j=n?25312:26336;if(!(Y|!Cb(M+8|0)|v[f+480180>>2]==1048576)){if(!w[p+41|0]){break _c}i=w[e+838|0];v[M+4>>2]=v[e+780>>2]+w[p+39|0];Ti(M+4|0,w[p+40|0]<<8);T=v[M+4>>2];v[e+780>>2]=T;X=(T|0)/256|0;v[M+4>>2]=X;t[e+838|0]=w[e+838|0]+w[p+41|0];$c:{ad:{switch(w[p+38|0]-1|0){case 3:e=aL(cn(f))+-64|0;X=v[M+4>>2];break $c;case 2:e=64-(i+1>>>1|0)|0;break $c;case 1:e=(i+1>>>1|0)+-64|0;break $c;case 0:e=(i>>>1^-1)&64;break $c;default:break ad}}e=t[i+21616|0]}Ti(m,8388607);i=v[m>>2]<<8;v[m>>2]=i;T=B(e,X);f=(T|0)/64|0;e=f>>31;p=e^e+f;e=p>>>2|0;f=m;bd:{if((T|0)<=-64){e=v[(e<<2)+l>>2];j=Ac(Ima(Hma(e,e>>31,i,i>>31),mb,65536,0),mb);e=v[m>>2];j=j-e|0;i=j;l=p&3;if(!l){break bd}i=v[(l<<2)+(n?25248:25184)>>2];j=Ac(Ima(Hma(i,i>>31,e,e>>31),mb,65536,0),mb)+j|0;e=v[m>>2];i=j-e|0;break bd}e=v[j+(e<<2)>>2];j=Ac(Ima(Hma(e,e>>31,i,i>>31),mb,65536,0),mb);e=v[m>>2];j=j-e|0;i=j;l=p&3;if(!l){break bd}i=v[(l<<2)+(n?25184:25248)>>2];j=Ac(Ima(Hma(i,i>>31,e,e>>31),mb,65536,0),mb)+j|0;e=v[m>>2];i=j-e|0}v[f>>2]=(e+i|0)/256;v[q+8>>2]=i&255;break _c}cd:{if(!(w[p+39|0]|v[f+480180>>2]&16777248)){v[e+780>>2]=w[p+40|0]<<8;break cd}dd:{ed:{if(v[f+480180>>2]&16777248){X=w[p+39|0]<<1;n=v[e+780>>2];i=e+780|0;break ed}if(w[e+89|0]&8){break dd}n=((w[p+40|0]<<8&65280)>>>0)/w[p+39|0]|0;X=v[e+780>>2];i=e+780|0}v[i>>2]=n+X}Ti(e+780|0,w[p+40|0]<<8)}i=w[e+838|0]+w[p+41|0]|0;t[e+838|0]=i;i=i<<24>>24;fd:{gd:{switch(w[p+38|0]-1|0){case 3:t[e+838|0]=i+1;n=t[(i&63)+21552|0];break fd;case 2:n=(64-(i>>>1|0)&127)+-64|0;break fd;case 1:n=((i>>>1|0)- -64&127)+-64|0;break fd;case 0:n=(i|0)>-1?-64:64;break fd;default:break gd}}i=w[e+838|0];n=0-t[i+21616|0]|0;if(v[f+480180>>2]!=1048576){break fd}n=(64-t[(i+-64&255)+21616|0]|0)/2<<16>>16}i=n;T=B(i,v[e+780>>2]);n=(T|0)/256|0;if(Y){z[q+20>>2]=C(C(C(i|0)*C(1220703143189894e-20))*C(w[p+40|0]))+z[q+20>>2];t[e+872|0]=w[e+872|0]|8;break _c}if(v[f+480180>>2]!=4){hd:{if((T|0)<=-256){n=0-n|0;e=0-T>>>16|0;f=(e<<2)+l|0;break hd}l=j;e=(T|0)/65536|0;f=j+(e<<2)|0}i=v[m>>2];j=v[((e<<2)+l|0)+4>>2];e=v[f>>2];e=((B(j-e|0,(n|0)/4&63)|0)/64|0)+e|0;e=Ac(Ima(Hma(i,i>>31,e,e>>31),mb,256,0),mb);v[m>>2]=e;v[q+8>>2]=e&255;v[m>>2]=v[m>>2]/256;break _c}v[m>>2]=v[m>>2]+((T|0)/16384|0)}jb=M+16|0;if(v[q+12>>2]<=v[F+480260>>2]){Eb(q+24|0,H,81);if(Cb(q+24|0)){v[k+1075060>>2]=0}v[q+12>>2]=v[F+480260>>2]}m=uj(g);id:{if(!m){break id}e=k+1075856|0;f=w[e|0];if(!(v[F+1074392>>2]|!(f&4)?f&8:1)){break id}pO(g,z[q+20>>2],u[q+18>>1],F);f=e;e=w[e|0];t[f|0]=(e&8?-9:-5)&e}jd:{if((v[A>>2]&134219264)!=512){break jd}if(!sd(s)){break jd}Eb(q+24|0,H,99);if(Ja=Cb(q+24|0)|!(w[A+1|0]&16),Ka=1,Ma=v[F+480180>>2]!=2,Ma?Ja:Ka){if(!(w[A+1|0]&8?v[F+480180>>2]==2:0)){if(m){e=v[r>>2]}else{e=_L(F,v[q+12>>2],v[k+1075688>>2],v[q+8>>2])}e=Hma(e,0,261625,0)+66904|0;j=mb;e=hd(Kma(e,e>>>0<66904?j+1|0:j,133808,0),mb);e=Hma(v[F+480240>>2],0,e,0)+32768|0;j=mb;j=e>>>0<32768?j+1|0:j;i=hd((j&65535)<<16|e>>>16,j>>>16|0);m=v[A>>2];e=1;kd:{if(m&2048){break kd}e=0;if(!(m&4096)){break kd}e=!v[k+1075680>>2]}j=v[s>>2];Eb(q+24|0,H,95);m=e;r=Cb(q+24|0);p=jb-16|0;jb=p;f=h;M=uk(j,f);ld:{if((M|0)==255){break ld}if(rj(j)){break ld}md:{if(i>>>0>6208431){n=7;e=1023;break md}n=7;nd:{if(i>>>0>3104215){break nd}n=6;if(i>>>0>1552107){break nd}n=5;if(i>>>0>776053){break nd}n=4;if(i>>>0>388026){break nd}n=3;if(i>>>0>194013){break nd}n=2;if(i>>>0>97006){break nd}n=i>>>0>48503}e=Hma(1<<20-n,0,i,0)+24858e3|0;l=mb;e=hd(Kma(e,e>>>0<24858e3?l+1|0:l,49716e3,0),mb)}if(r){u[p+14>>1]=(f&3)+e;u[p+12>>1]=1023;e=x[lf(p+14|0,p+12|0)>>1]}f=Ms(M);i=j+4|0;Ja=fc(i,M),Ka=(n<<10|e)>>>8|(m?0:32),t[Ja|0]=Ka;hh(v[j>>2],f|160,e&255);hh(v[j>>2],f|176,w[fc(i,M)|0]);t[j+530|0]=1}jb=p+16|0}f=v[s>>2];e=Hma(B(v[k+1075748>>2],B(v[k+1075744>>2],v[W>>2])),0,63,0)+33554432|0;j=mb;j=e>>>0<33554432?j+1|0:j;lp(f,h,hd((j&67108863)<<6|e>>>26,j>>>26|0)&255,0);e=k+1075668|0;i=e;m=v[e>>2];l=0;e=v[s>>2];f=uk(e,h);od:{if((f|0)==255){break od}if(rj(e)){break od}j=w[fc(Ii(e+314|0,f),10)|0];n=v[e>>2];e=j&-49;e=(m|0)<171?e|16:e;e=((m|0)>84?e|32:e)&255;hh(n,Ms(f)|192,e);l=(e>>>5&1)+(e<<27>>31)|0}v[i>>2]=(l<<7)+128}pd:{e=v[Q>>2];if(!e|(w[e+60|0]&7)!=1){break pd}e=e+48|0;if(md(e)){break pd}if(y[cL(g,0)+4>>2]<x[pj(e)>>1]){break pd}if(w[pj(e)+2|0]){break pd}yi(v[s>>2],h,1);Eb(q+24|0,H,109);e=Cb(q+24|0);m=v[A>>2];if(!e){m=m&-513;v[A>>2]=m}v[A>>2]=m|4096;v[k+1075680>>2]=0;break jd}Eb(q+24|0,H,99);if(!Cb(q+24|0)|!(w[A+1|0]&16)|v[k+1075680>>2]){break jd}yi(v[s>>2],h,1);v[A>>2]=v[A>>2]&-513}m=Hma(Jx(F,g,v[q+12>>2],v[q+8>>2]),mb,v[F+480240>>2],0);j=mb;h=Ima(m,j,65536,0);f=mb;e=o;m=m+65535|0;j=m>>>0<65535?j+1|0:j;m=!j&m>>>0<131071;v[e>>2]=m?1:h;v[e+4>>2]=m?0:f}qd:{if(!I){break qd}Eb(q+24|0,H,31);if(Cb(q+24|0)){break qd}ms(F,g)}m=v[A>>2];e=m&-65537;l=k+1075004|0;n=k+1075008|0;v[A>>2]=v[l>>2]|(v[n>>2]|v[N>>2])?(e|m<<7&65536)^65536:e;h=k+1075656|0;v[h>>2]=0;v[h+4>>2]=0;f=k+1075846|0;m=w[f|0];e=m-4|0;t[f|0]=e>>>0>m>>>0?0:e;i=k+1075847|0;m=w[i|0];e=m-4|0;t[i|0]=e>>>0>m>>>0?0:e;rd:{sd:{td:{ud:{vd:{wd:{e=k+1075088|0;m=v[e>>2];xd:{if(!m){break xd}if(!De(m)|!v[k+1075060>>2]){break xd}if(Kh(g)){break wd}}j=k+1075e3|0;v[j>>2]=0;break vd}j=k+1075e3|0;e=v[v[e>>2]+20>>2];v[j>>2]=e;if(e){break ud}}if(!oj(g)|w[A+1|0]&24){break td}}M=v[N>>2];p=v[k+1075668>>2];e=(B(M,256-p|0)|0)/16384|0;m=e>>>0<127?e:127;e=t[f|0];if((e|0)<=-1){t[f|0]=m;Z=m}else{Z=e}e=m>>>1|0;if((Z&255)>>>0<e>>>0){t[f|0]=e}e=(B(p,M)|0)/16384|0;e=e>>>0<127?e:127;m=t[i|0];if((m|0)<=-1){t[i|0]=e;m=e}e=e>>>1|0;if(e>>>0>(m&255)>>>0){break sd}break rd}if(w[f|0]>=129){t[f|0]=0}e=0;if(w[i|0]<129){break rd}}t[i|0]=e}yd:{zd:{if(v[j>>2]){e=k+1075660|0;Ad:{if(y[F+24624>>2]>=2){v[q+24>>2]=v[k+1075668>>2];ce(q+24|0,0,256);i=B(v[N>>2],J)>>>(w[E+37|0]?7:8)|0;m=e;Bd:{Cd:{Dd:{switch(v[E+32>>2]){case 0:if(!(w[F+24616|0]&16)){break Cd}case 1:f=v[q+24>>2];if((f|0)<=127){v[h>>2]=i>>>1;f=(B(f,i)|0)/256|0;break Bd}v[h>>2]=(B(i,256-f|0)|0)/256;f=i>>>1|0;break Bd;case 3:break Dd;default:break Cd}}Ti(q+24|0,255);f=h;j=v[q+24>>2];if((j|0)<=0){n=i<<16}else{n=B(i,x[(0-j<<1)+27872>>1])}v[f>>2]=n>>>16;f=B(i,x[(j<<1)+27360>>1])>>>16|0;break Bd}f=v[q+24>>2];v[h>>2]=(B(i,256-f|0)|0)/256;f=(B(f,i)|0)/256|0}v[m>>2]=f;break Ad}m=B(v[N>>2],J)>>>8|0;v[h>>2]=m;v[e>>2]=m}f=k+1075800|0;j=f;Ed:{Fd:{m=v[Q>>2];if(!m){break Fd}if(!Sn(w[m+14|0])){break Fd}m=w[v[Q>>2]+14|0];break Ed}if(Sn(w[F+480268|0])){m=w[F+480268|0];break Ed}if(w[R|0]&128){m=255;if(v[F+24668>>2]){break Ed}}m=w[F+24648|0]}t[j|0]=m;if(!(w[A+2|0]&2|(v[o>>2]!=0|v[o+4>>2]!=1)|(v[k+1075764>>2]|(m&255)==255))){t[f|0]=0}m=1<<v[E+28>>2];v[h>>2]=v[h>>2]/(m|0);m=v[e>>2]/(m|0)|0;v[e>>2]=m;h=v[A>>2];if(!(!(h&256)|v[F+24624>>2]!=2)){v[e>>2]=0-m}if(h&128){e=v[o>>2];m=0-(v[o+4>>2]+((e|0)!=0)|0)|0;v[o>>2]=0-e;v[o+4>>2]=m}o=F;f=jb-16|0;jb=f;m=g;v[g+28>>2]=0;v[g+32>>2]=0;l=g;Gd:{Hd:{h=v[g+88>>2];if(!(h&65536)){g=v[m+676>>2];e=v[m+672>>2];break Hd}e=v[m+20>>2];n=v[m+672>>2];Id:{if((e|0)!=(n|0)){g=v[m+24>>2];i=v[m+676>>2];break Id}g=v[m+24>>2];i=v[m+676>>2];if((g|0)==(i|0)){break Hd}}j=o+24604|0;h=f;g=(g|0)<(i|0)|(e|0)<(n|0);Jd:{if(g){e=tO(j);break Jd}e=sO(j)}v[h+12>>2]=e;Eb(f,o+1074312|0,4);if(!(!Cb(f)|!(v[o+480180>>2]&4))){e=v[o+24620>>2];e=Hma(e,e>>31,5,0)+500|0;j=mb;e=Ac(Ima(e,e>>>0<500?j+1|0:j,1e3,0),mb);v[f+12>>2]=e}h=v[m+656>>2];Kd:{if(!(!h|!g)){g=e;h=x[h+12>>1];if(h){g=(B(h,v[o+24620>>2])>>>0)/1e5|0}j=(h|0)!=0;break Kd}g=v[f+12>>2];j=0}p=g?g:1;h=v[m+676>>2];g=v[m+24>>2];n=h-g<<12;i=v[m+672>>2];M=v[m+20>>2];N=i-M<<12;if(!(w[m+90|0]&32|(!(h|i)|(j|!(g|M))))){v[f+12>>2]=v[o+1074380>>2];ce(f+12|0,e,2048);i=v[m+672>>2];p=v[f+12>>2];h=v[m+676>>2]}o=(n|0)/(p|0)|0;v[m+32>>2]=o;j=(N|0)/(p|0)|0;v[m+28>>2]=j;g=((B(o,p)|0)/-4096|0)+h|0;v[m+24>>2]=g;e=((B(j,p)|0)/-4096|0)+i|0;v[m+20>>2]=e;if(j|o){v[m+100>>2]=p;h=v[m+88>>2];break Gd}v[m+24>>2]=h;v[m+20>>2]=i;g=h;e=i;h=v[m+88>>2]&-65537;break Gd}v[m+24>>2]=g;v[m+20>>2]=e;h=h&-65537}v[l+88>>2]=h&-2097153;v[m+40>>2]=g<<12;v[m+36>>2]=e<<12;jb=f+16|0;if(!(w[A+1|0]&2)){break zd}break yd}v[l>>2]=0;v[n>>2]=0;v[k+1075060>>2]=0;if(v[k+1075080>>2]){break zd}if(!v[k+1075076>>2]){break yd}}e=x[F+480212>>1];u[F+480212>>1]=e+1;u[(F+(e<<1)|0)+1074466>>1]=G}v[k+1075652>>2]=v[A>>2]}G=G+1|0;if((G|0)!=256){continue}break}m=1;if(y[F+24608>>2]>x[F+480212>>1]){break Yb}e=F+1074466|0;g=e;l=e+(v[F+24608>>2]<<1)|0;o=e+(x[F+480212>>1]<<1)|0;h=jb-16|0;jb=h;v[h+8>>2]=F;i=h+8|0;j=i;f=l-e|0;if((f|0)>=3){n=f>>1;f=(n-2|0)/2|0;while(1){Fx(e,j,n,e+(f<<1)|0);p=(f|0)>0;f=f-1|0;if(p){continue}break}}if((l|0)!=(o|0)){f=l-g>>1;e=l;while(1){if(Ro(i,x[e>>1],x[g>>1])){YK(e,g);Fx(g,i,f,g)}e=e+2|0;if((o|0)!=(e|0)){continue}break}}e=l-g|0;if((e|0)>=3){e=e>>>1|0;while(1){YK(g,l-2|0);Fx(g,i,e-1|0,g);l=l-2|0;f=(e|0)>2;e=e-1|0;if(f){continue}break}}jb=h+16|0}jb=q+32|0;if(m){e=v[a+480208>>2];break i}g=v[a+480208>>2]|512;if(w[a+1304512|0]){break j}e=0;g=v[a+24620>>2];m=Ac(Ima(Hma(g,g>>31,100,0),mb,1e3,0),mb);Ld:{if(!m){break Ld}h=m>>>0<1048576?m:1048576;v[F+1074380>>2]=h;i=x[F+480212>>1];if(!i){break Ld}f=F+1074376|0;while(1){g=f+B(x[(f+(e<<1)|0)+90>>1],896)|0;o=g+1280|0;v[o>>2]=0;v[o+4>>2]=0;v[g+708>>2]=h;o=v[g+632>>2]<<12;v[g+648>>2]=o;F=v[g+628>>2]<<12;v[g+644>>2]=F;v[g+696>>2]=v[g+696>>2]|65536;v[g+636>>2]=(0-F|0)/(h|0);v[g+640>>2]=(0-o|0)/(h|0);e=e+1|0;if((i|0)!=(e|0)){continue}break}}e=v[a+480208>>2];g=e|256;if(m){break j}g=e|512}e=g;v[V+480208>>2]=e}if(e&512){Ja=a+1074392|0,Ka=vl(a),v[Ja>>2]=Ka;break h}v[aa+16>>2]=512;e=v[a+1074380>>2];v[aa+12>>2]=3;v[aa+24>>2]=b;v[aa+20>>2]=e;v[aa+8>>2]=aa+16;e=v[aa+12>>2];v[aa>>2]=v[aa+8>>2];v[aa+4>>2]=e;F=RS(aa);if(v[a+24632>>2]){e=a;g=d;m=0;f=jb-16|0;jb=f;h=F;i=h<<2;while(1){v[f>>2]=0;o=(e+(m<<11)|0)+16396|0;lK(o,i+o|0,f);m=m+1|0;if((m|0)!=4){continue}break}m=0;while(1){v[f+(m<<2)>>2]=(e+(m<<11)|0)+16396;m=m+1|0;if((m|0)!=4){continue}break}nb[v[v[g>>2]+8>>2]](g,f,v[e+24632>>2],h);jb=f+16|0}p=a;ja=0;f=jb-112|0;jb=f;m=F;if(m){H=p+12|0;s=p+24592|0;J=p+24588|0;sn(H,m,s,J);if(y[p+24624>>2]>=3){sn(p+8204|0,m,p+24600|0,p+24596|0)}u[f+30>>1]=0;ma=p+1074312|0;Eb(f+8|0,ma,33);e=Cb(f+8|0);k=x[p+480212>>1];if(k){Aa=e?2:1;Ba=p+24648|0;M=p+24596|0;N=p+24600|0;V=p+8204|0;r=p+397460|0;E=p+397456|0;I=p+393352|0;pa=p+1074376|0;while(1){j=pa+(ja<<1)|0;e=B(x[j+90>>1],896);i=e+pa|0;Y=i;Md:{Nd:{if(v[i+624>>2]){break Nd}g=e+p|0;if(v[g+1075080>>2]){break Nd}if(!v[g+1075076>>2]){break Md}}k=e+p|0;e=w[k+1075800|0]+1|0;Od:{if((e&255)>>>0<=5){q=v[(e<<24>>24<<2)+18440>>2];break Od}q=0}R=k+1075072|0;n=v[R>>2];A=n&1;Pd:{if(!(!(n&16777216)&w[p+24612|0]>>>5)){g=H;o=s;h=n;e=J;if(!(h&8388608)){break Pd}}g=m;e=I;if(!v[e+4116>>2]){sn(e+8|0,g,e+4104|0,e+4108|0)}v[e+4116>>2]=1;g=e+8|0;h=v[R>>2];o=E;e=r}if(!(!(h&256)|y[p+24624>>2]<3)){g=V;o=N;e=M}i=i+608|0;ea=wl(p,x[j+90>>1],2,1);Qd:{if((!ea|0)==(ea>>>0<251|0)){break Qd}j=v[(p+B(ea,160)|0)+906140>>2];if(!j){break Qd}h=v[j+24>>2];if(!h){break Qd}e=j+36|0;o=j+40|0;if(!(t[j+28|0]&1)){sn(h,m,o,e);v[j+28>>2]=v[j+28>>2]|1}g=h}X=0;h=f+8|0;v[h>>2]=0;v[h+4>>2]=0;v[h+8>>2]=0;v[h+12>>2]=0;j=i;if(v[i+16>>2]){mC(h,j);l=v[j+12>>2];Q=l>>31;G=Q+v[j+8>>2]|0;j=l>>31;l=j+l|0;l=G>>>0<Q>>>0?l+1|0:l;j=j^l;v[h+12>>2]=j>>>0>8191?2:16384/(j+1>>>0)|0}G=n>>>12&8|(n>>>5&2|(q|A));qa=k+1075809|0;Ca=k+1075792|0;Da=k+1075680|0;Ea=k+1075016|0;Fa=k+1075012|0;Ga=k+1075660|0;Ha=k+1075656|0;W=k+1074992|0;ba=k+1075080|0;ca=k+1075076|0;ra=k+1075008|0;sa=k+1075004|0;ha=k+1075088|0;ga=k+1075068|0;Q=k+1075060|0;ka=k+1075064|0;da=k+1075084|0;T=h;h=m;while(1){Rd:{j=v[da>>2];l=j?h>>>0>j>>>0?j:h:h;v[f+68>>2]=l;_=v[ka>>2];K=v[R>>2];k=v[W+4>>2];j=v[W>>2];v[f+56>>2]=j;v[f+60>>2]=k;Sd:{Td:{if(!l|!(j|k)){break Td}A=v[Q>>2];if(!A){break Td}l=v[f+8>>2];if(!l){break Td}v[Y+624>>2]=l;Z=v[i+4>>2];n=Z;l=v[i>>2];q=_&K<<30>>31;Ud:{if((q|0)>(n|0)){if((k|0)<-1?1:(k|0)<=-1){v[f+104>>2]=0;j=q;v[f+108>>2]=j<<1;l=ig(f+104|0,i);k=mb;n=k;v[i>>2]=l;v[i+4>>2]=k;if(!(k>>>0<j+v[Q>>2]>>>1>>>0?(j|0)<=(k|0):0)){l=0;v[i>>2]=l;n=j;v[i+4>>2]=j}K=v[f+60>>2];_=v[f+56>>2];k=_;j=0-(K+((k|0)!=0)|0)|0;k=0-k|0;v[f+56>>2]=k;v[f+60>>2]=j;v[W>>2]=k;v[W+4>>2]=j;j=v[R>>2];Vd:{if(j&4){k=j&-129;v[R>>2]=k;break Vd}k=j|128;v[R>>2]=k;j=v[Q>>2]-1|0;n=j;v[i>>2]=l;v[i+4>>2]=j;v[W>>2]=_;v[W+4>>2]=K}Wd:{if(!(k&2)){k=v[Q>>2];break Wd}k=v[Q>>2];if(n>>>0<k>>>0){break Ud}}v[i>>2]=0;v[i+4>>2]=k;break Td}if((n|0)>-1){break Ud}j=0;n=j;v[i>>2]=l;v[i+4>>2]=j;break Ud}if(A>>>0>Z>>>0){break Ud}if(!(K&2)){break Td}if(K&4){if((k|0)>0?1:(k|0)>=0?j>>>0>=1:0){n=0-(((j|0)!=0)+k|0)|0;j=0-j|0;v[f+56>>2]=j;v[f+60>>2]=n;v[W>>2]=j;v[W+4>>2]=n}v[R>>2]=K|128;j=1-((l|0)!=0)|0;l=0-l|0;K=(A<<1)-(j+Z|0)|0;j=K;n=j;v[i>>2]=l;v[i+4>>2]=j;if(A>>>0>j>>>0?j>>>0>_>>>0:0){break Ud}v[f+104>>2]=Aa;j=A-v[Lb(Q,f+104|0)>>2]|0;l=v[i>>2];n=j;v[i>>2]=l;v[i+4>>2]=j;break Ud}if((k|0)<-1?1:(k|0)<=-1){l=0-(((j|0)!=0)+k|0)|0;j=0-j|0;v[f+56>>2]=j;v[f+60>>2]=l;v[W>>2]=j;v[W+4>>2]=l}v[f+104>>2]=0;v[f+108>>2]=q-A;Sb(i,f+104|0);v[R>>2]=v[R>>2]|8192;l=v[i>>2];n=v[i+4>>2]}v[f+48>>2]=l;j=n;v[f+52>>2]=j;Xd:{Yd:{if((j|0)<(q|0)){k=0;if((n|0)<0|v[f+60>>2]<0){break Xd}break Yd}if((n|0)>0?1:(n|0)>=0){break Yd}k=0;break Xd}k=0;if(j>>>0>=y[Q>>2]){break Xd}ta=v[f+68>>2];v[f+44>>2]=ta;j=v[f+56>>2];n=v[f+60>>2];Cc(f+68|0,v[f+20>>2]);Ja=f,Ka=Fu(f+56|0,v[f+68>>2]-1|0),v[Ja+32>>2]=Ka;v[f+36>>2]=mb;_=n>>31;A=_;j=A+j|0;k=n;n=k>>31;l=k+n|0;Ia=j;k=j>>>0<A>>>0?l+1|0:l;A=v[f+48>>2];l=A+v[f+32>>2]|0;j=v[f+36>>2]+v[f+52>>2]|0;j=l>>>0<A>>>0?j+1|0:j;l=v[ka>>2];la=l+16|0;Z=v[f+52>>2];A=Z;K=v[f+48>>2];ua=A>>>0<l>>>0;if(A>>>0<la>>>0?ua:1){v[R>>2]=v[R>>2]&-8193}_=_^Ia;k=k^n;n=j;Zd:{_d:{$d:{if(!v[f+12>>2]){Z=v[f+60>>2];break $d}j=v[f+16>>2];if(j>>>0<=Z>>>0){n=f;l=v[f+60>>2];ae:{if((l|0)<-1?1:(l|0)<=-1){v[f+96>>2]=K;v[f+100>>2]=A;v[f+104>>2]=0;v[f+108>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;j=_l(f+88|0,_,k);break ae}j=v[ga>>2];v[f+104>>2]=K;v[f+108>>2]=A;v[f+96>>2]=0;v[f+100>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;j=_l(f+88|0,_,k)}v[n+44>>2]=j+1;v[Y+624>>2]=v[f+12>>2];break Zd}if(!(!(w[R+1|0]&32)|ua|Z>>>0>=la>>>0)){v[f+104>>2]=K;v[f+108>>2]=A;v[f+96>>2]=0;v[f+100>>2]=q+16;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=_l(f+88|0,_,k)+1|0,v[Ja+44>>2]=Ka;Ja=Y,Ka=v[f+12>>2]+B(v[ga>>2]-q|0,Zn(v[ha>>2]))|0,v[Ja+624>>2]=Ka;break Zd}la=v[f+60>>2];Z=la;if((Z|0)<0?1:(Z|0)<=0?y[f+56>>2]<1:0){break $d}if(ta>>>0<2|j>>>0>n>>>0){break _d}v[f+104>>2]=K;v[f+108>>2]=A;v[f+96>>2]=0;v[f+100>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=_l(f+88|0,_,k)+1|0,v[Ja+44>>2]=Ka;break Zd}if((Z|0)>-1){break _d}if((n|0)>=(q|0)){break Zd}v[f+96>>2]=K;v[f+100>>2]=A;v[f+104>>2]=0;v[f+108>>2]=l;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=_l(f+88|0,_,k)+1|0,v[Ja+44>>2]=Ka;break Zd}j=v[Q>>2];if((j|0)>(n|0)){break Zd}v[f+104>>2]=K;v[f+108>>2]=A;v[f+96>>2]=0;v[f+100>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=_l(f+88|0,_,k)+1|0,v[Ja+44>>2]=Ka}Yn(f+44|0,1,v[f+68>>2]);k=v[f+44>>2]}if((k|0)>0){break Sd}}v[Y+624>>2]=0;v[Q>>2]=0;v[i>>2]=0;v[i+4>>2]=0;v[da>>2]=0;K=0;j=i;l=v[i+96>>2];k=v[i+92>>2];if(l|k){if(h){while(1){i=K<<3;n=i+g|0;k=k-(((-2147483648-k>>>31|0)-1&255)+k>>8)|0;v[n>>2]=k+v[n>>2];i=(i|4)+g|0;l=l-(((-2147483648-l>>>31|0)-1&255)+l>>8)|0;v[i>>2]=l+v[i>>2];K=K+1|0;if((K|0)!=(h|0)){continue}break}}v[j+96>>2]=l;v[j+92>>2]=k}v[o>>2]=v[o>>2]+v[ca>>2];v[e>>2]=v[e>>2]+v[ba>>2];v[ba>>2]=0;v[ca>>2]=0;v[R>>2]=v[R>>2]&-129;break Rd}be:{ce:{if(y[p+24608>>2]<=x[f+30>>1]){break ce}if(v[da>>2]){j=G|4}else{if(!(v[ra>>2]|v[sa>>2])){break ce}j=G}l=(k<<3)+g|0;n=l-8|0;v[ca>>2]=0-v[n>>2];q=l-4|0;v[ba>>2]=0-v[q>>2];nb[v[(j<<2)+77360>>2]](i,Ba,g,k);v[ca>>2]=v[ca>>2]+v[n>>2];v[ba>>2]=v[ba>>2]+v[q>>2];X=1;g=l;break be}Ja=f,Ka=Hma(v[W>>2],v[W+4>>2],k,k>>31),v[Ja+104>>2]=Ka;v[f+108>>2]=mb;Sb(i,f+104|0);X=0;v[ba>>2]=0;v[ca>>2]=0;g=(k<<3)+g|0}j=v[da>>2];de:{if(!j){break de}if(j>>>0<=k>>>0){v[da>>2]=0;v[sa>>2]=v[Ha>>2];v[ra>>2]=v[Ga>>2];v[Fa>>2]=0;v[Ea>>2]=0;if(v[Da>>2]|!(w[R+1|0]&16)){break de}v[Q>>2]=0;v[Y+624>>2]=0;break de}v[da>>2]=j-k}j=0;K=0;l=v[i+4>>2];K=l>>>0>=y[ga>>2]?(w[R|0]&2)>>>1|0:K;n=l;l=v[Q>>2];j=n>>>0<l>>>0|(!l|w[R|0]&2)?j:!x[Ca>>1];h=h-k|0;Eb(f+104|0,ma,85);ee:{fe:{ge:{he:{if(!Cb(f+104|0)){break he}l=w[qa|0];if(!l|l>>>0>x[p+480190>>1]){break he}k=!(j|K);j=p+B(w[qa|0],104)|0;l=j+484380|0;n=v[ha>>2];if(k|(l|0)==(n|0)){break ge}v[ha>>2]=l;v[Y+624>>2]=v[j+484400>>2];l=x[j+484414>>1];v[R>>2]=l|v[R>>2]&-768;n=l<<30>>31;l=v[j+484388>>2];v[Q>>2]=n&l;j=v[j+484384>>2];v[ka>>2]=j;v[ga>>2]=l;v[i+4>>2]=j;mC(T,i);if(!v[Y+624>>2]){break Rd}if((h|0)>0){continue}break Rd}if(K){break fe}break ee}if(!K|(l|0)!=(n|0)){break ee}}Eb(f+104|0,ma,83);if(!Cb(f+104|0)|v[ka>>2]){break ee}v[i>>2]=v[i>>2];v[i+4>>2]=0;j=v[v[ha>>2]+8>>2];v[Q>>2]=j;v[ga>>2]=j}if((h|0)>0){continue}}break}v[Y+624>>2]=v[f+8>>2];u[f+30>>1]=x[f+30>>1]+X;ie:{if(!X|!ea|ea>>>0>250){break ie}e=v[(p+B(ea,160)|0)+906140>>2];if(!e){break ie}nb[v[v[e>>2]+144>>2]](e)}k=x[p+480212>>1]}ja=ja+1|0;if(ja>>>0<(k&65535)>>>0){continue}break}}Ja=p,Ka=x[Si(p+480214|0,f+30|0)>>1],u[Ja+480214>>1]=Ka}jb=f+112|0;if(sd(oa)){e=ia;g=(B(v[a+480232>>2],v[a+480236>>2])>>>0)/48|0;G=jb-16|0;jb=G;V=v[oa>>2];je:{if(!w[V+530|0]){break je}h=Hma(g,0,6169,0);g=mb;j=g>>>16|0;M=hd((g&65535)<<16|h>>>16,j);if(!m){break je}while(1){g=v[V>>2];o=v[g>>2];l=v[g+4>>2];if((o|0)<=(l|0)){i=g+14|0;j=g+12|0;while(1){v[g+8>>2]=v[g+12>>2];h=g;o=j;l=i;s=0;n=0;K=0;f=jb-16|0;jb=f;while(1){q=h+B(K,44)|0;ke:{if(!w[q+56|0]){u[f+12>>1]=0;u[f+14>>1]=0;break ke}k=v[q+32>>2];p=x[k+3840>>1];if(p&3){k=(x[q+36>>1]>>>7&7)>>>(w[k+3844|0]^1)>>>(p&1)|0;k=(p&4?0-k|0:k)&65535}else{k=0}k=k<<x[q+38>>1];p=f;A=v[q+52>>2];le:{if(A){r=x[A+32>>1];N=x[q+48>>1];A=Nf(v[q+16>>2],v[q+40>>2],k<<16>>16,0,u[q+46>>1]);H=v[q+40>>2];J=v[q+20>>2];if(!r){if(!N){k=k<<16>>16;A=Nf(J,H,k,A,0);A=Nf(v[q+24>>2],v[q+40>>2],k,A,0);k=Nf(v[q+28>>2],v[q+40>>2],k,A,0);break le}k=k<<16>>16;H=Nf(J,H,k,0,0);H=Nf(v[q+24>>2],v[q+40>>2],k,H,0);k=Nf(v[q+28>>2],v[q+40>>2],k,H,0)+A|0;break le}if(!N){k=k<<16>>16;A=Nf(J,H,k,A,0);H=Nf(v[q+24>>2],v[q+40>>2],k,0,0);k=Nf(v[q+28>>2],v[q+40>>2],k,H,0)+A|0;break le}k=k<<16>>16;H=Nf(J,H,k,0,0);k=(Nf(v[q+24>>2],v[q+40>>2],k,H,0)+A|0)+Nf(v[q+28>>2],v[q+40>>2],k,0,0)|0;break le}N=x[q+48>>1];k=k<<16>>16;A=Nf(v[q+16>>2],v[q+40>>2],k,0,u[q+46>>1]);H=v[q+40>>2];J=v[q+20>>2];if(!N){k=Nf(J,H,k,A,0);break le}k=Nf(J,H,k,0,0)+A|0}u[p+14>>1]=w[q+57|0]?k:0;u[f+12>>1]=w[q+58|0]?k:0}s=u[f+12>>1]+s|0;n=u[f+14>>1]+n|0;K=K+1|0;if((K|0)!=18){continue}break}k=o;o=(n|0)<32767?n:32767;u[k>>1]=(o|0)>-32768?o:-32768;o=(s|0)<32767?s:32767;u[l>>1]=(o|0)>-32768?o:-32768;u[h+3832>>1]=x[h+3832>>1]+1;o=(x[h+3834>>1]+1>>>0)%13440|0;u[h+3834>>1]=o;o=o>>>0<6720?o:13440-o|0;u[h+3836>>1]=o>>>8;if(!w[h+3843|0]){u[h+3836>>1]=o>>>10}o=x[h+3838>>1]+1|0;u[h+3838>>1]=o;if((o&65535)>>>0>=1024){u[h+3838>>1]=0;u[h+3840>>1]=x[h+3840>>1]+1&7}jb=f+16|0;o=v[g>>2];l=v[g+4>>2]-o|0;v[g+4>>2]=l;if((l|0)>=(o|0)){continue}break}}h=o-l|0;u[G+14>>1]=(B(u[g+12>>1],l)+B(h,u[g+8>>1])|0)/(o|0);u[G+12>>1]=(B(u[g+14>>1],l)+B(h,u[g+10>>1])|0)/(o|0);v[g+4>>2]=l+49716;v[e>>2]=v[e>>2]+B(M,u[G+14>>1]);v[e+4>>2]=v[e+4>>2]+B(M,u[G+12>>1]);e=e+8|0;m=m-1|0;if(m){continue}break}}jb=G+16|0}l=ia;e=F;g=za;me:{if(!v[g+4116>>2]){if(!v[g+4120>>2]){break me}sn(g+8|0,e,g+4104|0,g+4108|0)}f=v[g>>2];i=v[g+4184>>2];m=B(f,i)>>>4|0;m=m>>>0<32767?m:32767;u[g+4202>>1]=m;u[g+4200>>1]=m;o=v[g+54052>>2];m=B(o,f)>>>4|0;m=m>>>0<65536?m:65536;h=m+127>>>3|0;u[g+54050>>1]=h;m=m+255>>>4|0;u[g+54048>>1]=m;u[g+54046>>1]=m;u[g+54044>>1]=h;m=l;h=g+8|0;j=h;i=(i|0)>(o|0)?i:o;f=36-f>>>1|0;f=f>>>0>8?f:8;o=16-(B((i|0)<32768?i:32768,(f|0)<16?16-f|0:0)>>15)|0;f=0;i=e;if(e){while(1){n=f<<3;p=n+m|0;v[p>>2]=v[p>>2]+B(o,v[j+n>>2]>>4);n=n|4;p=n+m|0;v[p>>2]=v[p>>2]+B(o,v[j+n>>2]>>4);f=f+1|0;if((i|0)!=(f|0)){continue}break}}q=g+4172|0;f=h;o=0;m=g;i=v[g+4144>>2];j=v[g+4140>>2];if(e){n=u[m+4188>>1];while(1){p=o<<3;k=(p|4)+f|0;G=v[k>>2];p=f+p|0;A=v[p>>2]>>12;j=(B(n,A-j|0)>>15)+A|0;v[p>>2]=j;p=G>>12;i=(B(n,p-i|0)>>15)+p|0;v[k>>2]=i;o=o+1|0;if((e|0)!=(o|0)){continue}break}}v[m+4144>>2]=i;v[m+4140>>2]=j;ne:{if(!e){i=v[q>>2];break ne}m=q;i=x[m+22>>1];j=x[m+20>>1];p=v[m+4>>2];o=e;if(e){k=u[m+26>>1];J=u[m+18>>1];G=u[m+24>>1];M=u[m+16>>1];n=v[m>>2]-1|0;A=m+32928|0;while(1){H=Sc(v[f>>2]);s=Sc(v[f+4>>2]);j=Sc((j<<16>>16)-H|0);i=Sc((i<<16>>16)-s|0);j=Vc(Sc((B(j,M)|0)/65536<<1)+H|0);i=Vc(Sc((B(i,J)|0)/65536<<1)+s|0);s=A+(p<<2)|0;H=u[s+2>>1];N=u[s>>1];s=Vc(((B(N,G)|0)/-65536|0)+j|0);p=p+1&127;V=A+(p<<2)|0;r=Vc(((B(k,H)|0)/-65536|0)+i|0);u[V+2>>1]=r;u[V>>1]=s;n=n+1&8191;V=m+(n<<2)|0;Ja=V,Ka=Vc(N+((B(s,G)|0)/65536|0)|0),u[Ja+160>>1]=Ka;Ja=V,Ka=Vc(H+((B(k,r)|0)/65536|0)|0),u[Ja+162>>1]=Ka;f=f+8|0;o=o-1|0;if(o){continue}break}}k=g+53996|0;u[m+22>>1]=i;u[m+20>>1]=j;v[m+4>>2]=p;f=v[g+4180>>2];r=g+37612|0;m=h;o=e;while(1){j=f&4095;A=r+(j<<2)|0;i=m;M=f-v[g+53996>>2]&4095;f=4096-(j>>>0>M>>>0?j:M)|0;f=f>>>0<o>>>0?f:o;j=f>>>0<64?f:64;H=j;p=0;G=jb-32|0;jb=G;f=q;n=v[f>>2];while(1){v[G+(p<<2)>>2]=n+(v[(f+(p<<4)|0)+32>>2]^-1);p=p+1|0;if((p|0)!=7){continue}break}n=u[f+28>>1]/8|0;if(H){N=n<<16>>16;while(1){s=0;K=0;p=0;while(1){n=G+(p<<2)|0;J=v[n>>2]+1&8191;v[n>>2]=J;J=f+(J<<2)|0;V=u[J+160>>1];n=f+(p<<4)|0;J=u[J+162>>1];K=(B(V,u[n+44>>1])+K|0)+B(J,u[n+46>>1])|0;s=(B(V,u[n+40>>1])+s|0)+B(J,u[n+42>>1])|0;p=p+1|0;if((p|0)!=4){continue}break}n=0;p=4;E=Vc((s|0)/32768|0);I=Vc((K|0)/32768|0);s=0;while(1){J=G+(p<<2)|0;V=v[J>>2]+1&8191;v[J>>2]=V;Z=s;s=f+(V<<2)|0;V=u[s+160>>1];J=f+(p<<4)|0;T=u[s+162>>1];s=(Z+B(V,u[J+44>>1])|0)+B(T,u[J+46>>1])|0;n=(B(V,u[J+40>>1])+n|0)+B(T,u[J+42>>1])|0;p=p+1|0;if((p|0)!=7){continue}break}n=Vc(E+((n|0)/32768|0)|0);u[A>>1]=n;v[i>>2]=B(n,N);n=Vc(I+((s|0)/32768|0)|0);u[A+2>>1]=n;v[i+4>>2]=B(n,N);i=i+8|0;A=A+4|0;H=H-1|0;if(H){continue}break}}jb=G+32|0;A=r+(M<<2)|0;i=m;f=k;s=v[f+4>>2];n=s&2047;p=j;if(j){G=f+8256|0;H=f- -64|0;J=f+24640|0;M=f+16448|0;while(1){E=u[(G+((s+754&2047)<<2)|0)+2>>1];I=u[G+((s+1206&2047)<<2)>>1];V=u[(H+((s+1602&2047)<<2)|0)+2>>1];T=u[H+((s+1750&2047)<<2)>>1];R=J+((s+22&2047)<<2)|0;N=u[R+2>>1];R=u[R>>1];Q=J+((s+502&2047)<<2)|0;K=u[Q+2>>1];W=u[A>>1];X=u[A+2>>1];Q=u[Q>>1];Y=Sc(u[f+32>>1]-Q|0);ba=u[f+24>>1];ca=Sc(u[f+34>>1]-K|0);da=u[f+26>>1];_=Sc(u[f+36>>1]-R|0);ea=u[f+28>>1];ga=Sc(u[f+38>>1]-N|0);ha=u[f+30>>1];Ja=f,Ka=Vc(Sc((B(Y,ba)|0)/65536<<1)+Q|0),u[Ja+32>>1]=Ka;Ja=f,Ka=Vc(Sc((B(ca,da)|0)/65536<<1)+K|0),u[Ja+34>>1]=Ka;Ja=f,Ka=Vc(Sc((B(_,ea)|0)/65536<<1)+R|0),u[Ja+36>>1]=Ka;Ja=f,Ka=Vc(Sc((B(ga,ha)|0)/65536<<1)+N|0),u[Ja+38>>1]=Ka;N=Sc((B(u[f+32>>1],u[f+16>>1])|0)/32768|0);K=Sc((B(u[f+38>>1],u[f+22>>1])|0)/32768|0);R=Sc(N+((W|0)/4<<16>>16)|0);K=Sc(K+((X|0)/4<<16>>16)|0);Q=Sc(R+((B(T,u[f+8>>1])|0)/-65536|0)|0);N=n<<2;W=N+H|0;X=Sc(K+((B(V,u[f+10>>1])|0)/-65536|0)|0);u[W+2>>1]=X;u[W>>1]=Q;T=Sc(T+((B(Q,u[f+8>>1])|0)/65536|0)|0);Q=N+M|0;V=Sc(V+((B(X,u[f+10>>1])|0)/65536|0)|0);u[Q+2>>1]=V;u[Q>>1]=T;T=Sc(T+R|0);R=Sc(K+V|0);V=M+((s+426&2047)<<2)|0;K=u[V+2>>1];Q=u[V>>1];s=M+((s+682&2047)<<2)|0;W=u[s+2>>1];X=u[s>>1];s=Sc((B(W,u[f+42>>1])+B(X,u[f+40>>1])|0)/32768|0);V=Sc((B(K,u[f+46>>1])+B(Q,u[f+44>>1])|0)/32768|0);X=Sc(Sc(T+X|0)-s|0);W=Sc(Sc(R+W|0)-V|0);T=Sc(Sc(T+Q|0)-s|0);R=Sc(Sc(K+R|0)-V|0);s=Sc(s+((B(I,u[f+8>>1])|0)/-65536|0)|0);V=Sc(V+((B(E,u[f+10>>1])|0)/-65536|0)|0);K=u[f+8>>1];Q=u[f+10>>1];Y=G+N|0;u[Y+2>>1]=V;u[Y>>1]=s;Z=I;I=(B(s,K)|0)/65536|0;s=Sc(Z+I|0);N=J+N|0;V=(B(Q,V)|0)/65536|0;E=Sc(V+E|0);u[N+2>>1]=E;u[N>>1]=s;s=Sc(s+X|0);N=u[f+48>>1];E=Sc(E+W|0);v[i>>2]=(v[i>>2]+B(s,N)|0)+B(E,u[f+50>>1]);s=Sc(Sc(I)+T|0);N=u[f+52>>1];V=Sc(Sc(V)+R|0);v[i+4>>2]=(v[i+4>>2]+B(s,N)|0)+B(V,u[f+54>>1]);i=i+8|0;A=A+4|0;s=n+1|0;n=s&2047;p=p-1|0;if(p){continue}break}}v[f+4>>2]=n;f=j+v[g+4180>>2]&4095;v[g+4180>>2]=f;i=j+v[g+4172>>2]&8191;v[g+4172>>2]=i;m=(j<<3)+m|0;o=o-j|0;if(o){continue}break}}v[g+4172>>2]=i&8191;m=h;h=0;f=0;n=g;p=v[g+4160>>2];G=v[g+4156>>2];o=e;if(e){i=v[n+4164>>2];j=v[n+4168>>2];while(1){h=v[m>>2];f=v[m+4>>2];j=j-f|0;j=(((j|0)/1024|0)-j|0)+p|0;v[l+4>>2]=j+v[l+4>>2];i=i-h|0;i=(((i|0)/1024|0)-i|0)+G|0;v[l>>2]=i+v[l>>2];p=j+((j|0)/-512|0)|0;G=i+((i|0)/-512|0)|0;l=l+8|0;m=m+8|0;j=f;i=h;o=o-1|0;if(o){continue}break}}v[n+4168>>2]=f;v[n+4164>>2]=h;v[n+4160>>2]=p;v[n+4156>>2]=G;oe:{if(v[g+4116>>2]){v[g+4120>>2]=v[g+4124>>2];break oe}m=v[g+4120>>2];if(m>>>0>e>>>0){v[g+4120>>2]=m-e;break oe}DI(g);v[g+4120>>2]=0}v[g+4116>>2]=0}if(v[a+946300>>2]){k=0;G=0;f=F;h=f<<2;i=a;A=x[i+480214>>1]!=0;e=i+1074332|0;$=z[e>>2];va=z[e+4>>2];while(1){o=(i+B(k,160)|0)+906300|0;e=v[o>>2];pe:{if(!e|!v[e+24>>2]){break pe}if(!rh(e+44|0)){break pe}e=v[o>>2];if(!(nb[v[v[e>>2]+108>>2]](e)|0)){nb[v[v[e>>2]+104>>2]](e,1);nb[v[v[e>>2]+116>>2]](e)}m=e+44|0;g=Pd(m,0);m=Pd(m,1);qe:{if(t[e+28|0]&1){Jy(v[e+24>>2],g,m,f,$);break qe}j=e+40|0;if(v[e+36>>2]?1:v[j>>2]){sn(v[e+24>>2],f,j,e+36|0);Jy(v[e+24>>2],g,m,f,$);break qe}Rb(g,0,h);Rb(m,0,h)}v[e+28>>2]=v[e+28>>2]&-2;if(Eu(o)){break pe}A=!(w[e+28|0]&4)|A}k=k+1|0;if((k|0)!=250){continue}break}n=i+12|0;o=i+12300|0;j=i+14348|0;Jy(n,o,j,f,$);e=i+1074464|0;M=w[e|0];t[e|0]=0;g=o;m=j;while(1){l=(i+B(G,160)|0)+906300|0;e=v[l>>2];re:{if(!e|!v[e+24>>2]){break re}if(!rh(e+44|0)){break re}q=v[l>>2];se:{if(Eu(l)){break se}e=v[l>>2];if(nb[v[v[e>>2]+140>>2]](e)|w[v[l>>2]+28|0]&2){break se}k=0;if(!G){break re}while(1){if((Ij((i+B(k,160)|0)+906300|0)|0)==(G|0)){break se}k=k+1|0;if((G|0)!=(k|0)){continue}break}break re}e=q+44|0;H=Pd(e,0);J=Pd(e,1);p=v[l>>2];s=(g|0)==(H|0);g=s?o:g;e=g;m=s?j:m;h=m;te:{if(!(w[l+28|0]|w[l+29|0]<<8|(w[l+30|0]<<16|w[l+31|0]<<24))){break te}e=g;k=Ij(l);h=m;if(k>>>0<=G>>>0){break te}h=m;if((k|0)==255){break te}k=v[(i+B(k,160)|0)+906300>>2];h=m;if(!k){break te}if(!(w[p+28|0]&4)){nb[v[v[k>>2]+144>>2]](k)}k=k+44|0;h=m;if(!rh(k)){break te}e=Pd(k,0);h=Pd(k,1)}ue:{if(!Eu(l)){break ue}ve:{if(s){break ve}k=0;if(!f){break ve}while(1){s=k<<2;N=s+H|0;Z=N;$=z[N>>2];N=g+s|0;z[Z>>2]=$+z[N>>2];V=s+J|0;s=m+s|0;z[V>>2]=z[V>>2]+z[s>>2];v[N>>2]=0;v[s>>2]=0;k=k+1|0;if((f|0)!=(k|0)){continue}break}}m=h;g=e;if(!(A&1)){break ue}g=v[l>>2];if(g){nb[v[v[g>>2]+144>>2]](g)}g=e;k=Ij(l);if(k>>>0>249|k>>>0<=G>>>0){break ue}while(1){m=k&255;g=(i+B(m,160)|0)+906300|0;k=Ij(g);g=v[g>>2];if(g){nb[v[v[g>>2]+144>>2]](g)}if(k>>>0>m>>>0?k>>>0<=249:0){continue}break}m=h;g=e}we:{xe:{if(!((w[l+24|0]&2)>>>1|0)){if(!lC(l)|!(w[p+28|0]&4)){break xe}}k=0;if(!f){break we}while(1){l=k<<2;q=l+e|0;z[q>>2]=z[q>>2]+z[l+H>>2];q=h+l|0;z[q>>2]=z[q>>2]+z[l+J>>2];k=k+1|0;if((f|0)!=(k|0)){continue}break}break we}if(M){nb[v[v[q>>2]+124>>2]](q)}nb[v[v[q>>2]+60>>2]](q,e,h,f);v[p+32>>2]=f+v[p+32>>2];if(!lC(l)){break we}if((nb[v[v[q>>2]+152>>2]](q)|0)<1|y[p+32>>2]<v[i+24620>>2]<<2>>>0){break we}k=0;ye:{if(!f){break ye}while(1){ze:{l=k<<2;$=z[l+e>>2];if($>=C(1.1920928955078125e-7)|$<=C(-1.1920928955078125e-7)){break ze}$=z[h+l>>2];if($>=C(1.1920928955078125e-7)|!($>C(-1.1920928955078125e-7))){break ze}k=k+1|0;if((f|0)!=(k|0)){continue}break ye}break}v[p+32>>2]=0;break we}v[p+28>>2]=v[p+28>>2]|4}v[p+28>>2]=v[p+28>>2]&-3}G=G+1|0;if((G|0)!=250){continue}break}Ae:{if(!f){break Ae}e=1;while(1){h=n;$=C(z[g>>2]*va);Be:{if(C(D($))<C(2147483648)){j=~~$;break Be}j=-2147483648}v[h>>2]=j;h=n;$=C(z[m>>2]*va);Ce:{if(C(D($))<C(2147483648)){j=~~$;break Ce}j=-2147483648}v[h+4>>2]=j;if((e|0)==(f|0)){break Ae}n=n+8|0;m=m+4|0;g=g+4|0;e=e+1|0;continue}}}if(v[a+24624>>2]==1){e=ia;m=0;g=F;if(g){while(1){h=m<<3;v[e+(m<<2)>>2]=(v[e+(h|4)>>2]+v[e+h>>2]|0)/2;m=m+1|0;if((g|0)!=(m|0)){continue}break}}}if(w[ya+36|0]){g=F;j=jb-16|0;jb=j;De:{Ee:{e=a;Fe:{if(!v[e+1074376>>2]){h=e+1074448|0;v[h>>2]=0;v[h+4>>2]=0;v[e+1074456>>2]=v[e+1074444>>2];break Fe}f=v[e+1074456>>2];m=v[e+1074444>>2];Ge:{if((f|0)==(m|0)){i=v[e+1074448>>2];break Ge}v[e+1074456>>2]=m;h=e+24604|0;n=e+1074448|0;He:{if((f|0)<(m|0)){i=tO(h);break He}i=sO(h)}v[n>>2]=i;v[e+1074452>>2]=i}h=e+1074448|0;if((i|0)>=1){break Ee}}o=0;break De}f=(v[e+1074456>>2]<<12)-v[e+1074460>>2]|0;o=(f|0)/(i|0)|0;if(v[e+1074372>>2]!=2){break De}v[j+12>>2]=50;v[j+8>>2]=1e4/(v[e+1074452>>2]+1|0);l=v[zf(j+12|0,j+8|0)>>2];m=o>>31;if((l|0)>=(m+o^m)){break De}i=v[e+1074448>>2];n=v[e+1074452>>2];while(1){i=i+n|0;o=(f|0)/(i|0)|0;m=o>>31;if((l|0)<(m^m+o)){continue}break}v[h>>2]=i}Ie:{Je:{switch(v[e+24624>>2]-1|0){case 0:if((g|0)<1){break Ie}m=v[e+1074444>>2];n=m<<12;f=m;p=f>>31;i=e+12|0;m=0;while(1){Ke:{if(v[h>>2]>=1){l=v[e+1074460>>2]+o|0;v[e+1074460>>2]=l;q=v[i>>2];Ja=i,Ka=Ac(Ima(Hma(q,q>>31,l,l>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;v[e+1074448>>2]=v[e+1074448>>2]-1;break Ke}l=v[i>>2];Ja=i,Ka=Ac(Ima(Hma(l,l>>31,f,p),mb,256,0),mb),v[Ja>>2]=Ka;v[e+1074460>>2]=n}i=i+4|0;m=m+1|0;if((g|0)!=(m|0)){continue}break};break Ie;case 1:if((g|0)<1){break Ie}m=v[e+1074444>>2];p=m<<12;f=m;l=f>>31;i=e+12|0;m=0;while(1){Le:{if(v[h>>2]>=1){n=v[e+1074460>>2]+o|0;v[e+1074460>>2]=n;q=v[i>>2];Ja=i,Ka=Ac(Ima(Hma(q,q>>31,n,n>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;n=v[e+1074460>>2];k=n;q=n>>31;n=v[i+4>>2];Ja=i,Ka=Ac(Ima(Hma(k,q,n,n>>31),mb,1048576,0),mb),v[Ja+4>>2]=Ka;v[e+1074448>>2]=v[e+1074448>>2]-1;break Le}n=v[i>>2];Ja=i,Ka=Ac(Ima(Hma(n,n>>31,f,l),mb,256,0),mb),v[Ja>>2]=Ka;n=v[i+4>>2];Ja=i,Ka=Ac(Ima(Hma(n,n>>31,f,l),mb,256,0),mb),v[Ja+4>>2]=Ka;v[e+1074460>>2]=p}i=i+8|0;m=m+1|0;if((g|0)!=(m|0)){continue}break};break Ie;case 3:break Je;default:break Ie}}if((g|0)<1){break Ie}m=v[e+1074444>>2];p=m<<12;f=m;l=f>>31;i=e+12|0;m=e+8204|0;G=0;while(1){Me:{if(v[h>>2]>=1){n=v[e+1074460>>2]+o|0;v[e+1074460>>2]=n;q=v[i>>2];Ja=i,Ka=Ac(Ima(Hma(q,q>>31,n,n>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;n=v[e+1074460>>2];k=n;q=n>>31;n=v[i+4>>2];Ja=i,Ka=Ac(Ima(Hma(k,q,n,n>>31),mb,1048576,0),mb),v[Ja+4>>2]=Ka;n=v[e+1074460>>2];k=n;q=n>>31;n=v[m>>2];Ja=m,Ka=Ac(Ima(Hma(k,q,n,n>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;n=v[e+1074460>>2];k=n;q=n>>31;n=v[m+4>>2];Ja=m,Ka=Ac(Ima(Hma(k,q,n,n>>31),mb,1048576,0),mb),v[Ja+4>>2]=Ka;v[e+1074448>>2]=v[e+1074448>>2]-1;break Me}n=v[i>>2];Ja=i,Ka=Ac(Ima(Hma(n,n>>31,f,l),mb,256,0),mb),v[Ja>>2]=Ka;n=v[i+4>>2];Ja=i,Ka=Ac(Ima(Hma(n,n>>31,f,l),mb,256,0),mb),v[Ja+4>>2]=Ka;n=v[m>>2];Ja=m,Ka=Ac(Ima(Hma(n,n>>31,f,l),mb,256,0),mb),v[Ja>>2]=Ka;n=v[m+4>>2];Ja=m,Ka=Ac(Ima(Hma(n,n>>31,f,l),mb,256,0),mb),v[Ja+4>>2]=Ka;v[e+1074460>>2]=p}m=m+8|0;i=i+8|0;G=G+1|0;if((g|0)!=(G|0)){continue}break}}jb=j+16|0}if(v[na>>2]!=128){m=a+12|0;h=a+8204|0;e=F;g=v[a+24604>>2];f=v[a+24624>>2];Ne:{if((g|0)==128|f>>>0<2){break Ne}ZK(m,e,g);if(f>>>0<4){break Ne}ZK(h,e,g)}}h=c;f=ia;e=v[a+24624>>2];if((e|0)==4){e=ia;g=xa;m=F-1|0;if((m|0)>-1){while(1){i=m<<4;o=m<<3;j=o|4;v[e+(i|12)>>2]=v[j+g>>2];v[e+(i|8)>>2]=v[g+o>>2];v[e+(i|4)>>2]=v[e+j>>2];v[e+i>>2]=v[e+o>>2];i=(m|0)>0;m=m-1|0;if(i){continue}break}}e=v[a+24624>>2]}nb[v[v[c>>2]+8>>2]](h,f,e,F);m=v[a+1074380>>2]-F|0;v[a+1074380>>2]=m;v[a+1074376>>2]=F+v[a+1074376>>2];wa=F+wa|0;e=v[a+480208>>2];if(e&512){break h}b=b-F|0;if(b){continue}break}}jb=aa+32|0;return wa|0}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=jb-1584|0;jb=e;Jc(b);a:{b:{if(!Ef(b,e+1576|0)){break b}if(!PQ(e+1576|0)){break b}if(!c){f=1;break b}d=w[e+1576|3];t[e+1575|0]=d;v[e+1568>>2]=-1;v[e+1564>>2]=1048576;if(d>>>0>=5){d=Cf(b);v[e+1568>>2]=d;if(!Qb(b,d)){break b}v[e+208>>2]=134217727;J=e,K=v[Lb(e+208|0,e+1568|0)>>2]<<5,v[J+1564>>2]=K}D=rq(e+1552|0);d=e+1576|4;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;v[e+208>>2]=g;g=Q(333,e+1564|0,e+208|0)|0;f=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)==1){break y}g=v[g>>2];v[114578]=0;R(832,D|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break y}d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=0;v[114578]=0;d=W(833,b|0,D|0,d|0)|0;g=v[114578];v[114578]=0;z:{if((g|0)==1){break z}if(!d){break u}if(w[e+1575|0]>=5){v[114578]=0;Q(256,b|0,v[e+1568>>2]+12|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break z}}v[114578]=0;R(449,a|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break z}v[114578]=0;Z(477,a|0);d=v[114578];v[114578]=0;if((d|0)==1){break z}v[114578]=0;R(834,e+1528|0,D|0);g=v[114578];v[114578]=0;d=a;A:{B:{C:{D:{if((g|0)==1){break D}v[114578]=0;l=W(835,e+1536|0,e+1528|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break D}v[114578]=0;W(597,l|0,a+1304400|0,-1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;W(597,l|0,a+1304424|0,-1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;g=Q(836,l|0,e+1104|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break e}if(!g|!w[e+1104|0]|t[e+1104|0]<0){break v}g=e+1113|0;if((w[g|0]|w[g+1|0]<<8)>>>0>255){break v}h=e+1115|0;if((w[h|0]|w[h+1|0]<<8)>>>0>3999){break v}u[a+480188>>1]=w[e+1104|0];j=a+484360|0;o=e+1104|3;Oe(Vb(j),w[o|0]|w[o+1|0]<<8);u[a+480192>>1]=w[g|0]|w[g+1|0]<<8;u[a+480190>>1]=w[h|0]|w[h+1|0]<<8;g=e+1117|0;if(w[g|0]){break B}g=6;break A}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}g=w[g|0]}v[d+480196>>2]=g;d=a;g=e+1118|0;if(w[g|0]){g=B(w[g|0],1e4)}else{g=125e4}v[d+480204>>2]=g;o=e+1119|0;E:{if(t[o+1|0]&1){v[114578]=0;R(621,a|0,32);d=v[114578];v[114578]=0;if((d|0)!=1){break E}break e}if(w[o|0]&2){v[114578]=0;R(621,a|0,2);d=v[114578];v[114578]=0;if((d|0)==1){break e}break E}if(w[o|0]&128){v[114578]=0;R(621,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break e}break E}if(w[o|0]&8){v[114578]=0;R(621,a|0,16);d=v[114578];v[114578]=0;if((d|0)==1){break e}break E}v[114578]=0;R(621,a|0,4);d=v[114578];v[114578]=0;if((d|0)==1){break e}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[o|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[o|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[o|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[o+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[o+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[o+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[o+2|0]&8){v[114578]=0;W(479,a+1074312|0,5,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}}F:{d=v[a+480180>>2];G:{if((d|0)!=2){if((d|0)!=32){break G}d=w[e+1123|0];v[114578]=0;t[e+208|0]=d;t[e+136|0]=128;d=Q(393,e+208|0,e+136|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break x}v[a+480200>>2]=w[d|0]<<1;break G}d=w[e+1123|0];v[114578]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(393,e+208|0,e+136|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break F}v[a+480200>>2]=w[d|0]<<2}G=a+480188|0;h=e+1125|0;g=t[h|0];d=a;if(t[h|0]<=-1){g=g+52|0}else{F=rw(+(g|0)*.15500000000000003);H:{if(F<4294967296&F>=0){g=~~F>>>0;break H}g=0}g=g+51|0}v[d+480228>>2]=g;v[114578]=0;u[e+208>>1]=64;d=Q(478,G|0,e+208|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){I:{g=x[d>>1];if(g){while(1){d=v[a+480180>>2];if((d|0)==32){d=w[(e+f|0)+1126|0];v[114578]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(393,e+208|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break I}u[((f<<5)+a|0)+480286>>1]=w[d|0];d=v[a+480180>>2]}J:{if((d|0)==4){break J}d=(e+f|0)+1190|0;if(w[d|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break J}if(w[d|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break J}u[((f<<5)+a|0)+480284>>1]=w[d|0]}f=f+1|0;if((g|0)!=(f|0)){continue}break}}f=0;h=0;while(1){f=w[(e+h|0)+1254|0]!=0|f;h=h+1|0;if((h|0)!=16){continue}break}while(1){f=w[((i<<1)+e|0)+1271|0]!=0|f;i=i+1|0;if((i|0)!=128){continue}break}if(f&1){f=0;while(1){K:{d=(e+f|0)+1254|0;if(w[d|0]){v[114578]=0;R(509,e+136|0,15167);g=v[114578];v[114578]=0;L:{M:{N:{O:{P:{if((g|0)!=1){d=w[d|0];v[114578]=0;v[e+160>>2]=d-1;R(837,e+1088|0,e+160|0);d=v[114578];v[114578]=0;if((d|0)==1){break P}v[114578]=0;U(511,e+208|0,e+136|0,e+1088|0);d=v[114578];v[114578]=0;if((d|0)==1){break O}v[114578]=0;R(512,e+1072|0,((f<<5)+a|0)+901692|0);d=v[114578];v[114578]=0;if((d|0)==1){break N}v[114578]=0;Q(471,e+1072|0,e+208|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}yb(e+208|0);yb(e+1088|0);Ib(e+136|0);break K}d=P()|0;O()|0;break d}d=P()|0;O()|0;break L}d=P()|0;O()|0;break M}d=P()|0;O()|0;yb(e+208|0)}yb(e+1088|0)}Ib(e+136|0);break d}v[114578]=0;g=Q(85,e+208|0,15175)|0;d=v[114578];v[114578]=0;Q:{if((d|0)!=1){v[114578]=0;R(512,e+136|0,((f<<5)+a|0)+901692|0);d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;Q(471,e+136|0,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}yb(g);break K}d=P()|0;O()|0;break d}d=P()|0;O()|0;yb(g);break d}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){d=(e+1104|0)+(f<<1)|0;g=d;R:{if(w[d+167|0]){v[114578]=0;R(509,e+136|0,15176);h=v[114578];v[114578]=0;S:{T:{U:{V:{W:{X:{Y:{if((h|0)!=1){g=w[g+167|0];v[114578]=0;v[e+112>>2]=g-1;R(837,e+1088|0,e+112|0);g=v[114578];v[114578]=0;if((g|0)==1){break Y}d=w[d+166|0];v[114578]=0;t[e+1056|0]=d;R(838,e+1072|0,e+1056|0);d=v[114578];v[114578]=0;if((d|0)==1){break X}v[114578]=0;X(839,e+208|0,e+136|0,e+1088|0,e+1072|0);d=v[114578];v[114578]=0;if((d|0)==1){break W}v[114578]=0;R(512,e+160|0,((f<<5)+a|0)+902204|0);d=v[114578];v[114578]=0;if((d|0)==1){break V}v[114578]=0;Q(471,e+160|0,e+208|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break V}yb(e+208|0);yb(e+1072|0);yb(e+1088|0);Ib(e+136|0);break R}d=P()|0;O()|0;break d}d=P()|0;O()|0;break S}d=P()|0;O()|0;break T}d=P()|0;O()|0;break U}d=P()|0;O()|0;yb(e+208|0)}yb(e+1072|0)}yb(e+1088|0)}Ib(e+136|0);break d}v[114578]=0;g=Q(85,e+208|0,15175)|0;d=v[114578];v[114578]=0;Z:{if((d|0)!=1){v[114578]=0;R(512,e+136|0,((f<<5)+a|0)+902204|0);d=v[114578];v[114578]=0;if((d|0)==1){break Z}v[114578]=0;Q(471,e+136|0,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Z}yb(g);break R}d=P()|0;O()|0;break d}d=P()|0;O()|0;yb(g);break d}f=f+1|0;if((f|0)!=128){continue}break}}d=Vb(j);g=e+1104|1;g=w[g|0]|w[g+1|0]<<8;v[114578]=0;ea(581,d|0,l|0,g|0,255,254)|0;d=v[114578];v[114578]=0;_:{$:{aa:{ba:{ca:{da:{if((d|0)!=1){q=e+1104|5;d=w[q|0]|w[q+1|0]<<8;g=w[e+1104|0];v[114578]=0;U(343,e+1088|0,l|0,B(d,g)<<1);d=v[114578];v[114578]=0;if((d|0)==1){break da}d=w[q|0]|w[q+1|0]<<8;v[114578]=0;U(343,e+1072|0,l|0,d<<1);d=v[114578];v[114578]=0;if((d|0)==1){break ca}d=e+1104|7;d=w[d|0]|w[d+1|0]<<8;v[114578]=0;A=Q(397,e+1056|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ba}J=e,K=bc(A),v[J+136>>2]=K;J=e,K=cc(A),v[J+160>>2]=K;if(Jb(e+136|0,e+160|0)){while(1){d=v[e+136>>2];v[114578]=0;g=T(392,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}v[114578]=0;U(343,e+208|0,l|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break $}Wd(d,e+208|0);Bb(e+208|0);Uf(e+136|0);if(Jb(e+136|0,e+160|0)){continue}break}}d=v[a+480180>>2];k=1;p=c&1;if(!p){break _}g=w[q|0]|w[q+1|0]<<8;v[114578]=0;R(403,a+484344|0,g|0);g=v[114578];v[114578]=0;if((g|0)!=1){break _}d=P()|0;O()|0;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}E=a+484344|0;ea:{fa:{ga:{ha:{ia:{ja:{if(w[q|0]|w[q+1|0]<<8){n=(d|0)==16?14:(d|0)==32?1:13;while(1){v[114578]=0;d=T(359,e+1072|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ea}v[e+136>>2]=d;ka:{if(!p){break ka}v[114578]=0;d=W(404,E|0,r&65535,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ea}if(!d){break ka}j=0;if(!w[e+1104|0]){break ka}while(1){v[114578]=0;d=T(359,e+1088|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break fa}la:{if(nd(A)>>>0<=d>>>0){break la}m=tc(A,d);Jc(m);d=_b(E,r);v[114578]=0;f=W(472,d|0,0,j&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}g=0;if(!v[e+136>>2]){break la}while(1){v[114578]=0;z=T(389,m|0)|0;d=v[114578];v[114578]=0;ma:{na:{if((d|0)!=1){if(!z){break la}Ph(e+208|0);h=0;s=z&15;if(s){break na}break ma}d=P()|0;O()|0;break h}while(1){oa:{v[114578]=0;Q(840,m|0,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{d=w[e+160|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break ra;case 33:break va;case 30:case 31:break wa;case 29:break xa;case 28:break ya;case 26:break za;case 19:case 20:break Aa;case 17:break Ba;case 15:break Ca;case 14:break Da;case 10:break Ea;case 6:break Fa;case 5:break Ga;case 1:break Ha;case 0:break Ia;default:break Ja}}switch(d-48|0){case 4:break sa;case 1:case 2:break ta;case 0:break ua;default:break ra}}d=w[e+161|0];Ka:{if(d>>>0<=119){t[e+208|0]=d+n;break Ka}La:{switch(d-254|0){case 1:t[e+208|0]=255;break Ka;case 0:t[e+208|0]=254;break Ka;default:break La}}t[e+208|0]=253}v[114578]=0;d=T(611,e+208|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break oa}k=d&k;break pa}t[e+209|0]=w[e+161|0]+1;break pa}Ma:{if(w[e+210|0]){break Ma}d=v[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break Ma}d=w[e+161|0];if(d&15){break Ma}t[e+210|0]=11;t[e+212|0]=d>>>4;break pa}i=0;d=w[e+161|0];while(1){if((d|0)==w[i+20832|0]){t[e+212|0]=i;t[e+210|0]=11;break pa}i=i+1|0;if((i|0)!=10){continue}break}}t[e+211|0]=4;t[e+213|0]=w[e+161|0];break pa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>9|v[a+480180>>2]!=32)){t[e+212|0]=d;t[e+210|0]=8;break pa}t[e+213|0]=d;t[e+211|0]=5;break pa}Na:{if(w[e+210|0]){break Na}Oa:{d=v[a+480180>>2];if((d|0)!=4){if((d|0)!=32){break Na}i=w[e+161|0];if((i|0)!=255){break Oa}t[e+212|0]=64;t[e+210|0]=2;break pa}i=w[e+161|0];if(i&15){break Na}break qa}if(!(i&3)){break qa}}t[e+211|0]=9;t[e+213|0]=w[e+161|0];break pa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>64|v[a+480180>>2]==1)){t[e+212|0]=d;t[e+210|0]=1;break pa}t[e+213|0]=d;t[e+211|0]=13;break pa}t[e+211|0]=14;d=w[e+161|0];t[e+213|0]=d;if(v[a+480180>>2]==32){break pa}t[e+213|0]=B((d&240)>>>4|0,10)+(d&15);break pa}d=w[e+161|0];t[e+213|0]=d;if(d>>>0<=31){t[e+211|0]=16;break pa}t[e+211|0]=17;break pa}i=w[e+161|0];if(i>>>0>=16){t[e+212|0]=i>>>4;t[e+210|0]=(d|0)==20?3:5;break pa}t[e+212|0]=i;t[e+210|0]=(d|0)==20?4:6;break pa}d=w[e+161|0];if(d>>>0>=16){t[e+210|0]=10;t[e+212|0]=d>>>4;break pa}t[e+212|0]=d;t[e+210|0]=9;break pa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|16;break pa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|32;break pa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+15200|0];break pa}t[e+213|0]=w[e+161|0];d=w[e+211|0];t[e+211|0]=(d|0)==4?6:(d|0)==5?7:11;break pa}d=w[e+161|0];t[e+212|0]=(d>>>0)%10;if(d>>>0<=9){t[e+210|0]=5;break pa}if(d>>>0<=19){t[e+210|0]=6;break pa}if(d>>>0<=29){t[e+210|0]=3;break pa}if(d>>>0>39){break pa}t[e+210|0]=4;break pa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+15200|0];break pa}d=w[e+161|0]+33|0;if((d&255)>>>0>9){break pa}t[e+212|0]=d;t[e+210|0]=15;break pa}if(d>>>0>55){break pa}t[e+213|0]=w[e+161|0];t[e+211|0]=w[d+15200|0];break pa}t[e+210|0]=2;t[e+212|0]=i>>>2}h=h+1|0;if(s>>>0>(h&255)>>>0){continue}break ma}break}d=P()|0;O()|0;break h}v[114578]=0;v[e+160>>2]=(z>>>4|0)+g;d=Q(333,e+160|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ja}d=v[d>>2];if(d>>>0>g>>>0){while(1){h=v[e+208>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[e+212>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;f=B(w[e+1104|0],6)+f|0;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(y[e+136>>2]>g>>>0){continue}break}}j=j+1|0;if(w[e+1104|0]>(j&65535)>>>0){continue}break}}r=r+1|0;if(r>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}}if(!((k^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ia}h=0;break ha}d=P()|0;O()|0;break h}h=!((w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))&512);d=0;if(v[a+480180>>2]!=4){break ga}}d=x[a+480192>>1]}v[114578]=0;q=Q(841,e+1040|0,d|0)|0;d=v[114578];v[114578]=0;g=1;if((d|0)!=1){Pa:{Qa:{Ra:{if(x[a+480192>>1]){d=1;while(1){Sa:{Ta:{Ua:{if(!h){v[114578]=0;i=W(456,a|0,d&65535,0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ua}if(i){break Ta}}while(1){v[114578]=0;g=T(389,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}if(g){continue}break}if(w[e+1575|0]>=5){while(1){v[114578]=0;g=T(389,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){d=P()|0;O()|0;break j}if(g){continue}break}}v[114578]=0;Q(340,l|0,826)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Sa}}d=P()|0;O()|0;break j}f=Wb(e+136|0);v[114578]=0;W(597,l|0,f|0,-1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break Ra}v[114578]=0;Q(371,i+492|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break Ra}Va:{if(w[e+1575|0]<5){break Va}v[114578]=0;W(597,l|0,f|0,-1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break Ra}v[114578]=0;Q(371,i+524|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break Va}break Ra}v[114578]=0;j=Q(842,l|0,e+208|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break Ra}if(!j){break Qa}j=v[a+480180>>2];v[114578]=0;U(843,e+208|0,i|0,j|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ra}if(v[a+480180>>2]==4){g=Pb(q,g-1|0);i=x[e+1010>>1]|x[e+1012>>1]<<16;t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24}yb(f)}d=d+1|0;g=d&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}if(!h){break Pa}u[a+480192>>1]=0;break Pa}d=P()|0;O()|0;yb(f);break j}yb(f)}d=x[a+480190>>1];v[114578]=0;z=Q(844,e+192|0,d|0)|0;d=v[114578];v[114578]=0;j=1;if((d|0)!=1){j=w[e+1575|0]<=4?!(t[o|0]&1):j;s=c&2;c=0;Wa:{if(!x[a+480190>>1]){break Wa}h=1;g=1;while(1){d=c;r=Wb(e+176|0);v[114578]=0;W(597,l|0,r|0,-1)|0;c=v[114578];v[114578]=0;Xa:{Ya:{Za:{_a:{$a:{if((c|0)==1){break $a}v[114578]=0;Q(371,((h<<5)+a|0)+946304|0,r|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break $a}p=B(h,104);k=p+a|0;if(w[e+1575|0]<5){break _a}v[114578]=0;W(597,l|0,r|0,-1)|0;c=v[114578];v[114578]=0;if((c|0)==1){break $a}v[114578]=0;Q(372,k+484423|0,r|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break _a}}d=P()|0;O()|0;break Za}v[114578]=0;c=Q(845,l|0,e+208|0)|0;f=v[114578];v[114578]=0;ab:{bb:{cb:{db:{eb:{fb:{gb:{if((f|0)==1){break gb}if(!c){break fb}c=v[a+480180>>2];v[114578]=0;f=k+484380|0;X(846,e+208|0,f|0,c|0,j|0);c=v[114578];v[114578]=0;if((c|0)==1){break gb}i=0;hb:{if(((w[e+228|0]|w[e+229|0]<<8)&61440)!=28672|w[e+1575|0]<5){break hb}v[114578]=0;i=T(847,l|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break hb}d=P()|0;O()|0;break Za}if(!s){break Ya}C=w[e+228|0]|w[e+229|0]<<8;m=C&61440;if(!(m|(w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24)))){c=ad(e+136|0,(w[e+228|0]|w[e+229|0]<<8)&1?16:8,(w[e+228|0]|w[e+229|0]<<8)&1024?3:1,0,0);v[114578]=0;W(402,c|0,f|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break Ya}d=P()|0;O()|0;break Za}if(!(((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))+h|0)<1|(w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))>-1)){i=a+484380|0;m=B((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))+h|0,104);c=i+m|0;Cc(f,v[c>>2]);h=i+p|0;i=x[h+34>>1]&-2|u[c+34>>1]&1;u[h+34>>1]=i;u[h+34>>1]=i&65471|x[c+34>>1]&64;if(!De(c)){break Ya}v[114578]=0;c=T(466,f|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(!c){break Ya}c=v[k+484400>>2];v[114578]=0;c=T(467,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[(a+m|0)+484400>>2];v[114578]=0;h=T(848,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}lc(c,h,Bj(f));break Ya}d=P()|0;O()|0;break Za}if((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))<1){break Ya}if(t[e+228|0]&1){c=k+484414|0;u[c>>1]=x[c>>1]|1}if(w[e+229|0]&4){c=k+484414|0;u[c>>1]=x[c>>1]|64}c=w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24);v[114578]=0;U(343,e+160|0,b|0,c|0);p=v[114578];v[114578]=0;ib:{jb:{I=e;kb:{lb:{if((p|0)!=1){p=ue(f);H=(m|0)==16384;if(!((m|0)!=8192?H:1)){break jb}v[114578]=0;n=T(255,e+160|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ib}v[e+136>>2]=n;c=v[e+136>>2];n=4/(p>>>0)|0;if(c>>>0>4294967295/(n>>>0)>>>0){break lb}n=B(c,n);break kb}d=P()|0;O()|0;break Za}n=-1}v[I+136>>2]=n;Cc(f,n);if(!H){if((m|0)!=8192){break jb}v[114578]=0;c=T(466,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break bb}if(!c){break db}if(t[e+228|0]&1){c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(849,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)!=1){break cb}break bb}c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(850,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)==1){break bb}break cb}v[114578]=0;c=T(466,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break bb}if(!c){break db}if(t[e+228|0]&1){c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(851,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)==1){break bb}break cb}c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(852,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)==1){break bb}break cb}if((C&45056)==12288){c=NQ(e+136|0,e+160|0,w[e+247|0]|w[e+248|0]<<8,i);f=uz(z,h-1|0);Wd(f,c);v[f+16>>2]=v[c+16>>2];Bb(c);break db}if((m|0)!=32768){c=1;if((m|0)!=4096){break cb}h=Ze(e+136|0,e+160|0);v[114578]=0;Q(853,e+128|0,e+160|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){mb:{if(!w[e+133|0]){break mb}c=x[e+130>>1]<<1;if((c&65535)>>>0>(w[e+247|0]|w[e+248|0]<<8)>>>0){break mb}c=(w[e+247|0]|w[e+248|0]<<8)-c|0;t[e+247|0]=c;t[e+248|0]=c>>>8;v[114578]=0;Q(256,e+160|0,x[e+128>>1])|0;c=v[114578];v[114578]=0;if((c|0)==1){break eb}v[114578]=0;c=T(332,e+160|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break eb}v[114578]=0;U(343,e+112|0,e+160|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break eb}Wd(h,e+112|0);Bb(e+112|0)}v[114578]=0;c=g&65535;i=ea(854,a|0,c|0,h|0,1,1)|0;m=v[114578];v[114578]=0;if((m|0)==1){break eb}nb:{if(!i){v[114578]=0;i=aa(855,a|0,c|0,h|0,1)|0;c=v[114578];v[114578]=0;if((c|0)==1){break eb}c=1;if(!i){break nb}}ob:{if(!(w[e+247|0]|w[e+248|0]<<8)){break ob}c=w[e+247|0]|w[e+248|0]<<8;if(Bj(f)>>>0<=c>>>0){break ob}c=w[e+247|0]|w[e+248|0]<<8;i=Zn(f);k=k+484400|0;m=v[k>>2];v[114578]=0;m=T(467,m|0)|0;p=v[114578];v[114578]=0;if((p|0)==1){break a}k=v[k>>2];v[114578]=0;k=T(467,k|0)|0;p=v[114578];v[114578]=0;if((p|0)==1){break a}aj(m,k+(w[e+247|0]|w[e+248|0]<<8)|0,Bj(f)-(w[e+247|0]|w[e+248|0]<<8)|0);v[f>>2]=v[f>>2]-((c>>>0)/(i>>>0)|0)}c=v[e+216>>2];v[e+108>>2]=c;v[e+12>>2]=c;if(y[f>>2]>(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){v[f>>2]=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24)}c=d}Bb(h);break cb}break eb}v[114578]=0;c=Q(640,e+160|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(!c){break db}v[114578]=0;v[e+24>>2]=v[e+144>>2];c=v[e+140>>2];v[e+16>>2]=v[e+136>>2];v[e+20>>2]=c;U(641,f|0,1,e+16|0);c=v[114578];v[114578]=0;if((c|0)!=1){break db}}d=P()|0;O()|0;break ab}d=P()|0;O()|0;break ab}d=P()|0;O()|0;break Za}yb(r);c=d;break Wa}d=P()|0;O()|0;Bb(h);break ab}c=d}Bb(e+160|0);break Xa}d=P()|0;O()|0}Bb(e+160|0)}yb(r);break l}c=d}yb(r);g=g+1|0;h=g&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}if(!(!s|!x[a+480190>>1])){i=1;r=1;while(1){g=uz(z,i-1|0);v[114578]=0;b=T(339,g|0)|0;d=v[114578];v[114578]=0;pb:{qb:{rb:{if((d|0)!=1){if(!b){break pb}sb:{tb:{ub:{b=x[g+18>>1];vb:{if(!b){break vb}b=b+r&65535;if(!b){break vb}if(b>>>0<=x[a+480190>>1]){break ub}}v[114578]=0;T(255,g|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break tb}break m}b=uz(z,b-1|0);d=x[g+16>>1];Jc(b);f=x[g+16>>1];v[114578]=0;f=Q(258,b|0,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break m}if(!f){break pb}v[114578]=0;v[e+136>>2]=0;v[e+160>>2]=0;U(856,e+208|0,b|0,d|0);d=v[114578];v[114578]=0;wb:{if((d|0)!=1){v[114578]=0;d=T(414,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break wb}v[114578]=0;d=T(857,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break wb}f=v[e+208>>2];v[114578]=0;f=T(858,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break wb}v[114578]=0;j=ea(859,d|0,f|0,e+136|0,e+160|0,0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break wb}v[114578]=0;Q(340,b|0,v[e+136>>2])|0;b=v[114578];v[114578]=0;if((b|0)==1){break wb}Ec(e+208|0);b=1;break sb}d=P()|0;O()|0;break l}d=P()|0;O()|0;Ec(e+208|0);break l}Jc(g);v[e+136>>2]=0;v[e+160>>2]=0;j=0;b=0}v[114578]=0;R(860,e+208|0,g|0);d=v[114578];v[114578]=0;xb:{yb:{if((d|0)!=1){v[114578]=0;d=T(414,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break xb}k=v[e+208>>2];if(!b){v[114578]=0;b=T(857,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break rb}v[114578]=0;f=T(858,k|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break rb}v[114578]=0;j=ea(859,b|0,f|0,e+136|0,e+160|0,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break rb}v[114578]=0;Q(340,g|0,v[e+136>>2])|0;b=v[114578];v[114578]=0;if((b|0)==1){break rb}b=v[e+136>>2];k=k-b|0;d=b+d|0}if(j){break yb}c=1;break qb}d=P()|0;O()|0;break l}v[114578]=0;f=B(i,104)+a|0;b=f+484380|0;T(466,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break rb}i=f+484400|0;p=f+484414|0;h=0;f=v[e+160>>2];while(1){zb:{if(y[b>>2]<=h>>>0|(!k|(f|0)!=1?f:0)){break zb}if(!De(b)){break zb}v[114578]=0;v[e+112>>2]=0;v[e+176>>2]=0;f=T(857,d|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break rb}v[114578]=0;m=T(858,k|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break rb}v[114578]=0;f=ka(861,j|0,f|0,m|0,e+112|0,e+128|0,e+176|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break rb}v[114578]=0;v[e+136>>2]=f;Q(340,g|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break rb}f=v[b>>2];v[114578]=0;m=v[e+136>>2];f=T(862,f-h|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break rb}Ti(e+176|0,f);Ab:{if(v[e+176>>2]<1){break Ab}if(v[e+112>>2]!=(ue(b)|0)){break Ab}f=0;if(v[e+112>>2]<=0){break Ab}while(1){Bb:{if(t[p|0]&1){n=v[i>>2];s=ue(b);C=v[v[e+128>>2]+(f<<2)>>2];v[114578]=0;fa(863,n+(B(h,s)<<1)|0,C|0,v[e+112>>2],v[e+176>>2],f|0);n=v[114578];v[114578]=0;if((n|0)!=1){break Bb}break rb}n=v[i>>2];s=ue(b);C=v[v[e+128>>2]+(f<<2)>>2];v[114578]=0;fa(864,n+B(h,s)|0,C|0,v[e+112>>2],v[e+176>>2],f|0);n=v[114578];v[114578]=0;if((n|0)==1){break rb}}f=f+1|0;if((f|0)<v[e+112>>2]){continue}break}}v[114578]=0;n=v[e+176>>2];f=T(865,j|0)|0;s=v[114578];v[114578]=0;if((s|0)==1){break rb}k=k-m|0;d=d+m|0;v[e+160>>2]=f;h=h+n|0;continue}break}v[114578]=0;Z(866,j|0);b=v[114578];v[114578]=0;if((b|0)!=1){break qb}break rb}break rb}d=P()|0;O()|0;break l}d=P()|0;O()|0;Ec(e+208|0);break l}Ec(e+208|0)}r=r+1|0;i=r&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Cb:{if(v[a+480180>>2]!=4){break Cb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break Cb}b=w[Pb(q,f)|0];d=w[Pb(q,f)+1|0];g=w[Pb(q,f)+2|0];h=w[Pb(q,f)+3|0];v[114578]=0;f=f+1|0;ma(867,a|0,f&65535,b|0,d|0,g|0,h|0);b=v[114578];v[114578]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break l}Db:{Eb:{Fb:{Gb:{if(!(w[o+2|0]&16)){break Gb}v[114578]=0;b=Q(258,l|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}if(!b){break Gb}v[114578]=0;b=T(389,l|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}if(!(!(b&1)|!x[G>>1])){f=0;while(1){v[114578]=0;b=T(392,l|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Fb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[114578]=0;b=Q(258,l|0,1)|0;d=v[114578];v[114578]=0;Hb:{if((d|0)!=1){if(!b){break Gb}v[114578]=0;b=T(389,l|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Eb}if(!b){break Gb}v[114578]=0;d=T(392,l|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Db}v[114578]=0;U(343,e+208|0,l|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break Db}if(b>>>0>250){break Hb}v[114578]=0;R(666,e+208|0,(B(b,160)+a|0)+906140|0);b=v[114578];v[114578]=0;if((b|0)!=1){break Hb}d=P()|0;O()|0;Bb(e+208|0);break l}d=P()|0;O()|0;break l}Bb(e+208|0);continue}}j=a+901404|0;k=a+1074308|0;h=fd(e+112|0);g=0;b=0;Ib:{Jb:{while(1){v[114578]=0;d=Q(258,l|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ib}if(!d){break Jb}v[114578]=0;d=T(392,l|0)|0;f=v[114578];v[114578]=0;Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{if((f|0)!=1){v[114578]=0;f=T(392,l|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break _b}v[114578]=0;U(343,e+136|0,l|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break Zb}if((d|0)<=1397900629){if((d|0)==1229211981){break Xb}if((d|0)!=1229476432){break Lb}v[114578]=0;d=T(389,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[a+480216>>2]=d;v[114578]=0;d=T(389,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[a+480220>>2]=d;break Lb}if((d|0)==1397900630){break Yb}if((d|0)!=1414548815){break Lb}v[114578]=0;d=Q(618,e+136|0,15275)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}if(!d){break Vb}v[114578]=0;d=T(392,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;U(343,e+160|0,e+136|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break Wb}}d=P()|0;O()|0;break q}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}$b:{ac:{bc:{d=v[a+480180>>2];switch(d-2|0){case 1:break Lb;case 0:break Mb;case 2:break ac;default:break bc}}if((d|0)==16){break $b}if((d|0)!=32){break Lb}v[114578]=0;g=T(359,e+136|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;b=T(359,e+136|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break Lb}break r}v[114578]=0;v[e+208>>2]=32;d=T(255,e+136|0)|0;f=v[114578];v[114578]=0;cc:{if((f|0)==1){break cc}v[114578]=0;v[e+160>>2]=d;d=Q(33,e+208|0,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break cc}d=v[d>>2];v[114578]=0;aa(868,e+136|0,h|0,4,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break Lb}}d=P()|0;O()|0;break q}v[114578]=0;d=T(389,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Kb}v[114578]=0;f=Q(2,e+96|0,15256)|0;i=v[114578];v[114578]=0;dc:{ec:{fc:{if((i|0)!=1){v[114578]=0;R(219,e+160|0,f|0);i=v[114578];v[114578]=0;if((i|0)==1){break fc}v[114578]=0;v[e+176>>2]=d>>>4;v[e+128>>2]=d&15;X(534,e+208|0,e+160|0,e+176|0,e+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break ec}Gb(h,e+208|0);yb(e+208|0);Ib(e+160|0);yb(f);break Lb}d=P()|0;O()|0;break q}d=P()|0;O()|0;break dc}d=P()|0;O()|0;Ib(e+160|0)}yb(f);break q}v[114578]=0;Q(632,e+136|0,j|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;Z(633,j|0);d=v[114578];v[114578]=0;if((d|0)==1){break r}break Lb}v[114578]=0;d=T(255,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ub}u[e+208>>1]=d>>>5;d=Ce(E);v[114578]=0;u[e+176>>1]=d;d=Q(478,e+208|0,e+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ub}d=x[d>>1];if(d){i=0;while(1){v[114578]=0;W(869,e+160|0,e+208|0,32)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ub}f=_b(E,i);v[114578]=0;Q(870,f|0,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ub}i=i+1|0;if((d|0)!=(i|0)){continue}break}}Bb(e+160|0)}v[114578]=0;d=Q(618,e+136|0,15280)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}if(!d){break Sb}v[114578]=0;d=T(392,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;U(343,e+208|0,e+136|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break Tb}}d=P()|0;O()|0;break q}d=P()|0;O()|0;Bb(e+160|0);break q}v[114578]=0;d=T(255,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Rb}u[e+160>>1]=(d>>>0)/20;d=x[a+480188>>1];v[114578]=0;u[e+176>>1]=d;d=Q(478,e+160|0,e+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Rb}d=x[d>>1];if(d){f=0;while(1){v[114578]=0;W(635,e+208|0,((f<<5)+a|0)+480289|0,20)|0;i=v[114578];v[114578]=0;if((i|0)==1){break Rb}f=f+1|0;if((d|0)!=(f|0)){continue}break}}Bb(e+208|0)}v[114578]=0;Q(652,a|0,e+136|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;X(653,a|0,e+136|0,1,0);d=v[114578];v[114578]=0;if((d|0)==1){break r}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[114578]=0;U(664,a|0,e+136|0,g&65535);d=v[114578];v[114578]=0;if((d|0)==1){break r}}if(!v[k>>2]){break Lb}v[114578]=0;f=Q(2,e+160|0,15285)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Qb}v[114578]=0;R(242,e+176|0,k|0);d=v[114578];v[114578]=0;if((d|0)==1){break Pb}v[114578]=0;U(3,e+208|0,f|0,e+176|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ob}Gb(h,e+208|0);yb(e+208|0);yb(e+176|0);yb(f);break Lb}d=P()|0;O()|0;Bb(e+208|0);break q}d=P()|0;O()|0;break q}d=P()|0;O()|0;break Nb}d=P()|0;O()|0;yb(e+176|0)}yb(f);break q}v[114578]=0;g=T(359,e+136|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}}Bb(e+136|0);continue}break}d=P()|0;O()|0;break q}gc:{hc:{ic:{jc:{kc:{lc:{mc:{if(v[a+480180>>2]!=32){break mc}d=g&65535;if(d>>>0<256){break mc}if(d>>>0<532){break lc}}nc:{if(v[a+480180>>2]!=2){break nc}d=g&65535;if(d>>>0<12544){break nc}if(d>>>0<12820){break lc}}if(v[a+480180>>2]!=2){break kc}d=g&65535;if(d>>>0<4864|d>>>0>4895){break kc}}v[114578]=0;Z(634,j|0);d=v[114578];v[114578]=0;if((d|0)==1){break jc}}if(!(t[o+2|0]&1)){break gc}if(!(v[a+1074308>>2]|!x[a+480192>>1])){f=1;while(1){d=v[(((f&65535)<<2)+a|0)+900380>>2];if(d){v[114578]=0;g=Q(376,d|0,2)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ic}i=v[a+480180>>2];v[114578]=0;U(871,g|0,4,i|0);g=v[114578];v[114578]=0;if((g|0)==1){break hc}t[d+19|0]=w[d+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}if(y[a+1074308>>2]<18350080){v[114578]=0;d=a+1074312|0;Q(480,d|0,27)|0;g=v[114578];v[114578]=0;if((g|0)==1){break jc}v[114578]=0;Q(480,d|0,57)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jc}}if(y[a+1074308>>2]<19070976){v[114578]=0;Q(480,a+1074312|0,73)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jc}}if(y[a+1074308>>2]>=19267584){break gc}v[114578]=0;Q(480,a+1074312|0,50)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break gc}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{Dc:{Ec:{Fc:{if(Wc(h)){v[114578]=0;g=Q(2,e+80|0,15294)|0;d=v[114578];v[114578]=0;Gc:{Hc:{Ic:{if((d|0)!=1){v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ic}v[114578]=0;U(537,e+208|0,e+136|0,e+1575|0);d=v[114578];v[114578]=0;if((d|0)==1){break Hc}break Fc}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Gc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}v[114578]=0;g=Q(2,e- -64|0,15302)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ec}v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break Dc}v[114578]=0;X(453,e+208|0,e+136|0,e+1575|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break Cc}}Gb(h,e+208|0);yb(e+208|0);Ib(e+136|0);yb(g);v[114578]=0;g=Q(2,e+48|0,15315)|0;d=v[114578];v[114578]=0;if((d|0)==1){break zc}v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break yc}v[114578]=0;U(537,e+208|0,e+136|0,e+1575|0);d=v[114578];v[114578]=0;if((d|0)==1){break xc}Gb(a+1304436|0,e+208|0);yb(e+208|0);Ib(e+136|0);yb(g);v[114578]=0;d=Q(2,e+208|0,15331)|0;g=v[114578];v[114578]=0;if((g|0)==1){break vc}Gb(a+1304448|0,d);yb(d);d=v[a+480180>>2];if((d|0)>15){break Ac}switch(d-1|0){case 1:break rc;case 3:break sc;case 0:break tc;default:break w}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Bc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}if((d|0)==16){break uc}if((d|0)==32){break qc}if((d|0)!=16777216){break w}v[114578]=0;b=Q(2,e+208|0,15446)|0;d=v[114578];v[114578]=0;if((d|0)==1){break pc}Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15451)|0;d=v[114578];v[114578]=0;if((d|0)==1){break oc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break wc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15335)|0;d=v[114578];v[114578]=0;Jc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15339)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Jc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15352)|0;d=v[114578];v[114578]=0;Kc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15356)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Kc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15368)|0;d=v[114578];v[114578]=0;Lc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15371)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Lc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15385)|0;d=v[114578];v[114578]=0;Mc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15389)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Mc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;d=Q(2,e+208|0,15405)|0;g=v[114578];v[114578]=0;Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{if((g|0)!=1){Gb(a+1304484|0,d);yb(d);if(!(b&65535)){break Nc}v[114578]=0;g=Q(2,e+32|0,15408)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Tc}v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break Sc}v[114578]=0;v[e+176>>2]=(b&65280)>>>8;v[e+128>>2]=b&255;R(660,e+160|0,e+128|0);b=v[114578];v[114578]=0;if((b|0)==1){break Rc}v[114578]=0;X(645,e+208|0,e+136|0,e+176|0,e+160|0);b=v[114578];v[114578]=0;if((b|0)==1){break Qc}Gb(a+1304472|0,e+208|0);yb(e+208|0);yb(e+160|0);Ib(e+136|0);yb(g);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Oc}d=P()|0;O()|0;break Pc}d=P()|0;O()|0;yb(e+160|0)}Ib(e+136|0)}yb(g);break p}v[114578]=0;b=Q(2,e+208|0,15430)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break j}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}Gb(a+1304460|0,h);Uc:{if(v[a+1074308>>2]){v[a+1304496>>2]=7;break Uc}if(v[a+480180>>2]==1){v[a+1304496>>2]=2;break Uc}v[a+1304496>>2]=4}f=1;if(c&1){v[114578]=0;b=Q(2,e+208|0,15464)|0;c=v[114578];v[114578]=0;if((c|0)==1){break t}v[114578]=0;U(646,a|0,2,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break s}yb(b)}yb(h);LQ(z);KQ(q);gd(A);Bb(e+1072|0);Bb(e+1088|0)}Bb(l)}fe(D);break b}d=P()|0;O()|0;break p}d=P()|0;O()|0;yb(b);break p}d=P()|0;O()|0}Bb(e+136|0)}yb(h);break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0}LQ(z);break j}d=P()|0;O()|0}KQ(q);break h}d=P()|0;O()|0}gd(A)}Bb(e+1072|0)}Bb(e+1088|0);break d}d=P()|0;O()|0}Bb(l)}fe(D);S(d|0);L()}jb=e+1584|0;return f|0}V(0)|0;O()|0;Ab();L()}function bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=jb-608|0;jb=d;Jc(b);g=jb-16|0;jb=g;k=d+416|0;Zp(g+8|0,k);h=Hb(g+8|0);e=b;j=nc(e,ac(g,g+8|0));if((h|0)==(j|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(h|0)==(j|0);if(!e){QR(k)}a:{b:{c:{if(!e){break c}if(!tS(d+416|0)){break c}if(!Qb(b,hd(sS(d+416|0),mb))){break c}if(!c){f=1;break c}Hd(a,32);t[d+415|0]=0;k=fd(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if(v[d+416>>2]==778924148){v[114578]=0;R(621,a|0,16777216);e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;e=T(255,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(256,b|0,e-4|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;r=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break H}break b}I:{J:{K:{L:{M:{N:{if((w[d+456|0]|w[d+457|0]<<8)>>>0<2185|(w[d+456|0]|w[d+457|0]<<8)>>>0>4095){break N}v[114578]=0;e=T(255,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(256,b|0,e-4|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;r=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}if(r>>>0<256){break N}v[114578]=0;e=T(255,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(e>>>0<=r>>>0){break N}v[114578]=0;e=Q(256,b|0,r|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!e){break N}v[114578]=0;e=Q(622,b|0,13434)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!e){break N}v[114578]=0;R(621,a|0,16777216);e=v[114578];v[114578]=0;if((e|0)==1){break b}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=4096){v[114578]=0;b=Q(623,d+224|0,13438)|0;c=v[114578];v[114578]=0;if((c|0)==1){break G}v[114578]=0;R(624,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);f=0;break d}f=P()|0;O()|0;yb(b);break a}if((w[d+456|0]|w[d+457|0]<<8)>>>0<2194){break N}v[114578]=0;e=Q(623,d+224|0,13534)|0;f=v[114578];v[114578]=0;if((f|0)==1){break M}v[114578]=0;R(624,a|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break L}yb(e)}if(v[a+480180>>2]!=32){break H}if(((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break I}e=(w[d+456|0]|w[d+457|0]<<8)&4095;f=e<<16;if(v[d+476>>2]!=1414548815){break K}t[d+415|0]=1;break J}f=P()|0;O()|0;break a}f=P()|0;O()|0;yb(e);break a}if(e>>>0<297){break J}f=w[d+476|0]|w[d+477|0]<<8|f}v[a+1074308>>2]=f;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=2184?(w[d+458|0]|w[d+459|0]<<8)!=2184:0)){t[d+415|0]=1;v[a+1074308>>2]=18284544;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=535|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[114578]=0;e=W(625,d+480|0,255,64)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}O:{if(e){v[a+1074308>>2]=18219008;v[114578]=0;e=Q(2,d+224|0,13680)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break O}f=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[114578]=0;e=Q(2,d+224|0,13708)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}}Gb(k,e);yb(e);t[d+415|0]=1;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=514|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[a+1074308>>2]=17367040;v[114578]=0;e=Q(2,d+224|0,13744)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);t[d+415|0]=1;break H}f=P()|0;O()|0;break a}if((w[d+456|0]|w[d+457|0]<<8)!=768|(w[d+458|0]|w[d+459|0]<<8)!=768|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|(w[d+448|0]|w[d+449|0]<<8)!=256)){break H}if(w[d+469|0]|w[d+468|0]!=128){break H}v[a+1074308>>2]=18285088;t[d+415|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+460|0]|w[d+461|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+460|0]|w[d+461|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+460|0]|w[d+461|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+460|0]|w[d+461|0]<<8)<<3&32768;v[114578]=0;U(626,d+328|0,3,d+416|4);e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;R(417,d+224|0,d+328|0);e=v[114578];v[114578]=0;if((e|0)==1){break E}Gb(a+1304400|0,d+224|0);yb(d+224|0);if(!(!(w[d+462|0]&4)|(y[a+1074308>>2]<18285314?v[a+1074308>>2]:0))){v[a+480216>>2]=w[d+446|0];v[a+480220>>2]=w[d+447|0]}e=w[d+464|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+466|0]){v[a+480196>>2]=w[d+466|0]}t[d+224|0]=31;e=w[d+467|0];v[114578]=0;t[d+328|0]=e;e=Q(455,d+224|0,d+328|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);e=w[d+465|0];v[114578]=0;t[d+224|0]=e;t[d+328|0]=128;e=Q(393,d+224|0,d+328|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];f=0;while(1){j=(d+416|0)+f|0;g=j- -64|0;P:{if(w[g|0]==255){break P}v[114578]=0;h=(f<<5)+a|0;e=h+480280|0;Z(434,e|0);i=v[114578];v[114578]=0;if((i|0)==1){break D}C=h+480286|0,D=Fd(w[j+128|0],0,64),u[C>>1]=D;if(t[g|0]<=-1){v[e>>2]=v[e>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break P}if((g|0)!=100){break P}v[e>>2]=v[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}v[114578]=0;Q(256,b|0,192)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}Q:{if(!(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2187|(w[d+456|0]|w[d+457|0]<<8)>>>0>2189)){f=0;v[114578]=0;e=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}if(e){break d}v[114578]=0;e=T(392,b|0)|0;g=v[114578];v[114578]=0;R:{if((g|0)==1){break R}if(e>>>0>x[v[19811]+12>>1]){break d}g=Vb(a+484360|0);v[114578]=0;e=ea(627,g|0,b|0,e|0,65535,65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break R}if(!e){break d}break Q}f=P()|0;O()|0;break a}e=Vb(a+484360|0);f=w[d+448|0]|w[d+449|0]<<8;v[114578]=0;ea(581,e|0,b|0,f|0,255,254)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}}q=Jp(d+384|0);p=Jp(d+368|0);m=Jp(d+352|0);e=w[d+450|0]|w[d+451|0]<<8;f=0;v[114578]=0;e=W(628,b|0,q|0,e|0)|0;g=v[114578];v[114578]=0;S:{if((g|0)==1){break S}if(!e){break A}e=w[d+452|0]|w[d+453|0]<<8;v[114578]=0;e=W(628,b|0,p|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break S}if(!e){break A}e=w[d+454|0]|w[d+455|0]<<8;v[114578]=0;e=W(628,b|0,m|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break S}if(!e){break A}v[d+348>>2]=-1;C=d,D=bc(q),v[C+224>>2]=D;C=d,D=cc(q),v[C+328>>2]=D;if(!Jb(d+224|0,d+328|0)){break B}while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}_d(d+224|0);if(Jb(d+224|0,d+328|0)){continue}break}break B}f=P()|0;O()|0;break g}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}C=d,D=bc(p),v[C+224>>2]=D;C=d,D=cc(p),v[C+328>>2]=D;if(Jb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}_d(d+224|0);if(Jb(d+224|0,d+328|0)){continue}break}}C=d,D=bc(m),v[C+224>>2]=D;C=d,D=cc(m),v[C+328>>2]=D;if(Jb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}_d(d+224|0);if(Jb(d+224|0,d+328|0)){continue}break}}T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if(t[d+462|0]&1){e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114578]=0;v[d+224>>2]=e;e=Q(333,d+348|0,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ea}v[d+348>>2]=v[e>>2]}f=0;fa:{if((w[d+458|0]|w[d+459|0]<<8)!=532|(w[d+456|0]|w[d+457|0]<<8?(w[d+456|0]|w[d+457|0]<<8)!=532:0)|(w[d+447|0]|w[d+446|0])){break fa}if(w[d+460|0]&192|(w[d+469|0]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break fa}ga:{if(!(w[d+452|0]|w[d+453|0]<<8)|(w[d+450|0]|w[d+451|0]<<8)){break ga}if((v[b+8>>2]+(Kb(p)<<2)|0)+2>>>0>y[d+348>>2]){break ga}if(w[d+452|0]|w[d+453|0]<<8){e=0;while(1){v[114578]=0;f=T(392,b|0)|0;g=v[114578];v[114578]=0;ha:{if((g|0)!=1){if(!f){break ha}fg(b,((e&65535)<<2)+4|0);break ga}f=P()|0;O()|0;break g}e=e+1|0;if((e&65535)>>>0<(w[d+452|0]|w[d+453|0]<<8)>>>0){continue}break}}v[114578]=0;e=Q(2,d+224|0,13772)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}Gb(k,e);yb(e)}f=1;if(w[d+456|0]|w[d+457|0]<<8){break fa}v[114578]=0;e=Q(2,d+224|0,13785)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ba}Gb(k,e);yb(e)}ia:{if(w[d+462|0]&2){v[114578]=0;e=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break aa}v[114578]=0;g=e<<3;h=Q(258,b|0,g|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break aa}if(!(!h|y[d+348>>2]<g+v[b+8>>2]>>>0)){v[114578]=0;g=a+1304500|0;R(629,g|0,e|0);h=v[114578];v[114578]=0;if((h|0)==1){break aa}C=d,D=bc(g),v[C+328>>2]=D;C=d,D=cc(g),v[C+312>>2]=D;if(Jb(d+328|0,d+312|0)){while(1){g=v[d+328>>2];v[114578]=0;Q(630,b|0,d+224|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break $}v[114578]=0;R(631,d+224|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break $}v[d+328>>2]=v[d+328>>2]+48;if(Jb(d+328|0,d+312|0)){continue}break}}if(!(!e&f)){break ia}if(w[d+462|0]&4){v[114578]=0;e=Q(2,d+224|0,13796)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);break ia}f=P()|0;O()|0;break g}v[114578]=0;e=Q(2,d+224|0,13813)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);break ia}f=P()|0;O()|0;break g}fg(b,2);break ia}if(!f|(w[d+462|0]|w[d+463|0]<<8)>>>0>1){break ia}v[114578]=0;e=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break da}if(!e){v[114578]=0;e=Q(2,d+224|0,13772)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);break ia}f=P()|0;O()|0;break g}fg(b,2)}ja:{if(!(w[d+462|0]&8?1:w[d+460|0]&128)){break ja}v[114578]=0;e=a+901404|0;f=Q(632,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}if(!f){break ja}v[114578]=0;Z(633,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}}if((w[d+456|0]|w[d+457|0]<<8)>>>0<=531){v[114578]=0;Z(634,a+901404|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}}v[114578]=0;s=T(277,d+328|0)|0;e=v[114578];v[114578]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){v[114578]=0;e=Q(618,b|0,13819)|0;f=v[114578];v[114578]=0;if((f|0)==1){break pa}if(e){v[114578]=0;e=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break oa}v[114578]=0;U(343,d+224|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break oa}Wd(s,d+224|0);Bb(d+224|0)}u[a+480188>>1]=1;v[114578]=0;e=Q(618,b|0,13824)|0;f=v[114578];v[114578]=0;if((f|0)==1){break pa}if(e){v[114578]=0;e=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break na}v[114578]=0;U(343,d+224|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break na}v[114578]=0;e=T(255,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ma}v[114578]=0;u[d+312>>1]=(e>>>0)/20;e=Q(478,13830,d+312|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ma}e=x[e>>1];u[a+480188>>1]=e;if(e){f=0;while(1){v[114578]=0;W(635,d+224|0,((f<<5)+a|0)+480289|0,20)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ma}f=f+1|0;if((e|0)!=(f|0)){continue}break}}Bb(d+224|0)}if(y[b+8>>2]>y[d+348>>2]){break la}e=v[d+348>>2]-v[b+8>>2]|0;break ka}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;Bb(d+224|0);break i}v[114578]=0;e=T(332,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break _}}v[114578]=0;U(343,d+312|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break _}v[114578]=0;z=Q(636,a|0,d+312|0)|0;e=v[114578];v[114578]=0;qa:{ra:{if((e|0)==1){break ra}if(!(t[d+462|0]&1)|!(w[d+470|0]|w[d+471|0]<<8)){break qa}e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ra}if(!e){break qa}e=w[d+470|0]|w[d+471|0]<<8;v[114578]=0;aa(584,a+1304424|0,b|0,e|0,4)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break qa}}f=P()|0;O()|0;break j}f=0;u[a+480192>>1]=0;if(w[d+460|0]&4){e=w[d+450|0]|w[d+451|0]<<8;v[114578]=0;u[d+224>>1]=e;u[d+208>>1]=255;e=Q(478,d+224|0,d+208|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Z}u[a+480192>>1]=x[e>>1]}if(x[a+480192>>1]){while(1){e=Pb(q,f);sa:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break sa}e=Pb(q,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Y}if(!e){break sa}v[114578]=0;e=Q(258,b|0,554)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Y}if(!e){break sa}v[114578]=0;e=W(456,a|0,f+1&65535,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break X}if(!e){break sa}g=w[d+458|0]|w[d+459|0]<<8;v[114578]=0;aa(637,a|0,b|0,e|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break X}t[e+33|0]=w[d+469|0]}f=f+1|0;if(f>>>0<x[a+480192>>1]){continue}break}}v[d+308>>2]=0;if(w[d+452|0]|w[d+453|0]<<8){e=Pb(p,(w[d+452|0]|w[d+453|0]<<8)-1|0);v[d+308>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}e=w[d+452|0]|w[d+453|0]<<8;v[114578]=0;u[d+224>>1]=e;u[d+208>>1]=3999;e=Q(478,d+224|0,d+208|0)|0;f=v[114578];v[114578]=0;ta:{if((f|0)!=1){u[a+480190>>1]=x[e>>1];f=0;if(x[a+480190>>1]){break ta}g=0;break T}f=P()|0;O()|0;break j}j=c&2;n=d+244|0;g=0;while(1){e=Pb(p,f);ua:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break ua}e=Pb(p,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;h=v[114578];v[114578]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((h|0)==1){break Ba}if(!e){break ua}v[114578]=0;e=Q(638,b|0,d+224|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Ba}if(!e){break ua}v[114578]=0;i=f+1|0;e=B(i,104)+a|0;h=e+484380|0;o=Q(639,d+224|0,h|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break Aa}v[114578]=0;U(626,d+192|0,3,n|0);l=v[114578];v[114578]=0;if((l|0)==1){break za}v[114578]=0;R(417,d+208|0,d+192|0);l=v[114578];v[114578]=0;if((l|0)==1){break za}v[114578]=0;Q(371,((i<<5)+a|0)+946304|0,d+208|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ya}yb(d+208|0);v[114578]=0;o=Q(256,b|0,o|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break Aa}if(!o){break ua}e=x[e+484414>>1];if(!(e&512)){break xa}v[114578]=0;e=Q(640,b|0,d+208|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){if(!e){break wa}v[114578]=0;v[d+16>>2]=v[d+216>>2];e=v[d+212>>2];v[d+8>>2]=v[d+208>>2];v[d+12>>2]=e;U(641,h|0,1,d+8|0);e=v[114578];v[114578]=0;if((e|0)!=1){break wa}}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(d+208|0);break j}if(!(e&16384)){e=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;U(642,d+208|0,d+224|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break U}Ca:{if(j){e=0;v[114578]=0;W(402,d+208|0,h|0,b|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break Ca}break U}e=1;i=w[d+211|0];if(i>>>0>18){break Ca}i=1<<i;Da:{if(!(i&126991)){if(i&396800){break Da}break Ca}if(!w[d+208|0]){break Ca}}e=v[h>>2];v[114578]=0;i=Q(643,d+208|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break U}e=0;v[114578]=0;Q(340,b|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break U}}if(w[d+211|0]!=1){break va}g=v[h>>2]!=0|g;break va}v[114578]=0;Q(644,b|0,d+188|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break V}e=v[d+188>>2];if(!(!j|!e)){e=Wb(d+208|0);v[114578]=0;W(482,b|0,e|0,v[d+188>>2])|0;h=v[114578];v[114578]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((h|0)!=1){v[114578]=0;h=Q(2,d+160|0,13832)|0;o=v[114578];v[114578]=0;if((o|0)==1){break Ma}v[114578]=0;R(219,d+176|0,h|0);o=v[114578];v[114578]=0;if((o|0)==1){break La}v[114578]=0;v[d+156>>2]=i;U(13,d+144|0,0,e|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ka}v[114578]=0;X(645,d+192|0,d+176|0,d+156|0,d+144|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ja}v[114578]=0;U(646,a|0,2,d+192|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ia}yb(d+192|0);yb(d+144|0);Ib(d+176|0);yb(h);yb(e);break wa}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;break Fa}f=P()|0;O()|0;break Ga}f=P()|0;O()|0;break Ha}f=P()|0;O()|0;yb(d+192|0)}yb(d+144|0)}Ib(d+176|0)}yb(h)}yb(e);break j}v[114578]=0;Q(340,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break V}}e=0}h=v[b+8>>2];v[114578]=0;v[d+208>>2]=h;h=Q(647,d+308|0,d+208|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break W}v[d+308>>2]=v[h>>2];A=(e|0)!=0}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}break T}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}u[d+224>>1]=1;e=x[a+480190>>1];v[114578]=0;u[d+208>>1]=e;e=Q(454,d+224|0,d+208|0)|0;f=v[114578];v[114578]=0;Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{if((f|0)!=1){u[a+480190>>1]=x[e>>1];Za:{if(!(g&1)|(w[d+456|0]|w[d+457|0]<<8)!=516|(w[d+462|0]|w[d+463|0]<<8|(w[d+458|0]|w[d+459|0]<<8)!=512)){break Za}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&65527)!=21|(w[d+464|0]!=128|w[d+465|0]!=48)){break Za}if(w[d+469|0]|w[d+468|0]!=128|(w[d+470|0]|w[d+471|0]<<8)){break Za}g=d+544|0;e=d+480|0;f=1;while(1){f=(w[e|0]|128)!=160?0:f;e=e+1|0;if((g|0)!=(e|0)){continue}break}g=d+608|0;e=d+544|0;while(1){f=w[e|0]==64&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=20;while(1){f=!w[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break Za}v[114578]=0;e=Q(2,d+224|0,13910)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Oa}Gb(k,e);yb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;C=d,D=Kb(m),u[C+224>>1]=D;e=v[a+8>>2];v[114578]=0;e=Q(478,d+224|0,e+10|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ya}e=x[e>>1];u[d+188>>1]=e;if((Kb(m)|0)!=(e|0)){v[114578]=0;R(509,d+208|0,13924);e=v[114578];v[114578]=0;if((e|0)==1){break Xa}e=Kb(m);v[114578]=0;v[d+192>>2]=e;X(648,d+128|0,d+208|0,d+192|0,d+188|0);e=v[114578];v[114578]=0;if((e|0)==1){break Wa}v[114578]=0;e=Q(649,d+224|0,d+128|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Va}v[114578]=0;R(624,a|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ua}yb(e);yb(d+128|0);Ib(d+208|0)}if(c&1){break Ra}u[d+188>>1]=0;break Qa}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Sa}f=P()|0;O()|0;break Ta}f=P()|0;O()|0;yb(e)}yb(d+128|0)}Ib(d+208|0);break j}if(!x[d+188>>1]){break Qa}e=0;while(1){c=Pb(m,e);_a:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break _a}c=Pb(m,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Pa}if(!c){break _a}v[114578]=0;c=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}v[114578]=0;h=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}if((h-1&65535)>>>0>1023){break _a}v[114578]=0;f=Q(340,b|0,4)|0;g=v[114578];v[114578]=0;if((g|0)==1){break l}if(!f){break _a}v[114578]=0;U(343,d+224|0,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break m}c=0;f=x[a+480188>>1];v[114578]=0;g=Q(650,d+208|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}while(1){$a:{v[114578]=0;f=Q(258,d+224|0,1)|0;j=v[114578];v[114578]=0;ab:{bb:{if((j|0)!=1){if(!f){break $a}v[114578]=0;f=T(389,d+224|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}j=f<<24>>24;if(j){break bb}c=c+1|0;break ab}break p}cb:{f=j&127;i=f?f-1|0:0;f=i&65535;if(xc(g)>>>0>f>>>0){break cb}v[114578]=0;t[d+192|0]=0;U(651,g|0,f+1|0,d+192|0);n=v[114578];v[114578]=0;if((n|0)!=1){break cb}break p}if((j|0)<=-1){v[114578]=0;j=T(389,d+224|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break p}C=wc(g,f),D=j,t[C|0]=D}if(!(!(w[wc(g,f)|0]&15)|f>>>0<x[a+480188>>1])){u[a+480188>>1]=i+1}if(t[wc(g,f)|0]&1){v[114578]=0;Q(340,d+224|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}}if(w[wc(g,f)|0]&2){v[114578]=0;Q(340,d+224|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}}if(w[wc(g,f)|0]&4){v[114578]=0;Q(340,d+224|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}}if(!(w[wc(g,f)|0]&8)){break ab}v[114578]=0;Q(340,d+224|0,2)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}}if(c>>>0<h>>>0){continue}}break}c=v[b+8>>2];v[114578]=0;v[d+192>>2]=c;c=Q(647,d+308|0,d+192|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}v[d+308>>2]=v[c>>2];fe(g);Bb(d+224|0)}e=e+1|0;if(e>>>0<x[d+188>>1]){continue}break}}db:{eb:{c=v[d+308>>2];if(!c){break eb}v[114578]=0;Q(256,b|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}if(!A){break eb}while(1){fb:{v[114578]=0;c=Q(258,b|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break fb}if(!c){break eb}v[114578]=0;c=Q(618,b|0,14016)|0;e=v[114578];v[114578]=0;if((e|0)==1){break fb}gb:{if(!c){v[114578]=0;c=Q(618,b|0,14021)|0;e=v[114578];v[114578]=0;if((e|0)==1){break fb}if(!c){break gb}}v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}fg(b,8);if(c&-2139062144){break gb}if(c&1616928864){break eb}}v[114578]=0;c=T(359,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break fb}v[114578]=0;Q(340,b|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}f=P()|0;O()|0;break j}v[114578]=0;c=Q(652,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}c=c|w[d+415|0];t[d+415|0]=c;if(!(!c|z)){Ct(a+1074312|0);v[a+1074372>>2]=0}v[114578]=0;X(653,a|0,b|0,0,d+415|0);c=v[114578];v[114578]=0;if((c|0)==1){break q}v[114578]=0;n=a+484344|0;R(403,n|0,x[d+188>>1]);c=v[114578];v[114578]=0;if((c|0)==1){break q}u[d+156>>1]=0;if(!x[d+188>>1]){break Na}f=0;while(1){hb:{ib:{c=Pb(m,f);jb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Pb(m,x[d+156>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break jb}if(c){break ib}}v[114578]=0;c=W(404,n|0,x[d+156>>1],64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break jb}if(!c){v[114578]=0;R(509,d+208|0,14026);c=v[114578];v[114578]=0;kb:{lb:{mb:{nb:{ob:{if((c|0)!=1){v[114578]=0;U(654,d+112|0,d+208|0,d+156|0);c=v[114578];v[114578]=0;if((c|0)==1){break ob}v[114578]=0;c=Q(649,d+224|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break nb}v[114578]=0;R(624,a|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break mb}yb(c);yb(d+112|0);Ib(d+208|0);break Na}f=P()|0;O()|0;break j}f=P()|0;O()|0;break kb}f=P()|0;O()|0;break lb}f=P()|0;O()|0;yb(c)}yb(d+112|0)}Ib(d+208|0);break j}c=_b(n,x[d+156>>1]);v[114578]=0;R(655,c|0,s|0);c=v[114578];v[114578]=0;if((c|0)!=1){break hb}}f=P()|0;O()|0;break j}v[114578]=0;c=T(359,b|0)|0;e=v[114578];v[114578]=0;pb:{qb:{if((e|0)!=1){v[114578]=0;o=T(359,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break qb}v[114578]=0;e=Q(340,b|0,4)|0;f=v[114578];v[114578]=0;if((f|0)==1){break qb}if(!e){break hb}v[114578]=0;e=W(404,n|0,x[d+156>>1],o|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break qb}if(e){break pb}break hb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}v[114578]=0;U(343,d+224|0,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){c=_b(n,x[d+156>>1]);v[114578]=0;R(655,c|0,s|0);c=v[114578];v[114578]=0;rb:{if((c|0)!=1){c=x[a+480188>>1];v[114578]=0;i=Q(650,d+208|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){c=x[a+480188>>1];Ph(d+176|0);v[114578]=0;j=W(656,d+192|0,c|0,d+176|0)|0;c=v[114578];v[114578]=0;sb:{if((c|0)!=1){C=d,D=bc(_b(n,x[d+156>>1])),v[C+144>>2]=D;l=0;tb:{if(!o){break tb}while(1){v[114578]=0;c=Q(258,d+224|0,1)|0;e=v[114578];v[114578]=0;ub:{if((e|0)!=1){vb:{if(!c){break tb}v[114578]=0;c=T(389,d+224|0)|0;e=v[114578];v[114578]=0;wb:{if((e|0)!=1){c=c<<24>>24;if(c){break wb}oS(d+144|0,x[a+480188>>1]);l=l+1|0;break ub}break vb}xb:{e=c&127;h=e?e-1&65535:0;if(xc(i)>>>0>h>>>0){break xb}v[114578]=0;t[d+176|0]=0;e=h+1|0;U(651,i|0,e|0,d+176|0);f=v[114578];v[114578]=0;if((f|0)==1){break vb}Ph(d+176|0);v[114578]=0;U(657,j|0,e|0,d+176|0);e=v[114578];v[114578]=0;if((e|0)!=1){break xb}break vb}if((c|0)<=-1){v[114578]=0;c=T(389,d+224|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break vb}C=wc(i,h),D=c,t[C|0]=D}Ph(d+176|0);e=d+176|0;if(h>>>0<x[a+480188>>1]){e=Nc(d+144|0,h)}if(w[wc(i,h)|0]&16){C=e,D=w[Nc(j,h)|0],t[C|0]=D}if(w[wc(i,h)|0]&32){C=e,D=w[Nc(j,h)+1|0],t[C+1|0]=D}if(w[wc(i,h)|0]&64){C=e,D=w[Nc(j,h)+2|0],t[C+2|0]=D;C=e,D=w[Nc(j,h)+4|0],t[C+4|0]=D}if(t[wc(i,h)|0]<=-1){C=e,D=w[Nc(j,h)+3|0],t[C+3|0]=D;C=e,D=w[Nc(j,h)+5|0],t[C+5|0]=D}if(t[wc(i,h)|0]&1){v[114578]=0;c=T(389,d+224|0)|0;f=v[114578];v[114578]=0;g=e;yb:{zb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break zb}f=c;break yb}break vb}f=253;if((c-121&255)>>>0<132){break yb}f=(c&255)==253?0:c}t[g|0]=f;C=Nc(j,h),D=f,t[C|0]=D}if(w[wc(i,h)|0]&2){v[114578]=0;c=T(389,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break vb}t[e+1|0]=c;C=Nc(j,h),D=c,t[C+1|0]=D}if(w[wc(i,h)|0]&4){v[114578]=0;c=T(389,d+224|0)|0;f=v[114578];v[114578]=0;Ab:{Bb:{if((f|0)!=1){if(c>>>0>64){break Bb}t[e+4|0]=c;t[e+2|0]=1;break Ab}break vb}if(!(c<<24>>24>-1|c>>>0>192)){t[e+2|0]=2;t[e+4|0]=c^128;break Ab}if(c>>>0<=74){t[e+2|0]=5;t[e+4|0]=c-65;break Ab}if(c>>>0<=84){t[e+2|0]=6;t[e+4|0]=c-75;break Ab}if(c>>>0<=94){t[e+2|0]=3;t[e+4|0]=c-85;break Ab}if(c>>>0<=104){t[e+2|0]=4;t[e+4|0]=c-95;break Ab}if(c>>>0<=114){t[e+2|0]=13;t[e+4|0]=c-105;break Ab}if(c>>>0<=124){t[e+2|0]=12;t[e+4|0]=c-115;break Ab}f=c+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;t[e+2|0]=11;break Ab}f=c+53|0;g=f&255;if(g>>>0<=9){t[e+4|0]=f;t[e+2|0]=8;if(!g|!v[a+1074308>>2]|y[a+1074308>>2]>18285140){break Ab}t[e+2|0]=7;break Ab}c=c+33|0;if((c&255)>>>0>9){break Ab}t[e+4|0]=c;t[e+2|0]=15}c=w[e+2|0];C=Nc(j,h),D=c,t[C+2|0]=D;c=w[e+4|0];C=Nc(j,h),D=c,t[C+4|0]=D}if(!(w[wc(i,h)|0]&8)){break ub}v[114578]=0;R(473,d+104|0,d+224|0);c=v[114578];v[114578]=0;if((c|0)!=1){Cb:{c=cd(d+104|0);t[e+3|0]=w[d+104|0];t[e+5|0]=w[c|0];v[114578]=0;R(658,e|0,1);c=v[114578];v[114578]=0;if((c|0)==1){break Cb}c=w[e+3|0];C=Nc(j,h),D=c,t[C+3|0]=D;c=w[e+5|0];C=Nc(j,h),D=c,t[C+5|0]=D;break ub}}}}f=P()|0;O()|0;Ll(j);break sb}if(l>>>0<o>>>0){continue}break}}Ll(j);fe(i);Bb(d+224|0);break hb}f=P()|0;O()|0}fe(i);break rb}f=P()|0;O()|0;break rb}f=P()|0;O()|0}Bb(d+224|0);break j}f=P()|0;O()|0;break j}c=x[d+156>>1]+1|0;u[d+156>>1]=c;f=c&65535;if(f>>>0<x[d+188>>1]){continue}break}break Na}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}c=a+1074308|0;Db:{Eb:{if(!v[a+1074308>>2]){Fb:{if((w[d+456|0]|w[d+457|0]<<8)==2184){v[c>>2]=18284544;e=18284544;break Fb}e=v[c>>2]}if(!e){break Eb}}if(!Wc(k)){break Eb}v[114578]=0;e=Q(2,d+208|0,14078)|0;f=v[114578];v[114578]=0;Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((f|0)!=1){v[114578]=0;R(242,d+192|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break Lb}v[114578]=0;U(3,d+224|0,e|0,d+192|0);f=v[114578];v[114578]=0;if((f|0)==1){break Kb}Gb(k,d+224|0);yb(d+224|0);yb(d+192|0);yb(e);if(v[d+476>>2]==1414548815|((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break Gb}v[114578]=0;c=Q(2,d+224|0,14087)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ib}v[114578]=0;Q(192,k|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Hb}yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Jb}f=P()|0;O()|0;yb(d+192|0)}yb(e);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}if(!gD(c)){break Db}v[114578]=0;c=Q(2,d+224|0,14111)|0;e=v[114578];v[114578]=0;Mb:{if((e|0)!=1){v[114578]=0;Q(192,k|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Mb}yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}Nb:{switch((w[d+456|0]|w[d+457|0]<<8)>>>12|0){case 0:if(z){v[114578]=0;c=Q(2,d+224|0,14125)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Db}f=P()|0;O()|0;break j}Ob:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+462|0]|w[d+463|0]<<8|(w[d+460|0]|w[d+461|0]<<8)!=9)){break Ob}if(w[d+447|0]|w[d+446|0]|(w[d+450|0]|w[d+451|0]<<8|((w[d+454|0]|w[d+455|0]<<8)+1|0)!=(w[d+448|0]|w[d+449|0]<<8))){break Ob}if(w[d+464|0]!=128|w[d+465|0]!=100|(w[d+466|0]!=1|w[d+468|0]!=128)){break Ob}if(w[d+469|0]|(w[d+470|0]|w[d+471|0]<<8)|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24)|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break Ob}v[114578]=0;c=Q(2,d+224|0,14137)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Db}f=P()|0;O()|0;break j}Pb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+447|0]|w[d+446|0])){break Pb}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)){break Pb}v[c>>2]=16777381;v[114578]=0;c=Q(2,d+224|0,14156)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);t[d+415|0]=1;break Db}f=P()|0;O()|0;break j}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|v[d+476>>2]!=1229080643)){v[114578]=0;c=Q(2,d+224|0,14179)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);v[114578]=0;Q(480,a+1074312|0,38)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}break Db}f=P()|0;O()|0;break j}Qb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|(w[d+469|0]|(w[d+462|0]|w[d+463|0]<<8)>>>0>1)){break Qb}if(!x[a+480190>>1]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&4294)!=4)){break Qb}v[114578]=0;c=Q(85,d+224|0,14192)|0;e=v[114578];v[114578]=0;Rb:{Sb:{if((e|0)!=1){v[114578]=0;e=Q(659,a+484527|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Sb}yb(c);if(!e){break Qb}v[114578]=0;c=Q(2,d+224|0,14205)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Rb}Gb(k,c);yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}f=P()|0;O()|0;break j}Tb:{if(w[d+456|0]|w[d+457|0]<<8){break Tb}if(!Wc(k)){break Tb}v[114578]=0;c=Q(2,d+224|0,14219)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Db}f=P()|0;O()|0;break j}if((w[d+458|0]|w[d+459|0]<<8)>>>0>767){break Db}if(!Wc(k)){break Db}Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{if((w[d+458|0]|w[d+459|0]<<8)>>>0>=533){v[114578]=0;c=Q(2,d+224|0,14227)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);break _b}f=P()|0;O()|0;break j}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=533){v[114578]=0;c=Q(2,d+88|0,14248)|0;e=v[114578];v[114578]=0;$b:{ac:{bc:{if((e|0)!=1){v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break bc}e=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;v[d+192>>2]=e-532;U(245,d+224|0,d+208|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break ac}Gb(k,d+224|0);yb(d+224|0);Ib(d+208|0);break _b}f=P()|0;O()|0;break j}f=P()|0;O()|0;break $b}f=P()|0;O()|0;Ib(d+208|0)}yb(c);break j}v[114578]=0;c=Q(2,d+72|0,14272)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Zb}v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break Yb}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114578]=0;v[d+144>>2]=e;R(660,d+192|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break Xb}v[114578]=0;X(645,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break Wb}Gb(k,d+224|0);yb(d+224|0);yb(d+192|0);Ib(d+208|0)}yb(c);c=a+1304500|0;if(!md(c)|!(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24))){break Db}e=w[d+456|0]|w[d+457|0]<<8;f=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114578]=0;e=Q(661,e|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break t}f=Sp(d+224|0);v[f+44>>2]=e;v[114578]=0;R(662,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)!=1){break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Ub}f=P()|0;O()|0;break Vb}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(c);break j;case 1:c=w[d+456|0]|w[d+457|0]<<8;e=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114578]=0;U(663,d+224|0,c|0,e|0);c=v[114578];v[114578]=0;cc:{if((c|0)!=1){Gb(k,d+224|0);yb(d+224|0);if((w[d+456|0]|w[d+457|0]<<8)>>>0>=6092){break cc}v[114578]=0;Q(480,a+1074312|0,7)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break cc}break q}f=P()|0;O()|0;break j}c=w[d+456|0]|w[d+457|0]<<8;if((nS(4096)|0)<=(c|0)){break Db}v[114578]=0;Q(480,a+1074312|0,38)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}break Db;case 4:v[114578]=0;c=Q(2,d+56|0,14294)|0;e=v[114578];v[114578]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break hc}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114578]=0;v[d+144>>2]=e;R(660,d+192|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break gc}v[114578]=0;X(645,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break fc}Gb(k,d+224|0);yb(d+224|0);yb(d+192|0);Ib(d+208|0);yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break dc}f=P()|0;O()|0;break ec}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(c);break j;case 6:v[114578]=0;c=Q(2,d+224|0,14125)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Db}f=P()|0;O()|0;break j;case 7:if(!((w[d+456|0]|w[d+457|0]<<8)!=32767|(w[d+458|0]|w[d+459|0]<<8)!=533)){v[114578]=0;c=Q(2,d+224|0,14305)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Db}f=P()|0;O()|0;break j}v[114578]=0;c=Q(2,d+40|0,14314)|0;e=v[114578];v[114578]=0;ic:{jc:{kc:{if((e|0)!=1){v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break kc}v[d+192>>2]=w[d+457|0]&15;v[d+176>>2]=(w[d+456|0]|w[d+457|0]<<8)>>>4&15;e=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;v[d+144>>2]=e&15;fa(239,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break jc}Gb(k,d+224|0);yb(d+224|0);Ib(d+208|0);yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break ic}f=P()|0;O()|0;Ib(d+208|0)}yb(c);break j;case 13:break Nb;default:break Db}}v[114578]=0;c=Q(2,d+224|0,14329)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}Gb(k,c);yb(c)}lc:{if(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2186){break lc}v[114578]=0;c=Q(256,b|0,r|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}if(!c){break lc}c=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;U(664,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break q}}c=v[a+480180>>2];mc:{if((c|0)==16777216){v[114578]=0;Q(2,d+224|0,14336)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break mc}f=P()|0;O()|0;break j}v[114578]=0;b=Q(2,d+24|0,14272)|0;e=v[114578];v[114578]=0;if((e|0)==1){break z}v[114578]=0;R(219,d+208|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break y}v[d+176>>2]=w[d+459|0];e=w[d+458|0];v[114578]=0;v[d+144>>2]=e;R(660,d+192|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break x}v[114578]=0;X(645,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break w}}Gb(a+1304436|0,d+224|0);yb(d+224|0);if((c|0)!=16777216){yb(d+192|0);Ib(d+208|0);yb(d+24|0)}nc:{if(v[a+480180>>2]==16777216){v[114578]=0;Q(2,d+224|0,14349)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break nc}break r}v[114578]=0;Q(2,d+224|0,14354)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}}Gb(a+1304448|0,d+224|0);yb(d+224|0);Gb(a+1304460|0,k);v[a+1304496>>2]=v[a+1074308>>2]?7:4;Bb(d+312|0);Bb(s);f=1}Ji(m);Ji(p);Ji(q);break d}f=P()|0;O()|0;break j}f=P()|0;O()|0;break u}f=P()|0;O()|0;break v}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(b);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;fe(g);break n}f=P()|0;O()|0}Bb(d+224|0);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0}Bb(d+312|0)}Bb(s);break g}f=P()|0;O()|0}Ji(m);Ji(p);Ji(q);break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}yb(k)}jb=d+608|0;return f|0}f=P()|0;O()|0}yb(k);S(f|0);L()}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;e=jb-912|0;jb=e;Jc(b);a:{b:{if(!lR(b,e+856|0)){break b}if(!nR(e+856|0)){break b}if(!Qb(b,hd(mR(e+856|0),mb))){break b}if(!c){g=1;break b}Hd(a,8);vi(a);t[e+855|0]=w[e+856|3]-48;d=w[e+864|0]|w[e+865|0]<<8|(w[e+866|0]<<16|w[e+867|0]<<24);Qc(b,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24));ud(e+832|0,b,504);v[114578]=0;Q(774,b|0,e+544|0)|0;d=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((d|0)!=1){if(w[e+544|0]&128|w[e+827|0]>63){break c}Rb(e+464|0,0,80);o:{if(!(w[e+888|0]|w[e+889|0]<<8|(w[e+890|0]<<16|w[e+891|0]<<24))){break o}d=w[e+888|0]|w[e+889|0]<<8|(w[e+890|0]<<16|w[e+891|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){if(!f){break o}v[114578]=0;Q(775,b|0,e+464|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break o}}g=P()|0;O()|0;break f}v[114578]=0;U(776,e+456|0,b|0,w[e+855|0]);d=v[114578];v[114578]=0;if((d|0)!=1){ia=Bf(e+456|0);d=x[e+456>>1];if((d-1&65535)>>>0>126){break c}u[a+480188>>1]=d;f=jb-16|0;jb=f;J=e+440|0;d=J;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(815,d+8|0,f+12|0,f+8|0)|0;d=v[114578];v[114578]=0;p:{if((d|0)!=1){jb=f+16|0;break p}break a}q:{if(w[e+880|0]|w[e+881|0]<<8|(w[e+882|0]<<16|w[e+883|0]<<24)){d=w[e+880|0]|w[e+881|0]<<8|(w[e+882|0]<<16|w[e+883|0]<<24);v[114578]=0;Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=w[e+827|0];v[114578]=0;W(777,b|0,J|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break q}}g=P()|0;O()|0;break g}if(w[e+827|0]){break d}}d=w[e+827|0];u[a+480192>>1]=d;u[a+480190>>1]=d;g=1;ja=1;if(w[e+855|0]>=2){ja=t[e+808|0]>-1;d=x[a+480192>>1]}if(d&65535){ka=c&2;z=!ja;F=e+80|2;A=e+80|7;I=e+80|6;K=e+80|5;Y=e+80|4;C=e+56|4;s=1;D=1;while(1){v[114578]=0;d=D&65535;i=W(456,a|0,s&65535,d|0)|0;f=v[114578];v[114578]=0;r:{s:{t:{u:{if((f|0)!=1){if(!i){break e}k=v[((g<<2)+a|0)+900380>>2];v[114578]=0;u[e+60>>1]=0;v[e+56>>2]=0;G=T(277,e+152|0)|0;f=v[114578];v[114578]=0;v:{w:{x:{y:{if((f|0)!=1){f=g-1|0;i=Pb(J,f);z:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break z}f=Pb(J,f);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114578]=0;i=Q(256,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}if(!i){break z}v[114578]=0;Q(778,b|0,e+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}f=w[e+56|0]|w[e+57|0]<<8|(w[e+58|0]<<16|w[e+59|0]<<24);v[114578]=0;U(343,e+80|0,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24));f=v[114578];v[114578]=0;if((f|0)==1){break s}Wd(G,e+80|0);Bb(e+80|0)}i=w[C+1|0]&15;_=(w[C|0]|w[C+1|0]<<8)&128;if(!_){break y}v[114578]=0;R(779,k|0,0);f=v[114578];v[114578]=0;na=1;if((f|0)!=1){break x}break s}g=P()|0;O()|0;break g}if(i>>>0>=7){break x}f=w[i+14806|0];if(!i){i=f;break u}u[a+480190>>1]=(x[a+480190>>1]+f|0)-1;M=k+108|0;p=k+236|0;m=f-2|0;n=4;while(1){i=n-4|0;h=m<<3;l=i+(h+14864|0)|0;j=w[i+(h+14816|0)|0]+D|0;h=B(n,12);g=0;while(1){i=g+h|0;oa=dd(p,i),pa=j,u[oa>>1]=pa;i=fc(M,i);t[i|0]=w[i|0]+w[l|0];g=g+1|0;if((g|0)!=12){continue}break}o=1;n=n+1|0;if((n|0)!=10){continue}break}i=f;break w}f=1;if((i|0)!=7){i=1;break u}o=0;v[114578]=0;R(780,k|0,-24);f=v[114578];v[114578]=0;i=1;if((f|0)==1){break v}f=1}$=1;break t}break s}g=P()|0;O()|0;break g}o=0;if(z|_){break t}m=k+108|0;n=7;while(1){l=B(n,12);j=B(n,-12)+72|0;g=0;while(1){h=fc(m,g+l|0);t[h|0]=j+w[h|0];g=g+1|0;if((g|0)!=12){continue}break}n=n+1|0;if((n|0)!=10){continue}break}}v[114578]=0;Q(781,e+832|0,e+80|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){A:{if(!(!w[Y|0]|w[Y|0]>16)){t[k+31|0]=w[Y|0];$=1}if(!(!w[K|0]|w[K|0]>128)){t[k+30|0]=w[K|0]}B:{if(!i){break B}k=0;h=d;while(1){v[114578]=0;l=B(h,104)+a|0;R(388,l+484380|0,8);h=v[114578];v[114578]=0;if((h|0)==1){break s}h=w[I|0];v[114578]=0;t[e+408|0]=h;t[e+136|0]=64;j=Q(393,e+408|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break s}u[l+484410>>1]=w[j|0]<<2;t[l+484416|0]=w[A|0];k=k+1|0;h=k&65535;if(h>>>0>=i>>>0){break B}h=d+h|0;continue}}if(_|!ka){break r}p=ad(e+408|0,8,1,1,0);m=w[F|0]|w[F+1|0]<<8;l=w[e+80|0]|w[e+81|0]<<8;j=w[F|0]|w[F+1|0]<<8;v[114578]=0;g=T(255,G|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(w[C+1|0]&16){dA(p);g=g>>>1|0}if(w[C+1|0]&32){VB(p);g=g>>>1|0}if(w[C+1|0]&64){Vl(p,2)}g=o?(g>>>0)/((-1<<i^-1)>>>0)|0:g;if(!i){break r}k=(l<<8|l>>>8)&65535;o=k+((j<<8|j>>>8)&65535)|0;j=m<<8|m>>>8;n=0;h=d;while(1){l=B(h,104)+a|0;h=l+484380|0;v[h>>2]=g;v[114578]=0;W(402,p|0,h|0,G|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break A}k=k<<1;o=o<<1;if((j&65535)>>>0>=2){v[l+484388>>2]=o;v[l+484384>>2]=k;h=l+484414|0;u[h>>1]=x[h>>1]|2}n=n+1|0;h=n&65535;if(h>>>0>=i>>>0){break r}g=g<<1;h=d+h|0;continue}}}}}g=P()|0;O()|0;Bb(G);break g}Bb(G);D=f+D|0;s=s+1|0;g=s&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}d=e+464|4;C:{if(!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|!(w[e+472|0]|w[e+473|0]<<8)){break C}d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}if(!f){break C}d=w[e+472|0]|w[e+473|0]<<8;u[e+152>>1]=d<<8|d>>>8;d=w[e+827|0];v[114578]=0;u[e+80>>1]=d;f=Q(478,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}M=x[f>>1];if(!M){break C}I=e+152|5;p=e+152|3;z=e+152|1;f=e+88|0;m=e+80|4;d=w[e+474|0]|w[e+475|0]<<8;A=(d<<8|d>>>8)&65535;l=A>>>0<19;k=0;while(1){v[114578]=0;W(782,b|0,e+152|0,A|0)|0;d=v[114578];v[114578]=0;D:{E:{F:{if((d|0)!=1){k=k+1|0;h=v[((k<<2)+a|0)+900380>>2];if(!w[e+152|0]){break D}j=Cp(e+80|0,0,64);Cp(m,w[e+152|0]-1&65535,64);i=w[e+152|0];d=f;if(w[z|0]){i=i+(64/w[z|0]|0)|0}Cp(d,i,0);v[114578]=0;v[e+436>>2]=3;v[e+432>>2]=j;d=v[e+436>>2];v[e+8>>2]=v[e+432>>2];v[e+12>>2]=d;i=h+48|0;R(783,i|0,e+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break F}if(w[e+152|0]!=1){break E}oa=e,pa=bc(i),v[oa+80>>2]=pa;Md(e+424|0,e+80|0);v[114578]=0;Q(784,i|0,v[e+424>>2])|0;d=v[114578];v[114578]=0;if((d|0)!=1){break E}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}v[h>>2]=w[z|0]?w[z|0]<<9:32767;$=1;t[h+60|0]=w[h+60|0]|1}G:{if(l){break G}v[h+4>>2]=w[e+170|0]+1>>>1;if(A>>>0<21){break G}u[h+28>>1]=w[e+172|0]|w[e+173|0]<<8}i=B(x[dd(h+236|0,61)>>1],104)+a|0;t[i+484417|0]=w[p|0]<<4;H:{I:{if(A>>>0>=15){d=w[e+162|0]|w[e+163|0]<<8|(w[e+164|0]<<16|w[e+165|0]<<24);v[i+484384>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=w[e+166|0]|w[e+167|0]<<8|(w[e+168|0]<<16|w[e+169|0]<<24);h=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=w[e+162|0]|w[e+163|0]<<8|(w[e+164|0]<<16|w[e+165|0]<<24);v[i+484388>>2]=h+(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));break I}if(A>>>0<6){break H}}if(t[I|0]&1){d=i+484414|0;u[d>>1]=x[d>>1]|2}if(w[I|0]&8){d=i+484414|0;u[d>>1]=x[d>>1]|6}if(!(w[I|0]&4)){break H}u[i+484412>>1]=0}if((k|0)!=(M|0)){continue}break}}if(!(w[e+484|0]|w[e+485|0]<<8|(w[e+486|0]<<16|w[e+487|0]<<24))|!(w[e+488|0]|w[e+489|0]<<8)){break j}d=w[e+484|0]|w[e+485|0]<<8|(w[e+486|0]<<16|w[e+487|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}if(!f){break j}d=w[e+488|0]|w[e+489|0]<<8;u[e+152>>1]=d<<8|d>>>8;d=w[e+827|0];v[114578]=0;u[e+80>>1]=d;f=Q(478,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){j=x[f>>1];if(!j){break j}d=w[e+490|0]|w[e+491|0]<<8;i=(d<<8|d>>>8)&65535;h=0;J:while(1){K:{v[114578]=0;W(785,b|0,e+152|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break k}v[114578]=0;U(786,e+56|0,2,e+152|0);d=v[114578];v[114578]=0;if((d|0)==1){break l}v[114578]=0;R(417,e+80|0,e+56|0);d=v[114578];v[114578]=0;if((d|0)==1){break l}h=h+1|0;l=((h<<2)+a|0)+900380|0;d=v[l>>2];v[114578]=0;Q(371,d+492|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}yb(e+80|0);d=v[l>>2];v[114578]=0;R(787,e+80|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break n}oa=e,pa=vn(e+80|0),v[oa+56>>2]=pa;oa=e,pa=Hi(e+80|0),v[oa+408>>2]=pa;while(1){v[114578]=0;f=Q(788,e+56|0,e+408|0)|0;d=v[114578];v[114578]=0;L:{if((d|0)!=1){if(f){break L}Ap(e+80|0);if((h|0)!=(j|0)){continue J}break j}break K}v[114578]=0;f=T(789,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){p=v[l>>2];d=v[p+520>>2];m=(x[f>>1]<<5)+a|0;f=m+946328|0;v[f>>2]=v[p+516>>2];v[f+4>>2]=d;d=v[p+512>>2];f=m+946320|0;v[f>>2]=v[p+508>>2];v[f+4>>2]=d;d=v[p+504>>2];f=m+946312|0;v[f>>2]=v[p+500>>2];v[f+4>>2]=d;d=v[p+496>>2];f=m+946304|0;v[f>>2]=v[p+492>>2];v[f+4>>2]=d;st(e+56|0);continue}break}}break}g=P()|0;O()|0;Ap(e+80|0);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;yb(e+80|0);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}v[114578]=0;Z(634,a+901404|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}f=a+901692|0;d=w[14912]|w[14913]<<8|(w[14914]<<16|w[14915]<<24);t[f|0]=d;t[f+1|0]=d>>>8;t[f+2|0]=d>>>16;t[f+3|0]=d>>>24;t[a+901696|0]=w[14916];Jc(b);la=a+484360|0;M:{N:{O:{P:{Q:{R:{S:{if(!w[ia|0]){break S}Y=c&1;N=a+484344|0;ba=a+1304424|0;k=a+1304400|0;_=e+152|1;q=e+152|4;c=e+32|4;C=e+32|2;G=e+72|2;ka=e+72|3;H=e+544|2;while(1){v[114578]=0;X(790,b|0,e+856|0,e+464|0,e+544|0);d=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{if((d|0)==1){break $}i=ma&255;if(i){v[114578]=0;f=T(486,la|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break $}if((f|0)==255){break e}}r=Di(la,i);i=jb-16|0;jb=i;f=i+8|0;j=jb-16|0;jb=j;v[114578]=0;E=e+408|0;h=E;T(816,h+4|0)|0;d=v[114578];v[114578]=0;aa:{if((d|0)!=1){v[114578]=0;v[j+12>>2]=0;W(817,h+8|0,j+12|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break aa}break a}break a}oa=h,pa=hc(h),v[oa>>2]=pa;jb=j+16|0;jb=i+16|0;Xp(r);if(w[e+855|0]>1){break Z}d=w[H|0]|w[H+1|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>256|x[a+480188>>1]>16){break X}iR(e+152|0,e+544|0);d=w[H|0]|w[H+1|0]<<8;v[114578]=0;ea(791,r|0,e+152|0,(d<<8|d>>>8)&65535,65535,65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Y}oa=e,pa=bc(r),v[oa+152>>2]=pa;oa=e,pa=cc(r),v[oa+80>>2]=pa;if(Jb(e+152|0,e+80|0)){break _}break V}g=P()|0;O()|0;break g}while(1){d=v[e+152>>2];u[d>>1]=x[d>>1]+ca;te(e+152|0);if(Jb(e+152|0,e+80|0)){continue}break}break V}iR(e+152|0,e+544|0);if(!(w[e+164|0]|w[e+165|0]<<8)){break X}d=w[e+164|0]|w[e+165|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>64|x[a+480188>>1]>64){break X}j=w[e+172|0]|w[e+173|0]<<8|(w[e+174|0]<<16|w[e+175|0]<<24);if(!(w[e+176|0]|w[e+177|0]<<8)){o=32;break W}d=w[e+176|0]|w[e+177|0]<<8;v[114578]=0;u[e+80>>1]=d<<8|d>>>8;u[e+56>>1]=800;f=Q(478,e+80|0,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=x[f>>1];v[114578]=0;o=Gg(752,((d<<5)+50>>>0)/100|0,0);d=v[114578];v[114578]=0;if((d|0)!=1){break W}}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}zp(E);break e}d=w[e+160|0]|w[e+161|0]<<8|(w[e+162|0]<<16|w[e+163|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;ba:{if((d|0)==1){break ba}ca:{if(!f){break ca}g=0;if(!x[a+480188>>1]){break ca}da:{while(1){ea:{v[114578]=0;f=T(389,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ea}v[114578]=0;t[e+80|0]=f;t[e+56|0]=64;f=Q(393,e+80|0,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break da}u[((g<<5)+a|0)+480286>>1]=w[f|0];g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break ca}break}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}fa:{ga:{if(!(w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24))){break ga}d=w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break ba}if(!f){break ga}g=0;if(!x[a+480188>>1]){break fa}while(1){ha:{v[114578]=0;f=T(792,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ha}oa=((g<<5)+a|0)+480284|0,pa=(Yb(f,-16,16)<<3)+128|0,u[oa>>1]=pa;g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break fa}break}g=P()|0;O()|0;break M}v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break ba}}f=jb-16|0;jb=f;m=e+136|0;d=m;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(818,d+8|0,f+12|0,f+8|0)|0;d=v[114578];v[114578]=0;ia:{if((d|0)!=1){jb=f+16|0;break ia}break a}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;ja:{ka:{la:{ma:{na:{if((d|0)==1){break na}h=1;g=0;if(!f){break ja}d=w[H|0]|w[H+1|0]<<8;v[114578]=0;f=Q(258,b|0,((d<<8|d>>>8)&65535)<<1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break na}if(!f){break ja}d=w[H|0]|w[H+1|0]<<8;v[114578]=0;f=W(793,b|0,m|0,(d<<8|d>>>8)&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break na}if(!f){break ja}oa=e,pa=bc(m),v[oa+32>>2]=pa;oa=e,pa=cc(m),v[oa+128>>2]=pa;if(!Jb(e+32|0,e+128|0)){break ka}while(1){d=w[e+166|0]|w[e+167|0]<<8;f=(d<<8|d>>>8)&65535;d=v[e+32>>2];d=w[d|0]|w[d+1|0]<<8;d=(d<<8|d>>>8)&65535;oa:{if(f>>>0<d>>>0){break oa}f=w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24);v[114578]=0;Q(256,b|0,(f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))+(d<<2)|0)|0;d=v[114578];v[114578]=0;pa:{qa:{ra:{sa:{ta:{if((d|0)==1){break ta}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}if(!f){break oa}v[114578]=0;f=Q(258,b|0,42)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}if(!f){break oa}v[114578]=0;Q(794,b|0,e+80|0)|0;d=v[114578];v[114578]=0;ua:{if((d|0)!=1){if(md(r)){break ua}v[114578]=0;R(795,r|0,65534);d=v[114578];v[114578]=0;if((d|0)!=1){break ua}}g=P()|0;O()|0;break la}d=w[e+120|0]|w[e+121|0]<<8;v[114578]=0;d=(d<<8|d>>>8)&65535;v[e+76>>2]=d;f=Q(258,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break sa}if(!f){v[114578]=0;f=T(332,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break sa}Cc(e+76|0,f)}Cc(e+76|0,65534);l=oc(r);v[114578]=0;R(796,r|0,l+v[e+76>>2]|0);d=v[114578];v[114578]=0;if((d|0)==1){break qa}h=0;if(!v[e+76>>2]){break ra}while(1){va:{v[114578]=0;f=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break va}d=f<<16>>16;if((d|0)>=0){v[114578]=0;R(795,r|0,d+ca&65535);d=v[114578];v[114578]=0;if((d|0)==1){break va}}h=h+1|0;if(h>>>0<y[e+76>>2]){continue}break ra}break}g=P()|0;O()|0;break la}g=P()|0;O()|0;break la}g=P()|0;O()|0;break la}wa:{if(!w[e+80|0]){break wa}v[114578]=0;U(6,e+56|0,2,e+80|0);d=v[114578];v[114578]=0;xa:{if((d|0)!=1){v[114578]=0;R(487,r|0,e+56|0);d=v[114578];v[114578]=0;if((d|0)==1){break xa}yb(e+56|0);break wa}g=P()|0;O()|0;break la}g=P()|0;O()|0;yb(e+56|0);break la}if(!(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24))){break oa}d=w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){break pa}}g=P()|0;O()|0;break la}if(!f){break oa}while(1){ya:{v[114578]=0;f=Q(797,b|0,e+72|0)|0;d=v[114578];v[114578]=0;za:{Aa:{if((d|0)!=1){if(!f){break oa}d=w[ka|0];v[114578]=0;U(343,e+56|0,b|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break Aa}d=w[e+72|0]|w[e+73|0]<<8;v[114578]=0;f=T(798,l+((d<<8|d>>>8)&65535)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ma}u[e+54>>1]=f;if((w[e+72|0]|w[e+73|0]<<8)==65535){break ya}d=x[e+54>>1];if(oc(r)>>>0>d>>>0){break za}Bb(e+56|0);break oa}g=P()|0;O()|0;break la}g=P()|0;O()|0;break la}Ba:{if(w[G|0]==1){d=65535}else{if(w[G|0]!=2){break Ba}v[114578]=0;i=T(485,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ma}v[114578]=0;f=Q(799,E|0,e+54|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ma}u[f>>1]=i;d=65534}oa=rc(r,x[e+54>>1]),pa=d,u[oa>>1]=pa}Bb(e+56|0);continue}break}Bb(e+56|0)}te(e+32|0);if(Jb(e+32|0,e+128|0)){continue}break}break ka}g=P()|0;O()|0;break la}g=P()|0;O()|0;Bb(e+56|0)}gR(m);break M}h=0;g=1}gR(m);if(g){h=o>>>(j>>>25&1)|0;break U}zp(E);if(!h){break e}break T}g=P()|0;O()|0;break M}v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;Ca:{if((d|0)!=1){g=0;h=32;if(!x[a+480188>>1]){break U}while(1){d=w[(e+g|0)+810|0];v[114578]=0;t[e+152|0]=d;t[e+80|0]=64;f=Q(393,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ca}u[((g<<5)+a|0)+480286>>1]=w[f|0];g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break}break U}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}j=w[e+807|0];d=w[e+804|0]|w[e+805|0]<<8;z=w[e+807|0]&64;F=w[e+808|0]&32;n=(w[e+808|0]&31)+1|0;oa=a,pa=fR((d<<8|d>>>8)&65535,z>>>6|0,F>>>5|0,n),v[oa+480204>>2]=pa;oa=a,pa=Fd(w[e+809|0],1,32),v[oa+480196>>2]=pa;if(F){v[a+480216>>2]=n;v[a+480220>>2]=n<<2}Da:{Ea:{if(w[e+826|0]){d=w[e+826|0];v[114578]=0;t[e+152|0]=d;t[e+80|0]=64;f=Q(393,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ea}v[a+480200>>2]=w[f|0]<<2}v[a+480228>>2]=h;v[a+480232>>2]=h;v[a+480208>>2]=v[a+480208>>2]&-3|(w[e+807|0]>>>4^-1)&2;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(w[e+508|0]|w[e+509|0]<<8|(w[e+510|0]<<16|w[e+511|0]<<24))){break Qa}d=w[e+508|0]|w[e+509|0]<<8|(w[e+510|0]<<16|w[e+511|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Qa}d=w[e+512|0]|w[e+513|0]<<8|(w[e+514|0]<<16|w[e+515|0]<<24);v[114578]=0;W(482,b|0,k|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(w[ia|0]<2){break Qa}v[114578]=0;U(13,e+152|0,2,k|0);d=v[114578];v[114578]=0;if((d|0)==1){break Oa}v[114578]=0;R(487,r|0,e+152|0);d=v[114578];v[114578]=0;if((d|0)==1){break Na}yb(e+152|0)}d=w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24);Ra:{if((d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))>>>0<2){break Ra}d=w[e+476|0]|w[e+477|0]<<8|(w[e+478|0]<<16|w[e+479|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Ra}d=w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24);v[114578]=0;aa(584,ba|0,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))-1|0,4)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}}if(!(w[e+520|0]|w[e+521|0]<<8|(w[e+522|0]<<16|w[e+523|0]<<24))){break Da}d=w[e+520|0]|w[e+521|0]<<8|(w[e+522|0]<<16|w[e+523|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Da}v[114578]=0;f=Q(258,b|0,12)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Da}v[114578]=0;Q(340,b|0,6)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}v[114578]=0;f=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if((f|0)!=1){break Da}v[114578]=0;i=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break La}if(!i){break Da}v[114578]=0;f=Q(258,b|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break La}if(f){break Ma}break Da}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}g=P()|0;O()|0;yb(e+152|0);break M}td(e+152|0,ba);v[114578]=0;aa(584,ba|0,b|0,i|0,4)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ga}if(!Wc(e+152|0)){v[114578]=0;f=W(800,e+56|0,2,13)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ka}v[114578]=0;U(801,e+80|0,e+152|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ja}v[114578]=0;U(802,e+40|0,e+80|0,ba|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ia}Gb(ba,e+40|0);yb(e+40|0);yb(e+80|0);yb(f)}yb(e+152|0);break Da}g=P()|0;O()|0;break M}g=P()|0;O()|0;break Fa}g=P()|0;O()|0;break Ha}g=P()|0;O()|0;yb(e+80|0)}yb(f);break Fa}g=P()|0;O()|0}yb(e+152|0);break M}g=P()|0;O()|0;break M}Sa:{if(!(w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24))|w[e+855|0]<2){break Sa}o=0;if(!x[a+480188>>1]){break Sa}while(1){d=w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24);v[114578]=0;f=Q(256,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+(o<<2)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}Ta:{if(!f){break Ta}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}h=0;i=0;if(!f){break Ta}while(1){Ua:{v[114578]=0;f=Q(258,b|0,8)|0;d=v[114578];v[114578]=0;Va:{Wa:{Xa:{if((d|0)!=1){if(!f){break Ua}v[114578]=0;Q(803,b|0,e+152|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Xa}if(!(w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24))){break Ua}d=(w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24))&-225;switch((d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))-1|0){case 1:break Va;case 0:break Wa;default:continue}}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);h=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);continue}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);continue}break}if(!h|!i){break Ta}v[114578]=0;f=Q(256,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break O}if(!f){break Ta}v[114578]=0;W(635,b|0,((o<<5)+a|0)+480289|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break O}}o=o+1|0;if(o>>>0<x[a+480188>>1]){continue}break}}f=w[e+544|0]|w[e+545|0]<<8;v[114578]=0;s=f<<8|f>>>8;R(403,N|0,ca+s&65535);d=v[114578];v[114578]=0;Ya:{if((d|0)==1){break Ya}Za:{if(f){A=j&16;I=ca&65535;d=s&65535;M=d>>>0>1?d:1;i=0;while(1){_a:{if(!Y){break _a}d=w[e+872|0]|w[e+873|0]<<8|(w[e+874|0]<<16|w[e+875|0]<<24);v[114578]=0;f=Q(256,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+(i<<2)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Za}if(!f){break _a}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Za}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Za}if(!f){break _a}da=Wb(e+136|0);v[114578]=0;ga=T(277,e+80|0)|0;d=v[114578];v[114578]=0;$a:{ab:{if((d|0)!=1){l=w[e+855|0];if(l){break ab}v[114578]=0;Q(804,b|0,e+152|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}u[e+128>>1]=w[e+152|0];ha=w[_|0]+1|0;d=48;break $a}g=P()|0;O()|0;break P}j=t[e+806|0];v[114578]=0;Q(805,b|0,e+32|0)|0;d=v[114578];v[114578]=0;bb:{cb:{if((d|0)!=1){d=w[e+32|0]|w[e+33|0]<<8;u[e+128>>1]=d<<8|d>>>8;d=w[C|0]|w[C+1|0]<<8;ha=((d<<8|d>>>8)&65535)+1|0;d=c;if(!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break bb}h=v[b+8>>2];d=w[c|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;Q(806,b|0,e+152|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}if(!f){break cb}d=w[e+160|0]|w[e+161|0]<<8|(w[e+162|0]<<16|w[e+163|0]<<24);v[114578]=0;W(482,b|0,da|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){break cb}break Q}break Q}db:{if(!(w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24))){break db}d=w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}if(!f){break db}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}if(!f){break db}v[114578]=0;U(343,e+56|0,b|0,B(x[e+128>>1],ha)|0);d=v[114578];v[114578]=0;if((d|0)==1){break Q}Wd(ga,e+56|0);Bb(e+56|0)}v[114578]=0;Q(256,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}}d=j+(l>>>0<3?48:24)|0}v[114578]=0;j=i+I|0;h=W(404,N|0,j&65535,ha|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Q}if(h){K=_b(N,j);v[114578]=0;Q(496,K|0,da|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Q}jg(e+128|0,x[a+480188>>1]);D=0;while(1){v[114578]=0;g=W(472,K|0,D|0,0)|0;f=v[114578];v[114578]=0;eb:{fb:{if((f|0)!=1){o=0;if(x[e+128>>1]){break fb}break eb}break Q}while(1){gb:{if(!w[e+855|0]){v[114578]=0;R(807,e+152|0,b|0);f=v[114578];v[114578]=0;if((f|0)!=1){j=cd(e+152|0);f=Bf(e+152|0);h=w[e+152|0];t[g+1|0]=h>>>3&16|w[j|0]>>>4|h>>>1&32;t[g+3|0]=w[j|0]&15;t[g+5|0]=w[f|0];f=h&63;h=f?f+d|0:0;break gb}break Q}v[114578]=0;R(595,e+152|0,b|0);f=v[114578];v[114578]=0;hb:{ib:{if((f|0)!=1){p=cd(e+152|0);m=Bf(e+152|0);l=Rh(e+152|0);v[114578]=0;h=T(389,ga|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Q}t[g+4|0]=h;j=w[e+152|0];f=j&127;if(!f){break ib}h=d+f|0;break hb}break Q}h=0;if((j|0)!=128){break hb}t[g|0]=254}t[g+1|0]=w[p|0]&63;t[g+3|0]=w[m|0];t[g+5|0]=w[l|0]}if(h-1>>>0<=119){t[g|0]=h}v[114578]=0;fa(808,g|0,(z|0)!=0|0,(F|0)!=0|0,n|0,(A|0)!=0|0);f=v[114578];v[114578]=0;if((f|0)!=1){$=(h|0)>84&ja|$;g=g+6|0;o=o+1|0;if(x[e+128>>1]<=(o&65535)>>>0){break eb}continue}break}break Q}D=D+1|0;if((ha|0)!=(D|0)){continue}break}}Bb(ga);yb(da)}i=i+1|0;if((M|0)!=(i|0)){continue}break}}oa=e,pa=vn(E),v[oa+80>>2]=pa;oa=e,pa=Hi(E),v[oa+56>>2]=pa;jb:{while(1){v[114578]=0;f=Q(809,e+80|0,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break R}kb:{lb:{mb:{nb:{ob:{pb:{if(!f){if(!(w[e+464|0]|w[e+465|0]<<8|(w[e+466|0]<<16|w[e+467|0]<<24))){break pb}d=w[e+464|0]|w[e+465|0]<<8|(w[e+466|0]<<16|w[e+467|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ya}if(!f){break pb}ca=s+ca|0;zp(E);break T}v[114578]=0;h=T(810,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ob}d=x[h>>1];if(!d){g=0;break nb}v[114578]=0;f=Q(546,r|0,d-1&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break kb}g=x[h>>1];if(!f){break nb}v[114578]=0;g=Q(811,r|0,g-1&65535)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break mb}break kb}zp(E);break S}g=P()|0;O()|0;break M}if(x[h+2>>1]==(g+1|0)){break lb}v[114578]=0;g=W(812,N|0,1,0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break kb}if((g|0)==65535){break lb}oa=rc(r,x[h>>1]),pa=g,u[oa>>1]=pa}i=_b(N,g);d=x[h+2>>1];v[114578]=0;f=T(813,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jb}v[114578]=0;f=W(498,e+152|0,12,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jb}d=Gn(Ne(f,v[_b(N,g)+12>>2]-1|0));v[114578]=0;Q(499,i|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jb}s=(s&65535)>>>0>g>>>0?s:g+1|0}v[114578]=0;T(814,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}break R}break}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}ma=ma+1|0;if(w[ia|0]>(ma&255)>>>0){continue}break}}v[114578]=0;R(489,la|0,0);b=v[114578];v[114578]=0;if((b|0)!=1){if(!($&1)){k=x[a+480192>>1];if(k){g=1;while(1){c=(((g&65535)<<2)+a|0)+900380|0;b=v[c>>2];if(b){Xb(rt(b));k=x[a+480192>>1]}v[c>>2]=0;g=g+1|0;if((g&65535)>>>0<=(k&65535)>>>0){continue}break}}u[a+480192>>1]=0}qb:{rb:{sb:{tb:{ub:{vb:{wb:{if(na){v[114578]=0;c=Q(2,e+152|0,14917)|0;b=v[114578];v[114578]=0;if((b|0)==1){break wb}v[114578]=0;U(646,a|0,2,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break vb}yb(c)}k=14964;switch(w[e+855|0]){case 3:break rb;case 2:break sb;case 1:break tb;case 0:break ub;default:break qb}}g=P()|0;O()|0;break g}g=P()|0;O()|0;yb(c);break g}k=x[a+480188>>1]>4?14965:14986;break qb}k=15e3;break qb}k=15018;break qb}k=15036}v[114578]=0;c=Q(2,e+16|0,15063)|0;b=v[114578];v[114578]=0;xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){v[114578]=0;R(219,e+80|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break Bb}v[114578]=0;U(537,e+152|0,e+80|0,e+855|0);b=v[114578];v[114578]=0;if((b|0)==1){break Ab}Gb(a+1304436|0,e+152|0);yb(e+152|0);Ib(e+80|0);yb(c);v[114578]=0;c=Q(2,e+152|0,15079)|0;b=v[114578];v[114578]=0;if((b|0)==1){break yb}Gb(a+1304448|0,c);yb(c);v[114578]=0;Q(238,a+1304460|0,k|0)|0;b=v[114578];v[114578]=0;g=1;if((b|0)==1){break xb}v[a+1304496>>2]=2;break d}g=P()|0;O()|0;break g}g=P()|0;O()|0;break zb}g=P()|0;O()|0;Ib(e+80|0)}yb(c);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break M}g=P()|0;O()|0;Bb(ga)}yb(da);break M}g=P()|0;O()|0;break M}g=P()|0;O()|0}zp(E);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0}cR(J)}Bb(e+832|0);S(g|0);L()}g=0}cR(J)}Bb(e+832|0)}jb=e+912|0;return g|0}V(0)|0;O()|0;Ab();L()}function Cs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,za=0,Aa=0,Ba=0,Ca=0,Da=0;i=jb-176|0;jb=i;e=jb-16|0;jb=e;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[e+12>>2]=0;W(1373,a+8|0,e+12|0,e+8|0)|0;h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){jb=e+16|0;break b}break a}n=i+144|0;t[n+26|0]=0;u[n+24>>1]=0;v[n+16>>2]=0;v[n+20>>2]=-1;v[n+8>>2]=-1;v[n+12>>2]=-1;v[n>>2]=0;v[n+4>>2]=0;M=v[d+16>>2];ba=w[d+6|0];ka=b+484360|0;if(ba>>>0>=Mh(ka)>>>0){ba=w[ka+16|0]}la=a;D=Di(ka,ba);v[114578]=0;q=Q(1333,i+104|0,b|0)|0;a=v[114578];v[114578]=0;c:{if((a|0)!=1){h=v[q+4>>2];v[114578]=0;Y=W(1334,i+72|0,b|0,ba|0)|0;a=v[114578];v[114578]=0;d:{if((a|0)!=1){e:{f:{f=x[d+4>>1];g:{if(f>>>0>=oc(D)>>>0){break g}while(1){v[114578]=0;a=Q(546,D|0,f&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}if(a){break g}v[d>>2]=0;f=f+1|0;u[d+4>>1]=f;if(oc(D)>>>0>(f&65535)>>>0){continue}break}}a=v[d>>2];v[h+52>>2]=a;v[h+48>>2]=a;v[n+16>>2]=a;u[h+64>>1]=f;u[h+62>>1]=f;u[n+24>>1]=f;J=i- -64|0;Qf(J);qa=Dt(i+56|0);h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{ra=c&7;ta=(ra|0)!=7;s:{if(ta){break s}v[114578]=0;W(1335,J|0,1,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,2,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,3,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,28,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,35,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,37,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,36,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1335,J|0,38,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1336,qa|0,12,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;W(1336,qa|0,13,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break r}e=q+20|0;if(x[b+480188>>1]){f=0;while(1){if(w[((f<<5)+b|0)+480281|0]&4){Aa=Rc(e,f),Ba=-1,v[Aa+16>>2]=Ba}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}if((M|0)!=2){break s}a=x[d+12>>1];if(oc(D)>>>0<=a>>>0){break s}a=x[rc(D,a)>>1];v[114578]=0;l=b+484344|0;g=Q(444,l|0,a|0)|0;E=v[114578];v[114578]=0;if((E|0)==1){break h}if(!g){break s}g=_b(l,a);E=v[d+8>>2];v[114578]=0;g=Q(1337,g|0,E|0)|0;z=v[114578];v[114578]=0;if((z|0)==1){break h}if(!g){break s}g=0;a=_b(l,a);v[114578]=0;f=W(472,a|0,E|0,0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break i}if(!x[b+480188>>1]){break s}while(1){t:{u:{v:{switch(w[f|0]-253|0){case 0:if(x[b+480192>>1]){break u}break;case 1:case 2:break u;default:break v}}v[114578]=0;a=T(553,f|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}if(!a){break t}if(Ds(f)){break t}}Aa=Rc(e,g),Ba=-1,v[Aa+16>>2]=Ba}f=f+6|0;g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break}}$=h- -64|0;H=h+48|0;_=h+68|0;va=h+44|0;sa=q+8|0;ca=c&1;p=q+20|0;s=b+1074312|0;I=b+484344|0;wa=(M|0)!=3;ua=(M|0)!=2;E=0;while(1){v[h+48>>2]=v[h+52>>2];a=x[h+64>>1];u[h+62>>1]=a;v[114578]=0;a=Q(546,D|0,a|0)|0;e=v[114578];v[114578]=0;w:{if((e|0)!=1){x:{if(!a){break x}if(y[h+48>>2]<y[_b(I,x[rc(D,x[h+62>>1])>>1])+12>>2]){break x}v[H>>2]=0;Eb(i,s,63);if(Cb(i)){a=v[h+56>>2];v[h+56>>2]=0;v[h+48>>2]=a}a=x[h+64>>1]+1|0;u[h+62>>1]=a;u[h+64>>1]=a}if(!(A[q+32>>3]>=A[d+8>>3])|wa){break w}break l}a=P()|0;O()|0;break e}e=x[h+62>>1];a=h;y:{if(oc(D)>>>0>e>>>0){e=x[rc(D,x[h+62>>1])>>1];break y}e=65535}u[a+60>>1]=e;v[114578]=0;a=Q(444,I|0,e&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}if(!(x[h+62>>1]==x[d+12>>1]?x[h+60>>1]==65535|ua|a:1)){break l}z:{if(x[h+60>>1]<Ce(I)>>>0){break z}while(1){a=h;z=a;A:{B:{if(x[a+60>>1]!=65535){e=x[h+62>>1];if(oc(D)>>>0>e>>>0){break B}}if(x[D+28>>1]==x[h+62>>1]){break z}e=x[D+28>>1];break A}e=x[h+62>>1]+1|0}u[z+62>>1]=e;a=h;C:{if(oc(D)>>>0>(e&65535)>>>0){e=x[rc(D,x[h+62>>1])>>1];break C}e=65535}u[a+60>>1]=e;u[h+64>>1]=x[h+62>>1];v[114578]=0;a=Q(444,I|0,e&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}D:{if(a){break D}a=x[h+62>>1];v[114578]=0;a=aa(1338,Y|0,a|0,0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!a){break D}if(M>>>0<=1){a=x[h+62>>1];v[n+8>>2]=0;u[n+20>>1]=a;if(!M){break z}}v[114578]=0;a=aa(1339,Y|0,$|0,H|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}if(!a){break z}A[n>>3]=A[q+32>>3];v[114578]=0;R(1340,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[$>>1];v[114578]=0;Z(1341,q|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}a=x[h+64>>1];u[h+62>>1]=a;Aa=h,Ba=x[rc(D,a)>>1],u[Aa+60>>1]=Ba;v[h+52>>2]=v[h+48>>2];break z}if(x[h+60>>1]>=Ce(I)>>>0){continue}break}}if(x[$>>1]==65535){break k}a=x[h+60>>1];v[114578]=0;a=Q(444,I|0,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}if(!a){if(x[D+28>>1]==x[h+62>>1]){if(!M){break k}v[114578]=0;a=aa(1339,Y|0,$|0,H|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}if(!a){break k}A[n>>3]=A[q+32>>3];v[114578]=0;R(1340,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[$>>1];v[114578]=0;Z(1341,q|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[h+52>>2]=v[h+48>>2];continue}u[h+64>>1]=x[h+62>>1]+1;continue}if(y[h+48>>2]>=y[_b(I,x[h+60>>1])+12>>2]){v[H>>2]=0}a=x[h+62>>1];if(!(v[H>>2]==v[d+8>>2]?(a|0)!=x[d+12>>1]|ua:1)){break l}e=v[H>>2];v[114578]=0;a=aa(1338,Y|0,a|0,e|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}if(a){if(M>>>0<=1){u[n+20>>1]=x[h+62>>1];v[n+8>>2]=v[h+48>>2];if(!M){break k}}v[114578]=0;a=aa(1339,Y|0,$|0,H|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}if(!a){break k}A[n>>3]=A[q+32>>3];v[114578]=0;R(1340,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[$>>1];v[114578]=0;Z(1341,q|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[h+52>>2]=v[h+48>>2];continue}u[n+22>>1]=x[h+62>>1];a=v[h+48>>2];v[n+12>>2]=a;v[h+52>>2]=a+1;E:{F:{if(a>>>0>=y[_b(I,x[h+60>>1])+12>>2]){v[H>>2]=0;break F}if(v[H>>2]){break E}}f=0;if(!x[b+480188>>1]){break E}while(1){G=A[q+32>>3];Aa=Rc(p,f),Ca=G,A[Aa>>3]=Ca;a=v[h>>2];Aa=Rc(p,f),Ba=a,v[Aa+8>>2]=Ba;f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}a=_b(I,x[h+60>>1]);e=v[h+48>>2];v[114578]=0;f=W(472,a|0,e|0,0)|0;a=v[114578];v[114578]=0;G:{H:{I:{if((a|0)!=1){g=0;K=0;da=0;if(!x[b+480188>>1]){break H}while(1){J:{Eb(i,s,77);K:{if(Aa=Cb(i),Ba=0,Da=v[((g<<5)+b|0)+480280>>2]&1024,Da?Aa:Ba){break K}v[114578]=0;a=T(1342,f|0)|0;e=v[114578];v[114578]=0;L:{M:{N:{if((e|0)==1){break N}if(a){O:{if(!ca){break O}a=w[f+1|0];if(a-251>>>0<5|!a){break O}v[114578]=0;a=T(1343,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break N}v[114578]=0;e=T(1344,f|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break J}u[i+48>>1]=e;t[i|0]=w[f+1|0];u[i+2>>1]=x[i+48>>1];v[114578]=0;e=Q(1345,sa|0,i|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break J}u[e>>1]=a}gt((B(g,896)+h|0)+1418|0);break K}a=B(g,896)+h|0;e=a+1422|0;l=w[f+4|0]|w[f+5|0]<<8;t[e|0]=l;t[e+1|0]=l>>>8;a=a+1418|0;e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;P:{switch(w[f+3|0]-16|0){case 0:a=w[f+5|0];v[114578]=0;U(1346,b|0,h|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break N}break K;case 3:break L;case 4:break M;case 1:break P;default:break K}}Eb(i,s,5);if(!Cb(i)){break K}a=w[f+5|0];if(!a){break K}v[114578]=0;U(1346,b|0,h|0,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){break K}}a=P()|0;O()|0;break e}a=w[f+5|0];e=a&240;if((e|0)==96){da=(a&15)+da|0;break K}if((e|0)!=224|K){break K}a=w[f+5|0]&15;if(v[b+480180>>2]&2){K=0;if(!a){break K}}K=a+1|0;break K}a=w[f+5|0];if((a&240)!=224){break K}K=(a&15)+1|0}f=f+6|0;g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break I}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}g=da;if(K){break G}}K=1;da=g}F=B(v[h+40>>2]+da|0,K);g=0;Q:{if(!x[b+480188>>1]){l=0;na=0;oa=0;fa=0;ga=0;break Q}N=F-1|0;z=F-K|0;ha=B(z,1e4);ga=0;fa=0;oa=0;na=0;l=0;R:{while(1){S:{f=0;k=B(g,896)+h|0;a=k+1418|0;T:{if(w[a|0]){break T}e=a;if(w[a+1|0]|w[a+2|0]){break T}f=!w[e+3|0]}U:{if(f){break U}Eb(i,s,77);if(Aa=Cb(i),Ba=0,Da=v[((g<<5)+b|0)+480280>>2]&1024,Da?Aa:Ba){break U}f=w[k+1423|0];pa=k+1421|0;m=w[pa|0];e=w[a|0];j=k+1419|0;o=w[j|0];if(o){t[k+1429|0]=0;t[k+1433|0]=o;Aa=Rc(p,g),Ba=255,t[Aa+21|0]=Ba}v[114578]=0;o=T(553,a|0)|0;r=v[114578];v[114578]=0;if((r|0)==1){break S}if(o){t[k+1429|0]=e}v[114578]=0;r=T(553,a|0)|0;o=v[114578];v[114578]=0;if((o|0)==1){break S}o=k+608|0;V:{W:{X:{Y:{Z:{_:{if(!(w[j|0]?1:r)){break _}j=k+1433|0;r=w[j|0];if(x[b+480192>>1]){if(x[b+480192>>1]<r>>>0){break _}j=v[((w[j|0]<<2)+b|0)+900380>>2];if(!j){break _}$:{if(!(t[j+15|0]&1)){break $}r=v[j+8>>2];v[114578]=0;U(1347,o|0,r|0,b|0);r=v[114578];v[114578]=0;if((r|0)!=1){break $}a=P()|0;O()|0;break e}if(!be(e)){break _}r=x[dd(j+236|0,e-1|0)>>1]}if(!r|x[b+480190>>1]<r>>>0){break _}e=B(r,104)+b|0;if(!(w[e+484414|0]&32)){break _}e=x[e+484408>>1];v[114578]=0;U(1347,o|0,e|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break Z}}aa:{ba:{ca:{r=k+1420|0;e=w[r|0];switch(e-1|0){case 1:break X;case 2:case 3:break ba;case 0:break ca;default:break aa}}a=w[k+1422|0];Aa=Rc(p,g),Ba=a,t[Aa+21|0]=Ba;break X}a=w[k+1422|0];if(!a){break X}t[k+1462|0]=a;break X}if((e|0)==11){break Y}break X}a=P()|0;O()|0;break e}if(!w[k+1422|0]){break X}hy(i,b,a,0);a=hc(i);v[k+1384>>2]=v[i>>2];if(!w[a|0]){break X}m=0;break W}da:{switch(m-12|0){case 0:a=v[h+48>>2];e=x[h+60>>1];v[114578]=0;a=ea(1348,b|0,e|0,a|0,g&65535,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break S}v[h+56>>2]=0;u[h+64>>1]=a;if(!(v[b+480180>>2]&5?0:oa)){v[h+52>>2]=0}fa=1;if(!ca){ga=1;break U}v[k+1412>>2]=0;t[k+1469|0]=0;ga=1;break V;case 2:v[114578]=0;a=aa(1349,b|0,h|0,g&65535,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break R}if((a|0)==-1){m=14;break W}v[h+52>>2]=a;if(!ga){u[h+64>>1]=x[h+62>>1]+1}oa=1;if(!ca){break U}v[k+1412>>2]=0;t[k+1469|0]=0;break V;case 5:Eb(i,s,5);m=17;if(Cb(i)){break W}a=v[h+48>>2];e=x[h+60>>1];v[114578]=0;a=ea(1348,b|0,e|0,a|0,g&65535,0)|0;e=v[114578];v[114578]=0;ea:{fa:{if((e|0)!=1){a=B(a,1e4);if(!ca|!(v[b+480180>>2]&16777250)){break ea}if(a>>>0<1e4){break fa}t[k+1463|0]=(a>>>0)/1e4;break ea}a=P()|0;O()|0;break e}a=B(w[k+1463|0],1e4)}e=(a>>>0)/1e4|0;ga:{if(a>>>0>319999){break ga}j=B(ha,e&15);a=v[h+44>>2];if((e&240)==16){a=a+j|0;break ga}e=a-j|0;a=a>>>0<e>>>0?0:e}v[h+44>>2]=a;a=v[v[b+8>>2]+20>>2];e=v[v[b+8>>2]+24>>2];Eb(i,s,8);Yn(va,B(a,1e4),Cb(i)?255e4:B(e,1e4));break W;case 8:m=20;ha:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break W}v[k+696>>2]=v[k+696>>2]&-257|((f|0)==145)<<8;break W;case 1:t[k+1464|0]=f&15;break W;case 2:e=g;a=e;if(v[b+480180>>2]==2){e=x[b+480188>>1]-1|0;a=0}if(!(f&15)){fa=0;l=1;j=e&65535;if(j>>>0<(a&65535)>>>0){break W}while(1){G=A[q+32>>3];e=a&65535;Aa=Rc(p,e),Ca=G,A[Aa>>3]=Ca;l=v[h>>2];Aa=Rc(p,e),Ba=l,v[Aa+8>>2]=Ba;l=v[h+48>>2];Aa=Rc(p,e),Ba=l,v[Aa+12>>2]=Ba;v[(B(e,896)+h|0)+1412>>2]=v[h+48>>2];l=1;a=a+1|0;if(j>>>0>=(a&65535)>>>0){continue}break}break W}Eb(i,s,16);if(!(Cb(i)|v[b+480180>>2]==2)){fa=0;na=1;break W}na=1;fa=0;e=e&65535;if(e>>>0<(a&65535)>>>0){break W}j=v[H>>2]+1|0;while(1){v[(B(a&65535,896)+h|0)+1412>>2]=j;a=a+1|0;if(e>>>0>=(a&65535)>>>0){continue}break};break W;case 6:break ha;default:break W}}t[k+1472|0]=f&15;break W;case 7:m=19;a=f&240;if((a|0)!=240){if((a|0)!=96){break W}if(f&15){Aa=h,Ba=v[Rc(p,g)+12>>2],v[Aa+56>>2]=Ba;na=1;break W}G=A[q+32>>3];Aa=Rc(p,g),Ca=G,A[Aa>>3]=Ca;a=v[h>>2];Aa=Rc(p,g),Ba=a,v[Aa+8>>2]=Ba;a=v[h+48>>2];Aa=Rc(p,g),Ba=a,v[Aa+12>>2]=Ba;v[k+1412>>2]=v[h+48>>2];l=1;break W}t[k+1472|0]=f&15;break W;case 1:case 3:case 4:case 6:break W;default:break da}}if((m|0)!=28){break W}if((f&240)==160){Eb(i,s,58);m=28;if(Cb(i)){break W}t[k+1464|0]=f&15;break W}m=28}if(!ca){break U}ia:{ja:{ka:{la:{ma:{na:{oa:{switch(m-2|0){case 0:if(!f){break V}Eb(i,s,90);if(!Cb(i)){t[k+1440|0]=f}t[k+1439|0]=f;break V;case 1:if(!f){break V}Eb(i,s,90);if(!Cb(i)){t[k+1439|0]=f}t[k+1440|0]=f;break V;case 2:if(!f){break V}v[k+1384>>2]=f;break V;case 8:if(!f){break V}v[k+1272>>2]=f<<8;break V;case 4:case 9:if(!f){break V}t[k+1437|0]=f;break V;case 11:Aa=Rc(p,g),Ba=f,t[Aa+21|0]=Ba;break V;case 21:a=f<<(!(v[b+480180>>2]&59593760)&f<<24>>24>-1)&255;if(a>>>0<=128){v[_>>2]=a<<1;break V}if(v[b+480180>>2]&16777250){break V}v[_>>2]=256;break V;case 22:Eb(i,s,9);pa:{if(Cb(i)){a=k+1445|0;if(f){t[a|0]=f;break pa}f=w[a|0];break pa}if(f){t[h+1445|0]=f;break pa}f=w[h+1445|0]}a=_;e=f&240;j=f&15;qa:{if(!(!e|(j|0)!=15)){m=v[_>>2]+(e>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break qa}m=v[_>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(e|0)!=240)){break qa}m=v[_>>2]+B(z,(f>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(e){break qa}m=v[_>>2]-B(z,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=m;ce(_,0,256);break V;case 19:if(f>>>0>64){break V}v[k+1368>>2]=f;break V;case 20:a=k+1444|0;ra:{if(f){t[a|0]=f;break ra}f=w[a|0]}j=k+1368|0;e=v[j>>2];a=f;m=a&240;f=a&15;sa:{if(!(!m|(f|0)!=15)){v[i>>2]=e+(a>>>4|0);break sa}if(!(!f|(m|0)!=240)){v[i>>2]=e-f;break sa}if(f){v[i>>2]=e-B(f,z);break sa}v[i>>2]=e+B(z,a>>>4|0)}ce(i,0,64);v[j>>2]=v[i>>2];break V;case 7:zl(b,o,f,8);break V;case 25:break ia;case 6:break ja;case 24:break ka;case 3:break la;case 5:break ma;case 18:break na;case 17:break oa;default:break V}}if(!x[b+480188>>1]|f>>>0>15){break na}e=(f&1)<<14;a=0;while(1){j=B(a,896)+h|0;v[j+696>>2]=(e|v[j+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((f&240)!=128){break V}zl(b,o,f&15,4);break V}if(f){t[k+1437|0]=f}f=0}qk(o,f);break V}IM(b,o,f);break V}HM(o,f);break V}GM(o,f)}ta:{ua:{switch(w[r|0]-2|0){case 0:zl(b,o,w[k+1422|0],6);break ta;case 5:Eb(i,s,53);e=Cb(i);a=w[k+1422|0];if(e){t[k+1451|0]=a&15;break ta}qk(o,a<<4);break ta;case 6:break ua;default:break ta}}qk(o,w[k+1422|0])}va:{wa:{xa:{ya:{a=w[pa|0];switch(a-5|0){case 3:break wa;case 0:case 2:break xa;case 1:break U;default:break ya}}switch(a-26|0){case 1:break va;case 0:break xa;default:break U}}za:{if(v[b+480180>>2]&16777248){a=F;if(!(w[b+480208|0]&4)){break za}}a=z}e=w[k+1451|0];Eb(i,s,21);f=Cb(i);k=k+1447|0;a=B(a,e);t[k|0]=w[k|0]+(f?a<<2:a);break U}Aa:{if(v[b+480180>>2]&16777248){a=F;if(!(w[b+480208|0]&4)){break Aa}}a=z}e=w[k+1454|0];Eb(i,s,21);f=Cb(i);k=k+1448|0;a=B(a,e);t[k|0]=w[k|0]+(f?a<<2:a);break U}a=k+1449|0;t[a|0]=w[a|0]+B(N,w[k+1457|0]);v[114578]=0;R(1350,b|0,o|0);a=v[114578];v[114578]=0;if((a|0)==1){break S}}g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break Q}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if(v[h+40>>2]==65535?v[b+480180>>2]==4:0){break k}v[h+32>>2]=v[b+480216>>2];if(FM(_b(I,x[h+60>>1]))){Aa=h,Ba=v[_b(I,x[h+60>>1])+16>>2],v[Aa+32>>2]=Ba}v[114578]=0;z=Q(1351,b|0,h|0)|0;a=v[114578];v[114578]=0;Ba:{Ca:{if((a|0)!=1){a=B(F,z);A[q+32>>3]=+(a>>>0)/+y[b+24620>>2]+A[q+32>>3];v[h>>2]=a+v[h>>2];if(!(!x[b+480188>>1]|ta)){m=0;pa=(E|0)!=0&(E|0)!=(z|0);xa=K-1|0;while(1){Da:{if(v[Rc(p,m)+16>>2]==-1){break Da}r=1;Ea:{Fa:{j=B(m,896)+h|0;N=j+1421|0;switch(w[N|0]-4|0){case 0:case 2:break Ea;default:break Fa}}r=w[j+1420|0]==11}if(w[j+1419|0]){v[j+1268>>2]=0}f=j+1423|0;a=w[f|0];v[114578]=0;ha=j+1418|0;g=T(553,ha|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break p}k=j+608|0;e=a&15;o=0;Ga:{if(!g){break Ga}Ha:{Ia:{Ja:{if(!r){break Ja}if(!w[Rc(p,m)+20|0]){break Ja}g=v[j+1308>>2];v[114578]=0;g=io(1352,b,k,g,0);o=mb;ia=v[114578];v[114578]=0;if((ia|0)==1){break Ia}v[j+616>>2]=g;v[j+620>>2]=o}t[j+1432|0]=w[j+1429|0];ia=j+1300|0;za=v[ia>>2];g=w[j+1433|0];if(!g){break Ha}v[114578]=0;ma(1353,b|0,k|0,g|0,r|0,1,1);g=v[114578];v[114578]=0;if((g|0)!=1){break Ha}break o}a=P()|0;O()|0;break e}g=w[ha|0];v[114578]=0;ja(1354,b|0,k|0,g|0,r|0,1,0,65535);g=v[114578];v[114578]=0;if((g|0)==1){break o}a=a>>>4|0;Aa=Rc(p,m),Ba=1,t[Aa+20|0]=Ba;g=w[N|0];Ka:{if(!((w[f|0]&240)!=208|(g-19&255)>>>0>1)){o=e;if(e>>>0<F>>>0){break Ka}}o=(g|0)==33?a>>>0<F>>>0?a:0:0}o=!(v[b+480180>>2]&16777250)|(!o|K>>>0<2)?o:B(v[h+40>>2]+da|0,xa)+o|0;if(!r){Aa=Rc(p,m),Ba=0,v[Aa+16>>2]=Ba}g=w[N|0];La:{Ma:{if((g|0)==9){break Ma}Na:{if((g|0)!=19){if((g|0)!=20|(a|0)!=8){break Na}break Ma}if((a|0)==8){break Ma}}if(w[j+1420|0]!=2){break La}}v[ia>>2]=za}Oa:{Pa:{switch(g-39|0){default:if((g|0)!=10){break Oa}t[i|0]=0;a=v[h+48>>2];g=x[h+60>>1];v[114578]=0;g=ea(1348,b|0,g|0,a|0,m&65535,i|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){if(!w[i|0]){a=g<<8;if(!a){a=v[j+1272>>2]}g=(w[j+1464|0]<<16)+a|0}v[114578]=0;U(1355,b|0,k|0,g|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Ga}}a=P()|0;O()|0;break e;case 2:a=v[j+684>>2];g=w[f|0];v[114578]=0;g=Hma(a,0,g,0);a=mb;ia=a>>>8|0;a=Gg(752,(a&255)<<24|g>>>8,ia);g=v[114578];v[114578]=0;if((g|0)==1){break o}v[114578]=0;U(1355,b|0,k|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}break Ga;case 1:break Oa;case 0:break Pa}}if(!v[j+712>>2]){break Oa}v[114578]=0;X(1356,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break o}a=w[f|0];v[114578]=0;U(1357,h|0,k|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}o=v[h+40>>2]-1|0;break Ga}if(w[j+1420|0]!=15){break Ga}a=w[j+1422|0];if(a>>>0>9){break Ga}g=v[j+712>>2];if(!g){break Ga}Qa:{if(!a){g=v[j+1272>>2];break Qa}g=v[(g+(a<<2)|0)- -64>>2];v[j+1272>>2]=g}v[114578]=0;U(1355,b|0,k|0,g|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Ga}a=P()|0;O()|0;break e}Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{switch(w[ha|0]-253|0){case 0:if(x[b+480192>>1]){break _a}break;case 1:case 2:break _a;default:break $a}}g=w[N|0];if((g-19&255)>>>0<=1){if((w[f|0]&240)!=192){a=l;break Ya}a=l;if(e>>>0<F>>>0){break _a}break Ya}a=g&255;if((a|0)==33&(e|0)!=0&e+o>>>0<F>>>0){break _a}e=l;if((a|0)!=25){break Za}}g=w[N|0];e=1}if((g&255)==13){break Xa}a=e}if(w[j+1420|0]==1){v[j+1296>>2]=w[j+1422|0]<<2}if((!v[j+712>>2]|a)&1){break Wa}e=0;g=g&255;if(g>>>0>42){break Ta}e=a;break Ua}v[j+1296>>2]=w[f|0]<<2;if(!((!v[j+712>>2]|e)&1)){break Va}a=e}if(a&1){break Ra}break Sa}g=13}Eb(i,J,g);ab:{if(Cb(i)){break ab}if(w[N|0]!=19){break Ta}a=w[f|0]&240;if((a|0)==32){break ab}if((a|0)!=16){break Ta}}e=1}a=j+1420|0;if(w[a|0]<16){Pj(i,qa,w[a|0]);if(!((Cb(i)|e)&1)){break Sa}break Ra}if(e&1){break Ra}}if(pa){v[114578]=0;X(1356,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break p}}bb:{cb:{db:{a=w[N|0];if(a-6>>>0>=2){eb:{switch(a-19|0){case 1:break cb;case 0:break db;default:break eb}}if((a|0)!=11){break bb}}if(!(v[b+480180>>2]==1?w[f|0]:1)|!F){break bb}a=j+1480|0;g=0;while(1){t[a|0]=!g|w[a|0]&254;en(b,k,w[f|0]);g=g+1|0;if((F|0)!=(g|0)){continue}break}break bb}g=w[f|0];if(!(g&15)){if(!(v[b+480180>>2]&1048580)){break bb}g=w[f|0]}a=j+1480|0;t[a|0]=w[a|0]|1;a=g&240;if((a|0)!=176){if((a|0)!=160){break bb}bp(b,k,g&15,0);break bb}ap(b,k,g&15,0);break bb}fb:{gb:{hb:{a=w[f|0];switch(a-158|0){case 1:break gb;case 0:break hb;default:break fb}}v[114578]=0;X(1356,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break p}v[j+696>>2]=v[j+696>>2]&-129;break bb}v[114578]=0;X(1356,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break p}v[j+696>>2]=v[j+696>>2]|128;if(!v[j+684>>2]|v[k+4>>2]){break bb}v[114578]=0;a=T(553,ha|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break p}if(!(w[j+696|0]&2?a:1)){break bb}e=v[j+684>>2]-1|0;a=k;v[a>>2]=-1;v[a+4>>2]=e;break bb}if((a&240)!=112|a>>>0<115){break bb}v[114578]=0;U(1358,k|0,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}}a=j+1480|0;t[a|0]=w[a|0]|1;ib:{jb:{kb:{lb:{e=j+1420|0;switch(w[e|0]-3|0){case 0:case 1:break jb;case 3:break kb;case 2:break lb;default:break ib}}a=w[j+1422|0];Eb(i,s,41);bp(b,k,a,Cb(i));break ib}a=w[j+1422|0];Eb(i,s,41);ap(b,k,a,Cb(i));break ib}f=w[j+1422|0];mb:{if(f){break mb}Eb(i,s,41);f=0;if(!Cb(i)){break mb}f=w[j+1462|0];if(!f){break ib}}if(!F){break ib}e=w[e|0]==3?f<<4:f;f=0;while(1){t[a|0]=!f|w[a|0]&254;en(b,k,e&255);f=f+1|0;if((F|0)!=(f|0)){continue}break}}if(r){a=v[Rc(p,m)+16>>2];e=Rc(p,m);v[e+16>>2]=v[e+16>>2]+F;v[114578]=0;X(1356,q|0,m&65535,z|0,(a+o|0)+1|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Da}a=P()|0;O()|0;break e}a=Rc(p,m);v[a+16>>2]=v[a+16>>2]+(F-o|0);break Da}v[114578]=0;Z(1359,k|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}Aa=Rc(p,m),Ba=0,v[Aa+16>>2]=Ba}m=m+1|0;if(m>>>0<x[b+480188>>1]){continue}break}}if(!na){break Ba}Eb(i,s,68);if(Aa=Cb(i),Ba=0,Da=ga|oa,Da?Aa:Ba){break Ba}Eb(i+48|0,s,49);if(Aa=Cb(i+48|0),Ba=0,Da=ga,Da?Aa:Ba){break Ba}Eb(i+40|0,s,103);if(Cb(i+40|0)){E=z;if(fa){continue}}f=0;g=jb-16|0;jb=g;l=g+8|0;e=jb-16|0;jb=e;v[114578]=0;a=i;T(1376,a+4|0)|0;E=v[114578];v[114578]=0;nb:{if((E|0)!=1){v[114578]=0;v[e+12>>2]=0;W(1377,a+8|0,e+12|0,l|0)|0;l=v[114578];v[114578]=0;if((l|0)!=1){break nb}break a}break a}Aa=a,Ba=hc(a),v[Aa>>2]=Ba;jb=e+16|0;jb=g+16|0;e=i;if(!x[b+480188>>1]){break Ca}while(1){ob:{g=B(f,896)+h|0;a=w[g+1423|0];g=w[g+1421|0];pb:{if(a>>>0<192?(g|0)!=20|a>>>0<177:1){if(a>>>0<97|a>>>0>111|(g|0)!=19){break pb}}G=A[Rc(p,f)>>3];v[114578]=0;A[i+48>>3]=G;g=Q(1360,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ob}if(!v[g>>2]){v[114578]=0;g=Q(1360,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ob}v[g>>2]=1}v[114578]=0;g=Q(1360,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ob}g=v[g>>2];v[114578]=0;a=Q(1361,g|0,(a&15)+1|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ob}v[114578]=0;g=Q(1360,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ob}v[g>>2]=a}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break Ca}break}break q}a=P()|0;O()|0;break e}Aa=i,Ba=vn(e),v[Aa+40>>2]=Ba;Aa=i,Ba=Hi(e),v[Aa+32>>2]=Ba;while(1){v[114578]=0;a=Q(1362,i+40|0,i+32|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}if(!a){qb:{if(v[b+480180>>2]!=32){break qb}f=0;if(!x[b+480188>>1]){break qb}while(1){a=B(f,896)+h|0;if(!(w[a+1421|0]!=20|(w[a+1423|0]+79&255)>>>0>14)){G=A[q+32>>3];Aa=Rc(p,f),Ca=G,A[Aa>>3]=Ca;a=v[h>>2];Aa=Rc(p,f),Ba=a,v[Aa+8>>2]=Ba}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}wM(e);break Ba}v[114578]=0;a=T(1363,i+40|0)|0;g=v[114578];v[114578]=0;rb:{sb:{if((g|0)!=1){g=zb(a);G=A[q+32>>3];A[q+32>>3]=(G-A[a>>3])*+(v[g>>2]-1|0)+G;f=0;if(x[b+480188>>1]){break sb}break rb}break q}while(1){if(A[Rc(p,f)>>3]!=A[a>>3]){f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break rb}break}a=v[h>>2];l=Rc(p,f);v[h>>2]=v[h>>2]+B(v[g>>2]-1|0,a-v[l+8>>2]|0);Eb(i+48|0,s,16);if(!(Aa=Cb(i+48|0),Ba=1,Da=v[b+480180>>2]!=2,Da?Aa:Ba)){break rb}G=A[q+32>>3];Aa=Rc(p,f),Ca=G,A[Aa>>3]=Ca;a=v[h>>2];Aa=Rc(p,f),Ba=a,v[Aa+8>>2]=Ba;a=v[h+48>>2];Aa=Rc(p,f),Ba=a+1|0,v[Aa+12>>2]=Ba}v[114578]=0;T(1364,i+40|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){continue}break}break q}E=z;continue}}a=P()|0;O()|0;break e}a=P()|0;O()|0;wM(e);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}t[n+26|0]=1}tb:{ub:{if(!(!x[b+480188>>1]|(ra|0)!=7)){e=0;while(1){if(v[Rc(p,e)+16>>2]!=-1){v[114578]=0;X(1356,q|0,e&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break ub}}e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}if(w[n+26|0]){u[n+20>>1]=x[h+62>>1];v[n+8>>2]=v[h+48>>2]}A[n>>3]=A[q+32>>3];v[114578]=0;R(1340,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break tb}vb:{wb:{if(!ca){break wb}xb:{if(M?w[n+26|0]:1){a=b+1074376|0;DM(a,h);gy(a);a=0;v[b+1074400>>2]=0;t[b+1074464|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1304392|0;if(sd(d)){e=v[d>>2];v[114578]=0;Z(1365,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break tb}}yb:{if(x[b+480188>>1]){h=(ra|0)==7;while(1){e=B(a,896)+b|0;g=w[e+1075805|0];if(g){t[e+1075808|0]=g}if(!(h|w[Rc(p,a)+21|0]==255)){g=Rc(p,a);v[114578]=0;t[i|0]=64;g=Q(393,g+21|0,i|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break yb}v[e+1075672>>2]=w[g|0]<<2}zb:{g=e+1075088|0;l=v[g>>2];if(!l|!(w[l+35|0]&2)){break zb}if(!sd(d)){break zb}l=v[d>>2];g=v[g>>2];v[114578]=0;z=l;l=a&65535;U(1366,z|0,l|0,g+68|0);g=v[114578];v[114578]=0;if((g|0)!=1){g=v[d>>2];v[114578]=0;U(1367,g|0,l|0,1);g=v[114578];v[114578]=0;if((g|0)!=1){break zb}}a=P()|0;O()|0;break e}v[e+1075e3>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=hz(i);Aa=i,Ba=vn(sa),v[Aa+40>>2]=Ba;Aa=i,Ba=Hi(sa),v[Aa+32>>2]=Ba;Ab:{while(1){Bb:{v[114578]=0;a=Q(1368,i+40|0,i+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Bb}if(!a){g=250;a=d;e=a;Cb:{Db:{while(1){if(v[e>>2]){break Db}e=e+4|0;g=g-32|0;if(g>>>0>31){continue}break}a=(v[a+28>>2]&67108863)!=0;break Cb}a=1}if(!a){break xb}a=0;while(1){Eb(i+48|0,d,a);Eb:{if(!Cb(i+48|0)){break Eb}e=v[(B(a,160)+b|0)+906300>>2];h=v[v[e>>2]+172>>2];v[114578]=0;Z(h|0,e|0);e=v[114578];v[114578]=0;if((e|0)!=1){break Eb}a=P()|0;O()|0;break e}a=a+1|0;if((a|0)!=250){continue}break}break xb}v[114578]=0;e=T(1369,i+40|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break Ab}h=w[e|0]-1&255;a=v[(B(h,160)+b|0)+906300>>2];if(a){Eb(i+48|0,d,h);if(!Cb(i+48|0)){v[114578]=0;W(1370,d|0,h|0,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break vb}h=v[v[a>>2]+168>>2];v[114578]=0;R(h|0,a|0,-1);h=v[114578];v[114578]=0;if((h|0)==1){break vb}}h=x[e+2>>1];g=v[v[a>>2]+44>>2];e=x[e+4>>1];v[114578]=0;ya(g|0,a|0,h|0,C(C(C(e>>>0)*C(.0010010009864345193))));a=v[114578];v[114578]=0;if((a|0)==1){break vb}}v[114578]=0;T(1371,i+40|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){continue}}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if((c|0)==3){break xb}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074444>>2]=v[b+480200>>2]}if(w[ka+16|0]==(ba|0)){break wb}v[114578]=0;R(489,ka|0,ba|0);a=v[114578];v[114578]=0;if((a|0)==1){break tb}}if(c&9){v[114578]=0;R(1372,b+1304360|0,Y|0);a=v[114578];v[114578]=0;if((a|0)==1){break tb}}$o(Y);CM(q);jb=i+176|0;return}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}$o(Y);break d}a=P()|0;O()|0}CM(q);break c}a=P()|0;O()|0}Hl(la);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=jb-1728|0;jb=e;Jc(b);g=jb-16|0;jb=g;i=e+1600|0;aQ(g+8|0,i);h=Hb(g+8|0);f=b;j=nc(f,ac(g,g+8|0));if((h|0)==(j|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(h|0)==(j|0);if(!f){bQ(i)}a:{if(!f){break a}if(!gQ(e+1600|0)){break a}if(!Qb(b,hd(256,0))){break a}b:{if(!c){break b}Hd(a,1048576);vi(a);d=Ub(e+1584|0,16384);v[114578]=0;R(219,e+1328|0,d|0);f=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((f|0)!=1){p=e+1608|0;v[e+160>>2]=w[p+1|0];f=w[p|0];v[114578]=0;v[e+24>>2]=f;R(660,e+88|0,e+24|0);f=v[114578];v[114578]=0;if((f|0)==1){break r}v[114578]=0;X(645,e+240|0,e+1328|0,e+160|0,e+88|0);f=v[114578];v[114578]=0;if((f|0)==1){break q}Gb(a+1304436|0,e+240|0);yb(e+240|0);yb(e+88|0);Ib(e+1328|0);yb(d);d=Ub(e+240|0,16401);Gb(a+1304448|0,d);yb(d);yg(e+88|0,2,e+1610|0);Ic(e+1328|0,e+88|0);v[114578]=0;U(13,e+240|0,7,e+1328|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}Gb(a+1304460|0,e+240|0);yb(e+240|0);yb(e+1328|0);v[a+1304496>>2]=7;Ut(e+1328|0,2,e+1642|0);Ic(e+240|0,e+1328|0);Gb(a+1304400|0,e+240|0);yb(e+240|0);d=e+1712|0;u[a+480188>>1]=w[d|0]|w[d+1|0]<<8;d=Fd(w[e+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=d;A=e+1722|0;u[a+480192>>1]=w[A|0]|w[A+1|0]<<8;F=e+1724|0;u[a+480190>>1]=w[F|0]|w[F+1|0]<<8;d=Fd(w[e+1717|0],1,32);v[a+480216>>2]=d;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=d<<2;iu(b,e+1328|0);D=a+484360|0;z=e+1706|0;eq(Vb(D),e+1328|0,w[z|0]|w[z+1|0]<<8,65535,65535);d=e+1708|0;Oe(Vb(D),w[d|0]|w[d+1|0]<<8);ud(e+1312|0,b,hg(b));v[114578]=0;d=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}v[114578]=0;U(343,e+1296|0,b|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break n}q=x[a+480188>>1];v[114578]=0;C=Q(258,e+1312|0,274)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}if(C){u[a+480188>>1]=x[a+480188>>1]+8}E=c&1;if(!E){break l}d=e+1710|0;d=w[d|0]|w[d+1|0]<<8;v[114578]=0;R(403,a+484344|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break l}break f}h=P()|0;O()|0;break o}h=P()|0;O()|0;break p}h=P()|0;O()|0;yb(e+88|0)}Ib(e+1328|0)}yb(d);break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;break e}o=a+484344|0;r=e+1718|0;n=e+1710|0;if(!(w[n|0]|w[n+1|0]<<8)){break g}f=0;while(1){v[114578]=0;d=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}v[114578]=0;v[e+160>>2]=d;d=T(392,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}v[114578]=0;U(343,e+240|0,b|0,d+1&-2);d=v[114578];v[114578]=0;if((d|0)==1){break i}Cc(e+160|0,1024);d=v[e+160>>2];s:{if(!d|!E){break s}v[114578]=0;d=W(404,o|0,f&65535,d|0)|0;g=v[114578];v[114578]=0;t:{if((g|0)!=1){if(!d){break s}h=0;if(t[r|0]&1){j=0;while(1){v[114578]=0;d=Q(258,e+240|0,1)|0;g=v[114578];v[114578]=0;u:{if((g|0)!=1){if(!d){break s}v[114578]=0;d=T(389,e+240|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}k=0;if((d|0)!=255){break u}v[114578]=0;k=T(389,e+240|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;d=T(389,e+240|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break u}}break j}break j}v:{if(!(d&127)){break v}g=_b(o,f);v[114578]=0;i=W(472,g|0,j|0,h&65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}t[e+88|0]=0;t[e+89|0]=0;t[e+90|0]=0;t[e+91|0]=0;t[e+91|0]=0;t[e+92|0]=0;t[e+93|0]=0;t[e+94|0]=0;if(d&1){v[114578]=0;g=T(389,e+240|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}t[e+88|0]=g}if(d&2){v[114578]=0;g=T(389,e+240|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}t[e+89|0]=g}if(d&4){v[114578]=0;g=T(389,e+240|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}t[e+90|0]=g}if(d&8){v[114578]=0;g=T(389,e+240|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}t[e+91|0]=g}if(d&16){v[114578]=0;g=T(389,e+240|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}t[e+92|0]=g}if(d&32){v[114578]=0;g=T(389,e+240|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}t[e+93|0]=g}if(d&64){v[114578]=0;d=T(389,e+240|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}t[e+94|0]=d}v[114578]=0;d=Q(897,i|0,e+88|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}v[114578]=0;v[e+24>>2]=k;v[e+224>>2]=v[e+160>>2]+(j^-1);g=Q(333,e+24|0,e+224|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}m=d|m;G=v[g>>2];if(!G){break v}g=1;d=i;while(1){d=B(x[a+480188>>1],6)+d|0;l=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);t[d|0]=l;t[d+1|0]=l>>>8;t[d+2|0]=l>>>16;t[d+3|0]=l>>>24;l=w[i+4|0]|w[i+5|0]<<8;t[d+4|0]=l;t[d+5|0]=l>>>8;if((g|0)==(G|0)){break v}g=g+1|0;continue}}j=(j+k|0)+1|0;d=v[e+160>>2];if(j>>>0>=d>>>0){while(1){h=h+1|0;j=j-d|0;if(d>>>0<=j>>>0){continue}break}}if((h&65535)>>>0<q>>>0){continue}break}break s}g=0;if(v[e+160>>2]){break t}break s}break j}while(1){d=_b(o,f);v[114578]=0;i=Q(497,d|0,g|0)|0;d=v[114578];v[114578]=0;w:{x:{if((d|0)!=1){d=0;if(q){break x}break w}break j}while(1){y:{v[114578]=0;Q(898,e+240|0,e+88|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break y}v[114578]=0;h=Q(897,i+B(d,6)|0,e+88|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break y}m=h|m;d=d+1|0;if((q|0)!=(d|0)){continue}break w}break}break j}g=g+1|0;if(g>>>0<y[e+160>>2]){continue}break}}Bb(e+240|0);f=f+1|0;if(f>>>0<(w[n|0]|w[n+1|0]<<8)>>>0){continue}break}break g}h=P()|0;O()|0;yb(e+1328|0);break c}h=P()|0;O()|0;Bb(e+240|0);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}d=e+1714|0;if(!((w[d|0]|w[d+1|0]<<8)>>>0<=1|(w[d|0]|w[d+1|0]<<8)>>>0>4999)){z:{if(m&1){f=w[d|0]|w[d+1|0]<<8;d=0;v[114578]=0;g=Gg(460,((f>>>1|0)+11025e5>>>0)/(f>>>0)|0,0);f=v[114578];v[114578]=0;if((f|0)==1){break f}break z}s=2646e7/+(B(B(v[a+480216>>2],v[a+480196>>2]),w[d|0]|w[d+1|0]<<8)>>>0);A:{if(s<4294967296&s>=0){g=~~s>>>0;break A}g=0}d=2}v[a+480224>>2]=d;v[a+480204>>2]=g}d=x[a+480188>>1];v[114578]=0;t[e+240|0]=0;l=W(899,e+1280|0,d|0,e+240|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){g=a+1304412|0;i=a+1304424|0;h=e+240|3;E=0;B:{C:{D:{E:{F:{while(1){v[114578]=0;d=Q(258,e+1296|0,8)|0;f=v[114578];v[114578]=0;G:{if((f|0)!=1){if(d){break G}if(x[a+480188>>1]){d=0;while(1){f=t[wc(l,d)|0];H:{if((f|0)<=(d|0)|(f|0)>=x[a+480188>>1]){break H}i=((f<<5)+a|0)+480288|0;f=w[i|0];if(!f){break H}g=((d<<5)+a|0)+480288|0;h=w[g|0];if(!h){t[g|0]=f;break H}g=(B(h-1&255,160)+a|0)+906300|0;if((Ij(g)|0)!=255){while(1){g=(B(Ij(g),160)+a|0)+906300|0;if((Ij(g)|0)!=255){continue}break}}f=g+28|0;g=w[i|0]-1&255;g=g>>>0<250?g+128|0:0;t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[e+232>>2]=0;v[e+236>>2]=0;v[e+224>>2]=0;v[e+228>>2]=0;v[e+216>>2]=0;v[e+220>>2]=0;v[e+208>>2]=0;v[e+212>>2]=0;I:{J:{K:{L:{M:{N:{if(C){v[114578]=0;Q(900,e+1312|0,e+240|0)|0;d=v[114578];v[114578]=0;O:{if((d|0)!=1){g=0;while(1){d=x[a+480192>>1];v[114578]=0;d=Q(901,a|0,d+1&65535)|0;f=v[114578];v[114578]=0;P:{Q:{R:{S:{T:{U:{V:{if((f|0)!=1){f=g<<1;i=f+(e+224|0)|0;u[i>>1]=d;j=f+(e+208|0)|0;f=e+f|0;h=f+242|0;u[j>>1]=w[h|0]|w[h+1|0]<<8;if((d|0)==65535){break Q}f=w[f+242|0]|w[f+243|0]<<8;v[114578]=0;d=W(456,a|0,d|0,f+1&65535)|0;f=v[114578];v[114578]=0;if((f|0)==1){break V}if(!d){break P}v[114578]=0;R(509,e+160|0,16418);f=v[114578];v[114578]=0;if((f|0)==1){break U}v[114578]=0;v[e+24>>2]=g+1;U(902,e+88|0,e+160|0,e+24|0);f=v[114578];v[114578]=0;if((f|0)==1){break T}v[114578]=0;Q(371,d+492|0,e+88|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break S}yb(e+88|0);Ib(e+160|0);break P}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}h=P()|0;O()|0;break R}h=P()|0;O()|0;yb(e+88|0)}Ib(e+160|0);break B}u[i>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break O}h=P()|0;O()|0;break B}f=w[e+240|0]|w[e+241|0]<<8;d=0;v[114578]=0;m=Q(397,e+160|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}if(w[e+240|0]|w[e+241|0]<<8){while(1){v[114578]=0;f=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break K}v[114578]=0;U(343,e+88|0,b|0,f<<5);f=v[114578];v[114578]=0;if((f|0)==1){break L}Wd(tc(m,d),e+88|0);Bb(e+88|0);d=d+1|0;if(d>>>0<(w[e+240|0]|w[e+241|0]<<8)>>>0){continue}break}}d=w[n|0]|w[n+1|0]<<8;k=0;v[114578]=0;i=W(903,e+88|0,d|0,16428)|0;d=v[114578];v[114578]=0;if((d|0)==1){break M}if(w[z|0]|w[z+1|0]<<8){while(1){g=e+k|0;W:{if(w[g+258|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break W}if(x[rc(Vb(D),k)>>1]>=(w[n|0]|w[n+1|0]<<8)>>>0){break W}f=x[rc(Vb(D),k)>>1];X:{if(x[rc(i,f)>>1]==65535){d=w[g+258|0];H=rc(i,f),I=d,u[H>>1]=I;break X}if(x[rc(i,f)>>1]==w[g+258|0]){break X}v[114578]=0;d=W(904,o|0,f|0,0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break N}if((d|0)==65535){break X}H=rc(Vb(D),k),I=d,u[H>>1]=I;f=d}v[114578]=0;d=Q(444,o|0,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break N}if(!d){break W}C=tc(m,w[g+258|0]);Jc(C);v[114578]=0;d=T(255,C|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break N}if(!v[_b(o,f)+12>>2]){break W}G=d>>>5|0;j=0;while(1){d=_b(o,f);g=x[a+480188>>1];v[114578]=0;d=W(472,d|0,j|0,g-8&65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break N}g=0;while(1){Ph(e+24|0);h=x[e+28>>1];t[d+4|0]=h;t[d+5|0]=h>>>8;h=v[e+24>>2];t[d|0]=h;t[d+1|0]=h>>>8;t[d+2|0]=h>>>16;t[d+3|0]=h>>>24;Y:{if(j>>>0>=G>>>0){break Y}v[114578]=0;Q(905,C|0,e+24|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break N}if(t[e+24|0]>-1){break Y}t[d|0]=61;t[d+1|0]=w[(e+224|0)+(g<<1)|0];h=w[e+24|0]&31;t[e+72|0]=h;if(h){Ue(e+72|0,15);t[d+3|0]=20;t[d+5|0]=w[e+72|0]|208}t[d+2|0]=1;t[d+4|0]=w[e+25|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}j=j+1|0;if(j>>>0<y[_b(o,f)+12>>2]){continue}break}}k=k+1|0;if(k>>>0<(w[z|0]|w[z+1|0]<<8)>>>0){continue}break}}kf(i);gd(m)}Z:{if(!(w[r|0]&2)){break Z}q=w[r|0]&8?x[a+480188>>1]:q;if(!(w[n|0]|w[n+1|0]<<8)){break Z}d=0;f=((q&65535)+((w[p|0]|w[p+1|0]<<8)>>>0>591?E:0)|0)+((w[r|0]|w[r+1|0]<<8|(w[r+2|0]<<16|w[r+3|0]<<24))>>>4&1)|0;while(1){g=0;_:{if(!f){break _}while(1){$:{v[114578]=0;i=Q(258,b|0,4)|0;h=v[114578];v[114578]=0;if((h|0)==1){break $}if(!i){break _}i=w[p|0]|w[p+1|0]<<8;v[114578]=0;R(906,i|0,b|0);i=v[114578];v[114578]=0;if((i|0)==1){break $}g=g+1|0;if((f|0)!=(g|0)){continue}break _}break}h=P()|0;O()|0;break B}d=d+1|0;if(d>>>0<(w[n|0]|w[n+1|0]<<8)>>>0){continue}break}}v[114578]=0;n=Q(397,e+192|0,255)|0;d=v[114578];v[114578]=0;aa:{ba:{ca:{da:{ea:{fa:{if((d|0)!=1){D=e+88|7;r=e+88|1;z=e+88|4;o=e+88|2;C=e+88|3;f=0;while(1){d=f;v[114578]=0;Q(907,b|0,e+160|0)|0;f=v[114578];v[114578]=0;ga:{ha:{ia:{ja:{if((f|0)!=1){v[114578]=0;f=T(392,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ja}g=w[p|0]|w[p+1|0]<<8;v[114578]=0;f=(f|0)==32?428:f;g=g>>>0>513?f?f+4|0:f:f;U(343,e+240|0,b|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break ia}f=d+1|0;j=Ze(e+24|0,Wd(tc(n,d),e+240|0));Bb(e+240|0);if(d>>>0>=(w[A|0]|w[A+1|0]<<8)>>>0){break ga}v[114578]=0;d=f&65535;i=W(456,a|0,d|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break ha}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}if(!i){break ga}v[114578]=0;U(746,e+88|0,2,e+160|0);d=v[114578];v[114578]=0;ka:{la:{ma:{if((d|0)==1){break ma}v[114578]=0;R(417,e+240|0,e+88|0);d=v[114578];v[114578]=0;if((d|0)==1){break ma}v[114578]=0;Q(371,i+492|0,e+240|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break la}yb(e+240|0);if(!g){break ga}v[114578]=0;Q(908,j|0,e+240|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break da}m=0;if((w[p|0]|w[p+1|0]<<8)>>>0<513){break ka}v[114578]=0;m=T(359,j|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break ka}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break ba}h=P()|0;O()|0;yb(e+240|0);break ba}h=3;na:{if((w[p|0]|w[p+1|0]<<8)>>>0<514){break na}v[114578]=0;h=T(392,j|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break na}h=P()|0;O()|0;break ba}v[i>>2]=w[e+342|0]|w[e+343|0]<<8;t[i+16|0]=w[((w[e+344|0]|w[e+345|0]<<8)&3)+16430|0];t[i+17|0]=w[(w[e+345|0]&3)+16430|0];t[i+18|0]=w[((w[e+344|0]|w[e+345|0]<<8)>>>12&3)+16434|0];q=0;oa:{pa:{qa:{ra:{while(1){sa:{if(!(h&1)){break sa}v[114578]=0;Q(909,j|0,e+88|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ra}v[114578]=0;g=Q(376,i|0,w[q+16438|0])|0;d=v[114578];v[114578]=0;if((d|0)==1){break qa}d=g;if((q|0)!=3){k=w[g+12|0]&-17}else{k=w[g+12|0]&-17|w[e+88|0]<<4&16}t[d+12|0]=k;t[g+12|0]=w[g+12|0]&254|t[e+88|0]&1;t[g+12|0]=w[g+12|0]&251|w[e+88|0]<<1&4;t[g+12|0]=w[g+12|0]&253|w[e+88|0]>>>1&2;d=w[r|0];v[114578]=0;t[e+72|0]=d;t[e+56|0]=16;d=Q(393,e+72|0,e+56|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break pa}d=w[d|0];v[114578]=0;R(591,g|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break pa}d=w[o|0];t[g+15|0]=d;t[g+16|0]=d;t[g+13|0]=w[C|0];t[g+14|0]=w[z|0];d=0;if(!Kb(g)){break sa}while(1){k=(e+88|0)+(d<<2)|0;E=w[k+8|0]|w[k+9|0]<<8;H=Pb(g,d),I=E,u[H>>1]=I;k=Fd(w[k+10|0]|w[k+11|0]<<8,0,64);H=Pb(g,d),I=k,t[H+2|0]=I;d=d+1|0;if(Kb(g)>>>0>d>>>0){continue}break}}h=h>>>1|0;q=q+1|0;if((q|0)!=4){continue}break}if(!(t[i+60|0]&1|w[i+16|0]==3)){v[i>>2]=32767}v[114578]=0;U(910,i|0,127,1);d=v[114578];v[114578]=0;if((d|0)==1){break fa}v[114578]=0;U(911,i|0,0,1);d=v[114578];v[114578]=0;if((d|0)==1){break fa}if(!m){break ga}v[114578]=0;Q(912,j|0,e+88|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ca}if(!(m&2)){break oa}d=w[o|0]|w[o+1|0]<<8;v[114578]=0;d=ib(913,a|0,+(d>>>0))|0;g=v[114578];v[114578]=0;if((g|0)==1){break ca}v[114578]=0;U(910,i|0,d|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break ca}d=w[z|0];v[114578]=0;U(911,i|0,d|0,1);d=v[114578];v[114578]=0;if((d|0)!=1){break oa}break ca}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break ba}t[i+25|0]=w[r|0]==1;if(!(m&4)){break ga}t[i+31|0]=w[D|0]+1;t[i+34|0]=w[e+96|0]+1;if(t[e+96|0]<=-1){t[i+30|0]=w[e+103|0]+1}if(w[e+100|0]){d=0;h=i+108|0;while(1){g=d+1|0;v[e+72>>2]=g+t[e+100|0];eQ(e+72|0);m=v[e+72>>2];H=fc(h,d),I=m,t[H|0]=I;d=g;if(d>>>0<128){continue}break}}v[114578]=0;R(779,i|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break ca}}Bb(j);if((f|0)!=255){continue}break}p=hz(e+88|0);i=e+24|4;q=hz(e+160|0);g=0;ta:{ua:{while(1){v[114578]=0;Q(907,b|0,e+240|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}v[114578]=0;d=T(392,b|0)|0;f=v[114578];v[114578]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{if((f|0)!=1){v[114578]=0;U(343,e+72|0,b|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ca}if((w[F|0]|w[F+1|0]<<8)>>>0>g>>>0){v[114578]=0;U(746,e+56|0,2,e+240|0);f=v[114578];v[114578]=0;if((f|0)==1){break va}v[114578]=0;R(417,e+24|0,e+56|0);f=v[114578];v[114578]=0;if((f|0)==1){break va}v[114578]=0;Q(371,((g<<5)+a|0)+946336|0,e+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}yb(e+24|0)}if(!d|(w[F|0]|w[F+1|0]<<8)>>>0<=g>>>0){break wa}v[114578]=0;d=B(g+1|0,104)+a|0;f=d+484380|0;R(388,f|0,32);h=v[114578];v[114578]=0;if((h|0)==1){break Aa}v[114578]=0;Q(914,e+72|0,e+24|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break za}v[f>>2]=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);v[d+484404>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);if(w[e+32|0]>=2){h=d+484414|0;u[h>>1]=x[h>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[e+33|0]>=2){h=d+484414|0;u[h>>1]=x[h>>1]|64;v[f>>2]=v[f>>2]>>>1}m=2;Da:{if(w[e+35|0]!=1){m=6;if(w[e+35|0]!=2){break Da}}f=d+484414|0;u[f>>1]=x[f>>1]|m}v[d+484384>>2]=w[e+36|0]|w[e+37|0]<<8|(w[e+38|0]<<16|w[e+39|0]<<24);v[d+484388>>2]=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);u[d+484410>>1]=(w[e+44|0]|w[e+45|0]<<8)>>>7;if(w[e+46|0]!=128){break ya}f=d+484414|0;j=x[f>>1]|256;u[f>>1]=j;break xa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;yb(e+24|0);break ua}h=P()|0;O()|0;break ua}h=P()|0;O()|0;break ua}u[d+484408>>1]=t[e+46|0]+128;j=x[d+484414>>1]}f=d+484414|0;u[f>>1]=j|32;t[d+484416|0]=w[e+47|0];if(w[e+34|0]&2){Eb(e+56|0,q,g);ge(e+56|0,1)}if(w[e+34|0]&5){u[f>>1]=x[f>>1]|16384}if(!(w[e+34|0]&8)){break wa}Eb(e+56|0,p,g);ge(e+56|0,1);d=0;while(1){f=d<<1;Ea:{if(x[f+(e+208|0)>>1]!=(g|0)){break Ea}f=v[((x[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ea}t[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}Bb(e+72|0);g=g+1|0;if((g|0)==256){break ea}continue}break}h=P()|0;O()|0}Bb(e+72|0);break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break B}h=P()|0;O()|0;break ba}Fa:{if(!(w[A|0]|w[A+1|0]<<8)){break Fa}h=0;Ga:{Ha:{while(1){Ia:{d=tc(n,h);v[114578]=0;d=T(255,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ia}Ja:{if(!d){h=h+1|0;break Ja}d=tc(n,h);Jc(d);v[114578]=0;Q(908,d|0,e+240|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ha}d=jb-16|0;jb=d;f=e+24|0;v[f>>2]=0;v[f+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(923,f+8|0,d+12|0,d+8|0)|0;g=v[114578];v[114578]=0;Ka:{if((g|0)!=1){jb=d+16|0;break Ka}V(0)|0;O()|0;Ab();L()}d=w[e+240|0]|w[e+241|0]<<8;v[114578]=0;W(915,b|0,f|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ga}h=h+1|0;g=v[((h<<2)+a|0)+900380>>2];if(!(!g|w[g+34|0])){v[g+4>>2]=32;v[114578]=0;R(779,g|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break Ga}o=g+108|0;k=g+236|0;d=0;while(1){i=e+d|0;La:{if(w[i+242|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break La}m=Tk(f,w[i+242|0]);i=w[m|0];j=i+1|0;r=d+12|0;H=dd(k,r),I=j,u[H>>1]=I;if(i>>>0>=x[a+480190>>1]){break La}i=B(j,104)+a|0;t[i+484418|0]=w[e+338|0]&3;t[i+484419|0]=w[e+339|0];t[i+484420|0]=w[e+340|0];t[i+484421|0]=w[e+341|0];u[i+484412>>1]=w[m+1|0]<<1;t[i+484417|0]=w[m+2|0];i=j-1|0;Eb(e+72|0,p,i);if(Cb(e+72|0)){t[g+14|0]=0}Eb(e+72|0,q,i);if(!Cb(e+72|0)){break La}H=fc(o,r),I=61,t[H|0]=I}d=d+1|0;if((d|0)!=96){continue}break}}dQ(f)}if((w[A|0]|w[A+1|0]<<8)>>>0>h>>>0){continue}break Fa}break}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;dQ(f);break aa}Ma:{Na:{if(!(c&2)|!x[a+480190>>1]){break Na}g=1;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{while(1){d=B(g,104)+a|0;c=d+484416|0;f=t[c|0];i=d+484417|0;h=t[i|0];v[114578]=0;j=d+484380|0;ra(916,j|0,+((+(h|0)*.0078125-+(f-49|0))*.08333333333333333));f=v[114578];v[114578]=0;if((f|0)==1){break Ma}t[i|0]=0;t[c|0]=0;Ya:{c=x[d+484414>>1];Za:{if(!(c&16384)){c=ad(e+240|0,c&1?16:8,c&64?3:1,0,12);v[114578]=0;W(402,c|0,j|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break Za}h=P()|0;O()|0;break aa}v[114578]=0;f=T(392,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Ya}v[114578]=0;Q(340,b|0,12)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Ya}c=Wb(e+240|0);v[114578]=0;W(482,b|0,c|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Xa}v[114578]=0;Q(372,d+484423|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Xa}v[114578]=0;d=Q(2,e+8|0,16442)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Wa}v[114578]=0;R(219,e+72|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break Va}v[e+4>>2]=g;f=Qz(a);v[114578]=0;U(13,e+56|0,f|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ua}v[114578]=0;X(645,e+24|0,e+72|0,e+4|0,e+56|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ta}v[114578]=0;U(646,a|0,2,e+24|0);f=v[114578];v[114578]=0;if((f|0)==1){break Sa}yb(e+24|0);yb(e+56|0);Ib(e+72|0);yb(d);yb(c)}if(x[a+480190>>1]<=g>>>0){break Na}g=g+1|0;continue}break}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break Oa}h=P()|0;O()|0;break Oa}h=P()|0;O()|0;break Pa}h=P()|0;O()|0;break Qa}h=P()|0;O()|0;break Ra}h=P()|0;O()|0;yb(e+24|0)}yb(e+56|0)}Ib(e+72|0)}yb(d)}yb(c);break aa}gd(n);qq(l);Bb(e+1296|0);Bb(e+1312|0);break b}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break ba}h=P()|0;O()|0}Bb(j)}gd(n);break B}h=P()|0;O()|0;kf(i);break J}h=P()|0;O()|0;break J}h=P()|0;O()|0;break J}h=P()|0;O()|0}gd(m);break B}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}v[114578]=0;f=T(392,e+1296|0)|0;j=v[114578];v[114578]=0;d=a;_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{if((j|0)!=1){v[114578]=0;j=T(392,e+1296|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break mb}v[114578]=0;U(343,e+88|0,e+1296|0,j|0);j=v[114578];v[114578]=0;if((j|0)==1){break mb}if((f|0)<=844387157){if((f|0)==4674381){break cb}if((f|0)==5068115){break bb}if(m&1|(f|0)!=726487106){break $a}v[a+480224>>2]=2;v[114578]=0;s=+la(917,e+88|0);f=v[114578];v[114578]=0;if((f|0)==1){break _a}if(s==0){break $a}s=2646e7/(s*+(B(v[a+480216>>2],v[a+480196>>2])>>>0));if(!(s<4294967296&s>=0)){break lb}f=~~s>>>0;break kb}if((f|0)<=1314144591){if((f|0)==844387158){break ab}if((f|0)!=1280004692){break $a}j=0;if(!x[a+480188>>1]){break $a}while(1){v[114578]=0;d=Q(258,e+88|0,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}if(!d){break $a}d=Wb(e+240|0);v[114578]=0;W(597,e+88|0,d|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ib}f=Tb(d);k=Fb(d);v[114578]=0;X(416,e+24|0,3,f|0,k|0);f=v[114578];v[114578]=0;if((f|0)==1){break hb}v[114578]=0;R(417,e+160|0,e+24|0);f=v[114578];v[114578]=0;if((f|0)==1){break hb}v[114578]=0;Q(380,((j<<5)+a|0)+480289|0,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break gb}yb(e+160|0);yb(d);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break $a}if((f|0)==1397445204){break jb}if((f|0)!=1314144592){break $a}d=0;if(!(w[n|0]|w[n+1|0]<<8)){break $a}while(1){v[114578]=0;f=Q(258,e+88|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break eb}if(!f){break $a}v[114578]=0;f=Q(918,o|0,d&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break eb}if(!f){break $a}f=Wb(e+240|0);v[114578]=0;W(597,e+88|0,f|0,-1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break db}j=_b(o,d);v[114578]=0;Q(496,j|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break db}yb(f);d=d+1|0;if(d>>>0<(w[n|0]|w[n+1|0]<<8)>>>0){continue}break}break $a}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}f=0}v[d+480204>>2]=f;break $a}v[114578]=0;d=T(359,e+88|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}v[a+480232>>2]=d>>>9;v[a+480228>>2]=d>>>8;d=0;if(!x[a+480188>>1]){break $a}while(1){v[114578]=0;f=Q(919,e+88|0,e+240|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break F}if(f){u[((d<<5)+a|0)+480286>>1]=(w[e+240|0]|w[e+241|0]<<8)>>>10;f=w[h|0];H=wc(l,d),I=f,t[H|0]=I}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break $a}h=P()|0;O()|0;break fb}h=P()|0;O()|0;break fb}h=P()|0;O()|0;yb(e+160|0)}yb(d);break C}h=P()|0;O()|0;break C}h=P()|0;O()|0;yb(f);break C}v[114578]=0;Q(340,e+88|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}v[114578]=0;d=T(332,e+88|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}v[114578]=0;aa(584,i|0,e+88|0,d|0,2)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break $a}break D}v[114578]=0;Q(920,e+88|0,e+24|0)|0;d=v[114578];v[114578]=0;nb:{if((d|0)!=1){d=Wb(e+240|0);v[114578]=0;W(597,e+88|0,d|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break nb}if(Et(d,16405)){v[114578]=0;U(13,e+160|0,7,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break nb}Gb(g,e+160|0);yb(e+160|0)}yb(d);break $a}h=P()|0;O()|0;break C}h=P()|0;O()|0;yb(d);break C}v[114578]=0;E=T(392,e+88|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}}Bb(e+88|0);continue}break}h=P()|0;O()|0;break C}h=P()|0;O()|0;break C}h=P()|0;O()|0;break C}h=P()|0;O()|0}Bb(e+88|0)}qq(l);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0}Bb(e+1296|0)}Bb(e+1312|0)}S(h|0);L()}d=1}jb=e+1728|0;return d|0}function n1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=C(0),s=0,A=C(0),D=0,E=0,F=0,G=0,H=C(0),I=0,J=0,K=0,M=C(0),N=0,O=C(0),P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=C(0),$=0,aa=0,ba=0,ca=0,da=C(0),ea=C(0),fa=C(0),ga=C(0),ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;aa=jb-16|0;jb=aa;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{h=b+e|0;if(w[h|0]!=79|(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))!=(w[84480]|w[84481]<<8|(w[84482]<<16|w[84483]<<24))){break f}n=b+26|0;if((n|0)>=(a|0)){break e}p=b+27|0;j=e+n|0;c=w[j|0];if((a|0)<=(p+c|0)){break e}i=c+27|0;f=0;if(c){while(1){i=w[e+(f+p|0)|0]+i|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){f=yw(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}c=23;while(1){f=yw(f,0);if((c|0)!=26){c=c+1|0;continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=i-26;v[c+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);f=w[e+(n+w[j|0]|0)|0]==255?-1:w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24);v[c+1436>>2]=n;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){h=d+B(a,20)|0;j=h+1432|0;c=v[j>>2];f=0;n=v[h+1436>>2];i=b-n|0;l=h+1428|0;p=v[l>>2];i=(i|0)<(p|0)?i:p;if((i|0)>=1){while(1){c=yw(c,w[e+(f+n|0)|0]);k=f+1|0;f=k;if((i|0)!=(k|0)){continue}break}}f=p-i|0;v[l>>2]=f;v[j>>2]=c;g:{if(!f){f=c;c=h+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=i+n|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;h=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=h;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!LG(a)){v[f>>2]=0;b=0;break a}ha=jb-16|0;jb=ha;h=aa+4|0;p=h;n=a;c=n;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}l=Ae(g);if(v[g+96>>2]){break i}if((l|0)!=79){break j}if((Ae(g)|0)!=103){break j}if((Ae(g)|0)!=103){break j}if((Ae(g)|0)!=83){break j}if(!GG(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;dc(g,32);break i}j=vw(g);break i}dc(g,30)}if(!j){break h}if(jc(c,1)){dc(c,35);break h}j=ha;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=jc(c,ll(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ha+12>>2]=g;l=c+B(g,6)|0;if(!w[l+412|0]){i=v[c+112>>2];g=i>>1;break m}i=v[c+116>>2];g=i>>1;k=jc(c,1);J=jc(c,1);if(k|!w[l+412|0]){break m}v[p>>2]=i-v[c+112>>2]>>2;k=v[c+112>>2]+i>>2;break l}ia(50440,50496,3137,50528);L()}v[p>>2]=0;k=g}v[j+8>>2]=k;n:{if(!(!w[l+412|0]|J)){g=B(i,3);v[aa+8>>2]=g-v[c+112>>2]>>2;i=g+v[c+112>>2]>>2;break n}v[aa+8>>2]=g}v[ha+4>>2]=i;i=1}if(i){o:{Z=v[h>>2];oa=v[aa+8>>2];na=v[ha+4>>2];qa=h;p=0;P=jb-2368|0;jb=P;q=v[n+404>>2];pa=n+B(v[ha+12>>2],6)|0;D=w[pa+413|0];W=q+B(D,40)|0;ba=W;X=v[(n+(w[pa+412|0]<<2)|0)+104>>2];p:{i=v[n+4>>2];q:{if((i|0)>0){while(1){c=w[(v[ba+4>>2]+B(p,3)|0)+2|0];R=(P+1344|0)+(p<<2)|0;v[R>>2]=0;g=w[(c+W|0)+9|0];if(!x[(n+(g<<1)|0)+132>>1]){dc(n,21);c=0;break q}h=v[n+260>>2];r:{s:{if(jc(n,1)){c=2;l=v[(n+(p<<2)|0)+996>>2];j=h+B(g,1596)|0;G=v[(w[j+1588|0]<<2)+50668>>2];g=ll(G)-1|0;za=l,Aa=jc(n,g),u[za>>1]=Aa;za=l,Aa=jc(n,g),u[za+2>>1]=Aa;i=0;if(w[j|0]){while(1){S=w[(i+j|0)+1|0];h=S+j|0;k=w[h+33|0];g=0;s=w[h+49|0];t:{if(!s){break t}h=v[n+124>>2]+B(w[h+65|0],2096)|0;if(v[n+1396>>2]<=9){dk(n)}m=v[n+1392>>2];g=u[(h+((m&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=m;m=w[g+v[h+8>>2]|0];v[n+1392>>2]=E>>>m;T=v[n+1396>>2]-m|0;m=(T|0)<0;v[n+1396>>2]=m?0:T;g=m?-1:g;break u}g=kl(n,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(k){K=-1<<s^-1;h=c+k|0;while(1){m=0;k=u[((j+(S<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((k|0)<0){break v}k=v[n+124>>2]+B(k&65535,2096)|0;if(v[n+1396>>2]<=9){dk(n)}T=v[n+1392>>2];m=u[(k+((T&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){E=T;T=w[m+v[k+8>>2]|0];v[n+1392>>2]=E>>>T;J=v[n+1396>>2]-T|0;T=(J|0)<0;v[n+1396>>2]=T?0:J;m=T?-1:m;break w}m=kl(n,k)}if(!w[k+23|0]){break v}m=v[v[k+2088>>2]+(m<<2)>>2]}g=g>>s;u[l+(c<<1)>>1]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}i=i+1|0;if(i>>>0<w[j|0]){continue}break}}if(v[n+1396>>2]!=-1){break s}}v[R>>2]=1;break r}u[P+320>>1]=257;h=j+1592|0;c=v[j+1592>>2];if((c|0)>=3){g=2;while(1){c=j+338|0;i=g<<1;m=i+j|0;T=w[m+1088|0];s=T<<1;k=x[c+s>>1];R=w[m+1089|0];S=R<<1;K=u[l+s>>1];m=u[S+l>>1]-K|0;s=m>>31;c=(B(x[c+i>>1]-k|0,s^m+s)|0)/(x[c+S>>1]-k|0)|0;m=K+((m|0)<0?0-c|0:c)|0;s=i+l|0;i=x[s>>1];x:{y:{if(i){t[R+(P+320|0)|0]=1;t[T+(P+320|0)|0]=1;t[(P+320|0)+g|0]=1;c=i<<16>>16;k=G-m|0;if((c|0)>=((m|0)>(k|0)?k:m)<<1){if((m|0)<(k|0)){break x}m=G+(i^-1)|0;break y}if(c&1){m=m-(c+1>>>1|0)|0;break y}m=(c>>1)+m|0;break y}t[(P+320|0)+g|0]=0}u[s>>1]=m}c=v[h>>2];g=g+1|0;if((c|0)>(g|0)){continue}break}}m=0;if((c|0)<=0){break r}while(1){if(!w[(P+320|0)+m|0]){u[l+(m<<1)>>1]=65535;c=v[h>>2]}m=m+1|0;if((m|0)<(c|0)){continue}break}}i=v[n+4>>2];p=p+1|0;if((i|0)>(p|0)){continue}break}}z:{A:{c=v[n+80>>2];if(!(v[n+84>>2]!=v[n+92>>2]?c:0)){lc(P+320|0,P+1344|0,i<<2);h=x[W>>1];if(h){p=v[ba+4>>2];m=0;while(1){j=p+B(m,3)|0;g=w[j+1|0];j=(P+1344|0)+(w[j|0]<<2)|0;if(!(v[(P+1344|0)+(g<<2)>>2]?v[j>>2]:0)){v[(P+1344|0)+(g<<2)>>2]=0;v[j>>2]=0}m=m+1|0;if((h|0)!=(m|0)){continue}break}}T=X>>1;la=q+B(D,40)|0;if(w[la+8|0]){c=0;while(1){B:{if((i|0)<1){g=0;break B}j=v[ba+4>>2];m=0;g=0;while(1){if(w[(j+B(m,3)|0)+2|0]==(c|0)){l=g+P|0;h=m<<2;C:{if(v[h+(P+1344|0)>>2]){p=1;h=0;break C}p=0;h=v[(h+n|0)+800>>2]}t[l|0]=p;v[(P+256|0)+(g<<2)>>2]=h;g=g+1|0}m=m+1|0;if((m|0)!=(i|0)){continue}break}}ca=P+256|0;D=P;I=jb-16|0;jb=I;h=n;J=v[h+4>>2];m=v[h+396>>2];l=w[(c+la|0)+24|0];U=m+B(l,24)|0;j=v[U+4>>2];p=T;ma=x[(h+(l<<1)|0)+268>>1];i=p<<((ma|0)==2);k=i>>>0>j>>>0?j:i;j=v[U>>2];E=(k-(i>>>0>j>>>0?j:i)>>>0)/y[U+8>>2]|0;G=E<<2;i=B(J,G+4|0);V=v[v[h+124>>2]+B(w[U+13|0],2096)>>2];va=v[h+92>>2];D:{if(v[h+80>>2]){i=Jm(h,i);J=v[h+4>>2];break D}i=od(i)}j=0;if((J|0)>=1){k=(J<<2)+i|0;while(1){v[(j<<2)+i>>2]=k;k=k+G|0;j=j+1|0;if((J|0)!=(j|0)){continue}break}}G=i;E:{F:{G:{H:{I:{if((g|0)>=1){i=p<<2;j=0;while(1){if(!w[j+D|0]){Rb(v[ca+(j<<2)>>2],0,i)}j=j+1|0;if((j|0)!=(g|0)){continue}break}if((ma|0)!=2){break F}if((g|0)!=1){break I}break F}if((ma|0)!=2){break F}break H}j=0;if((g|0)<=0){break H}while(1){i=(g|0)==(j|0);if(!w[j+D|0]){break G}j=j+1|0;if((j|0)!=(g|0)){continue}break}break E}i=!g}if(i){break E}m=m+B(l,24)|0;s=m;R=(g|0)!=2;D=(E|0)<1;S=(g|0)<3;k=0;while(1){J:{if(!R){j=0;J=0;if(D){break J}while(1){i=v[U>>2]+B(v[U+8>>2],j)|0;v[I+12>>2]=i&1;v[I+8>>2]=i>>1;if(!k){l=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){dk(h)}q=v[h+1392>>2];i=u[(l+((q&1023)<<1)|0)+36>>1];K:{if((i|0)>=0){K=q;q=w[i+v[l+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;i=q?-1:i;break K}i=kl(h,l)}i=w[l+23|0]?v[v[l+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[G>>2]+(J<<2)>>2]=v[v[m+16>>2]+(i<<2)>>2]}L:{if((V|0)<1){break L}i=0;if((j|0)>=(E|0)){break L}while(1){l=v[U+8>>2];q=u[(v[s+20>>2]+(w[v[v[G>>2]+(J<<2)>>2]+i|0]<<4)|0)+(k<<1)>>1];M:{if((q|0)>=0){if(FG(h,v[h+124>>2]+B(q&65535,2096)|0,ca,2,I+12|0,I+8|0,p,l)){break M}break E}l=v[U>>2]+(l+B(j,l)|0)|0;v[I+8>>2]=l>>1;v[I+12>>2]=l&1}j=j+1|0;i=i+1|0;if((V|0)<=(i|0)){break L}if((j|0)<(E|0)){continue}break}}J=J+1|0;if((j|0)<(E|0)){continue}break}break J}if(S){break J}j=0;J=0;if(D){break J}while(1){l=v[U>>2]+B(v[U+8>>2],j)|0;i=(l|0)/(g|0)|0;v[I+12>>2]=l-B(g,i);v[I+8>>2]=i;if(!k){l=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){dk(h)}q=v[h+1392>>2];i=u[(l+((q&1023)<<1)|0)+36>>1];N:{if((i|0)>=0){K=q;q=w[i+v[l+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;i=q?-1:i;break N}i=kl(h,l)}i=w[l+23|0]?v[v[l+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[G>>2]+(J<<2)>>2]=v[v[m+16>>2]+(i<<2)>>2]}O:{if((V|0)<1){break O}i=0;if((j|0)>=(E|0)){break O}while(1){l=v[U+8>>2];q=u[(v[s+20>>2]+(w[v[v[G>>2]+(J<<2)>>2]+i|0]<<4)|0)+(k<<1)>>1];P:{if((q|0)>=0){if(FG(h,v[h+124>>2]+B(q&65535,2096)|0,ca,g,I+12|0,I+8|0,p,l)){break P}break E}l=v[U>>2]+(l+B(j,l)|0)|0;q=(l|0)/(g|0)|0;v[I+8>>2]=q;v[I+12>>2]=l-B(g,q)}j=j+1|0;i=i+1|0;if((V|0)<=(i|0)){break O}if((j|0)<(E|0)){continue}break}}J=J+1|0;if((j|0)<(E|0)){continue}break}}k=k+1|0;if((k|0)!=8){continue}break}break E}ra=m+B(l,24)|0;wa=ra;xa=(E|0)<1;J=0;while(1){if(!xa){i=0;sa=(g|0)<1;ya=sa|(J|0)!=0;p=0;while(1){j=0;if(!ya){while(1){if(!w[j+D|0]){l=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){dk(h)}m=v[h+1392>>2];k=u[(l+((m&1023)<<1)|0)+36>>1];Q:{if((k|0)>=0){q=m;m=w[k+v[l+8>>2]|0];v[h+1392>>2]=q>>>m;s=v[h+1396>>2]-m|0;m=(s|0)<0;v[h+1396>>2]=m?0:s;k=m?-1:k;break Q}k=kl(h,l)}k=w[l+23|0]?v[v[l+2088>>2]+(k<<2)>>2]:k;if((k|0)==-1){break E}v[v[G+(j<<2)>>2]+(i<<2)>>2]=v[v[ra+16>>2]+(k<<2)>>2]}j=j+1|0;if((j|0)!=(g|0)){continue}break}}R:{if((V|0)<1){break R}k=0;if((p|0)>=(E|0)){break R}while(1){j=0;if(!sa){while(1){S:{if(w[j+D|0]){break S}m=j<<2;l=u[(v[wa+20>>2]+(w[v[v[m+G>>2]+(i<<2)>>2]+k|0]<<4)|0)+(J<<1)>>1];if((l|0)<0){break S}R=h;l=v[h+124>>2]+B(l&65535,2096)|0;$=v[m+ca>>2];Y=v[U+8>>2];m=v[U>>2]+B(Y,p)|0;T:{U:{V:{if(ma){N=0;S=1;if((Y|0)<=0){break T}while(1){ja=$+(m<<2)|0;K=Y-N|0;s=0;o=C(0);F=DG(R,l);W:{if((F|0)<0){break W}q=l;s=v[l>>2];K=(s|0)<(K|0)?s:K;ka=B(s,F);X:{Y:{if(w[l+22|0]){F=0;if((K|0)>0){break Y}break X}F=0;if((K|0)<=0){break X}while(1){s=ja+(F<<2)|0;z[s>>2]=z[s>>2]+z[v[q+28>>2]+(F+ka<<2)>>2];s=1;F=F+1|0;if((K|0)!=(F|0)){continue}break}break W}while(1){s=ja+(F<<2)|0;o=C(z[v[q+28>>2]+(F+ka<<2)>>2]+o);z[s>>2]=z[s>>2]+o;o=C(z[q+12>>2]+o);s=1;F=F+1|0;if((K|0)!=(F|0)){continue}break}break W}s=1}if(!s){break V}s=v[l>>2];m=s+m|0;N=s+N|0;if((Y|0)>(N|0)){continue}break}break T}N=0;q=(Y|0)/v[l>>2]|0;if((q|0)<=0){break U}ja=$+(m<<2)|0;while(1){ka=ja+(N<<2)|0;F=Y-(m+N|0)|0;K=q;s=0;o=C(0);ta=DG(R,l);Z:{if((ta|0)<0){break Z}s=1;S=l;$=v[l>>2];ua=(F|0)>($|0)?$:F;if((ua|0)<1){break Z}$=B($,ta);F=0;while(1){s=ka+(B(F,K)<<2)|0;A=C(z[v[S+28>>2]+(F+$<<2)>>2]+o);z[s>>2]=z[s>>2]+A;o=w[S+22|0]?A:o;s=1;F=F+1|0;if((ua|0)!=(F|0)){continue}break}}if(!s){break V}N=N+1|0;if((q|0)!=(N|0)){continue}break}break U}S=0;break T}S=1}if(!S){break E}}j=j+1|0;if((j|0)!=(g|0)){continue}break}}p=p+1|0;k=k+1|0;if((V|0)<=(k|0)){break R}if((p|0)<(E|0)){continue}break}}i=i+1|0;if((p|0)<(E|0)){continue}break}}J=J+1|0;if((J|0)!=8){continue}break}}if(!v[h+80>>2]){Xb(G)}v[h+92>>2]=va;jb=I+16|0;c=c+1|0;if(c>>>0<w[la+8|0]){i=v[n+4>>2];continue}break}c=v[n+80>>2]}if(!(v[n+84>>2]!=v[n+92>>2]?c:0)){i=x[W>>1];if(i){h=(T|0)>1?T:1;g=n+800|0;while(1){c=i;i=c-1|0;if((X|0)>=2){p=v[ba+4>>2]+B(i,3)|0;j=v[g+(w[p+1|0]<<2)>>2];p=v[g+(w[p|0]<<2)>>2];m=0;while(1){l=m<<2;k=l+j|0;r=z[k>>2];l=l+p|0;o=z[l>>2];_:{if(!(o<=C(0))){if(!(r<=C(0))){A=C(o-r);break _}A=o;o=C(r+o);break _}if(!(r<=C(0))){A=C(r+o);break _}A=o;o=C(o-r)}z[l>>2]=o;z[k>>2]=A;m=m+1|0;if((h|0)!=(m|0)){continue}break}}if((c|0)>1){continue}break}}m=0;if(v[n+4>>2]<=0){break z}U=T<<2;while(1){g=m<<2;h=g+n|0;c=h;$:{if(v[g+(P+320|0)>>2]){Rb(v[c+800>>2],0,U);break $}g=X;i=v[c+800>>2];S=v[h+996>>2];p=1;c=n;h=w[(W+w[(v[W+4>>2]+B(m,3)|0)+2|0]|0)+9|0];aa:{if(!x[(c+(h<<1)|0)+132>>1]){dc(c,21);break aa}s=g>>1;G=v[c+260>>2]+B(h,1596)|0;c=B(w[G+1588|0],u[S>>1]);g=0;k=v[G+1592>>2];if((k|0)>=2){F=G+1592|0;I=G+1588|0;while(1){h=w[(p+G|0)+838|0]<<1;j=u[h+S>>1];if((j|0)>=0){j=B(w[I|0],j&65535);h=x[(h+G|0)+338>>1];if((h|0)!=(g|0)){l=i;k=g;D=j-c|0;q=h-g|0;R=(D|0)/(q|0)|0;ba:{K=(h|0)>(s|0)?s:h;if((K|0)<=(g|0)){break ba}g=l+(k<<2)|0;z[g>>2]=z[g>>2]*z[((c&255)<<2)+50880>>2];g=k+1|0;if((K|0)<=(g|0)){break ba}k=(D|0)>-1?1:-1;E=D;D=D>>31;E=E+D^D;D=R>>31;D=E-B(q,D+R^D)|0;J=D;while(1){E=l+(g<<2)|0;N=E;o=z[E>>2];E=(q|0)>(J|0);c=(c+R|0)+(E?0:k)|0;z[N>>2]=o*z[((c&255)<<2)+50880>>2];g=g+1|0;if((K|0)==(g|0)){break ba}J=D+(J-(E?0:q)|0)|0;continue}}k=v[F>>2];g=h}c=j}p=p+1|0;if((k|0)>(p|0)){continue}break}}if((g|0)<(s|0)){o=z[(c<<2)+50880>>2];while(1){c=i+(g<<2)|0;z[c>>2]=z[c>>2]*o;g=g+1|0;if((s|0)!=(g|0)){continue}break}}}}m=m+1|0;c=v[n+4>>2];if((m|0)<(c|0)){continue}break}break A}ia(50440,50496,3319,50688);L()}ia(50440,50496,3286,50688);L()}m=0;if((c|0)<=0){break z}while(1){ba=w[pa+412|0];G=X;V=G>>1;g=V<<2;s=n;ma=v[n+92>>2];p=v[(n+(m<<2)|0)+800>>2];c=V<<2;W=p+c|0;ca:{if(v[n+80>>2]){l=Jm(s,g);break ca}l=od(g)}h=(l+c|0)-8|0;k=v[(s+(ba<<2)|0)+1068>>2];da:{if(!V){g=k;break da}c=p;g=k;while(1){z[h+4>>2]=C(z[g>>2]*z[c>>2])-C(z[g+4>>2]*z[c+8>>2]);z[h>>2]=C(z[g>>2]*z[c+8>>2])+C(z[g+4>>2]*z[c>>2]);g=g+8|0;h=h-8|0;c=c+16|0;if((W|0)!=(c|0)){continue}break}}if(h>>>0>=l>>>0){c=((V<<2)+p|0)-12|0;while(1){z[h+4>>2]=C(z[g+4>>2]*z[c>>2])-C(z[g>>2]*z[c+8>>2]);z[h>>2]=C(z[g>>2]*C(-z[c>>2]))-C(z[g+4>>2]*z[c+8>>2]);c=c-16|0;g=g+8|0;h=h-8|0;if(l>>>0<=h>>>0){continue}break}}ca=G>>2;if((G|0)>=16){c=ca<<2;h=c+l|0;j=c+p|0;g=(k+(V<<2)|0)-32|0;i=p;c=l;while(1){o=z[c>>2];A=z[h>>2];r=z[c+4>>2];H=z[h+4>>2];z[j+4>>2]=r+H;z[j>>2]=z[c>>2]+z[h>>2];r=C(H-r);o=C(A-o);z[i+4>>2]=C(z[g+16>>2]*r)-C(z[g+20>>2]*o);z[i>>2]=C(z[g+20>>2]*r)+C(z[g+16>>2]*o);o=z[c+8>>2];A=z[h+8>>2];r=z[c+12>>2];H=z[h+12>>2];z[j+12>>2]=r+H;z[j+8>>2]=z[c+8>>2]+z[h+8>>2];r=C(H-r);o=C(A-o);z[i+12>>2]=C(z[g>>2]*r)-C(z[g+4>>2]*o);z[i+8>>2]=C(z[g+4>>2]*r)+C(z[g>>2]*o);c=c+16|0;h=h+16|0;i=i+16|0;j=j+16|0;g=g-32|0;if(k>>>0<=g>>>0){continue}break}}D=ll(G);g=G>>4;j=V-1|0;c=G>>3;h=0-c|0;EG(g,p,j,h,k);EG(g,p,j-ca|0,h,k);Y=G>>5;g=0-g|0;zo(Y,p,j,g,k,16);zo(Y,p,j-c|0,g,k,16);zo(Y,p,j-(c<<1)|0,g,k,16);zo(Y,p,j+B(c,-3)|0,g,k,16);i=2;if((D|0)>=10){i=D-4>>>1|0;h=2;while(1){c=h;h=c+1|0;q=2<<c;if((q|0)>=1){R=8<<c;S=G>>c+4;g=0;c=G>>c+2;K=0-(c>>1)|0;while(1){zo(S,p,j-B(c,g)|0,K,k,R);g=g+1|0;if((q|0)!=(g|0)){continue}break}}if((h|0)!=(i|0)){continue}break}}la=D-7|0;if((la|0)>(i|0)){while(1){c=i;i=c+1|0;g=G>>c+6;if((g|0)>=1){S=2<<c;K=8<<c;$=K<<2;J=G>>c+2;U=0-(J>>1)|0;h=k;c=j;while(1){F=p;I=c;E=U;D=h;q=K;N=J;R=S;if((R|0)>=1){ja=D+B(q,12)|0;o=z[ja>>2];ka=q<<3;A=z[ka+D>>2];q=D+(q<<2)|0;r=z[q>>2];H=z[ja+4>>2];M=z[D+(ka|4)>>2];da=z[q+4>>2];ea=z[D+4>>2];fa=z[D>>2];D=F+(I<<2)|0;F=D+(E<<2)|0;q=0-N<<2;while(1){I=F-4|0;Q=z[I>>2];ga=z[F>>2];_=z[D>>2];z[D>>2]=ga+_;E=D-4|0;O=z[E>>2];z[E>>2]=z[I>>2]+O;O=C(O-Q);Q=C(_-ga);z[I>>2]=C(O*fa)+C(Q*ea);z[F>>2]=C(Q*fa)-C(O*ea);I=F-12|0;ga=z[I>>2];E=D-8|0;O=z[E>>2];N=E;E=F-8|0;_=z[E>>2];z[N>>2]=_+O;N=D-12|0;Q=z[N>>2];z[N>>2]=z[I>>2]+Q;Q=C(Q-ga);O=C(O-_);z[I>>2]=C(Q*r)+C(O*da);z[E>>2]=C(O*r)-C(Q*da);I=F-20|0;ga=z[I>>2];E=D-16|0;O=z[E>>2];N=E;E=F-16|0;_=z[E>>2];z[N>>2]=_+O;N=D-20|0;Q=z[N>>2];z[N>>2]=z[I>>2]+Q;Q=C(Q-ga);O=C(O-_);z[I>>2]=C(Q*A)+C(O*M);z[E>>2]=C(O*A)-C(Q*M);I=F-28|0;ga=z[I>>2];E=D-24|0;O=z[E>>2];N=E;E=F-24|0;_=z[E>>2];z[N>>2]=_+O;N=D-28|0;Q=z[N>>2];z[N>>2]=z[I>>2]+Q;Q=C(Q-ga);O=C(O-_);z[I>>2]=C(Q*o)+C(O*H);z[E>>2]=C(O*o)-C(Q*H);F=q+F|0;D=D+q|0;I=(R|0)>1;R=R-1|0;if(I){continue}break}}c=c-8|0;h=($<<2)+h|0;D=(g|0)>1;g=g-1|0;if(D){continue}break}}if((i|0)!=(la|0)){continue}break}}c=p;g=G;if((0-(Y<<4)|0)<=-1){c=c+(j<<2)|0;h=c-(Y<<6)|0;o=z[k+(g>>3<<2)>>2];while(1){g=c-32|0;r=z[g>>2];H=z[c>>2];z[c>>2]=r+H;i=c-4|0;A=z[i>>2];k=i;i=c-36|0;M=z[i>>2];z[k>>2]=M+A;z[g>>2]=H-r;z[i>>2]=A-M;i=c-8|0;A=z[i>>2];k=i;i=c-40|0;H=z[i>>2];z[k>>2]=H+A;j=c-12|0;r=z[j>>2];k=j;j=c-44|0;M=z[j>>2];z[k>>2]=M+r;r=C(r-M);A=C(A-H);z[i>>2]=C(r+A)*o;z[j>>2]=C(r-A)*o;i=c-20|0;A=z[i>>2];j=c-52|0;r=z[j>>2];k=c-16|0;H=z[k>>2];q=k;k=c-48|0;M=z[k>>2];z[q>>2]=H+M;z[i>>2]=r+A;z[k>>2]=A-r;z[j>>2]=M-H;i=c-60|0;A=z[i>>2];j=c-28|0;r=z[j>>2];k=c-24|0;H=z[k>>2];q=k;k=c-56|0;M=z[k>>2];z[q>>2]=H+M;z[j>>2]=A+r;A=C(r-A);r=C(M-H);z[k>>2]=C(A+r)*o;z[i>>2]=C(r-A)*o;CG(c);CG(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}k=V-4|0;g=(l+(ca<<2)|0)-16|0;if(l>>>0<=g>>>0){h=l+(k<<2)|0;c=v[(s+(ba<<2)|0)+1100>>2];while(1){i=(x[c>>1]<<2)+p|0;z[h+12>>2]=z[i>>2];z[h+8>>2]=z[i+4>>2];z[g+12>>2]=z[i+8>>2];z[g+8>>2]=z[i+12>>2];i=(x[c+2>>1]<<2)+p|0;z[h+4>>2]=z[i>>2];z[h>>2]=z[i+4>>2];z[g+4>>2]=z[i+8>>2];z[g>>2]=z[i+12>>2];c=c+4|0;h=h-16|0;g=g-16|0;if(l>>>0<=g>>>0){continue}break}}h=l+(V<<2)|0;i=h-16|0;if(l>>>0<i>>>0){c=v[(s+(ba<<2)|0)+1084>>2];j=h;g=l;while(1){o=z[c+4>>2];D=j-4|0;A=z[D>>2];r=z[g+4>>2];H=C(A+r);M=z[c>>2];da=z[g>>2];q=j-8|0;ea=z[q>>2];fa=C(da-ea);O=C(C(o*H)-C(M*fa));A=C(r-A);z[g+4>>2]=O+A;o=C(C(M*H)+C(o*fa));r=C(ea+da);z[g>>2]=o+r;z[D>>2]=O-A;z[q>>2]=r-o;o=z[c+12>>2];j=j-12|0;A=z[j>>2];r=z[g+12>>2];H=C(A+r);M=z[c+8>>2];da=z[g+8>>2];ea=z[i>>2];fa=C(da-ea);O=C(C(o*H)-C(M*fa));A=C(r-A);z[g+12>>2]=O+A;o=C(C(M*H)+C(o*fa));r=C(ea+da);z[g+8>>2]=o+r;z[i>>2]=r-o;z[j>>2]=O-A;c=c+16|0;g=g+16|0;j=i;i=i-16|0;if(g>>>0<i>>>0){continue}break}}i=h-32|0;if(l>>>0<=i>>>0){g=v[(s+(ba<<2)|0)+1076>>2]+(V<<2)|0;c=(k<<2)+p|0;j=((G<<2)+p|0)-16|0;while(1){o=z[g-4>>2];A=z[h-8>>2];r=z[g-8>>2];H=z[h-4>>2];M=C(C(o*A)-C(r*H));z[p>>2]=M;z[c+12>>2]=-M;o=C(C(r*C(-A))-C(H*o));z[W>>2]=o;z[j+12>>2]=o;o=z[g-12>>2];A=z[h-16>>2];r=z[g-16>>2];H=z[h-12>>2];M=C(C(o*A)-C(r*H));z[p+4>>2]=M;z[c+8>>2]=-M;o=C(C(r*C(-A))-C(H*o));z[W+4>>2]=o;z[j+8>>2]=o;o=z[g-20>>2];A=z[h-24>>2];r=z[g-24>>2];H=z[h-20>>2];M=C(C(o*A)-C(r*H));z[p+8>>2]=M;z[c+4>>2]=-M;o=C(C(r*C(-A))-C(H*o));z[W+8>>2]=o;z[j+4>>2]=o;o=z[g-28>>2];A=z[i>>2];g=g-32|0;r=z[g>>2];H=z[h-28>>2];M=C(C(o*A)-C(r*H));z[p+12>>2]=M;z[c>>2]=-M;o=C(C(r*C(-A))-C(H*o));z[W+12>>2]=o;z[j>>2]=o;j=j-16|0;c=c-16|0;W=W+16|0;p=p+16|0;h=i;i=h-32|0;if(l>>>0<=i>>>0){continue}break}}if(!v[s+80>>2]){Xb(l)}v[s+92>>2]=ma;m=m+1|0;if((m|0)<v[n+4>>2]){continue}break}}IG(n);ea:{if(w[n+1377|0]){v[n+1060>>2]=0-T;t[n+1377|0]=0;v[n+1064>>2]=1;v[n+1412>>2]=X-na;break ea}c=v[n+1412>>2];if(!c){break ea}g=oa-Z|0;if((g|0)<=(c|0)){v[n+1412>>2]=c-g;v[qa>>2]=oa;Z=oa;break ea}Z=c+Z|0;v[qa>>2]=Z;v[n+1412>>2]=0}c=v[n+1064>>2];fa:{ga:{ha:{if(v[n+1388>>2]==v[n+1404>>2]){ia:{if(!c|!(w[n+1375|0]&4)){break ia}c=v[n+1408>>2];g=v[n+1060>>2];if(c>>>0>=g+(na-Z|0)>>>0){break ia}g=c-g|0;c=(c>>>0<g>>>0?0:g)+Z|0;c=(c|0)>(na|0)?na:c;v[aa+12>>2]=c;v[n+1060>>2]=c+v[n+1060>>2];break fa}v[n+1064>>2]=1;v[n+1060>>2]=v[n+1408>>2]+(Z-T|0);break ha}if(!c){break ga}}v[n+1060>>2]=v[n+1060>>2]+(oa-Z|0)}if(v[n+84>>2]!=v[n+92>>2]?v[n+80>>2]:0){break p}v[aa+12>>2]=na}c=1}jb=P+2368|0;break o}ia(50440,50496,3435,50688);L()}}else{c=0}jb=ha+16|0;if(!c){ja:{ka:{la:{c=v[a+100>>2];switch(c-32|0){case 0:break ka;case 3:break la;default:break ja}}v[a+100>>2]=0;while(1){if(za=0,Aa=(Lg(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ja}v[a+100>>2]=0;while(1){if(za=0,Aa=(Lg(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}p=aa;l=v[p+12>>2];G=v[p+4>>2];k=G;g=v[p+8>>2];i=0;ma:{na:{c=a;j=v[c+992>>2];oa:{if(!j){h=v[c+4>>2];j=0;break oa}X=j<<1;pa:{if((X|0)==v[c+112>>2]){h=n+1092|0}else{h=0;if((X|0)!=v[n+116>>2]){break pa}h=n+1096|0}h=v[h>>2]}n=h;if(!n){break na}h=v[c+4>>2];if((h|0)>=1){X=(j|0)<1;while(1){if(!X){m=c+(i<<2)|0;P=m;h=0;while(1){Z=v[m+800>>2]+(h+k<<2)|0;s=h<<2;z[Z>>2]=C(z[n+(j+(h^-1)<<2)>>2]*z[s+v[P+928>>2]>>2])+C(z[n+s>>2]*z[Z>>2]);h=h+1|0;if((j|0)!=(h|0)){continue}break}h=v[c+4>>2]}i=i+1|0;if((i|0)<(h|0)){continue}break}}j=v[c+992>>2]}X=l-g|0;v[c+992>>2]=X;if((h|0)>=1){i=0;while(1){if((g|0)<(l|0)){m=c+(i<<2)|0;P=m;h=0;n=g;while(1){z[v[P+928>>2]+(h<<2)>>2]=z[v[m+800>>2]+(n<<2)>>2];h=h+1|0;n=g+h|0;if((h|0)!=(X|0)){continue}break}h=v[c+4>>2]}i=i+1|0;if((i|0)<(h|0)){continue}break}}if(!j){break na}h=c;i=v[c+1416>>2];c=((g|0)>(l|0)?l:g)-k|0;v[h+1416>>2]=i+c;break ma}c=0}g=c;v[p+12>>2]=c;h=v[a+4>>2];if((h|0)>=1){c=0;while(1){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(G<<2);c=c+1|0;if((h|0)!=(c|0)){continue}break}}if(d){v[d>>2]=h}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}jb=aa+16|0;return b|0}function tg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,D=0;d=jb-2928|0;jb=d;a:{b:{if(vq(c)){Cc(b,268435456);o=v[c+8>>2];i=d+2904|0;e=i;v[e>>2]=0;v[e+4>>2]=0;Oi(e+8|0);v[d+2900>>2]=0;e=d;c:{d:{e:{f:{g:{h:{i:{if(w[a+3|0]-4>>>0<=4){v[114578]=0;g=T(332,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}v[d+2900>>2]=g;break i}g=w[a+3|0];if(g>>>0>18){break i}g=1<<g;j:{if(!(g&126991)){if(g&396800){break j}break i}if(!w[a|0]){break i}}f=v[b>>2];v[114578]=0;f=Q(643,a|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}v[114578]=0;U(856,d+736|0,c|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break g}f=d+736|0;g=v[f+4>>2];v[i>>2]=v[f>>2];v[i+4>>2]=g;g=i+8|0;MM(g);f=f+8|0;El(g,f);v[g>>2]=v[f>>2];v[g+4>>2]=v[f+4>>2];h=v[zb(f)>>2];s=zb(g),D=h,v[s>>2]=D;s=zb(f),D=0,v[s>>2]=D;v[f>>2]=0;v[f+4>>2]=0;Ec(d+736|0);v[114578]=0;f=T(414,i|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}v[d+2900>>2]=v[i>>2]}k:{g=w[a+3|0];if(g>>>0>18){break k}g=1<<g;l:{if(!(g&126991)){if(!(g&396800)){break k}g=1;break l}g=w[a|0]!=0}if(!g|y[b>>2]<262145){break k}g=v[d+2900>>2];h=w[a+3|0];v[114578]=0;v[d+720>>2]=((h|0)==11)<<4;h=Q(33,d+720|0,d+2900|0)|0;k=v[114578];v[114578]=0;if((k|0)!=1){v[d+736>>2]=g-v[h>>2];g=w[a+3|0];if(g>>>0>16){break f}m:{if(!(1<<g&126991)){if((g|0)==11){break m}break f}if(!(w[a|0]&7)){break f}}g=v[d+736>>2];if(g>>>0<=2147483647){g=g<<1;break e}g=-1;break e}a=P()|0;O()|0;break a}n:{if(!(w[a+3|0]==4|w[a+3|0]==5|w[a+3|0]==8)){if(w[a+3|0]!=7){break n}}v[114578]=0;v[d+736>>2]=v[d+2900>>2];g=T(1261,a|0)|0;h=v[114578];v[114578]=0;e=d;o:{p:{if((h|0)!=1){h=v[d+736>>2];g=8/(g>>>0)|0;if(h>>>0>4294967295/(g>>>0)>>>0){break p}g=B(g,h);break o}a=P()|0;O()|0;break a}g=-1}v[e+736>>2]=g;Cc(b,g);break d}if(w[a+3|0]!=6){break d}e=0;if(y[d+2900>>2]<10){break c}v[114578]=0;Q(340,c|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}v[114578]=0;g=T(392,c|0)|0;h=v[114578];v[114578]=0;e=d;q:{r:{s:{if((h|0)!=1){v[d+720>>2]=g;g=v[d+2900>>2];v[114578]=0;v[d+2896>>2]=g;g=Q(333,d+720|0,d+2896|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break s}v[d+736>>2]=v[g>>2];fg(c,8);g=v[d+736>>2];if(g>>>0>50529027){break r}g=B(g,85);break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=-1}v[e+736>>2]=g;Cc(b,(g>>>0)/(w[a|0]>>>3>>>0)|0);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}v[114578]=0;h=T(1261,a|0)|0;g=v[114578];v[114578]=0;t:{u:{if((g|0)!=1){v:{w:{switch(w[a+3|0]){default:g=0;break v;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:g=w[a|0];break v;case 9:g=16;break v;case 11:g=4;break v;case 10:case 17:case 18:break w}}g=8}h=B(g,h)>>>3|0;g=h-1|0;k=v[d+736>>2];if(g>>>0>-1-k>>>0){break u}g=g+k|0;break t}a=P()|0;O()|0;break a}g=-1}g=(g>>>0)/(h>>>0)|0}v[e+736>>2]=g;Cc(b,g)}if(!v[b>>2]){e=0;break c}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[114578]=0;e=T(466,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!e){e=0;v[b>>2]=0;break c}e=ad(d+736|0,8,1,0,11);v[114578]=0;e=Q(1262,a|0,e|0)|0;g=v[114578];v[114578]=0;x:{y:{z:{A:{B:{C:{D:{if((g|0)!=1){if(!e){break z}e=0;v[114578]=0;a=Q(1263,c|0,d+736|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}if(!a){break x}a=v[b>>2];v[114578]=0;v[d+720>>2]=a+1>>>1;a=T(332,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}Cc(d+720|0,a);v[114578]=0;a=T(857,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break C}e=v[d+720>>2];if(e){break B}e=16;break x}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];f=0;while(1){f=w[d+736|w[a|0]&15]+f|0;t[b|0]=f;f=w[d+736|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=f;e=e-1|0;if(!e){break y}a=a+1|0;b=b+2|0;continue}}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=5?w[a+3|0]!=4:0)){a=w[a+3|0];v[114578]=0;a=aa(1264,d+1808|0,c|0,b|0,(a|0)==5|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}Bb(a);e=v[c+8>>2]-o|0;break x}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[114578]=0;Q(340,c|0,4)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}v[114578]=0;a=T(392,c|0)|0;e=v[114578];v[114578]=0;E:{F:{G:{if((e|0)!=1){v[114578]=0;v[d+720>>2]=a;e=T(389,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}v[114578]=0;U(1265,d+736|0,c|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break E}Cc(d+720|0,v[d+736>>2]);v[114578]=0;a=v[d+720>>2];f=T(414,d+736|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){g=v[d+736>>2];h=v[b+20>>2];b=Bj(b);v[114578]=0;fa(1266,f|0,g|0,h|0,b|0,e<<24>>24);b=v[114578];v[114578]=0;if((b|0)!=1){break F}}a=P()|0;O()|0;Ec(d+736|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=a+9|0;Ec(d+736|0);break x}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[d+2900>>2];e=x[Al(d+1800|0)>>1];v[114578]=0;e=aa(1267,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}H:{I:{J:{K:{L:{M:{N:{if(!(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16)){e=0;v[114578]=0;f=Q(258,c|0,8)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!f){break x}v[114578]=0;f=T(392,c|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[d+2900>>2]=f;if(f>>>0<4){break x}v[114578]=0;U(343,d+720|0,c|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break H}f=im(d+736|0,d+720|0);Bb(d+720|0);v[114578]=0;k=T(1268,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}if(!v[b>>2]){break L}h=w[a|0];a=0;p=(h|0)!=16;g=0;while(1){O:{if(p){break O}v[114578]=0;q=Q(260,f|0,8)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break O}a=V(76880)|0;break M}v[114578]=0;r=Q(260,f|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break N}v[114578]=0;e=Q(260,f|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break N}P:{Q:{R:{if(!e){e=8;while(1){v[114578]=0;j=Q(260,f|0,1)|0;n=v[114578];v[114578]=0;if((n|0)==1){break P}if(j){break R}e=e+16|0;continue}}v[114578]=0;e=Q(260,f|0,3)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break Q}break N}v[114578]=0;j=Q(260,f|0,4)|0;n=v[114578];v[114578]=0;if((n|0)==1){break N}e=e+j|0}g=(g&255)+(((r?-1:0)^e)&255)|0;S:{if((h|0)!=16){t[v[b+20>>2]+a|0]=g;break S}u[v[b+20>>2]+(a<<1)>>1]=q&255|g<<8}a=a+1|0;if(a>>>0<y[b>>2]){continue}break L}break}a=V(76880)|0;break M}T:{U:{V:{W:{X:{if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){e=0;if(y[d+2900>>2]<5){break x}a=v[b+20>>2];v[114578]=0;a=T(467,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break X}v[114578]=0;a=T(1269,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}b=Bj(b);v[114578]=0;e=W(1270,c|0,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=8|w[a+1|0]!=1)){Y:{Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 2:break Z;case 1:break _;case 0:break $;default:break aa}}e=0;switch(a-10|0){case 0:break Y;case 2:break Z;default:break x}}v[114578]=0;e=W(1271,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1272,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}a=v[d+2900>>2];e=w[my(d+712|0)|0];v[114578]=0;e=aa(1273,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1274,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=8|w[a+1|0]!=3)){ba:{ca:{da:{ea:{g=w[a+3|0];switch(g|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}v[114578]=0;e=W(1275,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1276,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if((g|0)!=12){break x}}e=v[d+2900>>2];g=w[my(d+704|0)|0];v[114578]=0;e=aa(1277,b|0,f|0,e|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break x}f=v[b>>2]<<1;if((f|0)<1){break x}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break x}if(!(w[a|0]!=8|w[a+1|0]!=2)){e=0;fa:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1278,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1279,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break fa;default:break x}}a=v[d+2900>>2];e=w[my(d+696|0)|0];v[114578]=0;e=aa(1280,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){ga:{ha:{ia:{ja:{a=w[a+3|0];switch(a|0){case 1:break ia;case 0:break ja;case 2:break ga;default:break ha}}v[114578]=0;e=W(1281,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1282,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if((a|0)!=12){break x}}a=v[d+2900>>2];e=x[Al(d+688|0)>>1];v[114578]=0;e=aa(1283,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;ka:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1284,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1285,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break ka;default:break x}}a=v[d+2900>>2];e=x[Al(d+680|0)>>1];v[114578]=0;e=aa(1286,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){la:{ma:{na:{oa:{g=w[a+3|0];switch(g|0){case 2:break la;case 1:break na;case 0:break oa;default:break ma}}v[114578]=0;e=W(1287,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1288,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if((g|0)!=12){break x}}e=v[d+2900>>2];g=x[Al(d+672|0)>>1];v[114578]=0;e=aa(1289,b|0,f|0,e|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break x}f=v[b>>2];if(f<<1<1){break x}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break x}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){e=0;pa:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1290,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1291,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break pa;default:break x}}a=v[d+2900>>2];e=x[Al(d+664|0)>>1];v[114578]=0;e=aa(1292,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){e=0;qa:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1293,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1294,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break qa;default:break x}}a=v[d+2900>>2];e=x[Al(d+656|0)>>1];v[114578]=0;e=aa(1295,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){e=0;ra:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1296,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1297,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break ra;default:break x}}a=v[d+2900>>2];e=x[Al(d+648|0)>>1];v[114578]=0;e=aa(1298,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d>>1]=x[d+640>>1];e=aa(1299,b|0,f|0,e|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+2>>1]=x[d+632>>1];e=aa(1300,b|0,f|0,e|0,d+2|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+4>>1]=x[d+624>>1];e=aa(1301,b|0,f|0,e|0,d+4|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+6>>1]=x[d+616>>1];e=aa(1302,b|0,f|0,e|0,d+6|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+8>>1]=x[d+608>>1];e=aa(1303,b|0,f|0,e|0,d+8|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+10>>1]=x[d+600>>1];e=aa(1304,b|0,f|0,e|0,d+10|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+12>>1]=x[d+592>>1];e=aa(1305,b|0,f|0,e|0,d+12|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+14>>1]=x[d+584>>1];e=aa(1306,b|0,f|0,e|0,d+14|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+16>>1]=x[d+576>>1];e=aa(1307,b|0,f|0,e|0,d+16|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+18>>1]=x[d+568>>1];e=aa(1308,b|0,f|0,e|0,d+18|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+20>>1]=x[d+560>>1];e=aa(1309,b|0,f|0,e|0,d+20|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+22>>1]=x[d+552>>1];e=aa(1310,b|0,f|0,e|0,d+22|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+24>>1]=x[d+544>>1];e=aa(1311,b|0,f|0,e|0,d+24|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+26>>1]=x[d+536>>1];e=aa(1312,b|0,f|0,e|0,d+26|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+28>>1]=x[d+528>>1];e=aa(1313,b|0,f|0,e|0,d+28|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+30>>1]=x[d+520>>1];e=aa(1314,b|0,f|0,e|0,d+30|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+32>>1]=x[d+512>>1];e=aa(1315,b|0,f|0,e|0,d+32|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+34>>1]=x[d+504>>1];e=aa(1316,b|0,f|0,e|0,d+34|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+36>>1]=x[d+496>>1];e=aa(1317,b|0,f|0,e|0,d+36|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+38>>1]=x[d+488>>1];e=aa(1318,b|0,f|0,e|0,d+38|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=24|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[d+736>>2]=-2147483648;e=v[d+2900>>2];sa:{if(!w[a+2|0]){v[114578]=0;v[d+48>>2]=v[d+480>>2];v[d+476>>2]=0;a=v[d+476>>2];v[d+40>>2]=v[d+472>>2];v[d+44>>2]=a;e=ea(1319,b|0,f|0,e|0,d+736|0,d+40|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break sa}break T}v[114578]=0;v[d- -64>>2]=v[d+464>>2];v[d+460>>2]=0;a=v[d+460>>2];v[d+56>>2]=v[d+456>>2];v[d+60>>2]=a;e=ea(1320,b|0,f|0,e|0,d+736|0,d+56|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break T}}if(!e){break x}a=v[d+736>>2];if((a|0)==-2147483648){break x}f=x[b+32>>1];v[114578]=0;f=Hma(f,0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;a=Gg(752,(a&2147483647)<<1|f>>>31,a>>>31|0);f=v[114578];v[114578]=0;if((f|0)==1){break T}s=b,D=Fd(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[d+736>>2]=-2147483648;e=v[d+2900>>2];ta:{if(!w[a+2|0]){v[114578]=0;v[d+80>>2]=v[d+448>>2];v[d+444>>2]=0;a=v[d+444>>2];v[d+72>>2]=v[d+440>>2];v[d+76>>2]=a;e=ea(1321,b|0,f|0,e|0,d+736|0,d+72|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break ta}break U}v[114578]=0;v[d+96>>2]=v[d+432>>2];v[d+428>>2]=0;a=v[d+428>>2];v[d+88>>2]=v[d+424>>2];v[d+92>>2]=a;e=ea(1322,b|0,f|0,e|0,d+736|0,d+88|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break U}}if(!e){break x}a=v[d+736>>2];if((a|0)==-2147483648){break x}f=x[b+32>>1];v[114578]=0;a=Hma(f,0,a,0)+1073741824|0;f=mb;f=a>>>0<1073741824?f+1|0:f;a=Gg(752,(f&2147483647)<<1|a>>>31,f>>>31|0);f=v[114578];v[114578]=0;if((f|0)==1){break U}s=b,D=Fd(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[d+736>>2]=1065353216;e=v[d+2900>>2];ua:{if(!w[a+2|0]){v[114578]=0;v[d+412>>2]=0;v[d+416>>2]=1065353216;a=v[d+420>>2];v[d+112>>2]=v[d+416>>2];v[d+116>>2]=a;a=v[d+412>>2];v[d+104>>2]=v[d+408>>2];v[d+108>>2]=a;e=ea(1323,b|0,f|0,e|0,d+736|0,d+104|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break ua}break V}v[114578]=0;v[d+396>>2]=0;v[d+400>>2]=1065353216;a=v[d+404>>2];v[d+128>>2]=v[d+400>>2];v[d+132>>2]=a;a=v[d+396>>2];v[d+120>>2]=v[d+392>>2];v[d+124>>2]=a;e=ea(1324,b|0,f|0,e|0,d+736|0,d+120|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break V}}if(!e){break x}l=z[d+736>>2];if(l==C(1)){break x}l=hn(C(l*C(x[b+32>>1])),C(1),C(64));v[114578]=0;a=gb(1325,C(l))|0;f=v[114578];v[114578]=0;if((f|0)==1){break V}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=64|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[d+736>>2]=0;v[d+740>>2]=1072693248;e=v[d+2900>>2];va:{if(!w[a+2|0]){v[114578]=0;v[d+376>>2]=0;v[d+380>>2]=1072693248;v[d+368>>2]=0;v[d+372>>2]=0;v[d+144>>2]=0;v[d+148>>2]=0;v[d+152>>2]=0;v[d+156>>2]=1072693248;a=v[d+388>>2];v[d+160>>2]=v[d+384>>2];v[d+164>>2]=a;a=v[d+364>>2];v[d+136>>2]=v[d+360>>2];v[d+140>>2]=a;e=ea(1326,b|0,f|0,e|0,d+736|0,d+136|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break va}break W}v[114578]=0;v[d+344>>2]=0;v[d+348>>2]=1072693248;v[d+336>>2]=0;v[d+340>>2]=0;v[d+176>>2]=0;v[d+180>>2]=0;v[d+184>>2]=0;v[d+188>>2]=1072693248;a=v[d+356>>2];v[d+192>>2]=v[d+352>>2];v[d+196>>2]=a;a=v[d+332>>2];v[d+168>>2]=v[d+328>>2];v[d+172>>2]=a;e=ea(1327,b|0,f|0,e|0,d+736|0,d+168|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break W}}if(!e){break x}m=A[d+736>>3];if(m==1){break x}m=ky(m*+x[b+32>>1],1,64);v[114578]=0;a=za(1328,+m)|0;f=v[114578];v[114578]=0;if((f|0)==1){break W}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+320>>2]=939524096;a=v[d+324>>2];v[d+200>>2]=v[d+320>>2];v[d+204>>2]=a;e=aa(1329,b|0,f|0,e|0,d+200|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;v[d+312>>2]=939524096;a=v[d+316>>2];v[d+208>>2]=v[d+312>>2];v[d+212>>2]=a;e=aa(1330,b|0,f|0,e|0,d+208|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+304>>2]=939524096;a=v[d+308>>2];v[d+216>>2]=v[d+304>>2];v[d+220>>2]=a;e=aa(1331,b|0,f|0,e|0,d+216|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;v[d+296>>2]=939524096;a=v[d+300>>2];v[d+224>>2]=v[d+296>>2];v[d+228>>2]=a;e=aa(1332,b|0,f|0,e|0,d+224|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+288>>2]=872415232;a=v[d+292>>2];v[d+232>>2]=v[d+288>>2];v[d+236>>2]=a;e=aa(1329,b|0,f|0,e|0,d+232|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;v[d+280>>2]=872415232;a=v[d+284>>2];v[d+240>>2]=v[d+280>>2];v[d+244>>2]=a;e=aa(1330,b|0,f|0,e|0,d+240|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break x}e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+272>>2]=872415232;a=v[d+276>>2];v[d+248>>2]=v[d+272>>2];v[d+252>>2]=a;e=aa(1331,b|0,f|0,e|0,d+248|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break x}break b}v[114578]=0;v[d+264>>2]=872415232;a=v[d+268>>2];v[d+256>>2]=v[d+264>>2];v[d+260>>2]=a;e=aa(1332,b|0,f|0,e|0,d+256|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break I}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break K}}e=k+4|0;Bb(f);break x}a=P()|0;O()|0;break I}a=P()|0;O()|0}Bb(f);break a}a=P()|0;O()|0;break a}e=v[d+720>>2]+16|0}v[114578]=0;Q(256,c|0,e+o|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}}Ec(i)}jb=d+2928|0;return e|0}a=P()|0;O()|0}Ec(i);S(a|0);L()}function MT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-304|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!Ef(b,d+296|0)){break S}if(!vA(d+296|0)){break S}if(!c){p=1;break S}q=Jk(d+280|0,b);v[114578]=0;U(474,d+264|0,q|0,1);b=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((b|0)!=1){v[114578]=0;U(475,d+128|0,d+264|0,1229866575);b=v[114578];v[114578]=0;if((b|0)==1){break ea}v[114578]=0;p=Q(476,d+128|0,d+248|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break ga}Bb(d+128|0);if(!p){break T}v[114578]=0;R(449,a|0,524288);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Z(477,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break fa}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;Bb(d+128|0);break b}v[a+480208>>2]=12;b=w[d+256|0]|w[d+257|0]<<8;G=a,H=Fd((b<<8|b>>>8)&65535,1,127),u[G+480188>>1]=H;b=w[d+248|0]|w[d+249|0]<<8;v[114578]=0;u[d+128>>1]=b<<8|b>>>8;u[d+216>>1]=255;b=Q(478,d+128|0,d+216|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+248|2;b=w[b|0]|w[b+1|0]<<8;v[114578]=0;u[d+128>>1]=b<<8|b>>>8;u[d+216>>1]=3999;b=Q(478,d+128|0,d+216|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[114578]=0;b=a+1074312|0;W(479,b|0,6,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Q(480,b|0,21)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Q(480,b|0,13)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=Q(2,d+128|0,12385)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}Gb(a+1304436|0,b);yb(b);v[114578]=0;b=Q(2,d+128|0,12401)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}Gb(a+1304448|0,b);yb(b);v[114578]=0;e=Q(2,d+232|0,12405)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;R(219,d+216|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break j}v[114578]=0;R(481,d+200|0,d+296|4);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;R(481,d+184|0,d+296|5);b=v[114578];v[114578]=0;if((b|0)==1){break n}v[114578]=0;X(222,d+128|0,d+216|0,d+200|0,d+184|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}Gb(a+1304460|0,d+128|0);yb(d+128|0);yb(d+184|0);yb(d+200|0);Ib(d+216|0);yb(e);v[a+1304496>>2]=2;v[114578]=0;U(475,d+216|0,d+264|0,1312902469);b=v[114578];v[114578]=0;if((b|0)==1){break p}v[114578]=0;b=T(255,d+216|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break r}v[114578]=0;f=a+1304400|0;W(482,d+216|0,f|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;U(475,d+200|0,d+264|0,1397706311);b=v[114578];v[114578]=0;if((b|0)==1){break s}b=a+484360|0;Xp(Vb(b));ha:{e=d+248|4;h=w[e|0]|w[e+1|0]<<8;ia:{if(!h){break ia}e=0;h=(h<<8|h>>>8)&65535;while(1){v[114578]=0;g=Q(258,d+200|0,46)|0;j=v[114578];v[114578]=0;ja:{if((j|0)!=1){if(!g){break ia}v[114578]=0;W(483,d+200|0,d+128|0,44)|0;g=v[114578];v[114578]=0;if((g|0)!=1){if(!Wc(f)){break ja}v[114578]=0;Q(484,f|0,d+128|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break ja}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}v[114578]=0;g=T(485,d+200|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break ha}if(!md(Vb(b))){v[114578]=0;j=T(486,b|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ha}if((j|0)==255){break ia}}j=Vb(b);v[114578]=0;U(6,d+184|0,2,d+128|0);l=v[114578];v[114578]=0;if((l|0)==1){break u}v[114578]=0;R(487,j|0,d+184|0);j=v[114578];v[114578]=0;if((j|0)==1){break v}yb(d+184|0);j=Vb(b);v[114578]=0;ea(488,j|0,d+200|0,g|0,65535,65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ha}e=e+1|0;if(h>>>0>(e&65535)>>>0){continue}break}}v[114578]=0;R(489,b|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break w}v[114578]=0;U(475,d+184|0,d+264|0,1229869908);b=v[114578];v[114578]=0;if((b|0)==1){break x}v[114578]=0;b=T(490,d+184|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break G}ka:{if(!b){break ka}if(x[a+480192>>1]){h=1;while(1){v[114578]=0;Q(491,d+184|0,d+128|0)|0;b=v[114578];v[114578]=0;la:{ma:{na:{if((b|0)!=1){b=w[d+158|0]|w[d+159|0]<<8;v[114578]=0;b=W(456,a|0,h&65535,(b<<8|b>>>8)&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break na}if(!b){break la}e=w[d+158|0]|w[d+159|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>3999){break la}v[114578]=0;U(492,d+16|0,2,d+128|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;R(417,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)!=1){break ma}}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}v[114578]=0;Q(371,b+492|0,d- -64|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break z}yb(d- -64|0);v[114578]=0;U(492,d+16|0,2,d+128|0);e=v[114578];v[114578]=0;if((e|0)==1){break A}v[114578]=0;R(417,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break A}e=w[d+158|0]|w[d+159|0]<<8;v[114578]=0;Q(371,((((e<<8|e>>>8)&65535)<<5)+a|0)+946304|0,d- -64|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break B}yb(d- -64|0);v[b>>2]=0;e=w[d+174|0]|w[d+175|0]<<8;v[b+8>>2]=(e<<8|e>>>8)+128&65535;Cc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=w[d+158|0]|w[d+159|0]<<8;v[114578]=0;b=B((b<<8|b>>>8)&65535,104)+a|0;R(388,b+484380|0,0);e=v[114578];v[114578]=0;if((e|0)==1){break C}e=w[d+160|0]|w[d+161|0]<<8;v[114578]=0;u[d+64>>1]=e<<8|e>>>8;u[d+16>>1]=64;e=Q(478,d- -64|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}u[b+484410>>1]=x[e>>1]<<2;e=w[d+162|0]|w[d+163|0]<<8|(w[d+164|0]<<16|w[d+165|0]<<24);v[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(w[d+170|0]|w[d+171|0]<<8|(w[d+172|0]<<16|w[d+173|0]<<24))|!(w[d+177|0]&3)){break la}e=w[d+166|0]|w[d+167|0]<<8|(w[d+168|0]<<16|w[d+169|0]<<24);g=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+484384>>2]=g;e=w[d+170|0]|w[d+171|0]<<8|(w[d+172|0]<<16|w[d+173|0]<<24);f=b+484414|0;u[f>>1]=x[f>>1]|2;v[b+484388>>2]=g+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(w[d+177|0]&2)){break la}u[f>>1]=x[f>>1]|4}h=h+1|0;if(x[a+480192>>1]>=(h&65535)>>>0){continue}break}}v[114578]=0;U(475,d+112|0,d+264|0,1447382614);b=v[114578];v[114578]=0;if((b|0)==1){break G}v[114578]=0;X(493,d+112|0,0,a|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break E}Bb(d+112|0);v[114578]=0;U(475,d+96|0,d+264|0,1346719318);b=v[114578];v[114578]=0;if((b|0)==1){break G}v[114578]=0;X(493,d+96|0,1,a|0,w[d+300|0]>2|0);b=v[114578];v[114578]=0;if((b|0)==1){break F}Bb(d+96|0);if(!x[a+480192>>1]){break ka}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}Bb(d+184|0);v[114578]=0;U(475,d+128|0,d+264|0,1346458708);b=v[114578];v[114578]=0;if((b|0)==1){break H}v[114578]=0;b=T(339,d+128|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}if(!b|!(c&1)){break da}v[114578]=0;U(475,d+184|0,d+264|0,1347305805);b=v[114578];v[114578]=0;if((b|0)==1){break K}v[114578]=0;Q(340,d+184|0,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break M}j=d+248|6;b=w[j|0]|w[j+1|0]<<8;f=0;v[114578]=0;l=a+484344|0;R(403,l|0,(b<<8|b>>>8)&65535);b=v[114578];v[114578]=0;if((b|0)==1){break M}b=jb-16|0;jb=b;e=d+80|0;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(520,e+8|0,b+12|0,b+8|0)|0;h=v[114578];v[114578]=0;oa:{if((h|0)!=1){jb=b+16|0;break oa}V(0)|0;O()|0;Ab();L()}if(!(w[j|0]|w[j+1|0]<<8)){break ca}z=d+16|5;A=d+16|3;C=d+16|4;D=d+16|2;E=d+16|1;b=0;while(1){v[114578]=0;y=T(485,d+128|0)|0;h=v[114578];v[114578]=0;pa:{qa:{ra:{sa:{ta:{if((h|0)!=1){v[114578]=0;h=T(494,d+128|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ta}v[114578]=0;U(343,d- -64|0,d+128|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break sa}v[114578]=0;h=W(404,l|0,f&65535,y|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ra}if(!h){break pa}o=Wb(d+48|0);v[114578]=0;W(495,d+184|0,o|0,-1)|0;h=v[114578];v[114578]=0;if((h|0)!=1){h=_b(l,f);v[114578]=0;Q(496,h|0,o|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break qa}}break P}b=P()|0;O()|0;break N}b=P()|0;O()|0;break N}b=P()|0;O()|0;break N}b=P()|0;O()|0;break O}h=_b(l,f);v[114578]=0;h=Q(497,h|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break P}GT(e);n=0;ua:{while(1){v[114578]=0;g=Q(258,d- -64|0,1)|0;k=v[114578];v[114578]=0;va:{wa:{xa:{if((k|0)!=1){if(!g){break ua}v[114578]=0;k=T(389,d- -64|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break P}if(k){break wa}G=d,H=bc(e),v[G+40>>2]=H;G=d,H=cc(e),v[G+32>>2]=H;if(Jb(d+40|0,d+32|0)){break xa}break va}break P}while(1){ya:{h=v[d+40>>2];g=_b(l,f);k=w[h+1|0];h=w[h|0];v[114578]=0;h=W(498,d+16|0,h|0,k|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break ya}h=Ne(h,n);v[114578]=0;Q(499,g|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ya}te(d+40|0);if(Jb(d+40|0,d+32|0)){continue}break va}break}break P}Ph(d+16|0);r=x[a+480188>>1];v[114578]=0;g=T(389,d- -64|0)|0;i=v[114578];v[114578]=0;za:{Aa:{if((i|0)!=1){s=k-1|0;Ba:{if(!(g&1)){break Ba}v[114578]=0;i=T(389,d- -64|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break P}if(!i){break Ba}m=k>>>0>r>>>0?d+16|0:B(s,6)+h|0;if((i|0)!=31){if(i>>>0>253){break Ba}i=(B(i>>>4|0,12)+(i&15)|0)+13|0}else{i=255}t[m|0]=i}if(!(g&2)){break za}v[114578]=0;i=T(389,d- -64|0)|0;m=v[114578];v[114578]=0;if((m|0)!=1){break Aa}}break P}t[(k>>>0>r>>>0?E:(B(s,6)+h|0)+1|0)|0]=i}if(!(g&60)){continue}t[d+15|0]=0;t[d+14|0]=0;t[d+13|0]=0;t[d+12|0]=0;if(g&4){v[114578]=0;i=T(389,d- -64|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break P}t[d+14|0]=i}if(g&8){v[114578]=0;i=T(389,d- -64|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break P}t[d+12|0]=i}if(g&16){v[114578]=0;i=T(389,d- -64|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break P}t[d+15|0]=i}if(g&32){v[114578]=0;g=T(389,d- -64|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break P}t[d+13|0]=g}FT(d+15|0,d+13|0);FT(d+14|0,d+12|0);g=w[d+14|0];if(!(w[d+15|0]==13|g?(g|0)!=13:0)){lh(d+15|0,d+14|0);lh(d+13|0,d+12|0)}v[114578]=0;fa(500,d+32|0,d+15|0,d+13|0,d+14|0,d+12|0);g=v[114578];v[114578]=0;Ca:{if((g|0)==1){break Ca}v[114578]=0;g=Q(501,w[d+32|0],w[d+33|0])|0;i=v[114578];v[114578]=0;if((i|0)==1){break Ca}Da:{if(!g){break Da}G=d,H=bc(e),v[G+40>>2]=H;Md(d+8|0,d+40|0);v[114578]=0;W(502,e|0,v[d+8>>2],d+32|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Da}break P}g=B(s,6)+h|0;k=k>>>0>r>>>0;t[(k?D:g+2|0)|0]=w[d+15|0];t[(k?C:g+4|0)|0]=w[d+13|0];i=w[d+14|0];t[(k?A:g+3|0)|0]=i;t[(k?z:g+5|0)|0]=w[d+12|0];if((i|0)==40){F=1;continue}if((i|0)!=31){continue}b=1;continue}break P}GT(e);n=n+1|0;if(y>>>0<=n>>>0){break ua}h=_b(l,f);v[114578]=0;h=Q(497,h|0,n|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}break}break P}yb(o)}Bb(d- -64|0);f=f+1|0;h=w[j|0]|w[j+1|0]<<8;if(f>>>0<((h<<8|h>>>8)&65535)>>>0){continue}break}break ba}b=P()|0;O()|0;break t}b=P()|0;O()|0;break b}h=0;e=0;if(c&4){break aa}break U}b=0}DT(e);Bb(d+184|0);if(!(c&4)){break $}e=0;h=(b|0)!=0;if(!F){break aa}f=x[a+480188>>1];if(!f){e=1;break aa}b=0;while(1){e=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}}v[114578]=0;v[d+64>>2]=-1778364416;v[d+68>>2]=-16756736;U(475,d+184|0,d+264|0,1146310725);b=v[114578];v[114578]=0;Ea:{Fa:{Ga:{if((b|0)!=1){v[114578]=0;b=T(490,d+184|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ea}if(!b){break Fa}v[114578]=0;g=T(485,d+184|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Z}if(g){break Ga}f=e;break _}b=P()|0;O()|0;break I}b=0;f=e;while(1){v[114578]=0;j=T(389,d+184|0)|0;l=v[114578];v[114578]=0;Ha:{Ia:{if((l|0)!=1){if(x[a+480188>>1]<=b>>>0){break Ha}if(!e){break Ia}l=((b<<5)+a|0)+480280|0;v[l>>2]=v[l>>2]&-67108865|((j|0)!=0)<<26;break Ha}break Z}if(j){break Ha}f=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break _}Bb(d+184|0);if(!e){break W}break X}break Z}if(!b){break U}break V}v[114578]=0;Q(503,d+184|0,d- -64|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break Y}}b=P()|0;O()|0;Bb(d+184|0);break I}Bb(d+184|0);if(!(f&1)){break W}}v[114578]=0;Z(504,a+906300|0);b=v[114578];v[114578]=0;Ja:{Ka:{La:{Ma:{Na:{Oa:{if((b|0)==1){break Oa}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[114578]=0;v[d+184>>2]=0;b=a+906332|0;U(505,b|0,b+16|0,d+184|0);b=v[114578];v[114578]=0;if((b|0)==1){break Na}v[114578]=0;e=Q(85,d+184|0,12427)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Ma}v[114578]=0;Q(506,a+906348|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break La}yb(e);v[114578]=0;e=Q(85,d+184|0,12432)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Ka}v[114578]=0;Q(507,a+906380|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Ja}yb(e);v[114578]=0;b=a+906304|0;R(508,b|0,8);e=v[114578];v[114578]=0;if((e|0)==1){break Oa}BT(d+184|0,w[d+65|0],w[d+67|0],w[d+69|0],w[d+71|0]);e=v[d+188>>2];b=v[b>>2];f=v[d+184>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break W}b=P()|0;O()|0;break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(e);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(e);break I}if(!h){break U}}b=0;Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{while(1){kb:{v[114578]=0;v[d+48>>2]=B(b,127)>>>5;R(509,d- -64|0,12453);e=v[114578];v[114578]=0;if((e|0)==1){break kb}v[114578]=0;R(510,d+16|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break jb}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break ib}v[114578]=0;e=(b<<5)+a|0;R(512,d+80|0,e+902204|0);f=v[114578];v[114578]=0;if((f|0)==1){break hb}v[114578]=0;Q(471,d+80|0,d+184|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break hb}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);v[114578]=0;R(509,d- -64|0,12462);f=v[114578];v[114578]=0;if((f|0)==1){break eb}v[114578]=0;R(510,d+16|0,d+48|0);f=v[114578];v[114578]=0;if((f|0)==1){break db}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break cb}v[114578]=0;R(512,d+80|0,e+903228|0);f=v[114578];v[114578]=0;if((f|0)==1){break bb}v[114578]=0;Q(471,d+80|0,d+184|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break bb}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);v[114578]=0;R(509,d- -64|0,12471);f=v[114578];v[114578]=0;if((f|0)==1){break _a}v[114578]=0;R(510,d+16|0,d+48|0);f=v[114578];v[114578]=0;if((f|0)==1){break Za}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ya}v[114578]=0;R(512,d+80|0,e+904252|0);f=v[114578];v[114578]=0;if((f|0)==1){break Xa}v[114578]=0;Q(471,d+80|0,d+184|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Xa}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);v[114578]=0;R(509,d- -64|0,12480);f=v[114578];v[114578]=0;if((f|0)==1){break Ua}v[114578]=0;R(510,d+16|0,d+48|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ta}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break Sa}v[114578]=0;R(512,d+80|0,e+905276|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ra}v[114578]=0;Q(471,d+80|0,d+184|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ra}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);b=b+1|0;if((b|0)!=32){continue}break U}break}b=P()|0;O()|0;break I}b=P()|0;O()|0;break fb}b=P()|0;O()|0;break gb}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break $a}b=P()|0;O()|0;break ab}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break Va}b=P()|0;O()|0;break Wa}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break Pa}b=P()|0;O()|0;break Qa}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}v[114578]=0;U(475,d+184|0,d+264|0,1397575756);b=v[114578];v[114578]=0;if((b|0)==1){break Q}v[114578]=0;b=T(339,d+184|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break R}if(!(!x[a+480190>>1]|(!b|!(c&2)))){e=1;c=1;while(1){v[114578]=0;b=T(494,d+184|0)|0;f=v[114578];v[114578]=0;lb:{if((f|0)!=1){v[114578]=0;f=T(494,d+184|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break R}if(!(b&7)){break lb}e=(B(e,104)+a|0)+484380|0;v[e>>2]=f;b=ad(d- -64|0,b&4?32:b&2?16:8,1,1,0);v[114578]=0;W(402,b|0,e|0,d+184|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break lb}break R}break R}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}Bb(d+184|0);Bb(d+128|0);Bb(d+200|0);Bb(d+216|0)}rA(d+264|0);Bb(q)}jb=d+304|0;return p|0}b=P()|0;O()|0;Bb(d+184|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(o)}Bb(d- -64|0)}DT(e);break L}b=P()|0;O()|0}Bb(d+184|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0}Bb(d+128|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break y}b=P()|0;O()|0;Bb(d+96|0);break y}b=P()|0;O()|0;Bb(d+112|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(d- -64|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(d- -64|0)}Bb(d+184|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;yb(d+184|0);break t}b=P()|0;O()|0}Bb(d+200|0);break q}b=P()|0;O()|0;break q}b=P()|0;O()|0}Bb(d+216|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d+184|0);break m}b=P()|0;O()|0}yb(d+200|0);break k}b=P()|0;O()|0}Ib(d+216|0);break i}b=P()|0;O()|0}yb(e);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}rA(d+264|0)}Bb(q);S(b|0);L()}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=jb-320|0;jb=d;Jc(b);a:{if(!It(b,d+304|0)){break a}if(!FP(d+304|0)){break a}p=Jk(d+288|0,b);m=cz(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[114578]=0;X(953,d|0,p|0,1,1413891155);b=v[114578];v[114578]=0;if((b|0)==1){break r}break t}v[114578]=0;U(954,d|0,p|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break s}}b=m;if(v[b>>2]){Id(b);vP(b);up(b);Yf(zb(b),v[b>>2],We(b));s=zb(b),y=0,v[s>>2]=y;v[b>>2]=0;v[b+4>>2]=0}El(m,d);v[m>>2]=v[d>>2];v[m+4>>2]=v[d+4>>2];b=v[zb(d)>>2];s=zb(m),y=b,v[s>>2]=y;s=zb(d),y=0,v[s>>2]=y;v[d>>2]=0;v[d+4>>2]=0;Gl(d);v[114578]=0;U(955,d|0,m|0,1413891155);b=v[114578];v[114578]=0;u:{v:{if((b|0)!=1){v[114578]=0;e=Q(956,d|0,16779)|0;b=v[114578];v[114578]=0;if((b|0)==1){break v}Bb(d);if(!e){break b}if(c){break u}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Bb(d);break c}v[114578]=0;R(449,a|0,4194304);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[114578]=0;U(955,d+256|0,m|0,1280592212);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;b=T(255,d+256|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}v[114578]=0;W(679,d+256|0,a+1304400|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}n=a+484360|0;Xp(Vb(n));b=jb-16|0;jb=b;k=d+240|0;e=k;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(976,e+8|0,b+12|0,b+8|0)|0;e=v[114578];v[114578]=0;w:{if((e|0)!=1){jb=b+16|0;break w}V(0)|0;O()|0;Ab();L()}v[114578]=0;t[d+239|0]=0;U(957,d+224|0,m|0,1196314451);b=v[114578];v[114578]=0;if((b|0)==1){break i}s=d,y=bc(d+224|0),v[s+216>>2]=y;s=d,y=cc(d+224|0),v[s+208>>2]=y;x:{y:{z:{A:{B:{C:{if(!Jb(d+216|0,d+208|0)){break C}o=d+12|0;f=d+24|0;q=d+44|0;while(1){e=Jk(d+192|0,v[d+216>>2]);v[114578]=0;g=Q(958,d+192|0,d+176|0)|0;b=v[114578];v[114578]=0;D:{E:{F:{G:{H:{I:{if((b|0)!=1){b=1;if(!(g&w[d+185|0]==1)){break D}s=a,y=Fd(w[d+186|0],x[a+480188>>1],127),u[s+480188>>1]=y;v[114578]=0;h=T(959,d|0)|0;b=v[114578];v[114578]=0;J:{K:{L:{M:{if((b|0)!=1){v[114578]=0;U(960,d+160|0,1,d+176|0);b=v[114578];v[114578]=0;if((b|0)==1){break M}v[114578]=0;R(417,d+120|0,d+160|0);b=v[114578];v[114578]=0;if((b|0)==1){break M}v[114578]=0;R(961,d+152|0,q|0);b=v[114578];v[114578]=0;if((b|0)==1){break L}v[114578]=0;Q(471,d+152|0,d+120|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break L}yb(d+120|0);if(md(Vb(n))){break J}v[114578]=0;b=T(486,n|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break K}if((b|0)!=255){break J}b=2;break E}e=P()|0;O()|0;break k}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(d+120|0);break l}e=P()|0;O()|0;break l}b=Vb(n);v[114578]=0;U(6,d+120|0,4,q|0);g=v[114578];v[114578]=0;N:{O:{P:{if((g|0)!=1){v[114578]=0;R(487,b|0,d+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break P}yb(d+120|0);v[114578]=0;U(954,d+160|0,e|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break O}s=d,y=bc(d+160|0),v[s+144>>2]=y;s=d,y=cc(d+160|0),v[s+136>>2]=y;if(Jb(d+144|0,d+136|0)){break N}break H}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(d+120|0);break l}e=P()|0;O()|0;break l}Q:{R:{while(1){S:{e=v[d+144>>2];b=Ze(d+120|0,zb(e));g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);v[d+152>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[d+156>>2]=g;l=1;T:{e=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break T}e=0;if(!x[a+480188>>1]){break T}U:{while(1){v[114578]=0;g=Q(258,b|0,2)|0;i=v[114578];v[114578]=0;if((i|0)==1){break U}if(!g){break T}v[114578]=0;R(473,d+96|0,b|0);g=v[114578];v[114578]=0;V:{W:{X:{Y:{if((g|0)!=1){g=cd(d+96|0);switch(w[d+96|0]){case 4:break W;case 2:break X;case 0:break Y;default:break V}}break I}g=w[g|0];s=wc(d,e),y=g^128,t[s|0]=y;ee(d+104|0,f,e);ge(d+104|0,0);break V}s=wc(d,e),y=128,t[s|0]=y;ee(d+104|0,f,e);ge(d+104|0,1);break V}s=wc(d,e),y=128,t[s|0]=y;ee(d+104|0,f,e);ge(d+104|0,0)}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break T}break I}if(bz(d+152|0)>>>0<9){break T}i=0;v[114578]=0;Q(340,b|0,2)|0;e=v[114578];v[114578]=0;g=65535;if((e|0)==1){break S}while(1){v[114578]=0;e=Q(258,b|0,1)|0;j=v[114578];v[114578]=0;Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((j|0)!=1){if(!e){break T}v[114578]=0;e=T(389,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}switch(e|0){case 0:break T;case 14:break _;case 13:break $;case 12:break ba;case 8:break ca;case 7:break da;case 4:break ea;case 1:break fa;default:break aa}}break I}if(x[d+36>>1]==65535){e=Vb(n);v[114578]=0;e=T(544,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}u[d+36>>1]=e}e=Vb(n);v[114578]=0;e=T(544,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}v[114578]=0;u[d+38>>1]=e;e=Q(962,b|0,d+239|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}ga:{ha:{switch(e-254|0){case 1:v[114578]=0;e=da(963)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break ga}break I;case 0:break ha;default:break ga}}v[114578]=0;e=da(964)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}}j=Vb(n);v[114578]=0;R(795,j|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break I}g=(g&65535)==65535?i:g;break Z}v[114578]=0;e=T(359,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}if(e>>>0>=(g&65535)>>>0){u[d+40>>1]=e-g}Oe(Vb(n),x[d+40>>1]);break Z}v[114578]=0;e=T(389,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}t[d+43|0]=e;break Z}v[114578]=0;e=T(389,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}t[d+42|0]=e;break Z}v[114578]=0;e=Q(920,b|0,d+104|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}if(!(e&!w[d+104|0])|w[d+105|0]!=255|(w[d+106|0]|w[d+107|0])){break aa}if(w[d+108|0]!=1){break aa}if(!w[d+109|0]){break Z}}l=0;break T}v[114578]=0;R(807,d+112|0,b|0);e=v[114578];v[114578]=0;ia:{ja:{ka:{la:{if((e|0)!=1){e=cd(d+112|0);j=Bf(d+112|0);if(w[d+112|0]>=xc(d)>>>0){break Z}switch(w[j|0]){case 4:break ja;case 2:break ka;case 0:break la;default:break ia}}break I}e=w[e|0];s=wc(d,w[d+112|0]),y=e^128,t[s|0]=y;ee(d+104|0,f,w[d+112|0]);ge(d+104|0,0);break ia}s=wc(d,w[d+112|0]),y=128,t[s|0]=y;ee(d+104|0,f,w[d+112|0]);ge(d+104|0,1);break ia}s=wc(d,w[d+112|0]),y=128,t[s|0]=y;ee(d+104|0,f,w[d+112|0]);ge(d+104|0,0)}ma:{if(r){break ma}r=0;if(!vk(k)){break Z}if(w[wc(CP(k),w[d+112|0])|0]!=w[wc(d,w[d+112|0])|0]){break ma}ee(d+104|0,CP(k)+24|0,w[d+112|0]);e=Cb(d+104|0);ee(d+96|0,f,w[d+112|0]);if((Cb(d+96|0)|0)==(e|0)){break Z}}r=1;break Z}v[114578]=0;R(473,d+104|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break Q}e=cd(d+104|0);j=w[d+104|0];if(xc(o)>>>0<=j>>>0){break Z}e=w[e|0];s=wc(o,w[d+104|0]),y=(e>>>2|0)+1|0,t[s|0]=y}i=i+1|0;continue}}Bb(b);if(!l){break R}Gk(d+144|0);if(Jb(d+144|0,d+136|0)){continue}break H}break}break I}b=1;break F}break I}e=P()|0;O()|0;break k}e=P()|0;O()|0;Bb(b);break G}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break F}b=Vb(n);v[114578]=0;Z(965,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){b=0;v[114578]=0;R(966,k|0,h|0);e=v[114578];v[114578]=0;if((e|0)!=1){break F}}e=P()|0;O()|0}Gl(d+160|0);break l}Gl(d+160|0)}az(h)}Bb(d+192|0);if(!b){Uf(d+216|0);if(Jb(d+216|0,d+208|0)){continue}break C}break}e=0;if((b|0)!=2){break B}}e=0;v[114578]=0;R(489,n|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break q}if(md(k)){break B}if(c&2){v[114578]=0;U(957,d+192|0,m|0,1347244868);b=v[114578];v[114578]=0;if((b|0)==1){break x}s=d,y=bc(d+192|0),v[s+176>>2]=y;s=d,y=cc(d+192|0),v[s+152>>2]=y;f=w[d+239|0];if(Jb(d+176|0,d+152|0)){e=a+480190|0;g=d+13|0;l=d+17|0;while(1){b=v[d+176>>2];na:{oa:{pa:{qa:{ra:{if(!f){v[114578]=0;h=Q(967,b|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ra}if(!h){break na}h=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=h+1;if(h>>>0>3998){break pa}v[114578]=0;h=Q(454,e|0,d+104|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ra}u[a+480190>>1]=x[h>>1];v[114578]=0;R(968,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);h=v[114578];v[114578]=0;if((h|0)==1){break ra}v[114578]=0;U(969,d+160|0,1,g|0);h=v[114578];v[114578]=0;sa:{ta:{if((h|0)==1){break ta}v[114578]=0;R(417,d+120|0,d+160|0);h=v[114578];v[114578]=0;if((h|0)==1){break ta}v[114578]=0;Q(371,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break sa}yb(d+120|0);break pa}e=P()|0;O()|0;break oa}e=P()|0;O()|0;yb(d+120|0);break oa}v[114578]=0;h=Q(970,b|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break qa}if(!h){break na}h=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=h+1;if(h>>>0>3998){break pa}v[114578]=0;h=Q(454,e|0,d+104|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break qa}u[a+480190>>1]=x[h>>1];v[114578]=0;R(971,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);h=v[114578];v[114578]=0;if((h|0)==1){break qa}v[114578]=0;U(969,d+160|0,1,l|0);h=v[114578];v[114578]=0;ua:{va:{if((h|0)==1){break va}v[114578]=0;R(417,d+120|0,d+160|0);h=v[114578];v[114578]=0;if((h|0)==1){break va}v[114578]=0;Q(371,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ua}yb(d+120|0);break pa}e=P()|0;O()|0;break oa}e=P()|0;O()|0;yb(d+120|0);break oa}e=P()|0;O()|0;break oa}e=P()|0;O()|0;break oa}if((x[d+104>>1]-1&65535)>>>0>3998){break na}h=ad(d,8,1,0,2);v[114578]=0;W(402,h|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break na}e=P()|0;O()|0}gd(d+192|0);break j}Uf(d+176|0);if(Jb(d+176|0,d+152|0)){continue}break}}gd(d+192|0)}b=0;s=a,y=w[Fl(k,0)+43|0],v[s+480196>>2]=y;s=a,y=B(w[Fl(k,0)+42|0],1e4),v[s+480204>>2]=y;Oe(Vb(n),x[Fl(k,0)+40>>1]);if(x[a+480188>>1]){while(1){v[114578]=0;e=(b<<5)+a|0;f=e+480280|0;Z(434,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break y}s=e+480286|0,y=w[wc(Fl(k,0)+12|0,b)|0],u[s>>1]=y;s=e+480284|0,y=w[wc(Fl(k,0),b)|0],u[s>>1]=y;ee(d,Fl(k,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}wa:{if(w[d+239|0]){v[114578]=0;Q(2,d|0,16788)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break wa}break m}v[114578]=0;Q(2,d|0,16832)|0;b=v[114578];v[114578]=0;if((b|0)==1){break m}}Gb(a+1304436|0,d);yb(d);v[114578]=0;b=Q(2,d|0,16866)|0;f=v[114578];v[114578]=0;e=1;if((f|0)==1){break z}Gb(a+1304448|0,b);yb(b);v[a+1304496>>2]=4;if(!(c&1)|!x[a+480188>>1]){break B}v[114578]=0;U(957,d+192|0,m|0,1146045008);b=v[114578];v[114578]=0;if((b|0)==1){break n}b=nd(d+192|0);v[114578]=0;h=a+484344|0;R(403,h|0,b&65535);b=v[114578];v[114578]=0;if((b|0)==1){break p}s=d,y=bc(d+192|0),v[s+120>>2]=y;s=d,y=cc(d+192|0),v[s+160>>2]=y;if(Jb(d+120|0,d+160|0)){while(1){g=v[d+120>>2];v[114578]=0;b=T(255,g|0)|0;c=v[114578];v[114578]=0;xa:{ya:{za:{if((c|0)==1){break za}v[114578]=0;c=T(392,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}if((b|0)!=(c|0)){break xa}v[114578]=0;b=Q(972,g|0,8)|0;c=v[114578];v[114578]=0;if((c|0)==1){break za}if(b){break ya}break xa}e=P()|0;O()|0;break o}v[114578]=0;o=Q(962,g|0,d+239|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){v[114578]=0;i=T(359,g|0)|0;b=v[114578];v[114578]=0;Aa:{if((b|0)==1){break Aa}v[114578]=0;b=W(404,h|0,o|0,i|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Aa}l=0;if(!(b&(i|0)!=0)){break xa}while(1){Ba:{b=_b(h,o);v[114578]=0;c=Q(497,b|0,l|0)|0;b=v[114578];v[114578]=0;Ca:{Da:{Ea:{if((b|0)!=1){v[114578]=0;b=T(359,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ea}if(b>>>0<3){break Ca}v[114578]=0;U(343,d|0,g|0,b-2|0);b=v[114578];v[114578]=0;if((b|0)!=1){break Da}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}while(1){v[114578]=0;b=Q(258,d|0,3)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ba}if(b){v[114578]=0;R(473,d+176|0,d|0);b=v[114578];v[114578]=0;Fa:{Ga:{Ha:{Ia:{if((b|0)!=1){b=cd(d+176|0);u[d+152>>1]=x[a+480188>>1]-1;b=w[b|0];v[114578]=0;u[d+104>>1]=b;b=Q(478,d+152|0,d+104|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ba}e=x[b>>1];b=t[d+176|0];if((b|0)>-1){break Fa}v[114578]=0;b=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}if(w[d+239|0]){break Ha}if((b|0)!=255){break Ia}b=254;break Ga}break Ba}if(b>>>0>128){break Ga}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ga}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[d+176|0]}if(b&64){v[114578]=0;b=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}t[(c+B(e,6)|0)+1|0]=b+1;b=w[d+176|0]}if(b&32){v[114578]=0;b=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}t[d+152|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;v[114578]=0;t[d+104|0]=127;f=Q(393,d+152|0,d+104|0)|0;q=v[114578];v[114578]=0;if((q|0)==1){break Ba}t[b+4|0]=w[f|0]+1>>>1;b=w[d+176|0]}if(!(b&16)){continue}v[114578]=0;R(473,d+152|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break Ba}b=c+B(e,6)|0;f=w[cd(d+152|0)|0];t[b+5|0]=f;Ja:{switch(w[d+152|0]-1|0){case 0:t[(c+B(e,6)|0)+3|0]=11;if(!w[d+239|0]){t[b+5|0]=f<<3|15;continue}t[b+5|0]=f<<4|15;continue;case 1:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue;case 2:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue;case 3:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue;case 10:t[(c+B(e,6)|0)+3|0]=2;s=b,y=dt(f,w[d+239|0])|240,t[s+5|0]=y;continue;case 11:t[(c+B(e,6)|0)+3|0]=2;s=b,y=dt(f,w[d+239|0]),t[s+5|0]=y;continue;case 12:t[(c+B(e,6)|0)+3|0]=3;s=b,y=dt(f,w[d+239|0])|240,t[s+5|0]=y;continue;case 13:t[(c+B(e,6)|0)+3|0]=3;s=b,y=dt(f,w[d+239|0]),t[s+5|0]=y;continue;case 14:t[(c+B(e,6)|0)+3|0]=4;if(w[d+239|0]){continue}t[b+5|0]=(f&252)>>>2;continue;case 16:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue;case 15:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue;case 17:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue;case 18:t[(c+B(e,6)|0)+3|0]=20;continue;case 20:t[(c+B(e,6)|0)+3|0]=5;continue;case 21:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue;case 22:t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue;case 23:t[(c+B(e,6)|0)+3|0]=7;continue;case 30:t[(c+B(e,6)|0)+3|0]=8;continue;case 31:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue;case 40:t[(c+B(e,6)|0)+3|0]=10;v[114578]=0;e=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}t[b+5|0]=e;v[114578]=0;Q(340,d|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}break Ba;case 41:t[(c+B(e,6)|0)+3|0]=15;continue;case 42:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue;case 43:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue;case 50:t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[114578]=0;Q(340,d|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}break Ba;case 51:t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue;case 53:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue;case 60:t[(c+B(e,6)|0)+3|0]=16;continue;case 61:t[(c+B(e,6)|0)+3|0]=17;continue;case 70:t[(c+B(e,6)|0)+3|0]=1;continue;case 71:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue;case 72:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue;default:break Ja}}t[(c+B(e,6)|0)+3|0]=0;continue}break}Bb(d)}l=l+1|0;if((i|0)!=(l|0)){continue}break xa}break}e=P()|0;O()|0;Bb(d);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}Uf(d+120|0);if(Jb(d+120|0,d+160|0)){continue}break}}Ka:{if(vk(k)>>>0<2){break Ka}if(!vk(k)){break Ka}e=0;while(1){b=Di(n,e&255);c=Fl(k,e);f=x[rc(b,x[c+36>>1])>>1];v[114578]=0;f=Q(444,h|0,f|0)|0;g=v[114578];v[114578]=0;La:{Ma:{if((g|0)!=1){if(!f){break La}f=x[c+36>>1];v[114578]=0;f=Q(811,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break Ma}}e=P()|0;O()|0;break o}if(!(!r|!x[a+480188>>1])){l=c+24|0;b=0;while(1){ee(d,l,b);i=Cb(d);g=_b(h,f);Na:{if(i){v[114578]=0;i=W(498,d|0,20,145)|0;o=v[114578];v[114578]=0;if((o|0)!=1){i=Th(Fn(Ne(i,0),b&65535));v[114578]=0;Q(499,g|0,i|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Na}}e=P()|0;O()|0;break o}i=w[wc(c,b)|0];v[114578]=0;i=W(498,d|0,9,i|0)|0;o=v[114578];v[114578]=0;if((o|0)!=1){i=Th(Fn(Ne(i,0),b&65535));v[114578]=0;Q(499,g|0,i|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Na}}e=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(h,f);g=w[c+43|0];v[114578]=0;g=W(498,d|0,16,g|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break A}g=Th(Ne(g,0));v[114578]=0;Q(499,b|0,g|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break A}b=_b(h,f);c=w[c+42|0];v[114578]=0;c=W(498,d|0,17,c|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){c=Th(Ne(c,0));v[114578]=0;Q(499,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break La}}e=P()|0;O()|0;break o}e=e+1|0;if(vk(k)>>>0>e>>>0){continue}break}}gd(d+192|0);e=1}gd(d+224|0);BP(k);Bb(d+256|0);break b}e=P()|0;O()|0;break o}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break j}e=P()|0;O()|0}gd(d+192|0);break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}az(h)}Bb(d+192|0)}gd(d+224|0);break h}e=P()|0;O()|0}BP(k);break f}e=P()|0;O()|0}Bb(d+256|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Gl(m);Bb(p);S(e|0);L()}Gl(m);Bb(p)}jb=d+320|0;return e|0}function m1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=C(0);s=jb-1520|0;jb=s;g=Rb(s+8|0,0,1512);if(e){f=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=f;e=f&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;p=jb-1024|0;jb=p;f=s+8|0;t[f+1377|0]=1;a:{if(!Br(f)){break a}e=w[f+1375|0];if(!(e&2)){dc(f,34);break a}if(e&4){dc(f,34);break a}if(e&1){dc(f,34);break a}if(v[f+1116>>2]!=1){dc(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!xw(f,p+1018|0,6)|w[p+1018|0]!=102|(w[p+1019|0]!=105|w[p+1020|0]!=115)){break b}if(w[p+1021|0]!=104|w[p+1022|0]!=101|w[p+1023|0]!=97){break b}if((Ae(f)|0)!=100){break b}if(Ae(f)){break b}dc(f,38);break a}dc(f,34);break a}if((Ae(f)|0)!=1){dc(f,34);break a}if(!xw(f,p+1018|0,6)){dc(f,10);break a}if(!ww(p+1018|0)){dc(f,34);break a}if(ki(f)){dc(f,34);break a}e=Ae(f);v[f+4>>2]=e;if(!e){dc(f,34);break a}if(e>>>0>=17){dc(f,5);break a}e=ki(f);v[f>>2]=e;if(!e){dc(f,34);break a}ki(f);ki(f);ki(f);e=Ae(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){dc(f,20);break a}if((e<<24)-1610612736>>24<=-1){dc(f,20);break a}if(g>>>0>h>>>0){dc(f,20);break a}if(!(Ae(f)&1)){dc(f,34);break a}if(!Br(f)){break a}if(!vw(f)){break a}if(!uw(f)){break a}c:{d:{if((Lg(f)|0)==3){while(1){P=(p+1018|0)+b|0,Q=Lg(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!ww(p+1018|0)){dc(f,20);break c}g=tw(f);e=Td(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=Lg(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=tw(f);v[f+24>>2]=b;b=Td(f,b<<2);v[f+28>>2]=b;e=v[f+24>>2];if(!(b?0:(e|0)>=1)){e:{if((e|0)>0){while(1){g=tw(f);b=Td(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=Lg(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(Lg(f)&1)){dc(f,20);break c}KG(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=uw(f);KG(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!vw(f)){break a}if(!LG(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){g=e<<24;h=1;while(1){g=g>>31&79764919^g<<1;if((h|0)!=8){h=h+1|0;continue}break}v[(e<<2)+457184>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((Lg(f)|0)==5){while(1){P=(p+1018|0)+b|0,Q=Lg(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!ww(p+1018|0)){dc(f,20);break c}b=jc(f,8)+1|0;v[f+120>>2]=b;b=Td(f,B(b,2096));v[f+124>>2]=b;if(!b){dc(f,3);break c}Rb(b,0,B(v[f+120>>2],2096));f:{g:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((jc(f,8)&255)!=66){dc(f,20);break c}if((jc(f,8)&255)!=67){dc(f,20);break c}if((jc(f,8)&255)!=86){dc(f,20);break c}g=b+B(M,2096)|0;P=g,Q=jc(f,8)&255|jc(f,8)<<8,v[P>>2]=Q;P=g,Q=jc(f,8)&255|(jc(f,8)<<8&65280|jc(f,8)<<16),v[P+4>>2]=Q;q=g+4|0;e=g;h=jc(f,1);if(h){b=0}else{b=jc(f,1)}t[e+23|0]=b;if(!(v[g>>2]|!v[q>>2])){dc(f,20);break c}e=v[q>>2];h:{if(b&255){e=Jm(f,e);break h}e=Td(f,e);v[g+8>>2]=e}if(!e){dc(f,3);break c}i:{if(!h){b=0;k=0;i=v[q>>2];if((i|0)<=0){break i}while(1){j:{k:{if(w[g+23|0]){if(!jc(f,1)){break k}}h=jc(f,5)+1|0;t[b+e|0]=h;if((h&255)!=32){k=k+1|0;break j}dc(f,20);break c}t[b+e|0]=255}b=b+1|0;i=v[q>>2];if((b|0)<(i|0)){continue}break}break i}h=jc(f,5);k=0;b=0;i=v[q>>2];if((i|0)<1){break i}while(1){o=jc(f,ll(i-b|0));h=h+1|0;if((h|0)>=32){dc(f,20);break c}i=b+o|0;if((i|0)>v[q>>2]){dc(f,20);break c}Rb(b+e|0,h,o);b=i;i=v[q>>2];if((b|0)<(i|0)){continue}break}}l:{m:{if(w[g+23|0]){if(i>>2>(k|0)){break m}b=g;h=f;if(v[f+16>>2]<(i|0)){v[f+16>>2]=i;i=v[q>>2]}k=b;b=Td(h,i);v[k+8>>2]=b;if(!b){dc(f,3);break c}lc(b,e,v[q>>2]);ji(f,e,v[q>>2]);e=v[g+8>>2];t[g+23|0]=0}h=0;b=0;i=0;k=v[q>>2];if((k|0)>=1){while(1){i=((w[b+e|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((k|0)!=(b|0)){continue}break}}v[g+2092>>2]=i;b=Td(f,k<<2);v[g+32>>2]=b;if(b){i=g+2092|0;break l}dc(f,3);break c}v[g+2092>>2]=k;i=g+2092|0;n:{if(!k){h=0;break n}b=Td(f,k);v[g+8>>2]=b;if(!b){dc(f,3);break c}b=Jm(f,v[i>>2]<<2);v[g+32>>2]=b;if(!b){dc(f,3);break c}h=Jm(f,v[i>>2]<<2);if(h){break n}dc(f,3);break c}b=v[q>>2]+(v[i>>2]<<3)|0;if(b>>>0<=y[f+16>>2]){break l}v[f+16>>2]=b}k=g;o=e;r=v[q>>2];j=h;l=0;b=jb-128|0;jb=b;A=Rb(b,0,128);o:{p:{q:{r:{if((r|0)<1){break r}while(1){if(w[l+o|0]!=255){break r}l=l+1|0;if((r|0)!=(l|0)){continue}break}break q}if((l|0)!=(r|0)){break p}}b=1;if(!v[k+2092>>2]){break o}ia(52010,50496,1088,52033);L()}b=l+o|0;BG(k,0,l,0,w[b|0],j);m=w[b|0];if(m){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;n=(b|0)==(m|0);b=b+1|0;if(!n){continue}break}}I=1;n=l+1|0;if((r|0)<=(n|0)){b=1;break o}s:{t:{u:{while(1){v:{l=n+o|0;m=w[l|0];w:{if((m|0)==255){break w}b=m;if(!b){break s}while(1){K=A+(b<<2)|0;F=v[K>>2];if(!F){F=(b|0)>1;b=b-1|0;if(F){continue}break s}break}if(b>>>0>=32){break v}v[K>>2]=0;BG(k,jl(F),n,I,m,j);I=I+1|0;l=w[l|0];if((l|0)==(b|0)){break w}if(l>>>0>31){break u}if((b|0)>=(l|0)){break w}while(1){m=A+(l<<2)|0;if(v[m>>2]){break t}v[m>>2]=F+(1<<32-l);l=l-1|0;if((l|0)>(b|0)){continue}break}}b=1;n=n+1|0;if((r|0)!=(n|0)){continue}break o}break}ia(52051,50496,1111,52033);L()}ia(52068,50496,1116,52033);L()}ia(52095,50496,1118,52033);L()}b=0}jb=A+128|0;if(!b){if(w[g+23|0]){ji(f,h,0)}dc(f,20);break c}b=v[i>>2];if(b){b=Td(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){dc(f,3);break c}b=Td(f,(v[i>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){dc(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;j=e;m=h;l=0;n=0;x:{b=g;if(w[b+23|0]){n=v[b+2092>>2];if((n|0)<=0){break x}while(1){k=l<<2;P=k+v[b+2084>>2]|0,Q=jl(v[k+v[b+32>>2]>>2]),v[P>>2]=Q;l=l+1|0;n=v[b+2092>>2];if((l|0)<(n|0)){continue}break}break x}if(v[b+4>>2]>=1){while(1){if(AG(b,w[j+l|0])){P=v[b+2084>>2]+(n<<2)|0,Q=jl(v[v[b+32>>2]+(l<<2)>>2]),v[P>>2]=Q;n=n+1|0}l=l+1|0;if((l|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(n|0)){break x}ia(52113,50496,1185,52136);L()}mG(v[b+2084>>2],n,2303);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;y:{n=w[b+23|0];F=v[b+(n?2092:4)>>2];if((F|0)<1){break y}k=0;while(1){z:{o=k;l=b;if(n&255){o=v[m+(k<<2)>>2]}K=w[j+o|0];A:{if(!AG(l,K)){break A}N=k<<2;o=jl(v[N+v[b+32>>2]>>2]);r=v[b+2084>>2];l=0;n=v[b+2092>>2];if((n|0)>=2){while(1){A=n>>>1|0;O=A+l|0;I=o>>>0<y[r+(O<<2)>>2];l=I?l:O;n=I?A:n-A|0;if((n|0)>1){continue}break}}n=l<<2;if((o|0)!=v[n+r>>2]){break z}if(w[b+23|0]){v[n+v[b+2088>>2]>>2]=v[m+N>>2];t[v[b+8>>2]+l|0]=K;break A}v[n+v[b+2088>>2]>>2]=k}k=k+1|0;if((F|0)==(k|0)){break y}n=w[b+23|0];continue}break}ia(52159,50496,1215,52136);L()}}if(w[g+23|0]){ji(f,h,v[i>>2]<<2);ji(f,v[g+32>>2],v[i>>2]<<2);ji(f,e,v[q>>2]);v[g+32>>2]=0}b=g;Rb(b+36|0,255,2048);e=v[b+(w[b+23|0]?2092:4)>>2];if((e|0)>=1){o=(e|0)<32767?e:32767;k=v[b+8>>2];e=0;while(1){B:{if(w[e+k|0]>10){break B}C:{if(w[b+23|0]){h=jl(v[v[b+2084>>2]+(e<<2)>>2]);break C}h=v[v[b+32>>2]+(e<<2)>>2]}if(h>>>0>1023){break B}while(1){u[(b+(h<<1)|0)+36>>1]=e;k=v[b+8>>2];h=(1<<w[k+e|0])+h|0;if(h>>>0<1024){continue}break}}e=e+1|0;if((o|0)!=(e|0)){continue}break}}b=jc(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){dc(f,20);break c}if(b){P=g,R=JG(jc(f,32)),z[P+12>>2]=R;P=g,R=JG(jc(f,32)),z[P+16>>2]=R;P=g,Q=jc(f,4)+1|0,t[P+20|0]=Q;P=g,Q=jc(f,1),t[P+22|0]=Q;h=v[g>>2];k=v[q>>2];D:{if(w[g+21|0]==1){G=H(rw(+C(C(vo(+C(k|0)))/C(h|0))));E:{if(D(G)<2147483648){b=~~G;break E}b=-2147483648}e=b;G=H(kw(+C(C(b|0)+C(1)),h));F:{if(D(G)<2147483648){b=~~G;break F}b=-2147483648}b=e+((b|0)<=(k|0))|0;E=C(b|0);if(kw(+C(E+C(1)),h)<=+(k|0)){b=-1}else{G=H(kw(+E,h));G:{if(D(G)<2147483648){e=~~G;break G}e=-2147483648}b=(e|0)>(k|0)?-1:b}if((b|0)>-1){break D}dc(f,20);break c}b=B(h,k)}v[g+24>>2]=b;if(!b){dc(f,20);break c}e=Jm(f,b<<1);if(!e){break f}b=0;h=v[g+24>>2];if((h|0)>0){while(1){h=jc(f,w[g+20|0]);if((h|0)==-1){ji(f,e,v[g+24>>2]<<1);dc(f,20);break c}u[e+(b<<1)>>1]=h;b=b+1|0;h=v[g+24>>2];if((b|0)<(h|0)){continue}break}}H:{if(w[g+21|0]==1){k=w[g+23|0];I:{if(k){b=v[i>>2];if(b){break I}break H}b=v[q>>2]}b=Td(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){ji(f,e,v[g+24>>2]<<1);dc(f,3);break c}l=v[(k?i:q)>>2];if((l|0)>=1){q=g+2088|0;E=C(0);o=0;while(1){i=o;i=k?v[v[q>>2]+(i<<2)>>2]:i;b=1;j=0;J:{h=v[g>>2];if((h|0)<1){break J}while(1){J=C(C(z[g+12>>2]+E)+C(z[g+16>>2]*C(x[e+(((i>>>0)/(b>>>0)>>>0)%y[g+24>>2]<<1)>>1])));z[v[g+28>>2]+(B(h,o)+j<<2)>>2]=J;E=w[g+22|0]?J:E;h=v[g>>2];j=j+1|0;if((h|0)<=(j|0)){break J}m=v[g+24>>2];Hma(m,0,b,0);if(!mb){b=B(b,m);continue}else{ji(f,e,m<<1);dc(f,20);break c}}}o=o+1|0;if((l|0)!=(o|0)){continue}break}}t[g+21|0]=2;h=v[g+24>>2];break H}b=Td(f,h<<2);v[g+28>>2]=b;h=v[g+24>>2];if(!b){break g}if((h|0)<1){break H}E=C(z[g+12>>2]+C(z[g+16>>2]*C(x[e>>1])));z[b>>2]=E;b=1;h=v[g+24>>2];if((h|0)<=1){break H}J=C(0);while(1){J=w[g+22|0]?E:J;E=C(C(z[g+12>>2]+J)+C(z[g+16>>2]*C(x[e+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=E;b=b+1|0;h=v[g+24>>2];if((b|0)<(h|0)){continue}break}}ji(f,e,h<<1)}M=M+1|0;if((M|0)<v[f+120>>2]){continue}break}}K:{e=jc(f,6)+1&255;if(!e){break K}b=1;while(1){if(!jc(f,16)){if((b|0)==(e|0)){break K}b=b+1|0;continue}break}dc(f,20);break c}b=jc(f,6)+1|0;v[f+128>>2]=b;b=Td(f,B(b,1596));v[f+260>>2]=b;if(b){o=0;if(v[f+128>>2]<=0){break d}k=0;L:while(1){b=jc(f,16);u[((o<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){dc(f,20);break c}if(!b){e=v[f+260>>2]+B(o,1596)|0;P=e,Q=jc(f,8),t[P|0]=Q;P=e,Q=jc(f,16),u[P+2>>1]=Q;P=e,Q=jc(f,16),u[P+4>>1]=Q;P=e,Q=jc(f,6),t[P+6|0]=Q;P=e,Q=jc(f,8),t[P+7|0]=Q;b=(jc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){P=b+g|0,Q=jc(f,8),t[P|0]=Q;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}dc(f,4);break c}m=v[f+260>>2]+B(o,1596)|0;g=jc(f,5);t[m|0]=g;b=-1;i=0;e=0;if(g&255){while(1){g=jc(f,4);t[(e+m|0)+1|0]=g;g=g&255;b=(b|0)<(g|0)?g:b;e=e+1|0;if(e>>>0<w[m|0]){continue}break}while(1){g=i+m|0;P=g,Q=jc(f,3)+1|0,t[P+33|0]=Q;e=jc(f,2);t[g+49|0]=e;M:{if(e&255){e=jc(f,8);t[g+65|0]=e;if(v[f+120>>2]<=(e&255)){dc(f,20);break c}if(w[g+49|0]==31){break M}}e=0;while(1){N:{h=jc(f,8)-1|0;u[((m+(i<<4)|0)+(e<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break N}e=e+1|0;if((e|0)<1<<w[g+49|0]){continue}break M}break}dc(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}j=2;P=m,Q=jc(f,2)+1|0,t[P+1588|0]=Q;b=jc(f,4);v[m+1592>>2]=2;h=0;u[m+338>>1]=0;t[m+1589|0]=b;u[m+340>>1]=1<<b;i=m+1592|0;e=w[m|0];O:{if(e){b=m+1589|0;while(1){g=m+w[(h+m|0)+1|0]|0;if(w[g+33|0]){e=1;while(1){j=jc(f,w[b|0]);u[(m+(v[i>>2]<<1)|0)+338>>1]=j;j=v[i>>2]+1|0;v[i>>2]=j;if(w[g+33|0]>e>>>0){e=e+1|0;continue}break}e=w[m|0]}h=h+1|0;if(h>>>0<(e&255)>>>0){continue}break}if((j|0)<1){break O}}e=0;while(1){b=x[(m+(e<<1)|0)+338>>1];g=(p+16|0)+(e<<2)|0;u[g+2>>1]=e;u[g>>1]=b;e=e+1|0;j=v[i>>2];if((e|0)<(j|0)){continue}break}}h=m+338|0;mG(p+16|0,j,2302);e=0;j=v[i>>2];b=j-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(e|0)){e=0;P:{if((j|0)<=0){break P}while(1){t[(e+m|0)+838|0]=w[((p+16|0)+(e<<2)|0)+2|0];e=e+1|0;j=v[i>>2];if((e|0)<(j|0)){continue}break}e=2;if((j|0)<=2){break P}while(1){v[p+12>>2]=0;v[p+8>>2]=0;b=h;j=0;g=e;if((e|0)>=1){q=b+(g<<1)|0;r=-1;n=65536;while(1){A=b+(j<<1)|0;l=x[A>>1];if(!((r|0)>=(l|0)|x[q>>1]<=l>>>0)){v[p+12>>2]=j;l=x[A>>1];r=l}if(!((l|0)>=(n|0)|x[q>>1]>=l>>>0)){v[p+8>>2]=j;n=x[A>>1]}j=j+1|0;if((g|0)!=(j|0)){continue}break}}b=m+(e<<1)|0;t[b+1088|0]=v[p+12>>2];t[b+1089|0]=v[p+8>>2];e=e+1|0;j=v[i>>2];if((e|0)<(j|0)){continue}break}}k=(j|0)>(k|0)?j:k;o=o+1|0;if((o|0)<v[f+128>>2]){continue L}o=k<<1;break d}g=x[(p+16|0)+(e<<2)>>1];e=e+1|0;if((g|0)!=x[(p+16|0)+(e<<2)>>1]){continue}break}break}dc(f,20);break c}dc(f,3);break c}ji(f,e,h<<1);dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}dc(f,3);break c}dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}b=jc(f,6)+1|0;v[f+264>>2]=b;b=Td(f,B(b,24));v[f+396>>2]=b;if(!b){dc(f,3);break c}i=0;Rb(b,0,B(v[f+264>>2],24));Q:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=jc(f,16);u[((i<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){dc(f,20);break c}j=b+B(i,24)|0;P=j,Q=jc(f,24),v[P>>2]=Q;b=jc(f,24);v[j+4>>2]=b;if(b>>>0<y[j>>2]){dc(f,20);break c}P=j,Q=jc(f,24)+1|0,v[P+8>>2]=Q;P=j,Q=jc(f,6)+1|0,t[P+12|0]=Q;b=jc(f,8);t[j+13|0]=b;R:{S:{if(v[f+120>>2]>(b&255)){b=0;if(w[j+12|0]){break S}e=0;break R}dc(f,20);break c}while(1){g=jc(f,3);e=(p+16|0)+b|0;if(jc(f,1)){h=jc(f,5)<<3}else{h=0}t[e|0]=h+g;b=b+1|0;e=w[j+12|0];if(b>>>0<e>>>0){continue}break}}b=Td(f,e<<4);v[j+20>>2]=b;if(!b){break Q}if(w[j+12|0]){h=0;while(1){e=w[(p+16|0)+h|0];b=0;while(1){T:{if(e>>>b&1){g=jc(f,8);m=b<<1;k=h<<4;u[m+(k+v[j+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[m+(k+v[j+20>>2]|0)>>1]){break T}dc(f,20);break c}u[(v[j+20>>2]+(h<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}h=h+1|0;if(h>>>0<w[j+12|0]){continue}break}}b=Td(f,v[(v[f+124>>2]+B(w[j+13|0],2096)|0)+4>>2]<<2);v[j+16>>2]=b;if(!b){dc(f,3);break c}k=0;Rb(b,0,v[(v[f+124>>2]+B(w[j+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];e=w[j+13|0];if(v[(b+B(e,2096)|0)+4>>2]>0){while(1){g=v[B(e,2096)+b>>2];b=Td(f,g);h=k<<2;v[h+v[j+16>>2]>>2]=b;U:{e=v[h+v[j+16>>2]>>2];if(e){if((g|0)<1){break U}b=g-1|0;t[e+b|0]=(k>>>0)%w[j+12|0];e=k;if((g|0)==1){break U}while(1){g=b-1|0;m=w[j+12|0];e=(e|0)/(m|0)|0;t[g+v[h+v[j+16>>2]>>2]|0]=(e|0)%(m|0);m=(b|0)>1;b=g;if(m){continue}break}break U}dc(f,3);break c}k=k+1|0;b=v[f+124>>2];e=w[j+13|0];if((k|0)<v[(b+B(e,2096)|0)+4>>2]){continue}break}}i=i+1|0;if((i|0)<v[f+264>>2]){continue}break}}b=jc(f,6)+1|0;v[f+400>>2]=b;b=Td(f,B(b,40));v[f+404>>2]=b;if(!b){dc(f,3);break c}h=0;Rb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(jc(f,16)){dc(f,20);break c}g=b+B(h,40)|0;b=Td(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){dc(f,3);break c}b=g;if(jc(f,1)){e=jc(f,4)+1|0}else{e=1}t[b+8|0]=e;V:{if(jc(f,1)){b=jc(f,8)+1|0;u[g>>1]=b;W:{e=v[f+4>>2];b=b&65535;if((e|0)>=(b|0)){i=0;if(b){break W}break V}dc(f,20);break c}while(1){e=jc(f,ll(e-1|0));b=B(i,3);t[b+v[g+4>>2]|0]=e;e=jc(f,ll(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=e;e=v[f+4>>2];b=b+v[g+4>>2]|0;k=w[b|0];if((e|0)<=(k|0)){dc(f,20);break c}b=w[b+1|0];if((b|0)>=(e|0)){dc(f,20);break c}if((b|0)!=(k|0)){i=i+1|0;if(i>>>0>=x[g>>1]){break V}continue}break}dc(f,20);break c}u[g>>1]=0}if(jc(f,2)){dc(f,20);break c}i=v[f+4>>2];X:{Y:{b=w[g+8|0];if(b>>>0<=1){e=0;if((i|0)>0){while(1){t[(v[g+4>>2]+B(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break X}break Y}e=0;if((i|0)<=0){break Y}while(1){Z:{b=jc(f,4);i=B(e,3);t[(i+v[g+4>>2]|0)+2|0]=b;if(w[(i+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break Z}e=e+1|0;if((e|0)<v[f+4>>2]){continue}break Y}break}dc(f,20);break c}b=0;while(1){jc(f,8);i=b+g|0;e=i;P=e,Q=jc(f,8),t[P+9|0]=Q;i=jc(f,8);t[e+24|0]=i;if(v[f+128>>2]<=w[e+9|0]){dc(f,20);break c}if(v[f+264>>2]>(i&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break X}continue}break}dc(f,20);break c}h=h+1|0;if((h|0)<v[f+400>>2]){continue}break}}b=jc(f,6)+1|0;v[f+408>>2]=b;e=0;_:{if((b|0)<=0){break _}while(1){b=B(e,6)+f|0;P=b,Q=jc(f,1),t[P+412|0]=Q;P=b,Q=jc(f,16),u[P+414>>1]=Q;P=b,Q=jc(f,16),u[P+416>>1]=Q;g=jc(f,8);t[b+413|0]=g;if(x[b+414>>1]){dc(f,20);break c}if(x[b+416>>1]){dc(f,20);break c}if(v[f+400>>2]>(g&255)){e=e+1|0;if((e|0)>=v[f+408>>2]){break _}continue}break}dc(f,20);break c}IG(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;P=e,Q=Td(f,v[f+116>>2]<<2),v[P+800>>2]=Q;P=e,Q=Td(f,v[f+116>>2]<<1&2147483646),v[P+928>>2]=Q;g=Td(f,o);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){dc(f,3);break c}Rb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!HG(f,0,v[f+112>>2])){break a}if(!HG(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;r=f;k=h<<1&2147483646;o=k;m=v[f+264>>2];if((m|0)<1){e=4}else{l=v[f+396>>2];j=0;i=0;while(1){h=l+B(i,24)|0;q=v[h+4>>2];e=g>>>0>q>>>0?q:g;q=v[h>>2];h=(e-(g>>>0>q>>>0?q:g)>>>0)/y[h+8>>2]|0;j=(h|0)>(j|0)?h:j;i=i+1|0;if((m|0)!=(i|0)){continue}break}e=(j<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<k>>>0?o:e;v[r+12>>2]=e;$:{aa:{if(!v[f+80>>2]){break aa}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break $}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break aa}dc(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}ia(51940,50496,4182,51996);L()}dc(f,3)}b=0}jb=p+1024|0;ba:{ca:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ca}b=Td(s+8|0,1512);if(b){P=c,Q=v[lc(b,s+8|0,1512)+32>>2]-a|0,v[P>>2]=Q;v[d>>2]=0;break ba}MG(s+8|0)}b=0}jb=s+1520|0;return b|0}function Dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=jb-288|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+264|0;Gt(g+8|0,i);f=b;l=Hb(g+8|0);j=nc(b,ac(g,g+8|0));if((l|0)==(j|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(j|0)==(l|0);if(!f){PS(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!f){break u}if(!SS(d+264|0)){break u}if(!c){e=1;break u}Hd(a,1024);vi(a);v[a+480208>>2]=v[a+480208>>2]|12;wg(a+1074312|0,21);if(w[d+280|0]|w[d+281|0]<<8){e=w[d+280|0]|w[d+281|0]<<8;v[a+480204>>2]=B((e<<8|e>>>8)&65535,1e4)}if(w[d+278|0]|w[d+279|0]<<8){e=w[d+278|0]|w[d+279|0]<<8;v[a+480196>>2]=(e<<8|e>>>8)&65535}if(!w[d+274|0]){mj(a,1)}e=d+264|4;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);uA(b,a+1304400|0,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-14|0);b=Jk(d+160|0,b);v[114578]=0;U(579,d+248|0,b|0,1);e=v[114578];v[114578]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){Bb(b);v[114578]=0;U(580,d+160|0,d+248|0,1395544366);b=v[114578];v[114578]=0;if((b|0)==1){break E}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break L}if(!b){break F}v[114578]=0;b=T(485,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break L}v[114578]=0;e=T(485,d+160|0)|0;f=v[114578];v[114578]=0;N:{if((f|0)==1){break N}v[114578]=0;Q(340,d+160|0,4)|0;f=v[114578];v[114578]=0;if((f|0)==1){break N}f=a+484360|0;g=Vb(f);v[114578]=0;ea(581,g|0,d+160|0,b|0,65535,65535)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break M}}break L}e=P()|0;O()|0;Bb(b);break a}Oe(Vb(f),e);Bb(d+160|0);v[114578]=0;U(580,d+160|0,d+248|0,1346458708);b=v[114578];v[114578]=0;if((b|0)==1){break K}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}if(!b){break H}v[114578]=0;b=T(485,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[114578]=0;b=T(485,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}v[114578]=0;p=a+484344|0;R(403,p|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break J}v[114578]=0;l=T(494,d+160|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break J}switch(l-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=P()|0;O()|0;Bb(d+160|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+160|0);break b}if(!l){break G}}Bb(d+160|0);break A}Bb(d+160|0);v[114578]=0;U(580,d+232|0,d+248|0,1398157625);b=v[114578];v[114578]=0;if((b|0)==1){break D}v[114578]=0;b=T(490,d+232|0)|0;e=v[114578];v[114578]=0;O:{if((e|0)==1){break O}if(!b){break B}v[114578]=0;Q(340,d+232|0,2)|0;b=v[114578];v[114578]=0;if((b|0)==1){break O}v[114578]=0;e=T(494,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[114578]=0;Q(582,d+232|0,d+160|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+160|0)+(b<<1)|0;e=w[e|0]|w[e+1|0]<<8;v[114578]=0;v[d+96>>2]=(e<<8|e>>>8)&65535;v[d+80>>2]=180;e=Q(464,d+96|0,d+80|0)|0;f=v[114578];v[114578]=0;Q:{if((f|0)==1){break Q}e=v[e>>2];v[114578]=0;e=e-90|0;f=e>>31;e=Gg(460,Ima(e<<7|45,f<<7|e>>>25,90,0),mb);f=v[114578];v[114578]=0;if((f|0)==1){break Q}u[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}Bb(d+160|0);break A}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[114578]=0;Q(340,d+232|0,16)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=Q(258,d+232|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(b){v[114578]=0;b=T(485,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;u[d+96>>1]=b;u[d+80>>1]=256;b=Q(478,d+96|0,d+80|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[114578]=0;Q(340,d+232|0,128)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=Q(582,d+232|0,d+96|0)|0;e=v[114578];v[114578]=0;R:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break R}e=(d+96|0)+(b<<1)|0;e=w[e|0]|w[e+1|0]<<8;v[114578]=0;v[d+80>>2]=(e<<8|e>>>8)&65535;v[d+56>>2]=128;e=Q(464,d+80|0,d+56|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break R}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}Bb(d+232|0);v[114578]=0;U(580,d+160|0,d+248|0,1413830740);b=v[114578];v[114578]=0;S:{T:{if((b|0)!=1){v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(!b){break S}v[114578]=0;Q(583,d+160|0,d+96|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}if((w[d+106|0]|w[d+107|0]<<8)!=65535){break T}v[114578]=0;Q(340,d+160|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break T}break d}e=P()|0;O()|0;break b}v[114578]=0;b=T(332,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;aa(584,a+1304424|0,d+160|0,b|0,2)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}}Bb(d+160|0);v[114578]=0;U(580,d+96|0,d+248|0,1229869908);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;b=T(490,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if(b){v[114578]=0;b=T(485,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}U:{e=b<<16>>16;f=e&32767;if(f>>>0>3999){break U}v[114578]=0;b=Q(258,d+96|0,B(f,(e>>>14&2)+50|0)|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break y}if(!b){break U}u[a+480190>>1]=f;g=a+480190|0;if(!f){break z}i=d+178|0;b=1;j=(e|0)>-1;V:{W:{while(1){X:{e=b;Y:{Z:{_:{if(!j){v[114578]=0;e=T(485,d+96|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break _}e=e+1|0}v[114578]=0;u[d+56>>1]=e;Q(585,d+96|0,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if((x[d+56>>1]-1&65535)>>>0>3998){break Y}v[114578]=0;e=Q(454,g|0,d+56|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break Z}}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];h=x[d+56>>1];e=w[d+282|0]|w[d+283|0]<<8|(w[d+284|0]<<16|w[d+285|0]<<24);v[114578]=0;X(586,d+160|0,(B(h,104)+a|0)+484380|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24),l|0);e=v[114578];v[114578]=0;if((e|0)==1){break X}v[114578]=0;U(587,d+80|0,2,i|0);e=v[114578];v[114578]=0;if((e|0)==1){break W}v[114578]=0;R(417,d+232|0,d+80|0);e=v[114578];v[114578]=0;if((e|0)==1){break W}v[114578]=0;Q(371,((x[d+56>>1]<<5)+a|0)+946304|0,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break V}yb(d+232|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;yb(d+232|0);break f}Bb(d+96|0);break A}break w}e=P()|0;O()|0;break f}e=0;break v}v[114578]=0;b=T(485,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break x}}e=P()|0;O()|0;break f}if((b|0)==4){b=x[g>>1];v[114578]=0;u[d+160>>1]=b;u[d+232>>1]=255;b=Q(478,d+160|0,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[114578]=0;U(580,d+232|0,d+248|0,1229278806);b=v[114578];v[114578]=0;if((b|0)==1){break i}g=d+80|4;i=d+80|3;j=d+80|5;h=d+80|7;while(1){v[114578]=0;b=Q(258,d+96|0,15)|0;e=v[114578];v[114578]=0;$:{if((e|0)!=1){aa:{if(b){v[114578]=0;Q(588,d+96|0,d+80|0)|0;b=v[114578];v[114578]=0;ba:{if((b|0)!=1){b=w[d+80|0]|w[d+81|0]<<8;if(x[a+480192>>1]<=((b<<8|b>>>8)&65535)>>>0){continue}b=w[d+80|0]|w[d+81|0]<<8;b=B((b<<8|b>>>8)&65535,104)+a|0;t[b+484524|0]=w[d+88|0];e=w[h|0];t[b+484523|0]=255;t[b+484525|0]=e;b=w[d+80|0]|w[d+81|0]<<8;e=w[d+80|0]|w[d+81|0]<<8;v[114578]=0;e=W(456,a|0,(b<<8|b>>>8)+1&65535,(e<<8|e>>>8)+1&65535)|0;b=v[114578];v[114578]=0;if((b|0)==1){break aa}if(!e){continue}b=w[j|0]|w[j+1|0]<<8;v[114578]=0;u[d+160>>1]=b<<8|b>>>8;u[d+56>>1]=4095;b=Q(478,d+160|0,d+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}v[e>>2]=x[b>>1];if(w[i|0]==255){continue}b=w[i|0];v[114578]=0;b=Q(256,d+232|0,B(b,34)+2|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}if(!b){continue}v[114578]=0;Q(589,d+232|0,d+160|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break aa}t[e+60|0]=w[e+60|0]|1;b=w[d+160|0]|w[d+161|0]<<8;v[d+56>>2]=(b<<8|b>>>8)&65535;v[114578]=0;v[d+76>>2]=3;v[d+64>>2]=240;v[d+60>>2]=16;v[d+72>>2]=d+56;b=v[d+76>>2];v[d+8>>2]=v[d+72>>2];v[d+12>>2]=b;b=T(590,d+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}v[114578]=0;f=e+48|0;R(591,f|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break aa}b=0;if(Kb(f)){break ba}break $}break aa}while(1){ca:{t[d+56|0]=64;o=(d+160|0)+(b<<1)|0;n=w[o+2|0];v[114578]=0;t[d+48|0]=n;n=Q(393,d+56|0,d+48|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break ca}n=w[n|0];E=Pb(f,b),F=n,t[E+2|0]=F;o=w[o+3|0];E=Pb(f,b),F=o,u[E>>1]=F;b=b+1|0;if(Kb(f)>>>0>b>>>0){continue}break $}break}break aa}Bb(d+232|0);break w}}e=P()|0;O()|0;Bb(d+232|0);break f}if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(md(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Kb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}Bb(d+96|0);v[114578]=0;U(592,d+96|0,d+248|0,1145131092);b=v[114578];v[114578]=0;if((b|0)==1){break j}E=d,F=bc(d+96|0),v[E+48>>2]=F;E=d,F=cc(d+96|0),v[E+40>>2]=F;if(Jb(d+48|0,d+40|0)){A=c&1;o=d+232|4;n=(l|0)!=841887798;C=(l|0)!=841887796;while(1){i=v[d+48>>2];v[114578]=0;Q(340,i|0,4)|0;b=v[114578];v[114578]=0;da:{ea:{fa:{if((b|0)!=1){v[114578]=0;e=T(485,i|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;j=T(485,i|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break m}j=n?j:(j>>>0)/y[a+480196>>2]|0;if(!A|e>>>0>255){break da}v[114578]=0;b=W(404,p|0,e|0,j|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}if(!b){break da}if(n){break ea}v[114578]=0;Q(340,i|0,4)|0;b=v[114578];v[114578]=0;if((b|0)==1){break m}h=0;if(!x[a+480188>>1]){break da}while(1){v[114578]=0;b=T(485,i|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break fa}v[114578]=0;U(343,d+160|0,i|0,b+(b&1)&65535);b=v[114578];v[114578]=0;if((b|0)==1){break n}v[d+232>>2]=0;v[d+236>>2]=0;f=0;ga:{while(1){v[114578]=0;b=Q(258,d+160|0,6)|0;g=v[114578];v[114578]=0;if((g|0)==1){break o}if(!(b&y[d+232>>2]<j>>>0)){break ga}b=_b(p,e);v[114578]=0;b=W(472,b|0,v[d+232>>2],h&65535)|0;g=v[114578];v[114578]=0;ha:{ia:{if((g|0)!=1){v[114578]=0;R(593,d+56|0,d+160|0);g=v[114578];v[114578]=0;if((g|0)==1){break o}g=cd(d+56|0);s=Bf(d+56|0);q=Rh(d+56|0);m=hc(d+56|0);D=d+61|0;k=t[d+56|0];if((k-1&255)>>>0>95){break ia}t[b|0]=k+13;if(!v[d+236>>2]){break ha}t[b+3|0]=19;v[114578]=0;v[d+80>>2]=15;k=Q(464,o|0,d+80|0)|0;z=v[114578];v[114578]=0;if((z|0)==1){break o}t[b+5|0]=w[k|0]|208;break ha}break o}if((k|0)>-1){break ha}if(v[d+236>>2]){t[b+3|0]=19;v[114578]=0;v[d+80>>2]=15;k=Q(464,o|0,d+80|0)|0;z=v[114578];v[114578]=0;if((z|0)!=1){t[b+5|0]=w[k|0]|192;break ha}break o}t[b|0]=254}if(w[g|0]){t[b+2|0]=1;v[114578]=0;t[d+80|0]=64;g=Q(393,g|0,d+80|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break o}t[b+4|0]=w[g|0]}g=w[s|0];if(g){t[b+1|0]=g}g=w[q|0];if(g|w[m|0]){t[b+3|0]=g;t[b+5|0]=w[m|0];v[114578]=0;Z(574,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}}b=w[D|0];if(b&128){v[114578]=0;g=T(389,d+160|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break o}b=g|b<<8&32512}g=v[a+480196>>2];v[114578]=0;f=b+f|0;U(594,d+80|0,f|0,g|0);b=v[114578];v[114578]=0;if((b|0)!=1){b=v[d+84>>2];v[d+232>>2]=v[d+80>>2];v[d+236>>2]=b;continue}break}break o}Bb(d+160|0);h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break da}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}b=_b(p,e);v[114578]=0;b=W(472,b|0,0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}h=0;if(!j){break da}while(1){e=0;ja:{if(!x[a+480188>>1]){break ja}while(1){ka:{v[114578]=0;R(595,d+160|0,i|0);f=v[114578];v[114578]=0;if((f|0)==1){break ka}la:{if(!C){v[d+232>>2]=v[d+160>>2];m=cd(d+232|0);k=Bf(d+232|0);s=Rh(d+232|0);f=t[d+232|0];if((f|0)>=1){t[b|0]=(B((f&240)>>>4|0,12)+(f&15)|0)+12}g=b;f=w[m|0];q=f>>>2|0;if(q){t[b+2|0]=1;t[b+4|0]=q-1;f=w[m|0]}t[g+1|0]=f<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[s|0];break la}v[114578]=0;f=v[d+160>>2];v[d+36>>2]=f;v[d+20>>2]=f;R(596,d+20|0,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break ka}f=fc(d+160|0,0);t[b+1|0]=w[b+1|0]|w[f|0]&48}v[114578]=0;Z(574,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break ka}f=w[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!w[b+5|0]){break na}break ma}f=w[b+5|0];g=f&240;if(g){t[b+5|0]=g;break ma}if(f){break ma}}t[b+3|0]=0}b=b+6|0;e=e+1|0;if(x[a+480188>>1]>(e&65535)>>>0){continue}break ja}break}e=P()|0;O()|0;break k}h=h+1|0;if((h|0)!=(j|0)){continue}break}}Uf(d+48|0);if(Jb(d+48|0,d+40|0)){continue}break}}gd(d+96|0);v[114578]=0;U(580,d+160|0,d+248|0,1346458702);b=v[114578];v[114578]=0;if((b|0)==1){e=P()|0;O()|0;break b}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Wb(d+96|0);b=0;Ca:{while(1){Da:{v[114578]=0;e=Q(258,d+160|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Da}if(!e){break Ca}if(Ce(p)>>>0<=b>>>0){break Ca}v[114578]=0;W(597,d+160|0,f|0,32)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Da}e=_b(p,b);v[114578]=0;Q(496,e|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=P()|0;O()|0;yb(f);break Ba}yb(f)}Bb(d+160|0);v[114578]=0;U(580,d+160|0,d+248|0,1414679374);b=v[114578];v[114578]=0;if((b|0)==1){break Aa}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break wa}if(!b){break xa}f=Wb(d+96|0);b=0;while(1){v[114578]=0;e=Q(258,d+160|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break za}if(!e|x[a+480188>>1]<=b>>>0){break ya}v[114578]=0;W(597,d+160|0,f|0,32)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}v[114578]=0;Q(380,((b<<5)+a|0)+480289|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=P()|0;O()|0}Bb(d+160|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(f);break va}yb(f)}Bb(d+160|0);v[114578]=0;U(592,d+160|0,d+248|0,1145129300);b=v[114578];v[114578]=0;if((b|0)==1){break ua}E=d,F=bc(d+160|0),v[E+96>>2]=F;E=d,F=cc(d+160|0),v[E+232>>2]=F;if(Jb(d+96|0,d+232|0)){e=c&2;while(1){b=v[d+96>>2];v[114578]=0;c=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=ad(d+80|0,f&1?16:8,f&64?2:1,1,0);v[114578]=0;W(402,f|0,c+484484|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break p}}Uf(d+96|0);if(Jb(d+96|0,d+232|0)){continue}break}}gd(d+160|0);b=fd(d+96|0);if((l|0)!=841887798){break sa}v[114578]=0;c=Q(2,d+160|0,12790)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ta}Gb(b,c);yb(c);break ra}e=P()|0;O()|0}Bb(d+160|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break q}v[114578]=0;U(580,d+160|0,d+248|0,1447383635);c=v[114578];v[114578]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){v[114578]=0;c=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break qa}if(!c){break Fa}v[114578]=0;e=T(494,d+160|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Ka}v[114578]=0;c=Q(2,d+24|0,12810)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ja}v[114578]=0;R(219,d+80|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ia}v[114578]=0;v[d+56>>2]=e>>>4;v[d+48>>2]=e&15;X(598,d+232|0,d+80|0,d+56|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ha}Gb(b,d+232|0);yb(d+232|0);Ib(d+80|0);break Ea}e=P()|0;O()|0;break q}e=P()|0;O()|0;break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;break Ga}e=P()|0;O()|0;Ib(d+80|0)}yb(c);break r}v[114578]=0;c=Q(2,d+232|0,12832)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}Gb(b,c)}yb(c);Bb(d+160|0)}v[114578]=0;c=Q(2,d+160|0,12832)|0;e=v[114578];v[114578]=0;if((e|0)==1){break pa}Gb(a+1304436|0,c);yb(c);v[114578]=0;c=Q(2,d+160|0,12848)|0;e=v[114578];v[114578]=0;if((e|0)==1){break oa}Gb(a+1304448|0,c);yb(c);Gb(a+1304460|0,b);v[a+1304496>>2]=2;yb(b);e=1;break v}e=P()|0;O()|0;break r}e=P()|0;O()|0;break q}e=P()|0;O()|0;break q}bA(d+248|0)}jb=d+288|0;return e|0}e=P()|0;O()|0;break r}e=P()|0;O()|0;break k}Bb(d+160|0)}yb(b);break b}e=P()|0;O()|0;gd(d+160|0);break b}e=P()|0;O()|0;Bb(d+160|0);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0}gd(d+96|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0}Bb(d+96|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+160|0);break b}e=P()|0;O()|0;Bb(d+232|0)}bA(d+248|0)}S(e|0);L()}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=jb-528|0;jb=d;Jc(b);a:{if(!Bn(b,d+448|0)){break a}if(!LO(d+448|0)){break a}if(!Qb(b,hd(KO(d+448|0),mb))){break a}b:{if(!c){break b}Hd(a,4);vi(a);v[a+1074372>>2]=4;l=fd(d+432|0);c:{d:{j=d+486|0;e:{if(!(pd(j,17536,20)|(w[d+508|0]|w[d+509|0]<<8|(w[d+510|0]<<16|w[d+511|0]<<24))!=276)){e=48;if((w[d+506|0]|w[d+507|0]<<8)>>>0<260){break e}v[114578]=0;f=W(625,d+465|0,0,20)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}e=f?1154:34;break e}if(!pd(j,17557,20)){e=1;break e}v[114578]=0;U(747,d+416|0,3,j|0);f=v[114578];v[114578]=0;f:{g:{h:{if((f|0)==1){break h}v[114578]=0;R(417,d+72|0,d+416|0);f=v[114578];v[114578]=0;if((f|0)==1){break h}v[114578]=0;U(13,d+144|0,4,d+72|0);f=v[114578];v[114578]=0;if((f|0)==1){break g}Gb(l,d+144|0);yb(d+144|0);yb(d+72|0);if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))!=1852141647|(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))!=542396493){break f}e=1048;break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;yb(d+72|0);break c}if(!pd(j,17587,12)){e=16;if((x[d+498>>1]|x[d+500>>1]<<16)==538976288&(x[d+502>>1]|x[d+504>>1]<<16)==538976288){break e}v[a+1074372>>2]=5;break e}if(!pd(j,17601,20)){e=48;break e}if(!pd(j,17622,15)){v[114578]=0;f=a+1074312|0;Q(480,f|0,54)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;Q(480,f|0,51)|0;f=v[114578];v[114578]=0;e=16;if((f|0)==1){break d}break e}if(!pd(j,17638,14)){v[114578]=0;Q(480,a+1074312|0,57)|0;f=v[114578];v[114578]=0;e=16;if((f|0)!=1){break e}break d}e=pd(j,17653,11)?16:256}v[114578]=0;s=d+465|0;U(747,d+72|0,3,s|0);f=v[114578];v[114578]=0;i:{if((f|0)==1){break i}v[114578]=0;R(417,d+144|0,d+72|0);f=v[114578];v[114578]=0;if((f|0)==1){break i}Gb(a+1304400|0,d+144|0);yb(d+144|0);v[a+480260>>2]=1;v[a+480264>>2]=31999;q=a+484360|0;Oe(Vb(q),w[d+514|0]|w[d+515|0]<<8);u[a+480188>>1]=w[d+516|0]|w[d+517|0]<<8;f=w[d+520|0]|w[d+521|0]<<8;v[114578]=0;u[d+144>>1]=f;u[d+72>>1]=255;f=Q(478,d+144|0,d+72|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){u[a+480192>>1]=x[f>>1];if(w[d+524|0]|w[d+525|0]<<8){v[a+480196>>2]=w[d+524|0]|w[d+525|0]<<8}if(w[d+526|0]|w[d+527|0]<<8){h=a;g=v[19814];f=B(v[g+20>>2],1e4);g=B(v[g+24>>2],1e4);k=B(w[d+526|0]|w[d+527|0]<<8,1e4);g=g>>>0<k>>>0?g:k;if(f>>>0>k>>>0){g=f}v[h+480204>>2]=g}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+522|0]|w[d+523|0]<<8)<<4&16;f=(w[d+522|0]|w[d+523|0]<<8)<<3&32768;v[a+480208>>2]=f|v[a+480208>>2]&-32769;g=Vb(q);h=w[d+512|0]|w[d+513|0]<<8;v[114578]=0;ea(581,g|0,b|0,h|0,65535,65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}h=f>>>15|0?(e|0)==34?146:e:e;if(!(h&1024|(w[d+512|0]|w[d+513|0]<<8))){f=Vb(q);v[114578]=0;U(1033,f|0,1,0);f=v[114578];v[114578]=0;if((f|0)==1){break d}}f=w[d+508|0]|w[d+509|0]<<8|(w[d+510|0]<<16|w[d+511|0]<<24);v[114578]=0;Q(256,b|0,f+60|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}if((w[d+506|0]|w[d+507|0]<<8)>>>0>=260){v[114578]=0;U(1034,b|0,d+448|0,a|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}}t[d+415|0]=0;p=c&2;f=jb-16|0;jb=f;k=d+416|0;g=k;v[g>>2]=0;v[g+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(1056,g+8|0,f+12|0,f+8|0)|0;g=v[114578];v[114578]=0;j:{if((g|0)!=1){jb=f+16|0;break j}V(0)|0;O()|0;Ab();L()}k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(x[a+480192>>1]){C=d+90|0;D=d+177|0;e=1;f=-1;m=1;E:{while(1){v[114578]=0;g=T(392,b|0)|0;i=v[114578];v[114578]=0;F:{G:{H:{I:{J:{K:{if((i|0)!=1){fg(b,4);v[114578]=0;W(1035,b|0,d+144|0,(g?g:263)|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break E}L:{if((h|0)==1){if((w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))==245){v[a+1074308>>2]=16777381;v[114578]=0;g=Q(2,d+72|0,17665)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(l,g);yb(g);h=17;break L}e=P()|0;O()|0;break k}h=16;if((w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))!=263){break L}v[a+1074308>>2]=16777395;v[114578]=0;g=Q(2,d+72|0,17691)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(l,g);yb(g);h=17;break L}e=P()|0;O()|0;break k}if(w[d+171|0]|w[d+172|0]<<8){break L}if(!(!(h&2)|(w[d+173|0]|w[d+174|0]<<8|(w[d+175|0]<<16|w[d+176|0]<<24))|(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))!=263)){h=h|16;break L}if(!(!(h&256)|(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))==29)){h=h&-257;break L}if(!(h&160)){break L}h=(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))==33?h:0}v[114578]=0;g=W(456,a|0,m&65535,0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break E}if(!g){break F}i=((e<<2)+a|0)+900380|0;g=v[i>>2];v[114578]=0;R(1036,d+144|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break E}g=w[d+170|0];M:{if((f|0)==-1){f=g;break M}if(!(h&32)|(f|0)==(g|0)){break M}h=h&-161|128}if(!(w[d+171|0]|w[d+172|0]<<8)){break F}g=w[d+385|0];e=w[d+386|0];o=w[d+387|0]|w[d+388|0]<<8;n=w[d+391|0];r=w[d+171|0]|w[d+172|0]<<8;v[114578]=0;U(1037,d+128|0,a|0,r|0);r=v[114578];v[114578]=0;if((r|0)==1){break K}h=n|(o|(e|g))?h&-4:h;e=12;while(1){g=x[dd(v[i>>2]+236|0,e)>>1];if(oc(d+128|0)>>>0>g>>>0){g=x[rc(d+128|0,x[dd(v[i>>2]+236|0,e)>>1])>>1];E=dd(v[i>>2]+236|0,e),F=g,u[E>>1]=F}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+506|0]|w[d+507|0]<<8)>>>0>259){Kb(k);HO(k);Qg(k)}g=w[d+171|0]|w[d+172|0]<<8;v[114578]=0;g=Q(1038,d+112|0,g|0)|0;e=v[114578];v[114578]=0;N:{if((e|0)!=1){e=0;if(w[d+171|0]|w[d+172|0]<<8){break N}break J}e=P()|0;O()|0;break H}O:{P:{Q:{R:{while(1){v[114578]=0;Q(1039,b|0,d+72|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break O}v[114578]=0;R(1040,d+56|0,d+72|0);i=v[114578];v[114578]=0;S:{if((i|0)==1){break S}v[114578]=0;R(1041,k|0,d+56|0);i=v[114578];v[114578]=0;if((i|0)==1){break S}i=w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24);E=Pb(g,e),F=i,v[E>>2]=F;o=w[d+89|0];if(oc(d+128|0)>>>0>e>>>0){i=x[rc(d+128|0,e)>>1];v[114578]=0;n=(B(i,104)+a|0)+484380|0;R(1042,d+72|0,n|0);r=v[114578];v[114578]=0;if((r|0)==1){break R}v[114578]=0;R(1043,D|0,n|0);n=v[114578];v[114578]=0;if((n|0)==1){break R}v[114578]=0;U(587,d+40|0,3,C|0);n=v[114578];v[114578]=0;if((n|0)==1){break Q}v[114578]=0;R(417,d+56|0,d+40|0);n=v[114578];v[114578]=0;if((n|0)==1){break Q}v[114578]=0;Q(371,((i<<5)+a|0)+946304|0,d+56|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break P}yb(d+56|0);h=(w[d+86|0]&3)==3?(h&2)>>>1|0?h|4:h:h}z=o|z;e=e+1|0;if(e>>>0>=(w[d+171|0]|w[d+172|0]<<8)>>>0){break J}continue}break}e=P()|0;O()|0;break I}e=P()|0;O()|0;break I}e=P()|0;O()|0;break I}e=P()|0;O()|0;yb(d+56|0);break I}e=P()|0;O()|0;break I}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}if((w[d+506|0]|w[d+507|0]<<8)>>>0<260){break G}e=0;if(!(w[d+171|0]|w[d+172|0]<<8)){break G}T:{while(1){U:{o=w[Pb(k,e)+3|0];i=v[Pb(g,e)>>2];v[114578]=0;U(343,d+72|0,b|0,((o|0)==11?(i+1>>>1|0)+16|0:i)|0);i=v[114578];v[114578]=0;if((i|0)==1){break U}if(!(!p|oc(d+128|0)>>>0<=e>>>0)){o=x[rc(d+128|0,e)>>1];i=Pb(k,e);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);v[114578]=0;v[d+36>>2]=i;v[d+4>>2]=i;i=aa(1044,(B(o,104)+a|0)+484380|0,d+4|0,d+72|0,d+415|0)|0;o=v[114578];v[114578]=0;if((o|0)==1){break T}A=i^1|A}Bb(d+72|0);e=e+1|0;if(e>>>0<(w[d+171|0]|w[d+172|0]<<8)>>>0){continue}break G}break}e=P()|0;O()|0;break I}e=P()|0;O()|0;Bb(d+72|0)}oe(g)}kf(d+128|0);break k}oe(g);kf(d+128|0)}m=m+1|0;e=m&65535;if(e>>>0<=x[a+480192>>1]){continue}break}g=!(z&255);break D}e=P()|0;O()|0;break k}f=-1;g=1}if(!(!g|!(h&2))){v[114578]=0;e=W(625,s|0,0,20)|0;m=v[114578];v[114578]=0;if((m|0)==1){break C}h=e?h|16:h}V:{if((w[d+506|0]|w[d+507|0]<<8)>>>0>259){break V}if(c&3){v[114578]=0;U(1034,b|0,d+448|0,a|0);c=v[114578];v[114578]=0;if((c|0)==1){break C}}if(!p|!x[a+480190>>1]){break V}c=1;e=1;while(1){m=Pb(k,c-1|0);v[114578]=0;W(402,m|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break B}e=e+1|0;c=e&65535;if(c>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[114578]=0;c=Q(2,d+144|0,17716)|0;e=v[114578];v[114578]=0;if((e|0)==1){break A}v[114578]=0;U(646,a|0,2,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break z}yb(c)}v[114578]=0;c=Q(618,b|0,17799)|0;e=v[114578];v[114578]=0;if((e|0)==1){break C}if(c){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break C}v[114578]=0;aa(584,a+1304424|0,b|0,c|0,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break C}h=h|16}v[114578]=0;m=Q(618,b|0,17804)|0;c=v[114578];v[114578]=0;if((c|0)==1){break l}if(m){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}v[114578]=0;e=a+901404|0;W(1045,b|0,e|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break l}v[114578]=0;Z(633,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break l}h=h|16}v[114578]=0;c=Q(618,b|0,17809)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}if(c){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}u[d+144>>1]=c>>>5;e=a+484344|0;c=Ce(e);v[114578]=0;u[d+72>>1]=c;c=Q(478,d+144|0,d+72|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break x}i=x[c>>1];if(i){c=0;while(1){v[114578]=0;W(869,b|0,d+144|0,32)|0;p=v[114578];v[114578]=0;if((p|0)==1){break w}p=_b(e,c);v[114578]=0;Q(870,p|0,d+144|0)|0;p=v[114578];v[114578]=0;if((p|0)==1){break w}c=c+1|0;if((i|0)!=(c|0)){continue}break}}h=h|16}v[114578]=0;c=Q(618,b|0,17814)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}if(c){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break v}u[d+144>>1]=(c>>>0)/20;c=x[a+480188>>1];v[114578]=0;u[d+72>>1]=c;c=Q(478,d+144|0,d+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break u}c=x[c>>1];if(c){e=0;while(1){v[114578]=0;W(635,b|0,((e<<5)+a|0)+480289|0,20)|0;i=v[114578];v[114578]=0;if((i|0)==1){break q}e=e+1|0;if((c|0)!=(e|0)){continue}break}}h=h|16}v[114578]=0;c=Q(258,b|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}if(c){c=v[b+8>>2];v[114578]=0;Q(636,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break p}h=(c|0)==v[b+8>>2]?h:h|16}if(!(h&16)){break r}if(!(h&4)){break s}v[a+1074308>>2]=17367040;v[114578]=0;c=Q(2,d+144|0,17819)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}Gb(l,c);yb(c);break r}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;yb(c);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}if(!(h&2)){break r}v[a+1074308>>2]=18219008;v[114578]=0;c=Q(2,d+144|0,17840)|0;e=v[114578];v[114578]=0;if((e|0)==1){break o}Gb(l,c);yb(c)}W:{X:{Y:{Z:{_:{$:{aa:{if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))==1852141647&(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))==542396493){v[114578]=0;c=W(1046,d+144|0,d+494|0,12)|0;h=v[114578];v[114578]=0;if((h|0)==1){break aa}v[114578]=0;U(13,d+72|0,1,c|0);h=v[114578];v[114578]=0;if((h|0)==1){break $}v[114578]=0;h=T(1047,d+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break _}v[a+1074308>>2]=h;yb(d+72|0);v[a+1074372>>2]=y[a+1074308>>2]<19007257?4:5;yb(c);h=24}if(!(!v[a+1074308>>2]|h&8)){v[a+1074372>>2]=0;Ct(a+1074312|0)}c=h&32;ba:{if(!c){break ba}v[a+1074372>>2]=5;if(!m){v[114578]=0;Z(634,a+901404|0);e=v[114578];v[114578]=0;if((e|0)==1){break l}}if((w[d+506|0]|w[d+507|0]<<8)>>>0<260){break ba}v[114578]=0;W(479,a+1074312|0,4,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}}if(!Wc(l)){break W}if((g&h>>>8)!=1|f+1>>>0>1){break X}v[114578]=0;c=Q(2,d+144|0,17868)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Y}Gb(l,c);yb(c);break W}e=P()|0;O()|0;break k}e=P()|0;O()|0;break Z}e=P()|0;O()|0;yb(d+72|0)}yb(c);break k}e=P()|0;O()|0;break k}if(c){v[114578]=0;c=Q(2,d+144|0,17880)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(l,c);yb(c);break W}e=P()|0;O()|0;break k}v[114578]=0;c=Q(2,d+144|0,17908)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}Gb(l,c);yb(c)}t[d+40|0]=0;ca:{if(x[a+480192>>1]){v[114578]=0;c=Q(652,a|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}t[d+40|0]=c}v[114578]=0;X(653,a|0,b|0,1,d+40|0);b=v[114578];v[114578]=0;if((b|0)==1){break ca}c=a+1074308|0;if(!(!w[d+40|0]|y[c>>2]>=18284544)){v[c>>2]=18284544}da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{b=v[c>>2];if(b>>>0>=18284544){v[114578]=0;b=Q(2,d+72|0,17578)|0;f=v[114578];v[114578]=0;if((f|0)==1){break qa}v[114578]=0;R(1048,d+128|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break pa}v[114578]=0;U(3,d+144|0,b|0,d+128|0);f=v[114578];v[114578]=0;if((f|0)==1){break oa}Gb(l,d+144|0);yb(d+144|0);yb(d+128|0);yb(b);b=v[c>>2]}ra:{if(!b|y[c>>2]>=19005954){break ra}v[114578]=0;b=a+484344|0;c=Q(444,b|0,254)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}if(!c){c=Vb(q);v[114578]=0;R(1049,c|0,254);c=v[114578];v[114578]=0;if((c|0)==1){break ca}}v[114578]=0;b=Q(444,b|0,255)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ca}if(b){break ra}b=Vb(q);v[114578]=0;c=da(963)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}v[114578]=0;U(1050,b|0,255,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break ca}}if(!w[d+415|0]){break da}v[114578]=0;b=Q(2,d+144|0,17916)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ma}Gb(a+1304436|0,b);yb(b);v[114578]=0;b=Q(2,d+144|0,17937)|0;c=v[114578];v[114578]=0;if((c|0)==1){break la}Gb(a+1304448|0,b);yb(b);v[114578]=0;b=Q(2,d+24|0,17941)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ka}v[114578]=0;R(219,d+72|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break ja}v[d+112>>2]=w[d+507|0];c=w[d+506|0];v[114578]=0;v[d+56>>2]=c;R(660,d+128|0,d+56|0);c=v[114578];v[114578]=0;if((c|0)==1){break ia}v[114578]=0;X(645,d+144|0,d+72|0,d+112|0,d+128|0);c=v[114578];v[114578]=0;if((c|0)==1){break ha}Gb(a+1304472|0,d+144|0);yb(d+144|0);yb(d+128|0);Ib(d+72|0);yb(b);v[114578]=0;c=Q(2,d+144|0,17962)|0;b=v[114578];v[114578]=0;if((b|0)==1){break ea}Gb(a+1304484|0,c);break m}e=P()|0;O()|0;break k}e=P()|0;O()|0;break na}e=P()|0;O()|0;yb(d+128|0)}yb(b);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break fa}e=P()|0;O()|0;break ga}e=P()|0;O()|0;yb(d+128|0)}Ib(d+72|0)}yb(b);break k}e=P()|0;O()|0;break k}v[114578]=0;b=Q(2,d+8|0,17941)|0;c=v[114578];v[114578]=0;sa:{ta:{ua:{va:{wa:{xa:{if((c|0)!=1){v[114578]=0;R(219,d+72|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break xa}v[d+112>>2]=w[d+507|0];c=w[d+506|0];v[114578]=0;v[d+56>>2]=c;R(660,d+128|0,d+56|0);c=v[114578];v[114578]=0;if((c|0)==1){break wa}v[114578]=0;X(645,d+144|0,d+72|0,d+112|0,d+128|0);c=v[114578];v[114578]=0;if((c|0)==1){break va}Gb(a+1304436|0,d+144|0);yb(d+144|0);yb(d+128|0);Ib(d+72|0);yb(b);v[114578]=0;c=Q(2,d+144|0,17962)|0;b=v[114578];v[114578]=0;if((b|0)==1){break sa}Gb(a+1304448|0,c);break m}e=P()|0;O()|0;break k}e=P()|0;O()|0;break ta}e=P()|0;O()|0;break ua}e=P()|0;O()|0;yb(d+128|0)}Ib(d+72|0)}yb(b);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}yb(c);Gb(a+1304460|0,l);v[a+1304496>>2]=v[a+1074308>>2]?7:4;IO(k);yb(l);break b}e=P()|0;O()|0}IO(k);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}yb(l);S(e|0);L()}e=1}jb=d+528|0;return e|0}function oF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;u=jb-48|0;jb=u;a:{if(c>>>0<=2){c=c<<2;H=v[c+59820>>2];I=v[c+59808>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=$c(b)}if(el(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=$c(b)}e:{f:{while(1){if(t[f+59736|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=$c(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=u;k=jb-16|0;jb=k;h=(p(C(C(n|0)*C(N))),j(2));c=h&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;f=d<<25;d=c+1065353216|0;break h}f=h;d=f>>>7|0;f=f<<25;d=d|2147418112;if(c>>>0>=2139095040){break h}f=0;d=0;if(!c){break h}d=c;c=E(c);qf(k,d,0,0,0,c+81|0);i=v[k>>2];g=v[k+4>>2];f=v[k+8>>2];d=v[k+12>>2]^65536|16265-c<<16}v[b>>2]=i;v[b+4>>2]=g;v[b+8>>2]=f;v[b+12>>2]=h&-2147483648|d;jb=k+16|0;i=v[u+8>>2];g=v[u+12>>2];l=v[u>>2];h=v[u+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+59745|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=$c(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=$c(b)}if((f&-33)==88){f=jb-432|0;jb=f;h=v[b+104>>2];c=b;b=v[c+4>>2];p:{if(h>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=$c(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){k=1;v[c+4>>2]=b+1;b=w[b|0]}else{k=1;b=$c(c)}continue}break}b=$c(c)}e=1;if((b|0)!=48){break q}while(1){b=m;m=b-1|0;x=x-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=$c(c)}if((b|0)==48){continue}break}k=1}h=1073676288;while(1){u:{z=b|32;v:{w:{J=b-48|0;if(J>>>0<10){break w}if((b|0)!=46?z-97>>>0>=6:0){break u}if((b|0)!=46){break w}if(e){break u}e=1;m=i;x=g;break v}b=(b|0)>57?z-87|0:J;x:{if((g|0)<0?1:(g|0)<=0?i>>>0<=7:0){s=b+(s<<4)|0;break x}if((g|0)<0?1:(g|0)<=0?i>>>0<=28:0){og(f+48|0,b);rd(f+32|0,F,G,l,h,0,0,0,1073414144);F=v[f+32>>2];G=v[f+36>>2];l=v[f+40>>2];h=v[f+44>>2];rd(f+16|0,F,G,l,h,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);_f(f,q,r,A,D,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);A=v[f+8>>2];D=v[f+12>>2];q=v[f>>2];r=v[f+4>>2];break x}if(!b|o){break x}rd(f+80|0,F,G,l,h,0,0,0,1073610752);_f(f- -64|0,q,r,A,D,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);A=v[f+72>>2];D=v[f+76>>2];o=1;q=v[f+64>>2];r=v[f+68>>2]}b=i+1|0;k=b>>>0<1?g+1|0:g;i=b;g=k;k=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=$c(c)}continue}break}y:{z:{A:{if(!k){if(!v[c+104>>2]){if(d){break z}break A}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break A}v[c+4>>2]=b-2;if(!e){break z}v[c+4>>2]=b-3;break z}if((g|0)<0?1:(g|0)<=0?i>>>0<=7:0){l=i;h=g;while(1){s=s<<4;k=l+1|0;h=k>>>0<1?h+1|0:h;l=k;if((k|0)!=8|h){continue}break}}B:{C:{D:{if((b&-33)==80){l=nF(c,d);b=mb;h=b;if(l|(b|0)!=-2147483648){break B}if(d){if(v[c+104>>2]){break D}break C}q=0;r=0;Bh(c,0,0);c=0;b=0;break y}if(!v[c+104>>2]){break C}}v[c+4>>2]=v[c+4>>2]-1}l=0;h=0}if(!s){fi(f+112|0,+(n|0)*0);q=v[f+112>>2];r=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break y}b=e?m:i;c=(e?x:g)<<2|b>>>30;b=l+(b<<2)|0;c=c+h|0;c=b>>>0<l>>>0?c+1|0:c;i=b-32|0;g=c-(b>>>0<32)|0;b=g;if((b|0)>0?1:(b|0)>=0?i>>>0>0-H>>>0:0){v[114552]=68;og(f+160|0,n);rd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);rd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];r=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break y}b=H-226|0;c=i>>>0>=b>>>0;b=b>>31;if((b|0)<(g|0)?1:(g|0)>=(b|0)?c:0){if((s|0)>-1){while(1){_f(f+416|0,q,r,A,D,0,0,0,-1073807360);c=Tv(q,r,A,D,1073610752);b=(c|0)<0;_f(f+400|0,q,r,A,D,b?q:v[f+416>>2],b?r:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=i;i=b-1|0;g=g-(b>>>0<1)|0;A=v[f+408>>2];D=v[f+412>>2];q=v[f+400>>2];r=v[f+404>>2];s=s<<1|(c|0)>-1;if((s|0)>-1){continue}break}}b=i;c=H;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=((c|0)<0?1:(c|0)<=0?b>>>0<I>>>0:0)?(b|0)>0?b:0:I;E:{if((c|0)>=113){og(f+384|0,n);m=v[f+392>>2];x=v[f+396>>2];F=v[f+384>>2];G=v[f+388>>2];g=0;b=0;break E}fi(f+352|0,_h(1,144-c|0));og(f+336|0,n);F=v[f+336>>2];G=v[f+340>>2];m=v[f+344>>2];x=v[f+348>>2];rF(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],F,G,m,x);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(s&1)&((dl(q,r,A,D,0,0,0,0)|0)!=0&(c|0)<32);Bm(f+320|0,c+s|0);rd(f+304|0,F,G,m,x,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);_f(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);rd(f+288|0,c?0:q,c?0:r,c?0:A,c?0:D,F,G,m,x);_f(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Sv(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],b,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!dl(b,c,d,g,0,0,0,0)){v[114552]=68}qF(f+224|0,b,c,d,g,i);q=v[f+224>>2];r=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break y}v[114552]=68;og(f+208|0,n);rd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);rd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];r=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break y}Bh(c,0,0)}fi(f+96|0,+(n|0)*0);q=v[f+96>>2];r=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[u+16>>2]=q;v[u+20>>2]=r;v[u+24>>2]=b;v[u+28>>2]=c;jb=f+432|0;i=v[u+24>>2];g=v[u+28>>2];l=v[u+16>>2];h=v[u+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}m=b;f=c;s=n;b=0;n=0;e=jb-8976|0;jb=e;K=H+I|0;L=0-K|0;F:{G:{while(1){if((f|0)!=48){H:{if((f|0)!=46){break F}c=v[m+4>>2];if(c>>>0>=y[m+104>>2]){break H}v[m+4>>2]=c+1;f=w[c|0];break G}}else{c=v[m+4>>2];if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0]}else{f=$c(m)}n=1;continue}break}f=$c(m)}o=1;if((f|0)!=48){break F}i=-1;g=-1;while(1){c=v[m+4>>2];I:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break I}f=$c(m)}if((f|0)==48){c=i;i=c-1|0;g=g-(c>>>0<1)|0;continue}break}n=1}v[e+784>>2]=0;J:{K:{k=(f|0)==46;c=f-48|0;L:{M:{N:{O:{if(c>>>0>9?k:1){while(1){P:{if(k&1){if(!o){i=l;g=h;o=1;break P}k=!n;break O}k=h;h=l+1|0;k=h>>>0<1?k+1|0:k;l=h;h=k;if((b|0)<=2044){J=(f|0)==48?J:l;k=(e+784|0)+(b<<2)|0;n=k;if(z){c=(B(v[k>>2],10)+f|0)-48|0}v[n>>2]=c;n=1;f=z+1|0;c=(f|0)==9;z=c?0:f;b=b+c|0;break P}if((f|0)==48){break P}v[e+8960>>2]=v[e+8960>>2]|1;J=18396}c=v[m+4>>2];Q:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break Q}f=$c(m)}k=(f|0)==46;c=f-48|0;if(k|c>>>0<10){continue}break}}i=o?i:l;g=o?g:h;if(!(!n|(f&-33)!=69)){c=nF(m,d);f=mb;k=f;R:{if(c|(f|0)!=-2147483648){d=g+k|0;i=c+i|0;d=i>>>0<c>>>0?d+1|0:d;g=d;break R}if(!d){break L}if(!v[m+104>>2]){break R}v[m+4>>2]=v[m+4>>2]-1}if(!n){break M}break K}k=!n;if((f|0)<0){break N}}if(!v[m+104>>2]){break N}v[m+4>>2]=v[m+4>>2]-1}if(!k){break K}}v[114552]=28}l=0;h=0;Bh(m,0,0);c=0;b=0;break J}c=v[e+784>>2];if(!c){fi(e,+(s|0)*0);l=v[e>>2];h=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break J}if(!((i|0)!=(l|0)|(g|0)!=(h|0)|((h|0)>0?1:(h|0)>=0?l>>>0>9:0)|(c>>>I|0?(I|0)<=30:0))){og(e+48|0,s);Bm(e+32|0,c);rd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);l=v[e+16>>2];h=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break J}if((g|0)>0?1:(g|0)>=0?i>>>0>(H|0)/-2>>>0:0){v[114552]=68;og(e+96|0,s);rd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);rd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);l=v[e+64>>2];h=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break J}c=H-226|0;d=i>>>0<c>>>0;c=c>>31;if((c|0)>(g|0)?1:(g|0)<=(c|0)?d:0){v[114552]=68;og(e+144|0,s);rd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);rd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);l=v[e+112>>2];h=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break J}if(z){if((z|0)<=8){d=(e+784|0)+(b<<2)|0;c=v[d>>2];while(1){c=B(c,10);z=z+1|0;if((z|0)!=9){continue}break}v[d>>2]=c}b=b+1|0}S:{o=i;if((J|0)>(i|0)|(J|0)>=9|(i|0)>17){break S}if((o|0)==9){og(e+192|0,s);Bm(e+176|0,v[e+784>>2]);rd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);l=v[e+160>>2];h=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break J}if((o|0)<=8){og(e+272|0,s);Bm(e+256|0,v[e+784>>2]);rd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);og(e+224|0,v[(0-o<<2)+59808>>2]);pF(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);l=v[e+208>>2];h=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break J}c=(B(o,-3)+I|0)+27|0;d=v[e+784>>2];if(d>>>c|0?(c|0)<=30:0){break S}og(e+352|0,s);Bm(e+336|0,d);rd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);og(e+304|0,v[(o<<2)+59736>>2]);rd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);l=v[e+288>>2];h=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break J}while(1){c=b;b=c-1|0;if(!v[(e+784|0)+(b<<2)>>2]){continue}break}z=0;b=(o|0)%9|0;T:{if(!b){b=0;break T}d=(o|0)>-1?b:b+9|0;U:{if(!c){b=0;c=0;break U}i=v[(0-d<<2)+59808>>2];h=1e9/(i|0)|0;k=0;f=0;b=0;while(1){g=k;k=(e+784|0)+(f<<2)|0;l=v[k>>2];n=(l>>>0)/(i>>>0)|0;g=g+n|0;v[k>>2]=g;g=!g&(b|0)==(f|0);b=g?b+1&2047:b;o=g?o-9|0:o;k=B(h,l-B(i,n)|0);f=f+1|0;if((f|0)!=(c|0)){continue}break}if(!k){break U}v[(e+784|0)+(c<<2)>>2]=k;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;V:{while(1){if((o|0)!=36|y[l>>2]>=10384593?(o|0)>=36:0){break V}f=c+2047|0;i=0;while(1){k=0;f=f&2047;n=(e+784|0)+(f<<2)|0;g=v[n>>2];d=g>>>3|0;g=i+(g<<29)|0;h=d;h=g>>>0<i>>>0?h+1|0:h;i=g;g=h;if(!g&i>>>0>=1000000001|g){k=Kma(i,g,1e9,0);i=i-Hma(k,mb,1e9,0)|0}v[n>>2]=i;d=(b|0)==(f|0);c=(f|0)!=(c-1&2047)?c:d?c:i?c:f;if(!d){f=f-1|0;i=k;continue}break}z=z-29|0;if(!k){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=(e+784|0)+((c+2046&2047)<<2)|0;c=c-1&2047;v[d>>2]=v[d>>2]|v[(e+784|0)+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=k;continue}break}W:{X:while(1){d=c+1&2047;g=(e+784|0)+((c-1&2047)<<2)|0;while(1){i=(o|0)>45?9:1;Y:{while(1){n=b;f=0;Z:{while(1){_:{b=f+n&2047;if((b|0)==(c|0)){break _}b=v[(e+784|0)+(b<<2)>>2];h=v[(f<<2)+59760>>2];if(b>>>0<h>>>0){break _}if(b>>>0>h>>>0){break Z}f=f+1|0;if((f|0)!=4){continue}}break}if((o|0)!=36){break Z}i=0;g=0;f=0;l=0;h=0;while(1){b=f+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}rd(e+768|0,i,g,l,h,0,0,1342177280,1075633366);Bm(e+752|0,v[(e+784|0)+(b<<2)>>2]);_f(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);l=v[e+744>>2];h=v[e+748>>2];i=v[e+736>>2];g=v[e+740>>2];f=f+1|0;if((f|0)!=4){continue}break}og(e+720|0,s);rd(e+704|0,i,g,l,h,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];h=v[e+716>>2];i=0;g=0;q=v[e+704>>2];r=v[e+708>>2];o=z+113|0;d=o-H|0;f=(d|0)<(I|0);b=f?(d|0)>0?d:0:I;if((b|0)<=112){break Y}m=0;break W}z=i+z|0;b=c;if((n|0)==(c|0)){continue}break}k=1e9>>>i|0;l=-1<<i^-1;f=0;b=n;while(1){h=f;f=(e+784|0)+(n<<2)|0;m=v[f>>2];h=h+(m>>>i|0)|0;v[f>>2]=h;h=!h&(b|0)==(n|0);b=h?b+1&2047:b;o=h?o-9|0:o;f=B(k,l&m);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!f){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=f;c=d;continue X}v[g>>2]=v[g>>2]|1;b=d;continue}break}break}fi(e+656|0,_h(1,225-b|0));rF(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],q,r,l,h);F=v[e+696>>2];G=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];fi(e+640|0,_h(1,113-b|0));zD(e+672|0,q,r,l,h,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);i=v[e+672>>2];g=v[e+676>>2];m=v[e+680>>2];x=v[e+684>>2];Sv(e+624|0,q,r,l,h,i,g,m,x);_f(e+608|0,A,D,F,G,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];h=v[e+620>>2];q=v[e+608>>2];r=v[e+612>>2]}k=n+4&2047;$:{if((k|0)==(c|0)){break $}k=v[(e+784|0)+(k<<2)>>2];aa:{if(k>>>0<=499999999){if(!((n+5&2047)==(c|0)?k:1)){break aa}fi(e+496|0,+(s|0)*.25);_f(e+480|0,i,g,m,x,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);m=v[e+488>>2];x=v[e+492>>2];i=v[e+480>>2];g=v[e+484>>2];break aa}if((k|0)!=5e8){fi(e+592|0,+(s|0)*.75);_f(e+576|0,i,g,m,x,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);m=v[e+584>>2];x=v[e+588>>2];i=v[e+576>>2];g=v[e+580>>2];break aa}M=+(s|0);if((n+5&2047)==(c|0)){fi(e+528|0,M*.5);_f(e+512|0,i,g,m,x,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);m=v[e+520>>2];x=v[e+524>>2];i=v[e+512>>2];g=v[e+516>>2];break aa}fi(e+560|0,M*.75);_f(e+544|0,i,g,m,x,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);m=v[e+552>>2];x=v[e+556>>2];i=v[e+544>>2];g=v[e+548>>2]}if((b|0)>111){break $}zD(e+464|0,i,g,m,x,0,0,0,1073676288);if(dl(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break $}_f(e+448|0,i,g,m,x,0,0,0,1073676288);m=v[e+456>>2];x=v[e+460>>2];i=v[e+448>>2];g=v[e+452>>2]}_f(e+432|0,q,r,l,h,i,g,m,x);Sv(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,F,G);l=v[e+424>>2];h=v[e+428>>2];q=v[e+416>>2];r=v[e+420>>2];ba:{if((-2-K|0)>=(o&2147483647)){break ba}v[e+408>>2]=l;v[e+412>>2]=h&2147483647;v[e+400>>2]=q;v[e+404>>2]=r;rd(e+384|0,q,r,l,h,0,0,0,1073610752);n=v[e+400>>2];o=v[e+404>>2];s=v[e+408>>2];H=v[e+412>>2];c=Tv(n,o,s,H,1081081856);k=(c|0)<0;l=k?l:v[e+392>>2];h=k?h:v[e+396>>2];q=k?q:v[e+384>>2];r=k?r:v[e+388>>2];z=((c|0)>-1)+z|0;if((z+110|0)<=(L|0)){if((((Tv(n,o,s,H,1081081856)|0)<0?f:f&(b|0)!=(d|0))|0)!=1){break ba}if(!dl(i,g,m,x,0,0,0,0)){break ba}}v[114552]=68}qF(e+368|0,q,r,l,h,z);l=v[e+368>>2];h=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[u+32>>2]=l;v[u+36>>2]=h;v[u+40>>2]=b;v[u+44>>2]=c;jb=e+8976|0;i=v[u+40>>2];g=v[u+44>>2];l=v[u+32>>2];h=v[u+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}ca:{c=v[b+4>>2];da:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break da}c=$c(b)}if((c|0)==40){f=1;break ca}g=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];ea:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=$c(b)}if(c-97>>>0>=26?c-48>>>0<10|c-65>>>0<26|(c|0)==95:1){f=f+1|0;continue}break}g=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[114552]=28;Bh(b,0,0)}g=0}v[a>>2]=l;v[a+4>>2]=h;v[a+8>>2]=i;v[a+12>>2]=g;jb=u+48|0}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=jb-288|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!bu(b,d+280|0)){break x}if(!CR(d+280|0)){break x}if(!c){s=1;break x}A=Jk(d+264|0,b);v[114578]=0;U(743,d+248|0,A|0,0);b=v[114578];v[114578]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){v[114578]=0;U(744,d+232|0,d+248|0,20041);b=v[114578];v[114578]=0;if((b|0)==1){break N}v[114578]=0;b=T(339,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(!b){break y}v[114578]=0;b=Q(745,d+232|0,d+136|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(!b){break y}v[114578]=0;R(449,a|0,16384);b=v[114578];v[114578]=0;if((b|0)==1){break E}v[a+480208>>2]=8;v[114578]=0;b=a+1074312|0;W(479,b|0,9,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;Q(480,b|0,21)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;Q(480,b|0,30)|0;b=v[114578];v[114578]=0;if((b|0)==1){break E}v[114578]=0;b=Q(2,d+16|0,14652)|0;e=v[114578];v[114578]=0;if((e|0)==1){break K}Gb(a+1304436|0,b);yb(b);v[114578]=0;b=Q(2,d+16|0,14664)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}Gb(a+1304448|0,b);yb(b);v[114578]=0;e=Q(2,d+120|0,14668)|0;b=v[114578];v[114578]=0;if((b|0)==1){break I}b=w[d+284|0];switch(b-16|0){case 1:break H;case 0:break M;default:break L}}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}v[114578]=0;Q(2,d+104|0,14683)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break F}break e}if(!b){break G}v[114578]=0;Q(2,d+104|0,14698)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}break F}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[114578]=0;Q(2,d+104|0,14681)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break F}break e}v[114578]=0;Q(2,d+104|0,14687)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}}v[114578]=0;U(3,d+16|0,e|0,d+104|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}Gb(a+1304460|0,d+16|0);yb(d+16|0);yb(d+104|0);yb(e);v[a+1304496>>2]=4;v[114578]=0;U(746,d+120|0,3,d+136|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;R(417,d+16|0,d+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}Gb(a+1304400|0,d+16|0);yb(d+16|0);v[114578]=0;U(747,d+104|0,3,d+168|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;R(417,d+120|0,d+104|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;U(13,d+16|0,4,d+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}Gb(a+1304412|0,d+16|0);yb(d+16|0);yb(d+120|0);v[a+480200>>2]=w[d+192|0]+1;H=a,I=Fd(w[d+193|0],1,255),v[H+480196>>2]=I;H=a,I=B(Fd(w[d+194|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Vb(b);g=w[d+188|0]|w[d+189|0]<<8;v[114578]=0;ea(581,e|0,d+232|0,g|0,65535,65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}Oe(Vb(b),w[d+190|0]|w[d+191|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[114578]=0;e=(b<<5)+a|0;g=e+480280|0;Z(434,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break j}f=b+d|0;h=w[f+195|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;O:{if(t[f+195|0]<=-1){v[g>>2]=v[g>>2]|1024;break O}u[a+480188>>1]=b+1}v[114578]=0;W(748,d+232|0,e+480289|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[114578]=0;U(744,d+16|0,d+248|0,17741);b=v[114578];v[114578]=0;if((b|0)==1){break k}Wd(d+232|0,d+16|0);Bb(d+16|0);v[114578]=0;b=T(255,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;aa(584,a+1304424|0,d+232|0,b|0,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break E}v[114578]=0;U(744,d+16|0,d+248|0,21321);b=v[114578];v[114578]=0;if((b|0)==1){break l}Wd(d+232|0,d+16|0);Bb(d+16|0);v[114578]=0;b=T(339,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}P:{if(b){v[114578]=0;U(744,d+16|0,d+248|0,16723);b=v[114578];v[114578]=0;if((b|0)==1){break m}v[114578]=0;k=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}Q:{if(!k){break Q}j=c&2;while(1){v[114578]=0;e=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}if(!e){break Q}v[114578]=0;b=Q(258,d+232|0,56)|0;g=v[114578];v[114578]=0;if((g|0)==1){break n}if(!b){break Q}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[114578]=0;b=B(e,104)+a|0;g=b+484380|0;R(388,g|0,0);f=v[114578];v[114578]=0;if((f|0)==1){break n}v[114578]=0;W(548,d+232|0,((e<<5)+a|0)+946304|0,32)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;W(551,d+232|0,b+484423|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}R:{if(w[d+284|0]<=15){v[114578]=0;e=T(359,d+232|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break R}break n}v[114578]=0;e=T(392,d+232|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}}v[b+484404>>2]=e<<1;v[114578]=0;e=T(392,d+232|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}v[g>>2]=e;v[114578]=0;f=T(392,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=f;v[114578]=0;f=T(392,d+232|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break n}h=b+484388|0;v[h>>2]=f;if(f){i=b+484414|0;u[i>>1]=x[i>>1]|2;v[h>>2]=f+v[e>>2]}v[114578]=0;f=T(389,d+232|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break P}if(w[d+284|0]<=15){u[b+484410>>1]=f}v[114578]=0;i=T(389,d+232|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}l=b+484414|0;b=x[l>>1];f=8;if(i&1){b=b|1;u[l>>1]=b;v[g>>2]=v[g>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[h>>2]=v[h>>2]>>>1;f=16}u[l>>1]=b&65531|i<<1&4;b=ad(d+120|0,f,1,0,((i&12)!=0)<<3);S:{if(!j){break S}v[114578]=0;W(402,b|0,g|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break S}break n}m=m+1|0;if(k>>>0>(m&255)>>>0){continue}break}}Bb(d+16|0)}v[114578]=0;U(744,d+16|0,d+248|0,18761);b=v[114578];v[114578]=0;if((b|0)==1){break q}Wd(d+232|0,d+16|0);Bb(d+16|0);v[114578]=0;b=T(339,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(b){k=Hz(d+120|0);l=Hz(d+104|0);m=Hz(d+88|0);v[114578]=0;U(744,d+72|0,d+248|0,17750);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(749,d+72|0,k|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}Bb(d+72|0);v[114578]=0;U(744,d+56|0,d+248|0,17744);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(749,d+56|0,l|0);b=v[114578];v[114578]=0;if((b|0)==1){break t}Bb(d+56|0);v[114578]=0;U(744,d+40|0,d+248|0,17734);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(749,d+40|0,m|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}Bb(d+40|0);f=0;v[114578]=0;o=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break v}if(o){y=d+16|4;z=d+16|2;p=d+16|6;q=d+16|5;r=d+16|3;e=d+16|1;while(1){v[114578]=0;R(473,d|0,d+232|0);b=v[114578];v[114578]=0;if((b|0)==1){break A}n=cd(d);T:{U:{V:{if(!w[d|0]){break V}b=w[n|0];v[114578]=0;b=Q(258,d+232|0,B(b,14)+32|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}if(!b){break V}b=w[d|0];v[114578]=0;i=W(456,a|0,b|0,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break p}if(i){break U}}b=w[n|0];v[114578]=0;Q(340,d+232|0,B(b,14)+32|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break T}break p}v[114578]=0;W(548,d+232|0,i+492|0,32)|0;b=v[114578];v[114578]=0;if((b|0)==1){break p}if(!w[n|0]){break T}C=i+88|0;D=i+68|0;E=i+48|0;F=i+236|0;h=0;b=0;while(1){v[114578]=0;Q(750,d+232|0,d+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break w}W:{if(!w[d+16|0]|x[a+480190>>1]<w[d+16|0]){break W}g=e;if(w[e|0]>128){t[g|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){g=w[d+16|0];H=dd(F,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}G=w[e|0];b=w[r|0];v[114578]=0;U(751,E|0,b|0,k|0);b=v[114578];v[114578]=0;if((b|0)==1){break w}b=w[q|0];v[114578]=0;U(751,D|0,b|0,l|0);b=v[114578];v[114578]=0;if((b|0)==1){break w}b=w[d+29|0];v[114578]=0;U(751,C|0,b|0,m|0);b=v[114578];v[114578]=0;if((b|0)==1){break w}v[i>>2]=(w[p|0]|w[p+1|0]<<8)+1>>>1;b=w[d+16|0];X:{if(w[r|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break X}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}g=w[y|0];v[114578]=0;u[d+38>>1]=g<<1;u[d+36>>1]=254;j=Q(478,d+38|0,d+36|0)|0;g=v[114578];v[114578]=0;Y:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[j>>1];t[g+484418|0]=w[(w[d+27|0]&3)+14699|0];s=g+484419|0;t[s|0]=w[d+26|0];j=g+484420|0;t[j|0]=w[d+25|0]+3>>>2;t[g+484421|0]=w[d+24|0];b=w[s|0];if(!b){j=255;break Y}j=w[j|0];v[114578]=0;b=Gg(752,(((j<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0);j=v[114578];v[114578]=0;if((j|0)!=1){v[114578]=0;j=T(753,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break Y}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=G+1|0;t[s|0]=j;if(!(w[q|0]&64)){break W}g=g+484414|0;u[g>>1]=x[g>>1]|32}h=h+1|0;if(w[n|0]>(h&255)>>>0){continue}break}}f=f+1|0;if(o>>>0>(f&255)>>>0){continue}break}}wn(m);wn(l);wn(k)}s=1;l=Mp(d+120|0);if(!(c&1)){break z}v[114578]=0;U(744,d+16|0,d+248|0,21076);b=v[114578];v[114578]=0;Z:{_:{$:{if((b|0)!=1){b=Wd(d+232|0,d+16|0);v[114578]=0;b=T(339,b|0)|0;c=v[114578];v[114578]=0;aa:{ba:{ca:{da:{ea:{fa:{if((c|0)!=1){Bb(d+16|0);ga:{if(!b){break ga}v[114578]=0;c=T(359,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break fa}v[114578]=0;R(754,l|0,c+1|0);b=v[114578];v[114578]=0;if((b|0)==1){break fa}if(!c){break ga}b=1;while(1){v[114578]=0;e=T(359,d+232|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ea}v[114578]=0;U(343,d+16|0,d+232|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break ea}Wd(tc(l,b),d+16|0);e=(b|0)==(c|0);Bb(d+16|0);b=b+1|0;if(!e){continue}break}}v[114578]=0;U(744,d+16|0,d+248|0,16720);b=v[114578];v[114578]=0;if((b|0)==1){break da}b=Wd(d+232|0,d+16|0);v[114578]=0;b=T(339,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ca}Bb(d+16|0);if(!b){break aa}k=0;v[114578]=0;m=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break C}if(m){while(1){h=32;ha:{if(w[d+284|0]>=16){v[114578]=0;Q(755,d+232|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break $}if(!(w[d+16|0]>32|x[a+480188>>1]>=w[d+16|0])){u[a+480188>>1]=w[d+16|0]}h=w[d+16|0];if(!h){break ha}}e=0;while(1){v[114578]=0;b=T(359,d+232|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break _}if(!(!b|x[a+480188>>1]>(e&65535)>>>0)){u[a+480188>>1]=e+1}e=e+1|0;if((e&65535)>>>0<h>>>0){continue}break}}k=k+1|0;if(m>>>0>(k&65535)>>>0){continue}break}}v[114578]=0;Q(256,d+232|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ba}break C}b=P()|0;O()|0;Bb(d+16|0);break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;Bb(d+16|0);break B}v[114578]=0;n=a+484344|0;R(403,n|0,m|0);b=v[114578];v[114578]=0;if((b|0)==1){break C}if(!m){break aa}C=d+16|2;D=d+16|1;c=0;while(1){o=Wb(d+104|0);k=64;p=32;if(w[d+284|0]>=16){v[114578]=0;Q(755,d+232|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break D}p=w[d+16|0];b=w[D|0];v[114578]=0;U(756,d|0,3,C|0);e=v[114578];v[114578]=0;if((e|0)==1){break D}v[114578]=0;R(417,d+88|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break D}Gb(o,d+88|0);yb(d+88|0);k=b+1|0}v[114578]=0;b=W(404,n|0,c&65535,k|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}ia:{if(!b){v[114578]=0;Q(340,d+232|0,p<<1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ia}break D}b=_b(n,c);v[114578]=0;Q(496,b|0,o|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break D}q=0;if(!p){break ia}while(1){v[114578]=0;b=T(359,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}ja:{if(!b){break ja}if(nd(l)>>>0<=b>>>0){break ja}r=q&65535;if(r>>>0>=x[a+480188>>1]){break ja}i=tc(l,b);Jc(i);g=0;while(1){v[114578]=0;b=Q(258,i|0,1)|0;e=v[114578];v[114578]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){if(!b){break ja}b=_b(n,c);v[114578]=0;b=W(472,b|0,g|0,r|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}v[114578]=0;f=T(389,i|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}e=f>>>2|0;switch((f&3)-1|0){case 2:break ma;case 1:break na;case 0:break oa;default:break pa}}break D}g=(e+g|0)+1|0;break ka}if(!g){g=0;break ka}f=_b(n,c);v[114578]=0;f=W(472,f|0,g-1|0,r|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){while(1){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=h;t[b+1|0]=h>>>8;t[b+2|0]=h>>>16;t[b+3|0]=h>>>24;h=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=h;t[b+5|0]=h>>>8;g=g+1|0;if(k>>>0<=g>>>0){break ka}b=B(x[a+480188>>1],6)+b|0;h=e&255;e=e-1|0;if(h){continue}break ka}}break D}if(e>>>0>=g>>>0){break la}f=_b(n,c);v[114578]=0;e=W(472,f|0,e|0,r|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Z}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break la}if(e&1){v[114578]=0;f=T(389,i|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Z}t[b|0]=f>>>0>120?-1:f}if(e&2){v[114578]=0;f=T(389,i|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Z}t[b+1|0]=f}y=0;h=0;if(e&4){v[114578]=0;h=T(389,i|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}}j=0;if(e&8){v[114578]=0;f=T(389,i|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break D}y=f&15;j=f>>>4|0}z=0;f=0;if(e&16){v[114578]=0;f=T(389,i|0)|0;E=v[114578];v[114578]=0;if((E|0)==1){break D}}if(e&32){v[114578]=0;z=T(389,i|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}}v[114578]=0;ma(757,b|0,h|0,y|0,j|0,f|0,z|0);b=v[114578];v[114578]=0;if((b|0)==1){break D}}g=g+1|0}if(g>>>0<k>>>0){continue}break}}q=q+1|0;if((q&65535)>>>0<p>>>0){continue}break}}yb(o);c=c+1|0;if((m|0)!=(c|0)){continue}break}}v[114578]=0;U(744,d+16|0,d+248|0,20048);b=v[114578];v[114578]=0;qa:{ra:{sa:{if((b|0)!=1){b=Wd(d+232|0,d+16|0);v[114578]=0;b=T(339,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break sa}Bb(d+16|0);if(!b){break z}a=a+484344|0;if(!Ce(a)){break z}while(1){v[114578]=0;b=Q(258,d+232|0,16)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ra}if(!b){break z}v[114578]=0;W(758,d+232|0,d+16|0,16)|0;b=v[114578];v[114578]=0;if((b|0)==1){break qa}b=_b(a,0);v[114578]=0;Q(759,b|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break qa}if(Ce(a)){continue}break}break z}b=P()|0;O()|0;break B}b=P()|0;O()|0;Bb(d+16|0);break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}break D}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(o);break B}b=P()|0;O()|0}gd(l);break c}b=P()|0;O()|0;break o}gd(l)}Bb(d+232|0);Gz(d+248|0);Bb(A)}jb=d+288|0;return s|0}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;Bb(d+40|0);break o}b=P()|0;O()|0;Bb(d+56|0);break o}b=P()|0;O()|0;Bb(d+72|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break c}b=P()|0;O()|0}wn(m);wn(l);wn(k);break c}b=P()|0;O()|0;Bb(d+16|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+120|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+104|0);break d}b=P()|0;O()|0}yb(e)}Bb(d+232|0)}Gz(d+248|0)}Bb(A);S(b|0);L()}function _ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,X=0,Y=0,Z=0;e=jb-416|0;jb=e;Jc(b);g=jb-16|0;jb=g;f=e+208|0;UO(g+8|0,f);l=b;h=Hb(g+8|0);j=nc(b,ac(g,g+8|0));if((h|0)==(j|0)){$b(l,Hb(g+8|0))}jb=g+16|0;l=(h|0)==(j|0);if(!l){VO(f)}a:{if(!l){break a}if(!ZO(e+208|0)){break a}if(!c){d=1;break a}Hd(a,134217728);d=Ub(e+192|0,17360);v[114578]=0;R(219,e+144|0,d|0);l=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((l|0)!=1){v[114578]=0;o=e+208|4;U(1004,e+16|0,e+144|0,o|0);l=v[114578];v[114578]=0;if((l|0)==1){break r}Gb(a+1304436|0,e+16|0);yb(e+16|0);Ib(e+144|0);yb(d);d=Ub(e+16|0,17384);Gb(a+1304448|0,d);yb(d);v[a+480188>>2]=4;v[a+1304496>>2]=2;d=w[e+344|0]|w[e+345|0]<<8;v[a+480196>>2]=(d<<8|d>>>8)&65535;d=w[e+348|0]|w[e+349|0]<<8;v[a+480260>>2]=56;v[a+480264>>2]=13696;Y=a,Z=YO((d<<8|d>>>8)&65535),v[Y+480204>>2]=Z;In(Vb(a+484360|0),e+216|0,w[e+208|6],65535,65535);s=a+480190|0;d=jb-16|0;jb=d;p=e+176|0;l=p;v[l>>2]=0;v[l+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1019,l+8|0,d+12|0,d+8|0)|0;l=v[114578];v[114578]=0;s:{if((l|0)!=1){jb=d+16|0;break s}V(0)|0;O()|0;Ab();L()}q=Ql(e+160|0);l=0;if(w[e+408|0]|w[e+409|0]<<8){break p}break o}a=P()|0;O()|0;break q}a=P()|0;O()|0;Ib(e+144|0)}yb(d);break d}while(1){v[114578]=0;d=T(485,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}u[e+120>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=w[e+410|0]|w[e+411|0]<<8;if((w[o|0]|w[o+1|0]<<8)!=512){d=(d<<8|d>>>8)&65535}else{v[114578]=0;d=T(494,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}d=d-2|0}v[114578]=0;U(343,e+144|0,b|0,d|0);d=v[114578];v[114578]=0;t:{u:{v:{if((d|0)!=1){v[114578]=0;d=Q(454,s|0,e+120|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break v}C=x[d>>1];u[a+480190>>1]=C;v[114578]=0;d=B(x[e+120>>1],104)+a|0;f=d+484380|0;R(388,f|0,1);g=v[114578];v[114578]=0;w:{if((g|0)==1){break w}g=w[o|0]|w[o+1|0]<<8;if(((g<<8|g>>>8)&65535)>>>0>1){break u}v[114578]=0;W(1005,e+144|0,d+484423|0,31)|0;g=v[114578];v[114578]=0;if((g|0)==1){break w}v[114578]=0;Q(340,e+144|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break w}v[114578]=0;W(390,e+144|0,((x[e+120>>1]<<5)+a|0)+946304|0,30)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break t}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}g=Wb(e+16|0);v[114578]=0;W(597,e+144|0,g|0,257)|0;h=v[114578];v[114578]=0;x:{y:{if((h|0)==1){break y}v[114578]=0;Q(372,d+484423|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break y}v[114578]=0;Q(340,e+144|0,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break y}v[114578]=0;W(597,e+144|0,g|0,31)|0;h=v[114578];v[114578]=0;if((h|0)==1){break y}v[114578]=0;Q(371,((x[e+120>>1]<<5)+a|0)+946304|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break y}if(!(v[e+152>>2]&1)){break x}v[114578]=0;Q(340,e+144|0,1)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break x}}a=P()|0;O()|0;yb(g);break f}yb(g)}v[114578]=0;Q(1006,e+144|0,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break n}v[114578]=0;R(1007,e+16|0,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break n}if((w[o|0]|w[o+1|0]<<8)==512){t[d+484417|0]=w[e+34|0]<<3}z:{if(!(w[o|0]|w[o+1|0]<<8)){break z}v[114578]=0;R(386,q|0,C|0);g=v[114578];v[114578]=0;if((g|0)==1){break n}v[114578]=0;R(1008,p|0,C|0);g=v[114578];v[114578]=0;if((g|0)==1){break n}g=qd(p,x[e+120>>1]-1|0);yc(g);WO(g);ct(g);v[114578]=0;h=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}v[114578]=0;f=Q(258,b|0,h<<3)|0;j=v[114578];v[114578]=0;if((j|0)==1){break j}if(!f){break l}v[114578]=0;R(1009,g|0,h|0);f=v[114578];v[114578]=0;if((f|0)==1){break j}f=0;v[e+136>>2]=0;if(!h){if(!(w[d+484414|0]&2)){break z}f=v[d+484384>>2];v[e+128>>2]=f;d=v[d+484388>>2];v[114578]=0;v[e+132>>2]=d-f;R(1010,g|0,e+128|0);d=v[114578];v[114578]=0;if((d|0)!=1){break z}a=P()|0;O()|0;break f}while(1){v[114578]=0;d=T(494,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break k}v[114578]=0;v[e+128>>2]=d;d=T(494,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break k}v[114578]=0;v[e+132>>2]=d;R(1010,g|0,e+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}f=f+1|0;if(h>>>0>(f&65535)>>>0){continue}break}}Bb(e+144|0);l=l+1|0;d=w[e+408|0]|w[e+409|0]<<8;if((l&65535)>>>0<((d<<8|d>>>8)&65535)>>>0){continue}break}}D=128;if(w[o|0]|w[o+1|0]<<8){break m}v[114578]=0;D=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break m}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}l=a+480188|0;E=w[e+208|7];u[e+126>>1]=4;A:{B:{C:{if(!(w[o|0]|w[o+1|0]<<8)){f=x[l>>1];break C}g=v[b+8>>2];D:{if(!D){break D}while(1){v[114578]=0;d=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break B}if((d|0)==65535){break D}v[114578]=0;E=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}v[114578]=0;d=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break B}v[114578]=0;u[e+126>>1]=d;d=Q(454,l|0,e+126|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break B}u[l>>1]=x[d>>1];v[114578]=0;Q(340,b|0,B(x[e+126>>1],E)<<2)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}n=n+1|0;if((n&65535)>>>0<D>>>0){continue}break}}d=0;v[114578]=0;Q(256,b|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}f=x[l>>1];if(f>>>0>127){break b}}v[114578]=0;G=Q(1011,e+144|0,f&65535)|0;d=v[114578];v[114578]=0;if((d|0)!=1){E:{if(!D){break E}K=a+484344|0;X=c&1;H=w[e+347|0];g=0;l=0;while(1){d=l;if(w[o|0]|w[o+1|0]<<8){v[114578]=0;d=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}if((d|0)==65535){break E}v[114578]=0;E=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;f=T(485,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}u[e+126>>1]=f}F=E&65535;F:{G:{H:{if(!X){break H}v[114578]=0;M=d&65535;d=W(404,K|0,M|0,F|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}if(!d){break H}z=0;if(F){break G}break F}v[114578]=0;Q(340,b|0,B(x[e+126>>1],F)<<2)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break F}break g}while(1){d=_b(K,M);v[114578]=0;j=Q(497,d|0,z|0)|0;d=v[114578];v[114578]=0;I:{if((d|0)!=1){f=0;A=0;J:{K:{switch((H&3)-1|0){case 0:A=!(z&3);break J;case 1:A=!(z&1);break J;case 2:break K;default:break J}}A=(z&3)!=3}I=0;if(!x[e+126>>1]){break I}while(1){d=v[G>>2];v[114578]=0;R(595,e+128|0,b|0);h=v[114578];v[114578]=0;if((h|0)==1){break g}h=B(f,9)+d|0;d=cd(e+128|0);r=Bf(e+128|0);k=Rh(e+128|0);m=j+B(f,6)|0;t[m+1|0]=w[e+128|0];d=w[d|0];t[m|0]=d;i=w[k|0];t[m+5|0]=i;k=m+5|0;if(d){t[m|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;i=w[k|0]}n=i&255;J=w[r|0];L:{if(J>>>0>=240){d=n|(J&15)<<8;if(d){d=YO(d);v[114578]=0;d=za(1012,+(+(d>>>0)*1e-4))|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[k|0]=d;t[m+3|0]=17;break L}break g}t[m+3|0]=0;break L}N=n<<4;r=n>>>4|0;d=N|r;M:{switch(J|0){case 0:d=j+B(f,6)|0;if(i&255){t[d+3|0]=1;break L}t[d+3|0]=0;break L;case 1:t[(j+B(f,6)|0)+3|0]=2;break L;case 2:t[(j+B(f,6)|0)+3|0]=3;break L;case 3:v[114578]=0;t[e+16|0]=15;d=Q(393,k|0,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break L}break g;case 4:v[114578]=0;t[e+16|0]=15;d=Q(393,k|0,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break L}break g;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=i;t[h|0]=0;t[(j+B(f,6)|0)+3|0]=0;break L;case 6:t[h+7|0]=0;t[h+2|0]=i;t[h|0]=0;t[h+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break L;case 7:t[(j+B(f,6)|0)+3|0]=23;g=0;break L;case 8:t[(j+B(f,6)|0)+3|0]=0;g=d;break L;case 9:t[(j+B(f,6)|0)+3|0]=19;v[114578]=0;t[e+16|0]=15;d=Q(393,k|0,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[k|0]=w[d|0]|16;break L}break g;case 10:t[(j+B(f,6)|0)+3|0]=19;v[114578]=0;t[e+16|0]=15;d=Q(393,k|0,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[k|0]=w[d|0]|32;break L}break g;case 11:t[h+3|0]=d;t[(j+B(f,6)|0)+3|0]=0;break L;case 12:d=j+B(f,6)|0;t[d+4|0]=i;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break L;case 13:r=j+B(f,6)|0;N:{O:{if(n&240){t[(j+B(f,6)|0)+2|0]=4;d=(i&240)>>>4|0;break O}if(!(n&15)){break N}t[(j+B(f,6)|0)+2|0]=3;d=i&15}t[r+4|0]=d}t[h+3|0]=0;t[(j+B(f,6)|0)+3|0]=0;break L;case 14:t[(j+B(f,6)|0)+3|0]=19;t[k|0]=!(i&255);break L;case 15:t[(j+B(f,6)|0)+3|0]=16;t[k|0]=(i&240)>>>4;H=i&15;break L;case 16:t[h+5|0]=0;t[h+4|0]=i;t[(j+B(f,6)|0)+3|0]=0;break L;case 17:t[h+6|0]=n&15?i:0;t[(j+B(f,6)|0)+3|0]=0;break L;case 18:t[(j+B(f,6)|0)+3|0]=14;break L;case 19:t[h+8|0]=0;t[h+7|0]=i;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break L;case 20:t[(j+B(f,6)|0)+3|0]=12;break L;case 22:P:{d=w[m+1|0];Q:{if(!d){break Q}if(yc(p)>>>0<d>>>0){break Q}d=qd(p,w[m+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;v[114578]=0;Q(1013,e+16|0,0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break g}v[e+120>>2]=9;d=yc(d);v[114578]=0;v[e+12>>2]=d;d=Q(33,e+120|0,e+12|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break P}if(y[d>>2]<=(i&255)>>>0){break Q}d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(j+B(f,6)|0)+3|0]=0;break L}break g;case 23:d=w[m+1|0];R:{if(!d){break R}if(yc(p)>>>0<d>>>0){break R}d=qd(p,w[m+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;if(yc(d)>>>0<=(i&255)>>>0){break R}S:{if(x[qd(d,w[k|0])+8>>1]){break S}if(!En(a)){break S}i=x[s>>1]+1|0;u[s>>1]=i;Y=qd(d,w[k|0]),Z=i,u[Y+8>>1]=Z}Y=m,Z=w[qd(d,w[k|0])+8|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break L;case 24:T:{d=w[m+1|0];U:{if(!d){break U}if(yc(p)>>>0<d>>>0){break U}d=qd(p,w[m+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;v[114578]=0;Q(1013,e+16|0,0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break g}v[e+120>>2]=9;d=yc(d);v[114578]=0;v[e+12>>2]=d;d=Q(33,e+120|0,e+12|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break T}if(y[d>>2]>(i&255)>>>0){d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}V:{if(x[rc(q,w[m+1|0]-1|0)>>1]){break V}if(!En(a)){break V}d=x[s>>1]+1|0;u[s>>1]=d;Y=rc(q,w[m+1|0]-1|0),Z=d,u[Y>>1]=Z}Y=m,Z=w[rc(q,w[m+1|0]-1|0)|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break L}break g;case 25:d=w[m+1|0];W:{if(!d){break W}if(yc(p)>>>0<d>>>0){break W}d=qd(p,w[m+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;if(yc(d)>>>0<=(i&255)>>>0){break W}X:{if(x[qd(d,w[k|0])+10>>1]){break X}if(!En(a)){break X}i=x[s>>1]+1|0;u[s>>1]=i;Y=qd(d,w[k|0]),Z=i,u[Y+10>>1]=Z}Y=m,Z=w[qd(d,w[k|0])+10|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break L;case 29:t[(j+B(f,6)|0)+3|0]=11;t[k|0]=d;if(n&15){t[k|0]=N|15;break L}if(!r){break L}t[k|0]=r|240;break L;case 32:if(n&240){t[h+3|0]=r;t[(j+B(f,6)|0)+3|0]=0;break L}t[(j+B(f,6)|0)+3|0]=19;t[k|0]=i&15|192;break L;case 33:t[(j+B(f,6)|0)+3|0]=19;v[114578]=0;t[e+16|0]=15;d=Q(393,k|0,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[k|0]=w[d|0]|208;break L}break g;case 34:t[(j+B(f,6)|0)+3|0]=19;v[114578]=0;t[e+16|0]=15;d=Q(393,k|0,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[k|0]=w[d|0]|144;break L}break g;case 73:t[(j+B(f,6)|0)+3|0]=10;break L;case 78:if((i&112|128)==224){t[(j+B(f,6)|0)+3|0]=19;break L}t[(j+B(f,6)|0)+3|0]=0;break L;case 79:d=j+B(f,6)|0;if((i&255)>>>0<=31){t[d+3|0]=16;H=0;break L}t[d+3|0]=17;break L;default:break M}}t[(j+B(f,6)|0)+3|0]=0}n=0;i=w[h+3|0];if(!(w[m+2|0]|!i)){Y:{if(i>>>0>=16){t[m+2|0]=5;i=i>>>4|0;break Y}t[m+2|0]=6}t[m+4|0]=i;n=1}Z:{if(w[m+3|0]){break Z}d=w[h+1|0];_:{if(d){t[m+3|0]=2;break _}d=w[h+2|0];if(d){t[m+3|0]=3;break _}d=w[h|0];if(d){t[m+3|0]=19;break _}d=w[h+7|0];if(d){t[m+3|0]=4;t[h+8|0]=d;break _}d=w[h+4|0];if(d){t[m+3|0]=5;t[h+5|0]=d;break _}d=w[h+3|0];if(!(!d|n)){t[m+3|0]=11;t[k|0]=d;if(d&15){d=d|-16;break _}if(!(d&240)){break Z}d=d|15;break _}d=w[h+6|0];if(d){t[m+3|0]=8;break _}if(A){t[m+3|0]=20;A=0;d=97;break _}A=0;if(I){break Z}d=g&255;if(!d){break Z}t[m+3|0]=24;t[k|0]=g;if(g&15){d=g|-16}else{if(!(d&240)){I=1;break Z}d=g|15}I=1}t[k|0]=d}f=f+1|0;if(f>>>0<x[e+126>>1]){continue}break}break I}break g}z=z+1|0;if((F|0)!=(z|0)){continue}break}}l=l+1|0;if((l&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break g}if(w[o|0]|w[o+1|0]<<8){$:{while(1){v[114578]=0;d=Q(258,b|0,2)|0;l=v[114578];v[114578]=0;if((l|0)==1){break g}if(!d){break $}v[114578]=0;d=T(485,b|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break g}if((d|0)==65535){break $}v[114578]=0;Q(340,b|0,2)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;d=T(494,b|0)|0;l=v[114578];v[114578]=0;if((l|0)!=1){v[114578]=0;Q(340,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break g}v[114578]=0;Q(340,b|0,34)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}}aa:{if(!(!(c&2)|!C)){d=1;l=1;while(1){c=(B(d,104)+a|0)+484380|0;ba:{if(!v[c>>2]){break ba}g=ad(e+16|0,8,1,0,0);v[114578]=0;W(402,g|0,c|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break aa}if(yc(p)>>>0<d>>>0){break ba}d=d-1|0;g=qd(p,d);v[114578]=0;R(1014,c|0,g|0);g=v[114578];v[114578]=0;ca:{if((g|0)!=1){if(!x[rc(q,d)>>1]){break ca}g=x[rc(q,d)>>1];f=v[c>>2];v[114578]=0;fa(1015,c|0,(B(g,104)+a|0)+484380|0,0,f|0,0);g=v[114578];v[114578]=0;if((g|0)!=1){break ca}}break g}d=qd(p,d);Y=e,Z=bc(d),v[Y+16>>2]=Z;Y=e,Z=cc(d),v[Y+128>>2]=Z;if(!Jb(e+16|0,e+128|0)){break ba}while(1){d=v[e+16>>2];g=x[d+8>>1];if(g){f=v[d+4>>2];h=v[d>>2];v[114578]=0;fa(1015,c|0,(B(g,104)+a|0)+484380|0,h|0,f|0,1);g=v[114578];v[114578]=0;if((g|0)==1){break g}}g=x[d+10>>1];if(g){f=v[d+4>>2];d=v[d>>2];v[114578]=0;fa(1015,c|0,(B(g,104)+a|0)+484380|0,d|0,f|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break g}}zn(e+16|0);if(Jb(e+16|0,e+128|0)){continue}break}}l=l+1|0;d=l&65535;if(C>>>0>=d>>>0){continue}break}}Sy(G);d=1;break b}break g}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}Bb(e+144|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Sy(G);break e}Bb(e+144|0)}kf(q);XO(p)}S(a|0);L()}d=0}kf(q);XO(p)}jb=e+416|0;return d|0}function q1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0,M=0,N=C(0),O=C(0),P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=C(0);y=jb-17168|0;jb=y;v[y+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!Bo(a+6152|0,b)){break c}j=Ew(b,v[a+6148>>2])+Ao(b)|0;v[y+17164>>2]=j;if((c|0)==(j|0)){j=c;break b}d:{if((j+4|0)<=(c|0)){if(Bo(b,b+j|0)){break d}}v[y+17164>>2]=0;break c}if(j){break b}}g=b;s=Rb(a,0,6668)+6148|0;n=y+17164|0;f=c;e:{if((f|0)>=5){l=f-4|0;while(1){if(RG(g)){p=Ew(g,v[s>>2]);j=p+Ao(g)|0;i=0;f:{g:{if(p){break g}k=4;o=m+4|0;while(1){if((l|0)<=((k<<1)+m|0)){break f}p=0;i=g+k|0;h:{if(!Bo(g,i)){break h}E=k-Ao(g)|0;q=Ao(i)+E|0;if((f|0)<(q+(k+o|0)|0)){break h}if(!Bo(g,i+q|0)){break h}v[s>>2]=E;p=E;j=k}i=!p;if(p){break g}E=k>>>0<2303;k=k+1|0;if(E){continue}break}}if((f|0)<(j+m|0)|i){break f}k=g;q=f-m|0;i=0;o=0;i:{while(1){G=i;i=i+k|0;i=(G+Ew(i,p)|0)+Ao(i)|0;G=(o|0)!=0;if((q|0)<(i+4|0)){break i}G=0;if(!Bo(k,i+k|0)){break i}o=o+1|0;if((o|0)!=10){continue}break}G=1}if(G){break e}}if(!((f|0)!=(j|0)|m)){m=0;j=f;break e}v[s>>2]=0}g=g+1|0;m=m+1|0;if((l|0)!=(m|0)){continue}break}}j=0;m=f}v[n>>2]=j;j=v[y+17164>>2];o=m;if((m+j|0)<=(c|0)?j:0){break b}v[e>>2]=o;o=0;break a}E=b+o|0;v[a+6152>>2]=w[E|0]|w[E+1|0]<<8|(w[E+2|0]<<16|w[E+3|0]<<24);v[e+4>>2]=o;v[e>>2]=j+o;v[e+8>>2]=w[E+3|0]>191?1:2;aa=e,ba=VG(E),v[aa+12>>2]=ba;v[e+16>>2]=4-(w[E+1|0]>>>1&3);aa=e,ba=Dw(E),v[aa+20>>2]=ba;if(!d){o=Cw(E);break a}TG(y+17152|0,E+4|0,j-4|0);if(!(t[E+1|0]&1)){Ud(y+17152|0,16)}j:{if(v[e+16>>2]==3){o=0;g=y+17152|0;j=y+3740|0;m=0;b=E;c=w[b+1|0];f=B((c>>>3&1)+(c>>>4&1)|0,3)+(w[b+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;k=w[b+3|0]>191?1:2;k:{if(c&8){i=Ud(g,9);k=k<<1;m=Ud(g,k+7|0);break k}i=Ud(g,k|8)>>>k|0}c=B(f,40);l=c+42768|0;n=c+43088|0;q=B(f,23)+42576|0;f=-1;l:{while(1){c=w[b+3|0];I=Ud(g,12);u[j+4>>1]=I;p=Ud(g,9);u[j+6>>1]=p;if((p&65535)>>>0>288){break l}p=c>>>0>191?m<<4:m;aa=j,ba=Ud(g,8),t[aa+10|0]=ba;c=Ud(g,w[b+1|0]&8?4:9);t[j+13|0]=22;t[j+14|0]=0;v[j>>2]=q;u[j+8>>1]=c;m:{if(Ud(g,1)){c=Ud(g,2);t[j+11|0]=c;if(!(c&255)){break l}m=Ud(g,1);u[j+18>>1]=65287;t[j+12|0]=m;if(w[j+11|0]==2){c=j;n:{if(!(m&255)){v[j>>2]=l;t[j+18|0]=8;s=39;m=0;break n}v[j>>2]=n;s=30;m=w[b+1|0]&8?8:6}t[c+14|0]=s;t[j+13|0]=m;p=p&3855}c=Ud(g,10);aa=j,ba=Ud(g,3),t[aa+21|0]=ba;aa=j,ba=Ud(g,3),t[aa+22|0]=ba;aa=j,ba=Ud(g,3),t[aa+23|0]=ba;m=c<<5;break m}t[j+11|0]=0;t[j+12|0]=0;m=Ud(g,15);aa=j,ba=Ud(g,4),t[aa+18|0]=ba;c=Ud(g,3);t[j+20|0]=255;t[j+19|0]=c}t[j+17|0]=m&31;t[j+15|0]=m>>>10;t[j+16|0]=m>>>5&31;h=(I&65535)+h|0;c=j;o:{if(w[b+1|0]&8){m=Ud(g,1);break o}m=x[j+8>>1]>499}t[c+24|0]=m;aa=j,ba=Ud(g,1),t[aa+25|0]=ba;c=Ud(g,1);t[j+27|0]=p>>>12&15;t[j+26|0]=c;j=j+28|0;m=p<<4;k=k-1|0;if(k){continue}break}f=(v[g+4>>2]+h|0)>(v[g+8>>2]+(i<<3)|0)?-1:i}if(!((f|0)<0|v[y+17156>>2]>v[y+17160>>2])){b=y+17152|0;g=v[b+4>>2];h=v[b+8>>2];k=y+912|0;c=v[a+6144>>2];j=c-f|0;c=(c|0)>(f|0)?f:c;j=lc(k+12|0,(((j|0)>0?j:0)+a|0)+6156|0,c);m=v[b>>2]+(v[b+4>>2]/8|0)|0;b=(h-g|0)/8|0;lc(c+j|0,m,b);TG(k,j,b+c|0);j=v[a+6144>>2]>=(f|0);if(j){W=a+2304|0;o=v[e+8>>2];X=y+8620|0;Y=y+3852|0;b=0;while(1){Z=Rb(Y,0,4608);m=y+912|0;p=(B(B(b,o),28)+y|0)+3740|0;k=0;S=a;I=a+6152|0;if((o|0)>=1){s=m+7548|0;while(1){g=B(k,28)+p|0;P=x[g+4>>1];R=v[m+4>>2];L=(m+B(k,39)|0)+16156|0;q=m;G=s;l=k;h=jb-48|0;jb=h;f=g;H=!w[f+13|0]+(w[f+14|0]!=0)|0;M=w[f+25|0];c=h;Q=c+44|0;i=I;p:{if(w[i+1|0]&8){n=w[f+27|0];l=w[x[f+8>>1]+43504|0];r=l&3;t[h+47|0]=r;t[h+46|0]=r;l=l>>>2|0;t[h+45|0]=l;t[h+44|0]=l;l=B(H,28)+43408|0;break p}l=w[i+3|0]>>>4&(l|0)!=0;A=l?12:0;J=x[f+8>>1]>>>l|0;while(1){r=1;l=3;while(1){n=l;F=w[(l+A|0)+43520|0];t[(h+44|0)+l|0]=((J|0)/(r|0)|0)%(F|0);r=B(r,F);l=l-1|0;if(n){continue}break}A=A+4|0;J=J-r|0;if((J|0)>-1){continue}break}n=-16;l=(B(H,28)+43408|0)+A|0}r=0;while(1){H=w[l+r|0];if(H){q:{if(n&8){lc(c,L,H);break q}F=w[r+Q|0];if(!F){Rb(c,0,H);Rb(L,0,H);break q}T=(n|0)>-1?-1:-1<<F^-1;A=0;while(1){J=Ud(q,F);t[A+L|0]=(J|0)==(T|0)?-1:J;t[c+A|0]=J;A=A+1|0;if((H|0)!=(A|0)){continue}break}}n=n<<1;c=c+H|0;L=H+L|0;r=r+1|0;if((r|0)!=4){continue}}break}t[c+2|0]=0;t[c|0]=0;t[c+1|0]=0;l=w[f+14|0];r:{if(l){c=2-M|0;n=w[f+23|0]<<c;q=w[f+22|0]<<c;H=w[f+21|0]<<c;A=w[f+13|0];r=0;while(1){c=h+(r+A|0)|0;t[c|0]=H+w[c|0];t[c+1|0]=q+w[c+1|0];t[c+2|0]=n+w[c+2|0];r=r+3|0;if(l>>>0>r>>>0){continue}break}break r}if(!w[f+24|0]){break r}n=0;while(1){c=h+n|0;t[c+11|0]=w[c+11|0]+w[n+43544|0];n=n+1|0;if((n|0)!=10){continue}break}}D=Bw(C(2048),((((w[i+3|0]&224)==96)<<1)-w[f+10|0]|0)+258|0);n=0;if((l|0)!=(0-w[f+13|0]|0)){c=M+1|0;while(1){aa=G+(n<<2)|0,ca=Bw(D,w[h+n|0]<<c),z[aa>>2]=ca;n=n+1|0;if(n>>>0<w[f+14|0]+w[f+13|0]>>>0){continue}break}}jb=h+48|0;q=(m+B(k,2304)|0)+2940|0;c=s;T=P+R|0;D=C(0);R=0;G=m;i=v[m+4>>2];f=v[m>>2]+((i|0)/8|0)|0;h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);h=(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24))<<(i&7);l=i|-8;F=f+4|0;H=g;r=v[g>>2];A=x[g+6>>1];if(A){while(1){f=H+R|0;g=w[f+15|0];P=(u[(g<<1)+47968>>1]<<1)+43584|0;L=w[f+18|0];s:{if(g>>>0>=16){M=w[g+48032|0];_=32-M|0;while(1){U=w[r|0]>>>1|0;n=(A|0)>(U|0)?U:A;D=z[c>>2];while(1){i=u[P+(h>>>26&62)>>1];if((i|0)<=-1){f=5;while(1){h=h<<f;l=f+l|0;g=i&7;f=g;i=u[P+((h>>>32-f|0)-(i<<16>>19)<<1)>>1];if((i|0)<0){continue}break}}Q=i&65535;g=Q>>>8|0;l=g+l|0;h=h<<g;J=1;while(1){$=q;f=Q&15;t:{if((f|0)==15){i=h<<M;f=(h>>>_|0)+15|0;l=l+M|0;if((l|0)>=0){while(1){i=w[F|0]<<l|i;g=(l|0)>7;l=l-8|0;F=F+1|0;if(g){continue}break}}O=C(D*C(((i|0)>-1?1:-1)|0));g=f;u:{if((f|0)<=128){K=z[(g<<2)+48128>>2];break u}V=(g|0)<1024;g=V?g<<3:g;h=g<<1&64;N=C(C((g&63)-h|0)/C(h+(g&-64)|0));K=C(C(C(C(C(C(N*C(.2222222238779068))+C(1.3333333730697632))*N)+C(1))*(V?C(16):C(256)))*z[(g+h>>6<<2)+48128>>2])}O=C(O*K);break t}i=h;O=C(z[(((h>>>27&16|f)^16)<<2)+48064>>2]*D)}z[$>>2]=O;Q=Q>>>4|0;q=q+4|0;g=(f|0)!=0;l=g+l|0;h=i<<g;g=J&1;J=0;if(g){continue}break}if((l|0)>-1){while(1){h=w[F|0]<<l|h;g=(l|0)>7;l=l-8|0;F=F+1|0;if(g){continue}break}}n=n-1|0;if(n){continue}break}c=c+4|0;r=r+1|0;A=A-U|0;if((A|0)<1){break s}g=(L|0)>0;L=L-1|0;if(g){continue}break}break s}while(1){g=w[r|0]>>>1|0;J=(g|0)<(A|0)?g:A;D=z[c>>2];while(1){i=u[P+(h>>>26&62)>>1];if((i|0)<=-1){f=5;while(1){h=h<<f;l=f+l|0;n=i&7;f=n;i=u[P+((h>>>32-f|0)-(i<<16>>19)<<1)>>1];if((i|0)<0){continue}break}}i=i&65535;f=i>>>8|0;l=f+l|0;h=h<<f;f=1;while(1){n=i&15;z[q>>2]=z[(((n|h>>>27&16)^16)<<2)+48064>>2]*D;i=i>>>4|0;q=q+4|0;n=(n|0)!=0;l=n+l|0;h=h<<n;n=f&1;f=0;if(n){continue}break}if((l|0)>-1){while(1){h=w[F|0]<<l|h;f=(l|0)>7;l=l-8|0;F=F+1|0;if(f){continue}break}}J=J-1|0;if(J){continue}break}c=c+4|0;r=r+1|0;A=A-g|0;if((A|0)<1){break s}g=(L|0)>0;L=L-1|0;if(g){continue}break}}R=R+1|0;if((A|0)>0){continue}break}f=1-A|0}else{f=1}while(1){v:{g=w[H+26|0]?47952:47920;i=w[g+(h>>>28|0)|0];if(!(i&8)){i=w[g+((h<<4>>>32-(i&3))+(i>>>3)|0)|0]}g=i&7;l=g+l|0;if((T|0)<((l+(F-v[G>>2]<<3)|0)-24|0)){break v}f=f-1|0;if(!f){f=w[r|0]>>>1|0;if(!f){break v}r=r+1|0;D=z[c>>2];c=c+4|0}h=h<<g;if(i&128){z[q>>2]=(h|0)<0?C(-D):D;l=l+1|0;h=h<<1}if(i&64){z[q+4>>2]=(h|0)<0?C(-D):D;l=l+1|0;h=h<<1}f=f-1|0;if(!f){f=w[r|0]>>>1|0;if(!f){break v}r=r+1|0;D=z[c>>2];c=c+4|0}if(i&32){z[q+8>>2]=(h|0)<0?C(-D):D;l=l+1|0;h=h<<1}if(i&16){z[q+12>>2]=(h|0)<0?C(-D):D;l=l+1|0;h=h<<1}if((l|0)>=0){while(1){h=w[F|0]<<l|h;g=(l|0)>7;l=l-8|0;F=F+1|0;if(g){continue}break}}q=q+16|0;continue}break}v[G+4>>2]=T;k=k+1|0;if((o|0)!=(k|0)){continue}break}}c=w[S+6155|0];w:{if(c&16){i=0;q=jb-16|0;jb=q;n=m+2940|0;f=n+2304|0;g=p;H=v[g>>2];M=w[g+14|0];G=M+w[g+13|0]|0;r=G;l=q+4|0;v[l+8>>2]=-1;v[l>>2]=-1;v[l+4>>2]=-1;if(r>>>0>=1){while(1){c=0;A=i+H|0;k=w[A|0];h=0;x:{if(!k){break x}y:{while(1){h=c<<2;if(z[h+f>>2]!=C(0)|z[(h|4)+f>>2]!=C(0)){break y}c=c+2|0;if(k>>>0>c>>>0){continue}break}h=k;break x}v[l+((i>>>0)%3<<2)>>2]=i;h=w[A|0]}f=((h&255)<<2)+f|0;i=i+1|0;if((r|0)!=(i|0)){continue}break}}if(w[g+13|0]){c=v[q+12>>2];f=v[q+8>>2];h=v[q+4>>2];f=(f|0)>(h|0)?f:h;c=(c|0)>(f|0)?c:f;v[q+12>>2]=c;v[q+8>>2]=c;v[q+4>>2]=c}s=m+16195|0;c=M?3:1;h=G-c|0;i=0;while(1){k=h+i|0;f=k-c|0;if((f|0)<=v[(q+4|0)+(i<<2)>>2]){f=w[I+1|0]<<28>>31&3}else{f=w[f+s|0]}t[k+s|0]=f;i=i+1|0;if((c|0)!=(i|0)){continue}break}G=q+4|0;H=u[g+36>>1]&1;f=0;h=v[g>>2];c=w[h|0];if(c){M=w[I+1|0]&8?7:64;g=h;while(1){i=w[I+3|0]&32;z:{A:{if(v[G+((f>>>0)%3<<2)>>2]>=(f|0)){break A}k=w[f+s|0];if(k>>>0>=M>>>0){break A}N=i?C(1.4142135381698608):C(1);B:{if(w[I+1|0]&8){k=k<<3;K=z[k+48656>>2];D=z[(k|4)+48656>>2];break B}K=Bw(C(1),k+1>>>1<<H);k=k&1;D=k?C(1):K;K=k?K:C(1)}k=n;K=C(K*N);N=C(D*N);l=0;if((c|0)>=1){while(1){i=k+(l<<2)|0;D=z[i>>2];z[i+2304>>2]=D*N;z[i>>2]=D*K;l=l+1|0;if((l|0)!=(c|0)){continue}break}}break z}if(!i){break z}QG(n,c)}n=(w[g|0]<<2)+n|0;f=f+1|0;g=h+f|0;c=w[g|0];if(c){continue}break}}jb=q+16|0;break w}if((c&224)!=96){break w}QG(m+2940|0,576)}if((o|0)>=1){q=m+7708|0;k=0;while(1){c=w[S+6153|0];i=(w[p+12|0]!=0)<<1<<((B((c>>>3&1)+(c>>>4&1)|0,3)+(w[S+6154|0]>>>2&3)|0)==2);c=(m+B(k,2304)|0)+2940|0;l=c;if(w[p+14|0]){g=((m+B(k,2304)|0)+B(i,72)|0)+2940|0;s=q;h=q;F=v[p>>2]+w[p+13|0]|0;n=w[F|0];if(n){f=g;while(1){I=n&255;G=I<<1;n=1;while(1){z[h>>2]=z[f>>2];z[h+4>>2]=z[(I<<2)+f>>2];H=G<<2;z[h+8>>2]=z[H+f>>2];f=f+4|0;h=h+12|0;if((n|0)!=(I|0)){n=n+1|0;continue}break}f=f+H|0;n=w[F+3|0];F=F+3|0;if(n){continue}break}}lc(g,s,h-s|0);h=i-1|0}else{h=31}if((h|0)>=1){while(1){f=0;while(1){g=f<<2;s=g+l|0;g=g+48720|0;D=z[g>>2];N=z[s+72>>2];K=z[g+32>>2];g=(17-f<<2)+l|0;O=z[g>>2];z[s+72>>2]=C(D*N)-C(K*O);z[g>>2]=C(K*N)+C(D*O);f=f+1|0;if((f|0)!=8){continue}break}l=l+72|0;g=(h|0)>1;h=h-1|0;if(g){continue}break}}f=c;h=S+B(k,1152)|0;g=w[p+11|0];if(i){PG(f,h,48784,i);h=B(i,36)+h|0;f=B(i,72)+f|0}C:{if((g|0)==2){s=jb-80|0;jb=s;g=32-i|0;if((g|0)>=1){l=s|8;n=s|4;while(1){i=lc(s,f,72);I=v[h+20>>2];v[f+16>>2]=v[h+16>>2];v[f+20>>2]=I;I=v[h+12>>2];v[f+8>>2]=v[h+8>>2];v[f+12>>2]=I;I=v[h+4>>2];v[f>>2]=v[h>>2];v[f+4>>2]=I;G=i;i=h+24|0;Aw(G,f+24|0,i);Aw(n,f+48|0,i);Aw(l,h,i);f=f+72|0;h=h+36|0;i=(g|0)>1;g=g-1|0;if(i){continue}break}}jb=s+80|0;break C}PG(f,h,B((g|0)==3,72)+48784|0,32-i|0)}g=0;i=c+72|0;while(1){f=1;while(1){c=(f<<2)+i|0;z[c>>2]=-z[c>>2];c=f>>>0<16;f=f+2|0;if(c){continue}break}i=i+144|0;c=g>>>0<30;g=g+2|0;if(c){continue}break}p=p+28|0;k=k+1|0;if((o|0)!=(k|0)){continue}break}}SG(W,Z,18,v[e+8>>2],d,X);o=v[e+8>>2];d=B(o,1152)+d|0;b=b+1|0;if(b>>>0<(w[E+1|0]&8?2:1)>>>0){continue}break}}b=a;c=y+912|0;f=v[c+8>>2]>>>3|0;h=v[c+4>>2]+7>>>3|0;d=f-h|0;e=(d|0)>511;g=e?511:d;if((d|0)>=1){aj(b+6156|0,(c+(e?f-511|0:h)|0)+12|0,g)}v[b+6144>>2]=g;break j}Fw(a);break a}f=y+17152|0;o=0;m=0;p=0;b=y;g=b;k=0;D:{E:{F:{c=E;j=w[c+3|0];h=j>>>6|0;switch(h-1|0){case 2:break D;case 0:break F;default:break E}}k=(j>>>2&12)+4|0;break D}k=32}j=w[c+1|0];G:{if((j&6)==6){j=32;c=50188;break G}if(!(j&8)){j=30;c=50191;break G}j=w[c+2|0]>>>2&3;c=Dw(c)>>>((h|0)!=3)|0;c=c?c:192;if(c>>>0<=55){j=(j|0)==2?12:8;c=50212;break G}j=c>>>0>95?(j|0)!=1?30:27:27;c=50200}t[g+768|0]=j;t[g+769|0]=(j|0)<(k|0)?j:k;j=c;H:{if(!w[b+768|0]){break H}i=50096;while(1){if((o|0)==(p|0)){i=w[j|0]+50096|0;p=w[j+2|0]+p|0;m=w[j+1|0];j=j+3|0}c=o<<1;g=w[Ud(f,m)+i|0];t[(c+b|0)+770|0]=g;h=w[b+769|0];if(o>>>0<h>>>0){g=w[Ud(f,m)+i|0];h=w[b+769|0]}t[(b+(c|1)|0)+770|0]=h?g:0;g=w[b+768|0];o=o+1|0;if(g>>>0>o>>>0){continue}break}if(!g){m=g<<1;break H}o=0;while(1){c=b+o|0;I:{if(!w[c+770|0]){j=6;break I}if((w[E+1|0]&6)==6){j=2;break I}j=Ud(f,2);g=w[b+768|0]}t[c+834|0]=j;m=g<<1&510;o=o+1|0;if(m>>>0>o>>>0){continue}break}}j=b+770|0;E=b+834|0;c=b;p=0;if((m|0)>=1){while(1){h=w[j|0];g=h?19>>>w[p+E|0]&3|4:0;j=j+1|0;s=B(h,3)-6|0;k=4;D=C(0);while(1){if(g&k){i=Ud(f,6);h=(i|0)/3|0;D=C(z[(s+(i-B(h,3)|0)<<2)+50224>>2]*C(2097152>>>h|0))}z[c>>2]=D;c=c+4|0;k=k>>>1|0;if(k){continue}break}p=p+1|0;if((p|0)!=(m|0)){continue}break}}o=w[b+769|0];c=w[b+768|0];if(o>>>0<c>>>0){while(1){t[(b+(o<<1|1)|0)+770|0]=0;o=o+1|0;if(c>>>0>o>>>0){continue}break}}o=0;j=Rb(y+3852|0,0,4608);l=a+2304|0;n=y+8620|0;c=0;J:{while(1){q=((c<<2)+y|0)+3852|0;E=y+17152|0;p=v[e+16>>2]|1;h=0;g=y;k=w[g+768|0];b=576;while(1){K:{if(!(k&255)){k=0;break K}i=q+(B(h,p)<<2)|0;f=0;while(1){m=b;k=w[(f+g|0)+770|0];L:{if(!k){break L}if(k>>>0<=16){if((p|0)<1){break L}s=(-1<<k-1)+1|0;b=0;while(1){aa=(b<<2)+i|0,ca=C(Ud(E,k)+s|0),z[aa>>2]=ca;b=b+1|0;if((p|0)!=(b|0)){continue}break}break L}k=2<<k-17;b=Ud(E,(k-(k>>>3|0)|0)+3|0);if((p|0)<1){break L}I=k>>>1|0;s=k|1;k=0;while(1){G=b;b=(b>>>0)/(s>>>0)|0;z[(k<<2)+i>>2]=(G-B(s,b)|0)-I|0;k=k+1|0;if((p|0)!=(k|0)){continue}break}}b=18-m|0;i=(m<<2)+i|0;f=f+1|0;k=w[g+768|0];if(f>>>0<k<<1>>>0){continue}break}}h=h+1|0;if((h|0)!=4){continue}break}c=(p<<2)+c|0;if((c|0)==12){g=(o<<2)+y|0;b=j;c=y;f=w[c+769|0];h=j+B(f,72)|0;lc(h+2304|0,h,B(w[c+768|0]-f|0,72));if(w[c+768|0]){k=0;while(1){m=0;while(1){f=(m<<2)+b|0;z[f>>2]=z[f>>2]*z[g>>2];f=f+2304|0;z[f>>2]=z[f>>2]*z[g+12>>2];m=m+1|0;if((m|0)!=12){continue}break}g=g+24|0;b=b+72|0;k=k+1|0;if(k>>>0<w[c+768|0]){continue}break}}SG(l,j,12,v[e+8>>2],d,n);Rb(j,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[y+17156>>2]<=v[y+17160>>2]){o=o+1|0;if((o|0)==3){break J}continue}break}Fw(a);o=0;break a}j=1}o=B(Cw(a+6152|0),j)}jb=y+17168|0;return o|0}function WG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0;K=jb-144|0;jb=K;j=v[f>>2];N=g&4;M=N?-1:j+((d^-1)+e|0)|0;E=M+1|0;a:{b:{if(d>>>0<=e>>>0?E&M:1){v[f>>2]=0;v[c>>2]=0;k=-3;break b}F=e+j|0;D=v[c>>2];z=D+b|0;G=v[a+60>>2];s=v[a+40>>2];j=v[a+36>>2];A=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];l=b;p=e;r=-1;k=-1;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{q=v[a>>2];switch(q|0){case 10:break g;case 35:break h;case 17:break i;case 21:break j;case 37:break k;case 34:break l;case 42:break p;case 41:break q;case 53:break r;case 52:break s;case 51:break t;case 38:break u;case 27:break v;case 26:break w;case 25:break x;case 24:break y;case 23:break z;case 18:break A;case 16:break B;case 14:break C;case 11:break D;case 9:break E;case 7:break F;case 6:break G;case 3:break H;case 32:break I;case 5:break J;case 2:break L;case 1:break M;case 0:break N;case 36:break e;case 39:break f;default:break c}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;s=0;j=0;A=0;i=0;if(g&1){break M}break K}k=1;if((D|0)<1){break d}v[a+8>>2]=w[b|0];l=b+1|0}k=2;if(l>>>0>=z>>>0){break d}k=w[l|0];v[a+12>>2]=k;j=1;l=l+1|0;q=36;h=v[a+8>>2];if(((k|h<<8)>>>0)%31|k&32){break e}k=h&15;if(!N){h=256<<(h>>>4);if(h>>>0>32768|h>>>0>E>>>0){break e}if((k|0)==8){break K}break e}if((k|0)!=8){break e}}h=0;break o}if((D|0)<1){k=5;break d}l=b+1|0;m=w[b|0]<<i|m;i=i+8|0;h=2;break o}if((D|0)<1){k=32;break d}l=b+1|0;m=w[b|0]<<i|m;C=j;i=i+8|0;break n}h=1;break o}h=4;break o}h=3;break o}h=7;break o}h=9;break o}h=10;break o}h=11;break o}h=12;break o}h=13;break o}h=14;break o}h=15;break o}h=16;break o}h=17;break o}h=8;break o}h=5;break o}h=6;break o}h=18;break o}n=2;break m}n=1;break m}O:while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{switch(h|0){case 0:j=C;if(i>>>0>2){break Ea}h=1;continue;case 17:break ma;case 16:break na;case 15:break oa;case 14:break pa;case 13:break qa;case 12:break ra;case 11:break sa;case 10:break ta;case 9:break ua;case 8:break wa;case 7:break xa;case 6:break ya;case 5:break za;case 4:break Ba;case 3:break Ca;case 2:break Da;case 1:break Fa;default:break la}}k=3;while(1){if(l>>>0>=z>>>0){break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;C=j}j=m&7;v[a+20>>2]=j;H=1;h=j>>>1|0;v[a+24>>2]=h;i=i-3|0;m=m>>>3|0;k=0;j=C;switch(h|0){case 3:break g;case 0:break ka;case 1:break va;default:break ha}}h=i&-8;m=m>>>(i&7)|0;j=0;i=0;break ia}if(l>>>0<z>>>0){break Aa}k=7;break d}while(1){if(l>>>0>=z>>>0){k=6;break d}m=w[l|0]<<i|m;o=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(o){continue}break}l=k;i=1;break ia}t[(a+j|0)+10528|0]=w[l|0];l=l+1|0;h=i;i=2;break ia}while(1){if(l>>>0>=z>>>0){k=51;break d}m=w[l|0]<<i|m;o=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(o){continue}break}l=k;break R}if(p>>>0<F>>>0){t[p|0]=A;j=j-1|0;p=p+1|0;h=i;break V}r=2;q=52;break e}if(p>>>0<F>>>0){break ja}r=2;q=9;break e}if(l>>>0>=z>>>0){k=38;break d}k=F-p|0;h=z-l|0;h=h>>>0>k>>>0?k:h;h=h>>>0<j>>>0?h:j;j=j-h|0;p=lc(p,l,h)+h|0;l=h+l|0;break U}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Rb(a- -64|0,8,144);Rb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;break Z}while(1){if(l>>>0>=z>>>0){k=11;break d}m=w[l|0]<<i|m;k=l+1|0;l=k;h=i+8|0;i=h;I=t[j+42396|0];if(h>>>0<I>>>0){continue}break}l=k;k=j;i=h;j=1;break $}while(1){if(l>>>0>=z>>>0){k=14;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;h=1;break _}if(l>>>0>=z>>>0){k=16;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ga}break fa}while(1){if(l>>>0>=z>>>0){k=18;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(s>>>0>i>>>0){continue}break}O=A-16|0;l=h;h=3;break Y}if(l>>>0>=z>>>0){k=23;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ea}break da}if(p>>>0>=F>>>0){r=2;q=24;break e}t[p|0]=j;p=p+1|0;n=m;break X}while(1){if(l>>>0>=z>>>0){k=25;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(s>>>0>i>>>0){continue}break}l=h;h=3;break W}if(l>>>0>=z>>>0){k=26;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ca}break ba}while(1){if(l>>>0>=z>>>0){k=27;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(s>>>0>i>>>0){continue}break}l=h;h=6;break W}if(p>>>0>=F>>>0){r=2;q=53;break e}t[p|0]=w[(G-A&M)+d|0];p=p+1|0;G=G+1|0;break aa}h=2;continue}h=8;continue}while(1){Ga:{Ha:{Ia:{Ja:{Ka:{switch(i|0){case 0:if(j>>>0>3){break Ja}if(!h){i=0;h=3;continue O}i=h;if(h>>>0>7){break Ha}h=4;continue O;case 1:t[(a+j|0)+10528|0]=m;h=h-8|0;m=m>>>8|0;break Ga;default:break Ka}}j=j+1|0;break Ia}i=h;j=x[a+10528>>1];if((j|0)==(x[a+10530>>1]^65535)){break V}break f}i=0;continue}i=1;continue}i=2;continue}}j=0;break $}h=1;break Y}h=2;break Y}h=0;break W}h=1;break W}h=4;break W}h=5;break W}h=7;break W}while(1){La:{Ma:{Na:{if(!j){if(k>>>0>2){break Na}j=k;I=t[j+42396|0];if(I>>>0<=i>>>0){break La}h=9;continue O}j=k<<2;v[(j+a|0)+44>>2]=v[j+42384>>2]+((-1<<I^-1)&m);k=k+1|0;i=i-I|0;m=m>>>I|0;break Ma}j=0;Rb(a+7040|0,0,288);h=0;break _}j=0;continue}j=1;continue}}while(1){Oa:{Pa:{Qa:{if(!h){if(y[a+52>>2]<=j>>>0){break Qa}if(i>>>0>2){break Oa}h=10;continue O}t[(w[j+42448|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i-3|0;m=m>>>3|0;break Pa}v[a+52>>2]=19;H=v[a+24>>2];C=j;break Z}h=0;continue}h=1;continue}}h=0}while(1){Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{switch(h|0){case 0:j=0;if((H|0)<0){n=m;j=C;break X}J=Rb(K,0,64);k=B(H,3488)+a|0;Rb(k+352|0,0,3200);q=v[a+24>>2];r=v[((q<<2)+a|0)+44>>2];if(r){while(1){h=(w[(j+k|0)- -64|0]<<2)+J|0;v[h>>2]=v[h>>2]+1;j=j+1|0;if((r|0)!=(j|0)){continue}break}}v[J+64>>2]=0;v[J+68>>2]=0;k=0;o=0;j=1;while(1){h=j<<2;j=j+1|0;h=v[h+J>>2];k=h+k<<1;v[(J- -64|0)+(j<<2)>>2]=k;o=h+o|0;if((j|0)!=16){continue}break};if(!((k|0)==65536|o>>>0<=1)){j=C;break h}if(r){r=-1;D=0;E=B(H,3488)+a|0;while(1){q=w[(D+E|0)- -64|0];_a:{if(!q){break _a}h=(J- -64|0)+(q<<2)|0;j=v[h>>2];v[h>>2]=j+1;k=0;o=q;while(1){h=k;k=j&1|h<<1;j=j>>>1|0;o=o-1|0;if(o){continue}break}if(q>>>0<=10){if(k>>>0>1023){break _a}h=1<<q;j=q<<9|D;while(1){u[(E+(k<<1)|0)+352>>1]=j;k=h+k|0;if(k>>>0<1024){continue}break}break _a}k=E+((k&1023)<<1)|0;j=u[k+352>>1];$a:{if(j){k=r;r=j;break $a}u[k+352>>1]=r;k=r-2|0}j=h>>>8&8388607;if(q>>>0>=12){while(1){j=j>>>1|0;h=(E+((j&1)+(r^-1)<<1)|0)+2400|0;r=u[h>>1];if(!r){u[h>>1]=k;r=k;k=k-2|0}q=q-1|0;if(q>>>0>11){continue}break}}u[(E+((j>>>1&1)+(r^-1)<<1)|0)+2400>>1]=D;r=k}D=D+1|0;q=v[a+24>>2];if(D>>>0<y[((q<<2)+a|0)+44>>2]){continue}break}}j=0;if((q|0)!=2){break Sa}break Wa;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];ab:{if((h|0)>=0){h=h>>9;if(!h|h>>>0>i>>>0){break ab}break Va}if(i>>>0<11){break ab}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break Va}}h=11;continue O;case 2:k=u[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break Ya}h=10;while(1){o=m>>>h|0;h=h+1|0;k=u[(((o&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break};break Xa;default:break Za}}o=t[O+42404|0]+((-1<<s^-1)&m)|0;i=i-s|0;m=m>>>s|0;k=a+j|0;Rb(k+10532|0,(A|0)==16?w[k+10531|0]:0,o);j=j+o|0;break Wa}h=k>>9;k=k&511}i=i-h|0;m=m>>>h|0;A=k;if(k>>>0>15){break Ua}t[(a+j|0)+10532|0]=A;j=j+1|0}k=v[a+48>>2];o=v[a+44>>2];h=k+o|0;if(h>>>0<=j>>>0){break Ta}if(i>>>0>14){break Va}if((z-l|0)<=1){h=1;continue}m=w[l|0]<<i|m|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=2;continue}if(!((A|0)!=16|j)){j=0;A=16;break i}O=A-16|0;s=t[O+42400|0];if(s>>>0<=i>>>0){break Ra}h=12;continue O}if((h|0)!=(j|0)){break j}h=a+10532|0;lc(a- -64|0,h,o);lc(a+3552|0,h+o|0,k);q=v[a+24>>2];C=j}H=q-1|0;v[a+24>>2]=H;h=0;continue}h=3;continue}}h=2}bb:while(1){cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];rb:{if((h|0)>=0){h=h>>9;if(!h|h>>>0>i>>>0){break rb}break cb}if(i>>>0<11){break rb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break cb}}h=13;continue O;case 1:k=u[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break pb}h=10;while(1){j=m>>>h|0;h=h+1|0;k=u[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break};j=k;break ob;case 3:break fb;case 4:break gb;case 5:break kb;case 6:break lb;case 2:break qb;default:break mb}}while(1){m=z-l|0;if(!((F-p|0)>1?(m|0)>=4:0)){if(i>>>0>14){m=n;break cb}if((m|0)<=1){m=n;h=0;continue bb}m=w[l|0]<<i|n|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0;break cb}if(!(i>>>0>14)){n=(w[l|0]|w[l+1|0]<<8)<<i|n;l=l+2|0;i=i+16|0}m=i;h=l;j=u[(((n&1023)<<1)+a|0)+352>>1];sb:{if((j|0)<0){l=10;while(1){i=n>>>l|0;l=l+1|0;j=u[(((i&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break sb}l=j>>9}i=m-l|0;m=n>>>l|0;if(j&256){l=h;break nb}tb:{if(i>>>0>14){k=i;break tb}k=i+16|0;m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0}l=h;h=u[(((m&1023)<<1)+a|0)+352>>1];ub:{if((h|0)<0){n=10;while(1){i=m>>>n|0;n=n+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break ub}n=h>>9}t[p|0]=j;i=k-n|0;n=m>>>n|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=n;j=h;break nb}h=k>>9;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break nb}h=14;continue O}C=256;o=j&511;h=256;if((o|0)==256){break T}s=0;h=m;k=(o<<2)-1028|0;j=v[k+41872>>2];r=j;if(o-265>>>0>19){break eb}s=v[k+42e3>>2];if(s>>>0>i>>>0){h=15;continue O}h=3;continue}if(!j){n=m;j=-1;break ib}j=j-1|0;h=18;continue O}i=i-s|0;n=m>>>s|0;A=((-1<<s^-1)&m)+A|0;break jb}s=u[(((m&1023)<<1)+a|0)+3840>>1];vb:{if((s|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;s=u[(((k&1)+(s^-1)<<1)+a|0)+5888>>1];if((s|0)<0){continue}break}k=s;break vb}h=s>>9;k=s&511}o=k<<2;A=v[o+42128>>2];i=i-h|0;m=m>>>h|0;s=0;if(k-4>>>0>25){n=m;break jb}s=v[o+42256>>2];if(s>>>0<=i>>>0){break hb}h=17;continue O}G=p-d|0;if(!(!N|G>>>0>=A>>>0)){m=n;break k}h=(G-A&M)+d|0;if((h>>>0<p>>>0?p:h)+j>>>0>F>>>0){m=n;h=7;continue}if(j>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break ib}t[p|0]=w[h|0];if((j|0)!=1){t[p+1|0]=w[h+1|0]}p=j+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];wb:{if((h|0)>=0){h=h>>9;if(!h|h>>>0>i>>>0){break wb}break db}if(i>>>0<11){break wb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break db}}h=16;continue O}i=i-s|0;h=m>>>s|0;r=((-1<<s^-1)&m)+j|0}j=r;m=h;if(i>>>0>14){break db}if((z-l|0)<=1){h=4;continue}m=m|w[l|0]<<i|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(h?j:0){break S}i=h}if(j){break P}h=0}C=h;if(!(t[a+20|0]&1)){break Q}break n}i=h;if(h>>>0>7){break R}h=5;continue}i=h-8|0;A=m&255;m=m>>>8|0;h=6;continue}h=0;continue}h=7;continue}}n=i&-8;xb:{if(!n|b>>>0>=l>>>0){break xb}while(1){n=n-8|0;l=l-1|0;if(l>>>0<=b>>>0){break xb}if(n){continue}break}}if(!n){m=(((n&63)>>>0>=32?0:-1<<n)^-1)&m>>>(i&7);o=0;h=0;j=C;i=0;if(!(g&1)){break l}n=0;break m}ia(42408,41840,2787,42418);L()}while(1){yb:{zb:{Ab:{Bb:{Cb:{Db:{switch(n|0){case 0:if(o>>>0>3){j=o;i=h;break l}if(h){break Cb}i=0;j=o;n=1;continue;case 1:break Db;default:break Bb}}if(l>>>0<z>>>0){break zb}k=42;break d}j=o;i=h;if(h>>>0>7){break Ab}n=2;continue}while(1){if(l>>>0>=z>>>0){k=41;break d}m=w[l|0]<<i|m;n=i>>>0>4294967287;d=l+1|0;l=d;h=i+8|0;i=h;if(n){continue}break}l=d;o=j}n=m&255;m=m>>>8|0;h=h-8|0;break yb}n=w[l|0];l=l+1|0;o=j;h=i}v[a+16>>2]=v[a+16>>2]<<8|n;o=o+1|0;n=0;continue}}r=0;q=34;break e}q=37;r=-1;break e}q=21;r=-1;break e}q=17;r=-1;break e}q=35;r=-1;break e}q=10;r=-1;break e}q=39;r=-1}v[a>>2]=q;Eb:{if(i>>>0<8|b>>>0>=l>>>0){break Eb}while(1){i=i-8|0;l=l-1|0;if(l>>>0<=b>>>0){break Eb}if(i>>>0>7){continue}break}}k=r;break c}v[a>>2]=k;k=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=G;v[a+40>>2]=s;v[a+36>>2]=j;v[a+32>>2]=A;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=l-b;h=p-e|0;v[f>>2]=h;if(!(g&9)|(k|0)<0){break b}b=v[a+28>>2];i=b>>>16|0;l=b&65535;if(h){n=(h>>>0)%5552|0;while(1){j=0;if(n>>>0>=8){m=8;while(1){o=w[e|0]+l|0;C=o+w[e+1|0]|0;j=C+w[e+2|0]|0;f=j+w[e+3|0]|0;d=f+w[e+4|0]|0;c=d+w[e+5|0]|0;b=c+w[e+6|0]|0;l=b+w[e+7|0]|0;i=l+(b+(c+(d+(f+(j+(C+(i+o|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;if(n>>>0>(m|7)>>>0){m=m+8|0;continue}break}j=n&8184}if(j>>>0<n>>>0){b=n-j|0;m=e;while(1){l=w[m|0]+l|0;i=l+i|0;m=m+1|0;j=j+1|0;if((n|0)!=(j|0)){continue}break}e=b+e|0}h=h-n|0;i=(i>>>0)%65521|0;l=(l>>>0)%65521|0;n=5552;if(h){continue}break}}b=i<<16|l;v[a+28>>2]=b;if(k){break b}k=0;if(g&1){break a}}jb=K+144|0;return k}jb=K+144|0;return v[a+16>>2]==(b|0)?0:-2}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=jb-304|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!et(b,d+208|0)){break h}if(!gP(d+208|0)){break h}if(!Qb(b,hd(fP(d+208|0),mb))){break h}if(!c){s=1;break h}Hd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=fd(d+192|0);i:{j:{k:{l:{m:{n:{o:{switch(((w[d+248|0]|w[d+249|0]<<8)&61440)-4096>>>12|0){case 0:p:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|w[d+240|0]&15)){break p}if((w[d+246|0]|w[d+247|0]<<8)&65455){break p}v[a+1074308>>2]=18219008;v[114578]=0;e=Q(2,d+32|0,17034)|0;f=v[114578];v[114578]=0;h=1;if((f|0)==1){break n}Gb(k,e);yb(e);v[114578]=0;W(479,a+1074312|0,81,1)|0;f=v[114578];v[114578]=0;e=1;if((f|0)!=1){break i}break b}q:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|(w[d+246|0]|w[d+247|0]<<8))){break q}if(w[d+261|0]){break q}v[114578]=0;e=Q(2,d+32|0,17060)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);break j}g=P()|0;O()|0;break a}v[114578]=0;f=Q(2,d+32|0,17074)|0;i=v[114578];v[114578]=0;g=1;if((i|0)!=1){Gb(k,f);yb(f);break k}g=P()|0;O()|0;break a;case 1:v[114578]=0;f=Q(2,d+32|0,17089)|0;i=v[114578];v[114578]=0;e=1;if((i|0)!=1){Gb(k,f);yb(f);break k}g=P()|0;O()|0;break a;case 2:r:{s:{t:{u:{v:{j=w[d+248|0]|w[d+249|0]<<8;w:{if(j>>>0<=12820){v[114578]=0;e=Q(2,d+32|0,17103)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);break w}g=P()|0;O()|0;break a}v[114578]=0;e=Q(2,d+160|0,17119)|0;f=v[114578];v[114578]=0;if((f|0)==1){break v}v[114578]=0;R(219,d+176|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break u}f=w[d+248|0]|w[d+249|0]<<8;v[114578]=0;v[d+144>>2]=f-12820;U(245,d+32|0,d+176|0,d+144|0);f=v[114578];v[114578]=0;if((f|0)==1){break t}Gb(k,d+32|0);yb(d+32|0);Ib(d+176|0)}yb(e);if((w[d+248|0]|w[d+249|0]<<8)>>>0<12807){break l}if(w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24)){break r}break l}g=P()|0;O()|0;break a}g=P()|0;O()|0;break s}g=P()|0;O()|0;Ib(d+176|0)}yb(e);break a}e=w[d+248|0]|w[d+249|0]<<8;f=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);v[114578]=0;e=Q(661,e|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}f=Sp(d+32|0);v[f+44>>2]=e;v[114578]=0;R(662,a+1304500|0,f|0);e=v[114578];v[114578]=0;if((e|0)!=1){break l}g=P()|0;O()|0;break a;case 3:if((w[d+248|0]|w[d+249|0]<<8)==16640){v[114578]=0;g=Q(2,d+32|0,17143)|0;f=v[114578];v[114578]=0;e=1;if((f|0)!=1){Gb(k,g);yb(g);v[114578]=0;W(479,a+1074312|0,81,1)|0;f=v[114578];v[114578]=0;g=0;if((f|0)==1){break b}break i}g=P()|0;O()|0;break a}e=w[d+248|0]|w[d+249|0]<<8;f=w[d+262|0]|w[d+263|0]<<8;v[114578]=0;U(663,d+32|0,e|0,f|0);f=v[114578];v[114578]=0;e=1;if((f|0)!=1){Gb(k,d+32|0);yb(d+32|0);v[a+480260>>2]=1;f=w[d+248|0]|w[d+249|0]<<8;i=1;if((nS(16384)|0)>(f|0)){break i}v[114578]=0;W(479,a+1074312|0,38,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}break i}g=P()|0;O()|0;break a;case 4:j=(w[d+248|0]|w[d+249|0]<<8)&4095;e=j<<16;f=a;if(j>>>0>=297){e=e|(w[d+262|0]|w[d+263|0]<<8)}v[f+1074308>>2]=e;v[114578]=0;e=Q(2,d+176|0,17155)|0;f=v[114578];v[114578]=0;x:{y:{z:{if((f|0)!=1){v[114578]=0;R(242,d+144|0,a+1074308|0);f=v[114578];v[114578]=0;if((f|0)==1){break z}v[114578]=0;U(3,d+32|0,e|0,d+144|0);f=v[114578];v[114578]=0;if((f|0)==1){break y}Gb(k,d+32|0);yb(d+32|0);yb(d+144|0);break j}g=P()|0;O()|0;break a}g=P()|0;O()|0;break x}g=P()|0;O()|0;yb(d+144|0)}yb(e);break a;case 5:v[114578]=0;e=Q(2,d+32|0,17143)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);v[114578]=0;W(479,a+1074312|0,81,1)|0;f=v[114578];v[114578]=0;e=0;if((f|0)==1){break b}break i}g=P()|0;O()|0;break a;case 6:v[114578]=0;e=Q(2,d+32|0,17164)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);break j}g=P()|0;O()|0;break a;default:break o}}if((w[d+248|0]|w[d+249|0]<<8)!=51712){break i}v[114578]=0;e=Q(2,d+32|0,17177)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);break j}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}v[114578]=0;f=a+1074312|0;W(479,f|0,23,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;W(479,f|0,38,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;e=1;W(479,f|0,107,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[a+480260>>2]=1;if(j>>>0>12820){break i}}v[114578]=0;f=Q(2,d+128|0,17184)|0;i=v[114578];v[114578]=0;A:{B:{C:{D:{E:{if((i|0)!=1){v[114578]=0;R(219,d+176|0,f|0);i=v[114578];v[114578]=0;if((i|0)==1){break E}v[d+16>>2]=w[d+249|0]&15;i=w[d+248|0];v[114578]=0;v[d>>2]=i;R(660,d+144|0,d|0);i=v[114578];v[114578]=0;if((i|0)==1){break D}v[114578]=0;fa(997,d+32|0,d+176|0,k|0,d+16|0,d+144|0);i=v[114578];v[114578]=0;if((i|0)==1){break C}Gb(k,d+32|0);yb(d+32|0);yb(d+144|0);Ib(d+176|0);yb(f);i=0;break i}g=P()|0;O()|0;break a}g=P()|0;O()|0;break A}g=P()|0;O()|0;break B}g=P()|0;O()|0;yb(d+144|0)}Ib(d+176|0)}yb(f);break a}yb(e);e=0}v[114578]=0;f=Q(2,d+32|0,17193)|0;j=v[114578];v[114578]=0;F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{if((j|0)!=1){Gb(a+1304436|0,f);yb(f);v[114578]=0;f=Q(2,d+32|0,17209)|0;j=v[114578];v[114578]=0;if((j|0)==1){break T}Gb(a+1304448|0,f);yb(f);Gb(a+1304460|0,k);v[a+1304496>>2]=v[a+1074308>>2]?7:4;if(e){v[114578]=0;e=a+1074312|0;Q(480,e|0,77)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(480,e|0,78)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(480,e|0,79)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(480,e|0,80)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(480,e|0,82)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(480,e|0,96)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}}h=((w[d+248|0]|w[d+249|0]<<8)&61440)>>>0<4097|((w[d+248|0]|w[d+249|0]<<8)>>>0<12820?((w[d+248|0]|w[d+249|0]<<8)&61440)==12288:0)?h:1;v[114578]=0;e=a+901404|0;Z(998,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!h){v[114578]=0;Z(634,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}}v[114578]=0;U(577,d+176|0,1,d+208|0);e=v[114578];v[114578]=0;if((e|0)==1){break S}v[114578]=0;R(417,d+32|0,d+176|0);e=v[114578];v[114578]=0;if((e|0)==1){break S}Gb(a+1304400|0,d+32|0);yb(d+32|0);if(w[d+246|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+246|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+246|0]&64?0:(w[d+248|0]|w[d+249|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}e=w[d+257|0];v[a+480196>>2]=e;U:{V:{if(e){if((e|0)!=255){break V}e=0;if(!g){break U}}v[a+480196>>2]=6}e=g}v[a+480204>>2]=B(w[d+258|0],1e4);if(w[d+258|0]<=32){v[a+480204>>2]=e?125e4:32e4}g=w[d+256|0];v[114578]=0;t[d+32|0]=g;t[d+176|0]=64;g=Q(393,d+32|0,d+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break O}g=w[g|0];v[a+480200>>2]=g<<2;if(!((w[d+248|0]|w[d+249|0]<<8)>>>0>4895|g)){v[a+480200>>2]=256}if((w[d+250|0]|w[d+251|0]<<8)!=1|w[d+259|0]>7){break Q}g=w[d+259|0];v[114578]=0;v[d+32>>2]=(g<<4)+16;v[d+176>>2]=127;g=Q(464,d+32|0,d+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break R}v[a+480228>>2]=v[g>>2];break P}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}if(!(w[d+259|0]!=18?w[d+259|0]!=2:0)){v[a+480228>>2]=32;break P}g=w[d+259|0];v[114578]=0;v[d+32>>2]=g&127;v[d+176>>2]=16;g=Q(552,d+32|0,d+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break N}v[a+480228>>2]=v[g>>2]}v[a+480232>>2]=36;if(!(!i|(w[d+248|0]|w[d+249|0]<<8)>>>0>=19763)){v[a+480232>>2]=64}u[a+480188>>1]=4;i=Dt(d+120|0);g=0;while(1){v[114578]=0;f=(g<<5)+a|0;o=f+480280|0;Z(434,o|0);h=v[114578];v[114578]=0;if((h|0)==1){break M}h=d+g|0;j=w[h+272|0];if(w[h+272|0]!=255){u[a+480188>>1]=g+1;u[f+480284>>1]=j&8?204:51}if(t[h+272|0]<=-1){v[o>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[f+480284>>1]=128;Pj(d+32|0,i,g);ge(d+32|0,1)}g=g+1|0;if((g|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}g=Vb(a+484360|0);f=w[d+240|0]|w[d+241|0]<<8;v[114578]=0;ea(581,g|0,b|0,f|0,255,254)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}q=cq(d+176|0);g=w[d+242|0]|w[d+243|0]<<8;v[114578]=0;W(395,b|0,q|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}o=cq(d+144|0);g=w[d+244|0]|w[d+245|0]<<8;v[114578]=0;W(395,b|0,o|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){if(w[d+261|0]==252){g=0;v[114578]=0;Q(999,b|0,d+32|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}while(1){h=(d+32|0)+g|0;f=w[h|0];W:{if(!(f&32)){break W}j=((g<<5)+a|0)+480284|0;if(e){Pj(d+16|0,i,g);if(Cb(d+16|0)){break W}f=w[h|0]}u[j>>1]=(((f&15)<<8|8)>>>0)/15}g=g+1|0;if((g|0)!=32){continue}break}}f=w[d+242|0]|w[d+243|0]<<8;g=0;v[114578]=0;u[d+32>>1]=f;u[d+16>>1]=3999;f=Q(478,d+32|0,d+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break L}f=x[f>>1];u[a+480190>>1]=f;if(f){f=c&2;i=d+80|0;while(1){h=rc(q,g);h=w[h|0]|w[h+1|0]<<8;v[114578]=0;h=Q(256,b|0,h<<4)|0;j=v[114578];v[114578]=0;if((j|0)==1){break K}X:{if(!h){break X}v[114578]=0;h=Q(1e3,b|0,d+32|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break K}if(!h){break X}v[114578]=0;h=g+1|0;j=(B(h,104)+a|0)+484380|0;U(1001,d+32|0,j|0,e|0);l=v[114578];v[114578]=0;if((l|0)==1){break K}v[114578]=0;U(577,d|0,1,i|0);l=v[114578];v[114578]=0;Y:{Z:{_:{if((l|0)==1){break _}v[114578]=0;R(417,d+16|0,d|0);l=v[114578];v[114578]=0;if((l|0)==1){break _}v[114578]=0;Q(371,((h<<5)+a|0)+946304|0,d+16|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Z}yb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))|(!f|w[d+32|0]>1)){break X}h=w[d+46|0];l=w[d+47|0];p=w[d+45|0];v[114578]=0;h=Q(256,b|0,l<<12|h<<4|p<<20)|0;l=v[114578];v[114578]=0;if((l|0)==1){break Y}if(!h){break X}h=w[d+250|0]|w[d+251|0]<<8;v[114578]=0;U(1002,d+16|0,d+32|0,(h|0)==1|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;W(402,d+16|0,j|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break X}}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;yb(d+16|0);break f}g=P()|0;O()|0;break f}g=g+1|0;if(g>>>0<x[a+480190>>1]){continue}break}}s=1;if(!(c&1)){break F}c=w[d+248|0]|w[d+249|0]<<8;e=w[d+244|0]|w[d+245|0]<<8;v[114578]=0;u[d+32>>1]=e;u[d+16>>1]=255;e=Q(478,d+32|0,d+16|0)|0;g=v[114578];v[114578]=0;$:{aa:{if((g|0)!=1){r=x[e>>1];v[114578]=0;f=a+484344|0;R(403,f|0,r|0);e=v[114578];v[114578]=0;if((e|0)==1){break aa}y=c>>>0<4896;if(r){break $}l=0;p=0;break G}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}A=d+32|5;C=d+32|3;z=d+32|4;D=d+32|2;E=d+32|1;i=0;p=0;l=0;while(1){v[114578]=0;c=W(404,f|0,i&65535,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}ba:{if(!c){break ba}c=rc(o,i);if(!(w[c|0]|w[c+1|0]<<8)){break ba}c=rc(o,i);c=w[c|0]|w[c+1|0]<<8;v[114578]=0;c=Q(256,b|0,c<<4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}if(!c){break ba}v[114578]=0;Q(340,b|0,2)|0;c=v[114578];v[114578]=0;if((c|0)==1){break J}g=0;c=_b(f,i);v[114578]=0;c=Q(497,c|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break I}while(1){v[114578]=0;n=T(389,b|0)|0;e=v[114578];v[114578]=0;ca:{da:{if((e|0)!=1){if(n){break da}if(g>>>0>62){break ba}c=_b(f,i);v[114578]=0;g=g+1|0;c=Q(497,c|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break ca}}g=P()|0;O()|0;break f}F=Qh(d+32|0);e=n&31;h=e>>>0<x[a+480188>>1];j=B(e,6)+c|0;if(n&32){v[114578]=0;R(473,d+16|0,b|0);e=v[114578];v[114578]=0;ea:{fa:{ga:{if((e|0)!=1){m=cd(d+16|0);e=w[d+16|0];if(e>>>0>239){break ga}e=(B(e>>>4|0,12)+(e&15)|0)+13|0;break fa}g=P()|0;O()|0;break f}ha:{switch(e-254|0){case 0:break fa;case 1:break ha;default:break ea}}e=0}t[(h?j:d+32|0)|0]=e}t[(h?j+1|0:E)|0]=w[m|0]}ia:{if(!(n&64)){break ia}v[114578]=0;e=T(389,b|0)|0;m=v[114578];v[114578]=0;ja:{if((m|0)!=1){m=h?j+2|0:D;t[d+16|0]=e;if(e<<24>>24>-1|e>>>0>192){break ja}t[m|0]=2;t[(h?j+4|0:z)|0]=w[d+16|0]^128;break ia}g=P()|0;O()|0;break f}t[m|0]=1;v[114578]=0;t[d|0]=64;e=Q(393,d+16|0,d|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break H}t[(h?j+4|0:z)|0]=w[e|0]}if(!(n&128)){break ca}v[114578]=0;R(473,d+16|0,b|0);e=v[114578];v[114578]=0;ka:{if((e|0)!=1){e=cd(d+16|0);m=h?j+3|0:C;t[m|0]=w[d+16|0];n=h?j+5|0:A;t[n|0]=w[e|0];Wy(h?j:F,0);la:{e=w[m|0];if((e|0)==20){if((w[n|0]&240)!=160){break ca}if((w[d+248|0]|w[d+249|0]<<8)>>>0<4896){break la}e=w[m|0]}if((e|0)!=31){break ca}e=w[n|0];if(e>>>0<=15){break ka}y=0;break ca}t[n|0]=w[n|0]&15^136;break ca}g=P()|0;O()|0;break f}if(e>>>0<=7){p=p+1|0;break ca}l=((e|0)!=8)+l|0}if(g>>>0<64){continue}break}}i=i+1|0;if((r|0)!=(i|0)){continue}break}break G}g=P()|0;O()|0;break f}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}if(!y){break F}a=x[a+480188>>1];if((a|0)>(l+p|0)|(a|0)<=(l-p|0)){break F}e=Ce(f)-1&65535;a=0;c=0;if(Ce(f)>>>0>e>>>0){while(1){if(mh(Ge(f,a))){b=bc(Ge(f,a));g=cc(Ge(f,a));a=jb-16|0;jb=a;v[a>>2]=g;v[a+8>>2]=b;if(Jb(a+8|0,a)){while(1){b=v[a+8>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Dj(a+8|0);if(Jb(a+8|0,a)){continue}break}}jb=a+16|0}c=c+1|0;a=c&65535;if(e>>>0>=a>>>0){continue}break}}}Cj(o);Cj(q);yb(k)}jb=d+304|0;return s|0}g=P()|0;O()|0}Cj(o);break d}g=P()|0;O()|0}Cj(q);break a}g=P()|0;O()|0;break a}g=P()|0;O()|0}yb(k);S(g|0);L()}function q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{b:{c:{d:{e:{f:{if(Vd(b,38235)){Wb(a);break f}if(Vd(b,38236)){b=jb-96|0;jb=b;d=Wb(a);v[114578]=0;Z(236,b- -64|0);a=v[114578];v[114578]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[114578]=0;v[b+32>>2]=0;R(2119,b+48|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}v[114578]=0;Q(1251,d|0,b+48|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break o}yb(b+48|0);v[114578]=0;Q(1996,d|0,38894)|0;a=v[114578];v[114578]=0;q:{if((a|0)==1){break q}v[114578]=0;v[b+32>>2]=5;R(2119,b+48|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[114578]=0;Q(1251,d|0,b+48|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}yb(b+48|0);v[114578]=0;Q(1996,d|0,38894)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;v[b+32>>2]=9;R(2119,b+48|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}v[114578]=0;Q(1251,d|0,b+48|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break k}yb(b+48|0);v[114578]=0;a=Q(85,b+48|0,38235)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}f=Fb(a);yb(a);if(!f){break i}v[114578]=0;Q(1996,d|0,38235)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}f=gh(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[114578]=0;v[b+12>>2]=a;R(2119,b+16|0,b+12|0);a=v[114578];v[114578]=0;if((a|0)==1){break D}v[114578]=0;U(2120,b+32|0,39478,b+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break C}v[114578]=0;R(1536,f|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break B}yb(b+32|0);yb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[114578]=0;c=Q(85,b+32|0,39480)|0;a=v[114578];v[114578]=0;if((a|0)==1){break z}v[114578]=0;R(1536,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break y}yb(c);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(c);break r}if(!w[(b- -64|0)+17|0]){break w}v[114578]=0;c=Q(85,b+32|0,39489)|0;a=v[114578];v[114578]=0;if((a|0)==1){break v}v[114578]=0;R(1536,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break u}yb(c)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(c);break r}v[114578]=0;c=Q(85,b+32|0,39495)|0;a=v[114578];v[114578]=0;E:{if((a|0)!=1){v[114578]=0;R(1536,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break E}yb(c);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(c);break r}if(md(f)){break g}v[114578]=0;Q(1996,d|0,39499)|0;a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;c=Q(85,b+16|0,38894)|0;a=v[114578];v[114578]=0;F:{G:{H:{if((a|0)!=1){v[114578]=0;U(2121,b+32|0,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break H}v[114578]=0;Q(1251,d|0,b+32|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break G}yb(b+32|0);yb(c);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;yb(b+32|0)}yb(c);break r}a=P()|0;O()|0}kd(f)}_e(b- -64|0);break c}kd(f);_e(b- -64|0);jb=b+96|0;break f}if(Vd(b,38252)){v[g>>2]=0;Tr(a,g);break f}if(Vd(b,38274)){v[g>>2]=5;Tr(a,g);break f}if(Vd(b,38296)){v[g>>2]=9;Tr(a,g);break f}if(Vd(b,38318)){f=jb-16|0;jb=f;b=jb-16|0;jb=b;v[b+12>>2]=38235;Ub(a,v[b+12>>2]);jb=b+16|0;jb=f+16|0;break f}if(Vd(b,38341)){b=Ub(g,38235);f=Fb(b);v[114578]=0;Q(85,a|0,(f?38370:38368)|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}yb(b);break f}if(Vd(b,38372)){b=jb-48|0;jb=b;dD(b+16|0);v[114578]=0;f=Q(2,b|0,39569)|0;c=v[114578];v[114578]=0;I:{J:{K:{L:{if((c|0)!=1){v[114578]=0;U(251,b+32|0,b+16|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break L}v[114578]=0;U(9,a|0,0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break K}yb(b+32|0);yb(f);yb(b+16|0);jb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;yb(b+32|0)}yb(f)}yb(b+16|0);break a}if(Vd(b,38389)){b=jb-16|0;jb=b;i=jb-16|0;jb=i;v[i+8>>2]=53;f=b;c=jb-176|0;jb=c;h=Gv(c+160|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[i+8>>2];if(d&1){v[114578]=0;v[c+144>>2]=19468288;R(242,c+96|0,c+144|0);d=v[114578];v[114578]=0;if((d|0)==1){break $}v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break _}yb(c+96|0);d=v[i+8>>2]}if(!(d&4)){break Y}v[114578]=0;d=da(243)|0;e=v[114578];v[114578]=0;if((e|0)==1){break X}if(!d){break Z}break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}v[114578]=0;Z(244,c+96|0);d=v[114578];v[114578]=0;aa:{if((d|0)!=1){v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break aa}yb(c+96|0);break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}ba:{d=v[i+8>>2];if(!(d&8)){break ba}v[114578]=0;d=Q(2,c+128|0,7142)|0;e=v[114578];v[114578]=0;ca:{da:{ea:{fa:{ga:{if((e|0)!=1){v[114578]=0;R(219,c+144|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break ga}v[114578]=0;U(245,c+96|0,c+144|0,7152);e=v[114578];v[114578]=0;if((e|0)==1){break fa}v[114578]=0;R(201,h|0,c+96|0);e=v[114578];v[114578]=0;if((e|0)==1){break ea}yb(c+96|0);Ib(c+144|0);yb(d);d=v[i+8>>2];break ba}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ca}a=P()|0;O()|0;break da}a=P()|0;O()|0;yb(c+96|0)}Ib(c+144|0)}yb(d);break N}ha:{if(!(d&16)){break ha}v[114578]=0;Z(236,c+96|0);d=v[114578];v[114578]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((d|0)!=1){v[114578]=0;R(246,c+144|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break ja}d=Wc(c+144|0);yb(c+144|0);if(!d){v[114578]=0;d=Q(2,c- -64|0,7156)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ga}v[114578]=0;R(219,c+80|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break Fa}v[114578]=0;R(246,c+48|0,c+96|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ea}v[114578]=0;U(247,c+144|0,c+80|0,c+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break Da}v[114578]=0;R(201,h|0,c+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ca}yb(c+144|0);yb(c+48|0);Ib(c+80|0);yb(d)}if(!Wc(Ug(c+96|0))){v[114578]=0;d=Q(2,c+32|0,7160)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ya}v[114578]=0;R(219,c+80|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break xa}e=Ug(c+96|0);v[114578]=0;U(247,c+144|0,c+80|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break wa}v[114578]=0;R(201,h|0,c+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break va}yb(c+144|0);Ib(c+80|0);yb(d)}v[114578]=0;R(248,c+144|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break sa}d=Wc(c+144|0);yb(c+144|0);if(!d){v[114578]=0;d=Q(2,c+16|0,7156)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ra}v[114578]=0;R(219,c+80|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break qa}v[114578]=0;R(248,c+48|0,c+96|0);e=v[114578];v[114578]=0;if((e|0)==1){break pa}v[114578]=0;U(247,c+144|0,c+80|0,c+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break oa}v[114578]=0;R(201,h|0,c+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break na}yb(c+144|0);yb(c+48|0);Ib(c+80|0);yb(d)}_e(c+96|0);d=v[i+8>>2];break ha}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;break Ba}a=P()|0;O()|0;yb(c+144|0)}yb(c+48|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ua}a=P()|0;O()|0;yb(c+144|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ka}a=P()|0;O()|0;break la}a=P()|0;O()|0;break ma}a=P()|0;O()|0;yb(c+144|0)}yb(c+48|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0}_e(c+96|0);break N}Ha:{if(!(d&32)){break Ha}v[114578]=0;d=da(243)|0;e=v[114578];v[114578]=0;if((e|0)==1){break X}if(d){break Ha}fd(c+96|0);v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break O}yb(c+96|0)}if(w[i+8|0]&64){v[114578]=0;Z(249,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break W}v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break V}yb(c+96|0)}v[114578]=0;d=Q(2,c+96|0,7166)|0;e=v[114578];v[114578]=0;if((e|0)==1){break U}v[114578]=0;U(250,c|0,h|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break T}v[114578]=0;e=Q(2,c+144|0,10991)|0;j=v[114578];v[114578]=0;if((j|0)==1){break S}v[114578]=0;U(251,f|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break R}yb(e);yb(c);yb(d);bl(h);jb=c+176|0;break M}a=P()|0;O()|0;break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;yb(e)}yb(c)}yb(d);break N}a=P()|0;O()|0;yb(c+96|0)}bl(h);S(a|0);L()}jb=i+16|0;v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38402)){b=jb-48|0;jb=b;Jq(b);v[114578]=0;R(246,b+32|0,b|0);f=v[114578];v[114578]=0;Ia:{Ja:{if((f|0)!=1){v[114578]=0;U(9,a|0,0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break Ja}yb(b+32|0);_e(b);jb=b+48|0;break f}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;yb(b+32|0)}_e(b);break a}if(Vd(b,38413)){b=jb-32|0;jb=b;Jq(b);f=Ug(b);v[114578]=0;U(9,a|0,0,f|0);a=v[114578];v[114578]=0;if((a|0)!=1){_e(b);jb=b+32|0;break f}a=P()|0;O()|0;_e(b);break a}if(Vd(b,38425)){b=jb-48|0;jb=b;Jq(b+16|0);Ka:{if(v[b+28>>2]){f=v[b+28>>2];v[114578]=0;v[b+12>>2]=f;R(2119,a|0,b+12|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Ka}a=P()|0;O()|0;_e(b+16|0);break a}Wb(a)}_e(b+16|0);jb=b+48|0;break f}if(Vd(b,38441)){Jq(g);b=w[g+16|0];v[114578]=0;Q(85,a|0,(b?38368:38370)|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_e(g);break f}a=P()|0;O()|0;_e(g);break a}if(Vd(b,38460)){Jq(g);b=w[g+17|0];v[114578]=0;Q(85,a|0,(b?38368:38370)|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_e(g);break f}a=P()|0;O()|0;_e(g);break a}if(Vd(b,38486)){Jq(g);b=w[g+18|0];v[114578]=0;Q(85,a|0,(b?38368:38370)|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_e(g);break f}a=P()|0;O()|0;_e(g);break a}if(Vd(b,38504)){b=jb-16|0;jb=b;f=jb-32|0;jb=f;c=fd(b);v[114578]=0;Z(236,f|0);d=v[114578];v[114578]=0;La:{Ma:{Na:{if((d|0)!=1){d=Ug(f);v[114578]=0;Q(237,c|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Na}_e(f);jb=f+32|0;break La}a=P()|0;O()|0;break Ma}a=P()|0;O()|0;_e(f)}yb(c);break a}v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38510)){d=jb-16|0;jb=d;b=jb+-64|0;jb=b;c=fd(d);v[114578]=0;f=Q(2,b+16|0,7127)|0;h=v[114578];v[114578]=0;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((h|0)!=1){v[114578]=0;R(219,b+32|0,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break Ua}v[114578]=0;v[b+12>>2]=13;v[b+8>>2]=0;v[b+4>>2]=0;fa(239,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);h=v[114578];v[114578]=0;if((h|0)==1){break Ta}v[114578]=0;Q(192,c|0,b+48|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Sa}yb(b+48|0);Ib(b+32|0);yb(f);jb=b- -64|0;break Oa}a=P()|0;O()|0;break Pa}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;break Ra}a=P()|0;O()|0;yb(b+48|0)}Ib(b+32|0)}yb(f)}yb(c);break a}v[114578]=0;U(9,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break f}a=P()|0;O()|0;break c}if(Vd(b,38525)){b=jb-16|0;jb=b;Cn(b,0,7349);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38533)){b=jb-48|0;jb=b;d=Ub(b+16|0,39574);v[114578]=0;R(2122,b|0,2);f=v[114578];v[114578]=0;Va:{Wa:{Xa:{Ya:{if((f|0)!=1){v[114578]=0;U(3,b+32|0,d|0,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ya}v[114578]=0;U(9,a|0,0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break Xa}yb(b+32|0);yb(b);yb(d);jb=b+48|0;break f}a=P()|0;O()|0;break Va}a=P()|0;O()|0;break Wa}a=P()|0;O()|0;yb(b+32|0)}yb(b)}break c}if(Vd(b,38541)){b=jb-16|0;jb=b;Cn(b,0,9345);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38549)){b=jb-16|0;jb=b;Hq(b,0);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38553)){b=jb-16|0;jb=b;Hq(b,2);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38571)){b=jb-16|0;jb=b;Hq(b,3);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}Wb(a)}jb=g+32|0;break d}a=P()|0;O()|0;yb(b);break a}return}yb(d);break a}a=P()|0;O()|0;yb(b)}S(a|0);L()}function XT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-288|0;jb=e;Jc(b);a:{if(SA(b,12222)){o=Wb(e+272|0);v[114578]=0;f=W(432,b|0,o|0,-1)|0;i=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((i|0)!=1){if(!f){break b}v[114578]=0;f=Q(447,b|0,e+264|0)|0;i=v[114578];v[114578]=0;u:{if((i|0)==1){break u}if(!f){break b}if(!RA(e+264|0)){break b}d=QA(e+264|0);v[114578]=0;d=Gg(448,d,mb);f=v[114578];v[114578]=0;if((f|0)==1){break u}v[114578]=0;f=Q(258,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}d=0;if(!f){break b}if(!c){break c}v[114578]=0;R(449,a|0,4096);d=v[114578];v[114578]=0;if((d|0)==1){break u}v[114578]=0;Q(450,a+1304400|0,o|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break u}v[114578]=0;d=Q(2,e+96|0,12230)|0;f=v[114578];v[114578]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){Gb(a+1304436|0,d);yb(d);v[114578]=0;d=Q(2,e+96|0,12194)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}Gb(a+1304448|0,d);yb(d);v[114578]=0;d=Q(2,e+248|0,12244)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}v[114578]=0;R(219,e+48|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break D}t[e+216|0]=w[e+264|1];f=w[e+264|0];v[114578]=0;t[e+8|0]=f;R(452,e+232|0,e+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break C}v[114578]=0;X(453,e+96|0,e+48|0,e+216|0,e+232|0);f=v[114578];v[114578]=0;if((f|0)==1){break B}Gb(a+1304460|0,e+96|0);yb(e+96|0);yb(e+232|0);Ib(e+48|0);yb(d);v[a+1304496>>2]=4;if(w[e+264|0]<2){break w}v[114578]=0;u[e+96>>1]=8192;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break y}v[114578]=0;u[e+48>>1]=d;d=Q(454,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break y}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[114578]=0;t[e+96|0]=1;d=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break x}v[114578]=0;t[e+48|0]=d;d=Q(455,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break x}v[a+480196>>2]=w[d|0];v[114578]=0;Q(340,b|0,3)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break v}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break z}b=P()|0;O()|0;break A}b=P()|0;O()|0;yb(e+232|0)}Ib(e+48|0)}yb(d);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[114578]=0;t[e+96|0]=32;d=T(389,b|0)|0;f=v[114578];v[114578]=0;G:{H:{if((f|0)==1){break H}v[114578]=0;t[e+48|0]=d;d=Q(455,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break H}v[a+480204>>2]=B(w[d|0],1e4);v[114578]=0;t[e+96|0]=1;d=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}v[114578]=0;t[e+48|0]=d;d=Q(455,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}v[a+480196>>2]=w[d|0];v[114578]=0;d=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break v}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[a+480208>>2]=d>>>2&16|12;n=Ql(e+232|0);m=Ql(e+216|0);I:{J:{if(!x[a+480192>>1]){break J}j=1;i=e+80|1;p=e+96|12;while(1){v[114578]=0;f=W(456,a|0,j&65535,0)|0;d=v[114578];v[114578]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[114578]=0;d=W(433,b|0,f+492|0,-1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break M}if(!d){break J}v[114578]=0;h=T(389,b|0)|0;d=v[114578];v[114578]=0;N:{O:{P:{Q:{if((d|0)!=1){Rb(e+96|0,0,120);if(!h){break K}if(w[e+264|0]){v[114578]=0;d=Q(457,b|0,e+96|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Q}if(!d){break K}}if(!w[e+264|0]){v[114578]=0;d=W(261,b|0,p|0,96)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Q}if(!d){break K}}g=f+236|0;d=0;while(1){l=w[(e+96|0)+d|0];k=x[a+480190>>1];r=dd(g,d),s=(k+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[114578]=0;d=f+48|0;U(458,e+8|0,d|0,b|0);g=v[114578];v[114578]=0;if((g|0)==1){break P}v[114578]=0;g=f+68|0;U(458,e+32|0,g|0,b|0);l=v[114578];v[114578]=0;if((l|0)==1){break P}v[114578]=0;l=f+88|0;U(458,e+88|0,l|0,b|0);k=v[114578];v[114578]=0;if((k|0)==1){break P}v[114578]=0;Q(459,b|0,e+80|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break O}v[f>>2]=(w[i|0]|w[i+1|0]<<8)&4095;f=w[i|0]|w[i+1|0]<<8;au(e+80|0,d,0);au(e+80|0,g,1);au(e+80|0,l,2);r=e,s=bc(d),v[r+48>>2]=s;r=e,s=cc(d),v[r+72>>2]=s;if(Jb(e+48|0,e+72|0)){break N}break L}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}while(1){R:{d=v[e+48>>2];t[e+68|0]=64;k=w[d+2|0];v[114578]=0;t[e+71|0]=((k<<6)- -64>>>0)/127;k=Q(393,e+68|0,e+71|0)|0;q=v[114578];v[114578]=0;if((q|0)==1){break R}t[d+2|0]=w[k|0];_d(e+48|0);if(Jb(e+48|0,e+72|0)){continue}break L}break}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}r=e,s=bc(g),v[r+48>>2]=s;r=e,s=cc(g),v[r+72>>2]=s;S:{if(!Jb(e+48|0,e+72|0)){break S}while(1){T:{d=v[e+48>>2];t[e+68|0]=64;g=w[d+2|0];v[114578]=0;t[e+71|0]=((g<<6)+128>>>0)/255;g=Q(393,e+68|0,e+71|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break T}t[d+2|0]=w[g|0];_d(e+48|0);if(Jb(e+48|0,e+72|0)){continue}break S}break}b=P()|0;O()|0;break e}r=e,s=bc(l),v[r+48>>2]=s;r=e,s=cc(l),v[r+72>>2]=s;U:{if(!Jb(e+48|0,e+72|0)){break U}l=1<<(f>>>12&3);while(1){k=v[e+48>>2];d=t[k+2|0];d=Hma(d^-128,d>>31^-1,l,0);g=mb;f=g;V:{if((f|0)>-1?1:(f|0)>=-1?d>>>0>=4294967292:0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break V}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}v[114578]=0;d=Gg(460,d,f);f=v[114578];v[114578]=0;if((f|0)!=1){t[k+2|0]=d^128;_d(e+48|0);if(Jb(e+48|0,e+72|0)){continue}break U}break}b=P()|0;O()|0;break e}d=x[a+480190>>1]+1|0;u[e+68>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){f=0;d=0;while(1){v[114578]=0;W(433,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Z}v[114578]=0;Q(461,b|0,e+48|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Y}v[114578]=0;R(462,e+48|0,(B(x[e+68>>1]+d|0,104)+a|0)+484380|0);d=v[114578];v[114578]=0;if((d|0)==1){break Y}d=w[e+80|0];g=w[e+67|0];v[114578]=0;u[e+72>>1]=d|f<<8&32512|((g&3)!=0)<<15;R(463,m|0,e+72|0);d=v[114578];v[114578]=0;if((d|0)==1){break X}f=f+1|0;d=f&65535;if(h>>>0<=d>>>0){break W}g=x[e+68>>1]+d|0;if(g>>>0<=3999){continue}break}}v[114578]=0;Q(340,b|0,20)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}v[114578]=0;R(463,n|0,e+68|0);d=v[114578];v[114578]=0;if((d|0)==1){break f}v[e+48>>2]=3999;d=x[a+480190>>1];v[114578]=0;v[e+72>>2]=d+h;d=Q(464,e+48|0,e+72|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}u[a+480190>>1]=v[d>>2]}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}d=Wb(e+96|0);v[114578]=0;f=W(432,b|0,d|0,-1)|0;i=v[114578];v[114578]=0;_:{$:{aa:{if((i|0)!=1){if(f){v[114578]=0;U(13,e+48|0,6,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break _}Gb(a+1304412|0,e+48|0);yb(e+48|0)}yb(d);f=0;while(1){v[114578]=0;d=(f<<5)+a|0;Z(434,d+480280|0);i=v[114578];v[114578]=0;if((i|0)==1){break aa}v[114578]=0;W(435,b|0,d+480289|0,-1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break aa}f=f+1|0;if((f|0)!=32){continue}break}v[114578]=0;d=Q(465,b|0,e+32|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}if(!d){break k}if((w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))>>>0<12){break o}d=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);v[114578]=0;d=Q(258,b|0,d-11|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}if(d){break $}break o}break p}b=P()|0;O()|0;break e}v[e+88>>2]=(w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))-11;j=rq(e+96|0);v[114578]=0;W(438,b|0,j|0,v[e+88>>2])|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;v[e+48>>2]=50529027;d=Q(333,e+88|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}v[e+80>>2]=B(v[d>>2],85);i=Wb(e+48|0);d=e+32|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;v[e+8>>2]=d;d=Q(333,e+80|0,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break t}d=v[d>>2];v[114578]=0;R(111,i|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break t}if(v[e+88>>2]){f=0;while(1){ba:{h=w[wc(j,f)|0];d=f+1|0;if(!((h|0)!=255|v[e+88>>2]-d>>>0<2)){d=t[wc(j,d)|0];h=w[wc(j,f+2|0)|0];r=e,s=sf(i),v[r+8>>2]=s;Md(e+24|0,e+8|0);v[114578]=0;aa(439,i|0,v[e+24>>2],h|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=f+3|0;break ba}break t}v[114578]=0;R(110,i|0,h<<24>>24);f=v[114578];v[114578]=0;if((f|0)!=1){break ba}break t}f=d;if(y[e+88>>2]>d>>>0){continue}break}}v[114578]=0;X(440,e+8|0,4,6,i|0);d=v[114578];v[114578]=0;ca:{if((d|0)!=1){Gb(i,e+8|0);yb(e+8|0);d=Tb(i);v[114578]=0;d=T(441,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}f=Fb(i);v[114578]=0;ea(442,a+1304424|0,d|0,f|0,74,0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ca}yb(i);fe(j);break o}break t}break t}break p}b=P()|0;O()|0;break e}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(i);break q}b=P()|0;O()|0;break q}b=P()|0;O()|0}fe(j);break e}b=P()|0;O()|0;yb(d);break e}d=Vb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[114578]=0;ea(443,d|0,b|0,f|0,65535,65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}j=c&1;if(j){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[114578]=0;R(403,a+484344|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break n}}d=e+264|3;da:{if(!(w[d|0]|w[d+1|0]<<8)){break da}i=a+484344|0;f=0;while(1){v[114578]=0;h=Q(258,b|0,4)|0;g=v[114578];v[114578]=0;ea:{if((g|0)!=1){if(h){break ea}break da}b=P()|0;O()|0;break e}v[114578]=0;h=T(392,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}v[114578]=0;U(343,e+96|0,b|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break i}fa:{if(!j){break fa}v[114578]=0;h=T(389,e+96|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}v[114578]=0;Q(340,e+96|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}v[114578]=0;h=W(404,i|0,f&65535,h+1|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}if(!h){break fa}v[114578]=0;W(436,e+96|0,e+48|0,-1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}h=_b(i,f);v[114578]=0;Q(437,h|0,e+48|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}h=_b(i,f);v[114578]=0;U(445,h|0,1,e+96|0);h=v[114578];v[114578]=0;if((h|0)==1){break g}}Bb(e+96|0);f=f+1|0;if(f>>>0<(w[d|0]|w[d+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break k}if(!x[a+480190>>1]){break l}d=0;while(1){if(w[rc(m,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=ad(e+96|0,u[f+484414>>1]&1?16:8,1,0,u[rc(m,d)>>1]>-1?0:6);v[114578]=0;W(402,d|0,f+484380|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break l}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}if(!x[a+480190>>1]){break k}b=0;while(1){c=w[rc(m,b)|0];ga:{if(!c){break ga}c=c-1&65535;if(oc(n)>>>0<=c>>>0){break ga}c=(w[rc(m,b)+1|0]&127)+x[rc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break ga}f=B(c,104);i=f+a|0;d=i+484380|0;if(!De(d)){break ga}j=a+484380|0;h=B(b+1|0,104);c=j+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[(f+j|0)+34>>1]&1;v[c>>2]=v[d>>2];v[114578]=0;c=T(466,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}if(!c){break ga}c=v[(a+h|0)+484400>>2];v[114578]=0;c=T(467,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}f=v[i+484400>>2];v[114578]=0;f=T(467,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}lc(c,f,Bj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}kf(m);kf(n);break c}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;Bb(e+96|0);break e}b=P()|0;O()|0}kf(m);kf(n)}yb(o);S(b|0);L()}d=1}yb(o)}jb=e+288|0;return d|0}V(0)|0;O()|0;Ab();L()}function k3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-48|0;jb=e;d=Ub(e+32|0,38719);f=uf(c,d);yb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){jj(a,0,v[b+24>>2]+1304448|0);break k}d=Ub(e+32|0,38724);f=uf(c,d);yb(d);if(f){jj(a,0,v[b+24>>2]+1304436|0);break k}d=Ub(e+32|0,38734);f=uf(c,d);yb(d);if(f){jj(a,0,v[b+24>>2]+1304484|0);break k}d=Ub(e+32|0,38747);f=uf(c,d);yb(d);if(f){jj(a,0,v[b+24>>2]+1304472|0);break k}d=Ub(e+32|0,38765);f=uf(c,d);yb(d);if(f){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=78736;l:{while(1){if((d|0)==v[b>>2]){Cn(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=78784){continue}break}fd(c)}v[114578]=0;U(9,a|0,0,e+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break j}yb(e+32|0);break k}d=Ub(e+32|0,38775);f=uf(c,d);yb(d);if(f){l=e+32|0;g=v[v[b+24>>2]+480184>>2];c=jb-48|0;jb=c;b=78736;i=jb-16|0;jb=i;j=i+8|0;d=jb-16|0;jb=d;v[114578]=0;h=c+32|0;f=h;T(1523,f+4|0)|0;m=v[114578];v[114578]=0;m:{n:{o:{if((m|0)!=1){v[114578]=0;v[d+12>>2]=0;W(1524,f+8|0,d+12|0,j|0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break o}break n}break n}q=f,r=hc(f),v[q>>2]=r;jb=d+16|0;break m}V(0)|0;O()|0;Ab();L()}jb=i+16|0;d=fd(l);while(1){if((g|0)==v[b>>2]){f=v[b+4>>2];v[114578]=0;f=Q(2,c+16|0,f|0)|0;i=v[114578];v[114578]=0;p:{q:{r:{s:{t:{u:{if((i|0)!=1){v[114578]=0;U(1522,c|0,h|0,f|0);i=v[114578];v[114578]=0;if((i|0)==1){break s}if(!w[c+4|0]){break p}if(!Wc(d)){v[114578]=0;i=Q(2,c|0,20816)|0;l=v[114578];v[114578]=0;if((l|0)==1){break u}v[114578]=0;Q(192,d|0,i|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break t}yb(i)}v[114578]=0;Q(192,d|0,f|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break p}b=P()|0;O()|0;break r}b=P()|0;O()|0;break q}b=P()|0;O()|0;break r}b=P()|0;O()|0;yb(i);break r}b=P()|0;O()|0}yb(f)}yb(d);VK(h);S(b|0);L()}yb(f)}b=b+12|0;if((b|0)!=78784){continue}break}VK(h);jb=c+48|0;v[114578]=0;U(9,a|0,0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,38790);f=uf(c,d);yb(d);if(f){jj(a,0,v[b+24>>2]+1304460|0);break k}d=Ub(e+32|0,38798);f=uf(c,d);yb(d);if(f){jj(a,0,v[b+24>>2]+1304412|0);break k}d=Ub(e+32|0,38805);f=uf(c,d);yb(d);if(f){Af(e+32|0,v[b+24>>2]+1304400|0);v[114578]=0;U(2186,a|0,b|0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,38811);f=uf(c,d);yb(d);if(f){v:{if(!md(Pw(v[b+24>>2]))){if(v[OH(Pw(v[b+24>>2]))+12>>2]){break v}}Wb(a);break k}b=OH(Pw(v[b+24>>2]));g=jb-192|0;jb=g;lc(g+144|0,b,44);h=v[b+44>>2];if(h){lc(g+44|0,b,44);c=jb-16|0;jb=c;b=Vv(v[g+64>>2]+1900|0,v[g+60>>2]+1|0,v[g+56>>2])-Vv(1970,1,1)|0;b=Hma(b,b>>31,86400,0);d=B(v[g+52>>2],3600);f=d;b=b+d|0;d=mb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[g+48>>2],60);i=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<i>>>0?b+1|0:b;d=v[g+44>>2];i=d;f=d+f|0;d=(d>>31)+b|0;b=EF(c+8|0,f,f>>>0<i>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];jb=c+16|0;v[g+96>>2]=b;v[g+100>>2]=d;m=g+96|0;d=g+88|0;f=v[g+96>>2];i=v[g+100>>2];c=2147483647;n=Sd(+(h>>>0)*.054945054945054944);b=-1;w:{if(!(n<0x8000000000000000)){break w}c=-2147483648;b=0;if(!(n>-0x8000000000000000)){break w}if(D(n)<0x8000000000000000){c=D(n)>=1?~~(n>0?F(H(n*2.3283064365386963e-10),4294967295):I((n-+(~~n>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~n>>>0;break w}b=0}k=d;d=c+i|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=EF(k,f,d);j=jb-16|0;jb=j;h=v[b>>2];o=v[b+4>>2];v[j+12>>2]=0;v[j+8>>2]=0;v[j+4>>2]=0;b=Vv(1970,1,1)+Ima(h,o,86400,0)|0;l=b>>31;c=b;d=Hma(b,l,1e4,0)+14780|0;b=mb;i=d;b=d>>>0<14780?b+1|0:b;f=b;d=Ima(d,b,-14609700,-1);b=c;k=d+b|0;d=l+mb|0;d=b>>>0>k>>>0?d+1|0:d;b=k;k=Ima(i,f,365242500,0);b=b+k|0;d=mb+d|0;d=b>>>0<k>>>0?d+1|0:d;k=Ima(i,f,-146097e4,-1);b=k+b|0;d=mb+d|0;d=b>>>0<k>>>0?d+1|0:d;k=b;b=Ima(i,f,3652425,0);f=mb;p=f;i=k;k=Hma(b,f,-365,-1);i=i+k|0;f=mb+d|0;f=i>>>0<k>>>0?f+1|0:f;d=f;if(!((d|0)>0?1:(d|0)>=0)){d=p-(b>>>0<1)|0;b=b-1|0;f=Hma(b,d,-365,-1)+c|0;d=l+mb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;i=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=(b|0)/100|0;i=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<i>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;i=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<i>>>0?d+1|0:d;i=f}f=b;c=Hma(i,d,100,0)+52|0;b=mb;b=Ima(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[j+12>>2]=f+d;v[j+8>>2]=(c-B(d,12)|0)+1;b=Hma(b,mb,306,0)+5|0;d=mb;b=Ima(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[j+4>>2]=b+1;vF(m);v[m+20>>2]=v[j+12>>2]-1900;v[m+16>>2]=v[j+8>>2]-1;b=v[j+4>>2];q=m,r=Jma(Ima(h,o,3600,0),mb,24),v[q+8>>2]=r;v[m+12>>2]=b;b=Ima(h,o,60,0);c=mb;q=m,r=Jma(b,c,60),v[q+4>>2]=r;q=m,r=h-Hma(b,c,60,0)|0,v[q>>2]=r;jb=j+16|0;lc(g+144|0,g+96|0,44)}i=e+32|0;l=lc(g,g+144|0,44);c=l;b=jb-112|0;jb=b;d=fd(b+96|0);v[114578]=0;f=Q(2,b+80|0,6848)|0;h=v[114578];v[114578]=0;x:{y:{z:{A:{B:{if((h|0)!=1){h=v[c+20>>2];if(!h){break y}v[114578]=0;v[b+48>>2]=h+1900;R(191,b- -64|0,b+48|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;Q(192,d|0,b- -64|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break B}yb(b- -64|0);if(y[c+16>>2]>11){break y}v[114578]=0;h=Q(2,b+48|0,6850)|0;g=v[114578];v[114578]=0;C:{D:{E:{F:{G:{H:{if((g|0)!=1){g=v[c+16>>2];v[114578]=0;v[b+16>>2]=g+1;R(193,b+32|0,b+16|0);g=v[114578];v[114578]=0;if((g|0)==1){break H}v[114578]=0;U(3,b- -64|0,h|0,b+32|0);g=v[114578];v[114578]=0;if((g|0)==1){break G}v[114578]=0;Q(192,d|0,b- -64|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break F}yb(b- -64|0);yb(b+32|0);yb(h);if(v[c+12>>2]-1>>>0<=30){break C}break y}a=P()|0;O()|0;break A}a=P()|0;O()|0;break D}a=P()|0;O()|0;break E}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(h);break A}v[114578]=0;h=Q(2,b+48|0,6850)|0;g=v[114578];v[114578]=0;I:{J:{K:{L:{M:{N:{O:{if((g|0)!=1){v[114578]=0;R(193,b+32|0,c+12|0);g=v[114578];v[114578]=0;if((g|0)==1){break O}v[114578]=0;U(3,b- -64|0,h|0,b+32|0);g=v[114578];v[114578]=0;if((g|0)==1){break N}v[114578]=0;Q(192,d|0,b- -64|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break M}yb(b- -64|0);yb(b+32|0);yb(h);h=v[c+8>>2];if(h){break J}if(v[c+4>>2]){break I}if(!v[c>>2]){break y}break I}a=P()|0;O()|0;break A}a=P()|0;O()|0;break K}a=P()|0;O()|0;break L}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(h);break A}if(h>>>0>23){break y}}if(y[c+4>>2]>59){break y}v[114578]=0;h=Q(2,b- -64|0,6852)|0;g=v[114578];v[114578]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((g|0)!=1){v[114578]=0;Q(192,d|0,h|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ga}yb(h);if(v[c+32>>2]>=1){v[114578]=0;h=Q(2,b- -64|0,6854)|0;g=v[114578];v[114578]=0;if((g|0)==1){break fa}Gb(f,h);yb(h)}v[114578]=0;R(193,b+32|0,c+8|0);h=v[114578];v[114578]=0;if((h|0)==1){break ea}v[114578]=0;h=Q(2,b+16|0,6861)|0;g=v[114578];v[114578]=0;if((g|0)==1){break da}v[114578]=0;U(3,b+48|0,b+32|0,h|0);g=v[114578];v[114578]=0;if((g|0)==1){break ca}v[114578]=0;R(193,b|0,c+4|0);g=v[114578];v[114578]=0;if((g|0)==1){break ba}v[114578]=0;U(3,b- -64|0,b+48|0,b|0);g=v[114578];v[114578]=0;if((g|0)==1){break aa}v[114578]=0;Q(192,d|0,b- -64|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break $}yb(b- -64|0);yb(b);yb(b+48|0);yb(h);yb(b+32|0);if(y[c>>2]<62){break W}v[114578]=0;U(194,i|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break V}break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(h);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break X}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Z}a=P()|0;O()|0;break _}a=P()|0;O()|0;yb(b- -64|0)}yb(b)}yb(b+48|0)}yb(h)}yb(b+32|0);break A}v[114578]=0;h=Q(2,b+48|0,6861)|0;g=v[114578];v[114578]=0;if((g|0)==1){break U}v[114578]=0;R(193,b+32|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break T}v[114578]=0;U(3,b- -64|0,h|0,b+32|0);c=v[114578];v[114578]=0;if((c|0)==1){break S}v[114578]=0;Q(192,d|0,b- -64|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break R}yb(b- -64|0);yb(b+32|0);yb(h);v[114578]=0;Q(192,d|0,f|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break y}}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(h);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break z}a=P()|0;O()|0;yb(b- -64|0)}yb(f)}yb(d);S(a|0);L()}td(i,d)}yb(f);yb(d);jb=b+112|0;jb=l+192|0;v[114578]=0;U(9,a|0,0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,38816);f=uf(c,d);yb(d);if(f){c=b;wO(e+32|0,v[b+24>>2]+1304424|0);ha:{ia:{ja:{if(!Wc(e+32|0)){break ja}c=v[c+24>>2];v[114578]=0;c=T(2187,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ha}ka:{switch(c|0){case 0:v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ja}c=P()|0;O()|0;break b;case 1:v[114578]=0;R(2189,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ja}c=P()|0;O()|0;break b;case 2:if(Wc(e+32|0)){v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}Gb(e+32|0,e+16|0);yb(e+16|0)}if(!Wc(e+32|0)){break ja}v[114578]=0;R(2189,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ja}c=P()|0;O()|0;break b;case 3:if(Wc(e+32|0)){v[114578]=0;R(2189,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}Gb(e+32|0,e+16|0);yb(e+16|0)}if(!Wc(e+32|0)){break ja}v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ja}c=P()|0;O()|0;break b;case 4:v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;la:{ma:{if((c|0)!=1){v[114578]=0;R(2189,e|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break la}if(Wc(e+16|0)){break ma}v[114578]=0;Q(1251,e+32|0,e+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break ma}break d}c=P()|0;O()|0;break b}if(!Wc(e)){v[114578]=0;Q(1251,e+32|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}}yb(e);yb(e+16|0);break ja}c=P()|0;O()|0;break c;case 5:break ka;default:break ja}}v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;na:{if((c|0)!=1){v[114578]=0;R(2189,e|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break ia}if(Wc(e)){break na}v[114578]=0;Q(1251,e+32|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break na}break f}c=P()|0;O()|0;break b}if(!Wc(e+16|0)){v[114578]=0;Q(1251,e+32|0,e+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}}yb(e);yb(e+16|0)}v[114578]=0;U(2186,a|0,b|0,e+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break ha}yb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Ub(e+32|0,38824);f=uf(c,d);yb(d);if(f){wO(e+32|0,v[b+24>>2]+1304424|0);v[114578]=0;U(2186,a|0,b|0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}f=c;c=Ub(e+32|0,38836);d=uf(f,c);yb(c);if(d){a=Wb(a);b=b+68|0;q=e,r=bc(b),v[q+32>>2]=r;q=e,r=cc(b),v[q+16>>2]=r;if(!Jb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[114578]=0;Q(1996,a|0,38845)|0;c=v[114578];v[114578]=0;if((c|0)==1){break g}}v[114578]=0;Q(1251,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}zn(e+32|0);c=0;if(Jb(e+32|0,e+16|0)){continue}break}break k}Ub(a,38235)}jb=e+48|0;return}c=P()|0;O()|0;yb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(a);break a}c=P()|0;O()|0;yb(e)}yb(e+16|0);break b}c=P()|0;O()|0;yb(e)}yb(e+16|0)}yb(e+32|0)}S(c|0);L()}function od(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=jb-16|0;jb=m;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){f=v[115886];i=a>>>0<11?16:a+11&-8;c=i>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+463592>>2];a=e+8|0;c=v[e+8>>2];b=b+463584|0;m:{if((c|0)==(b|0)){n=463544,o=Lma(-2,d)&f,v[n>>2]=o;break m}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[115888];if(k>>>0>=i>>>0){break l}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+463592>>2];b=v[g+8>>2];a=a+463584|0;n:{if((b|0)==(a|0)){f=Lma(-2,c)&f;v[115886]=f;break n}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=i|3;d=g+i|0;b=c<<3;e=b-i|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+463584|0;g=v[115891];b=1<<b;o:{if(!(b&f)){v[115886]=b|f;b=c;break o}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[115891]=d;v[115888]=e;break a}h=v[115887];if(!h){break l}b=(h&0-h)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+463848>>2];d=(v[b+4>>2]&-8)-i|0;c=b;while(1){p:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break p}}c=(v[a+4>>2]&-8)-i|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}j=b+i|0;if(j>>>0<=b>>>0){break k}l=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}i=-1;if(a>>>0>4294967231){break l}a=a+11|0;i=a&-8;j=v[115887];if(!j){break l}f=31;d=0-i|0;if(i>>>0<=16777215){a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|i>>>a+21&1)+28|0}c=v[(f<<2)+463848>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=i<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-i|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){a=2<<f;a=(0-a|a)&j;if(!a){break l}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+463848>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-i|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[115888]-i>>>0<=d>>>0){break l}h=e+i|0;if(h>>>0<=e>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[115888];if(c>>>0>=i>>>0){d=v[115891];b=c-i|0;u:{if(b>>>0>=16){v[115888]=b;a=d+i|0;v[115891]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=i|3;break u}v[115891]=0;v[115888]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}h=v[115889];if(h>>>0>i>>>0){b=h-i|0;v[115889]=b;c=v[115892];a=c+i|0;v[115892]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}a=0;j=i+47|0;b=j;if(v[116004]){c=v[116006]}else{v[116007]=-1;v[116008]=-1;v[116005]=4096;v[116006]=4096;v[116004]=m+12&-16^1431655768;v[116009]=0;v[115997]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=i>>>0){break a}d=v[115996];if(d){b=v[115994];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[463988]&4){break f}v:{w:{d=v[115892];if(d){a=463992;while(1){b=v[a>>2];if(d>>>0<b+v[a+4>>2]>>>0?b>>>0<=d>>>0:0){break w}a=v[a+8>>2];if(a){continue}break}}b=Xk(0);if((b|0)==-1){break g}f=c;d=v[116005];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=i>>>0|f>>>0>2147483646){break g}d=v[115996];if(d){a=v[115994];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=Xk(f);if((b|0)!=(a|0)){break v}break e}f=e&g-h;if(f>>>0>2147483646){break g}b=Xk(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|i+48>>>0<=f>>>0)){b=v[116006];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Xk(b)|0)!=-1){f=b+f|0;b=a;break e}Xk(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}L()}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115997]=v[115997]|4}if(c>>>0>2147483646){break d}b=Xk(c);a=Xk(0);if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=i+40>>>0){break d}}a=v[115994]+f|0;v[115994]=a;if(a>>>0>y[115995]){v[115995]=a}x:{y:{z:{g=v[115892];if(g){a=463992;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break z}a=v[a+8>>2];if(a){continue}break}break y}a=v[115890];if(!(a>>>0<=b>>>0?a:0)){v[115890]=b}a=0;v[115999]=f;v[115998]=b;v[115894]=-1;v[115895]=v[116004];v[116001]=0;while(1){d=a<<3;c=d+463584|0;v[d+463592>>2]=c;v[d+463596>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115889]=c;a=a+b|0;v[115892]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115893]=v[116008];break x}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break y}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[115892]=c;b=v[115889]+f|0;a=b-a|0;v[115889]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[115893]=v[116008];break x}if(y[115890]>b>>>0){v[115890]=b}c=b+f|0;a=463992;A:{B:{C:{D:{E:{F:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break F}break}if(!(w[a+12|0]&8)){break E}}a=463992;while(1){c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break D}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=i|3;f=c+(c+8&7?-8-c&7:0)|0;h=i+j|0;c=f-h|0;if((f|0)==(g|0)){v[115892]=h;a=v[115889]+c|0;v[115889]=a;v[h+4>>2]=a|1;break B}if(v[115891]==(f|0)){v[115891]=h;a=v[115888]+c|0;v[115888]=a;v[h+4>>2]=a|1;v[a+h>>2]=a;break B}a=v[f+4>>2];if((a&3)==1){g=a&-8;G:{if(a>>>0<=255){d=v[f+8>>2];a=a>>>3|0;b=v[f+12>>2];if((b|0)==(d|0)){n=463544,o=v[115886]&Lma(-2,a),v[n>>2]=o;break G}v[d+12>>2]=b;v[b+8>>2]=d;break G}i=v[f+24>>2];b=v[f+12>>2];H:{if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break H}I:{a=f+20|0;d=v[a>>2];if(d){break I}a=f+16|0;d=v[a>>2];if(d){break I}b=0;break H}while(1){e=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[e>>2]=0}if(!i){break G}d=v[f+28>>2];a=(d<<2)+463848|0;J:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break J}n=463548,o=v[115887]&Lma(-2,d),v[n>>2]=o;break G}v[i+(v[i+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break G}}v[b+24>>2]=i;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break G}v[b+20>>2]=a;v[a+24>>2]=b}f=f+g|0;c=c+g|0}v[f+4>>2]=v[f+4>>2]&-2;v[h+4>>2]=c|1;v[c+h>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;K:{if(!(c&a)){v[115886]=a|c;a=b;break K}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break B}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;e=(a<<2)+463848|0;d=v[115887];b=1<<a;L:{if(!(d&b)){v[115887]=b|d;v[e>>2]=h;v[h+24>>2]=e;break L}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break C}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=h;v[h+24>>2]=d}v[h+12>>2]=h;v[h+8>>2]=h;break B}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115889]=c;a=a+b|0;v[115892]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115893]=v[116008];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116001];v[c+16>>2]=v[116e3];v[c+20>>2]=a;a=v[115999];v[c+8>>2]=v[115998];v[c+12>>2]=a;v[116e3]=c+8;v[115999]=f;v[115998]=b;v[116001]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break x}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;M:{if(!(c&a)){v[115886]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break x}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+463848|0;c=v[115887];b=1<<a;N:{if(!(c&b)){v[115887]=b|c;v[d>>2]=g;v[g+24>>2]=d;break N}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break A}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break x}a=v[d+8>>2];v[a+12>>2]=h;v[d+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=d;v[h+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[115889];if(a>>>0<=i>>>0){break d}b=a-i|0;v[115889]=b;c=v[115892];a=c+i|0;v[115892]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}v[114552]=48;a=0;break a}O:{if(!f){break O}c=v[e+28>>2];a=(c<<2)+463848|0;P:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break P}j=Lma(-2,c)&j;v[115887]=j;break O}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break O}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break O}v[b+20>>2]=a;v[a+24>>2]=b}Q:{if(d>>>0<=15){a=d+i|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break Q}v[e+4>>2]=i|3;v[h+4>>2]=d|1;v[d+h>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;R:{if(!(c&a)){v[115886]=a|c;a=b;break R}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break Q}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;c=(a<<2)+463848|0;S:{b=1<<a;T:{if(!(b&j)){v[115887]=b|j;v[c>>2]=h;v[h+24>>2]=c;break T}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);i=v[c>>2];while(1){b=i;if((v[b+4>>2]&-8)==(d|0)){break S}c=a>>>29|0;a=a<<1;c=b+(c&4)|0;i=v[c+16>>2];if(i){continue}break}v[c+16>>2]=h;v[h+24>>2]=b}v[h+12>>2]=h;v[h+8>>2]=h;break Q}a=v[b+8>>2];v[a+12>>2]=h;v[b+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=b;v[h+8>>2]=a}a=e+8|0;break a}U:{if(!l){break U}c=v[b+28>>2];a=(c<<2)+463848|0;V:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break V}n=463548,o=Lma(-2,c)&h,v[n>>2]=o;break U}v[(v[l+16>>2]==(b|0)?16:20)+l>>2]=e;if(!e){break U}}v[e+24>>2]=l;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break U}v[e+20>>2]=a;v[a+24>>2]=e}W:{if(d>>>0<=15){a=d+i|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break W}v[b+4>>2]=i|3;v[j+4>>2]=d|1;v[d+j>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+463584|0;e=v[115891];a=1<<a;X:{if(!(a&f)){v[115886]=a|f;a=c;break X}a=v[c+8>>2]}v[c+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=c;v[e+8>>2]=a}v[115891]=j;v[115888]=d}a=b+8|0}jb=m+16|0;return a|0}function Zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=jb+-64|0;jb=f;Jc(a);a:{b:{if(b>>>0<=2){C=f,D=Gd(a),t[C+56|0]=D;$b(a,2);e=f+56|2;b=hg(a);t[e|0]=b;t[e+1|0]=b>>>8;e=f+56|4;b=Cf(a);t[e|0]=b;t[e+1|0]=b>>>8;t[e+2|0]=b>>>16;t[e+3|0]=b>>>24;break b}Ef(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{n=d+484344|0;b=f+56|2;r=Fd(w[b|0]|w[b+1|0]<<8,1,1024);m=nx(n,r,0);if((m|0)!=65535){e=Rn(_b(n,m),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];s=x[lf(f,f+40|0)>>1];g=s+1|0;if(x[d+480188>>1]>(g&65535)>>>0){b=g&65535;while(1){t[e+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Qt(f+40|0,g,f);if(r){b=(b|0)!=0;while(1){d:{e:{if(!w[wc(o,0)|0]){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}l=g<<24>>24;if((l|0)<=-1){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}C=wc(o,0),D=g,t[C|0]=D}y=0;t[f|0]=0;h=l&63;f:{g:{if(!h){break g}v[114578]=0;e=T(389,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}t[f|0]=e;l=0;h:{switch(h-1|0){case 0:t[c+12|0]=0;v[114578]=0;t[f+36|0]=1;e=Q(455,f+36|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){t[c+14|0]=w[e|0];t[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}t[c+15|0]=e;b=1;t[c+12|0]=1;g=w[c+13|0];if(!g){break g}t[c+14|0]=B(B(e,g),15);break g;case 2:e=e>>>4|0;t[c+13|0]=e;if(e){b=w[c+12|0]!=0;break f}t[c+12|0]=0;break f;case 3:l=e;break f;case 5:if(!e){break f}b=(w[c+12|0]?15:14)+c|0;g=w[b|0];t[b|0]=g>>>0<256-e>>>0?e+g|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(w[c+12|0]?15:14)+c|0;l=w[g|0];t[g|0]=l>>>0>e+1>>>0?l-e|0:1}l=0}v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d}l=0;e=wc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;y=0;if(!(b&1)){break d}}b=w[c+12|0];e=w[c+13|0];if(e?0:b){break d}i:{if(b){v[f>>2]=1;b=w[c+15|0];v[114578]=0;v[f+28>>2]=B(b,e)<<1;e=Q(552,f|0,f+28|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}e=v[e>>2];break i}e=B(w[c+14|0],30)+30|0}b=255;j:{while(1){h=B(b,e);if(h-1536>>>0<10752){break j}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(h|0)/48;ce(f+32|0,32,255);v[114578]=0;v[f>>2]=1;e=Q(552,f|0,f+36|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}t[c+16|0]=v[e>>2];y=1}b=_b(n,m);v[114578]=0;b=W(472,b|0,k|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(s){z=k-1|0;i=1;p=1;while(1){k:{if(!w[wc(o,i)|0]){v[114578]=0;j=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(j&128){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}C=wc(o,i),D=g,t[C|0]=D}A=1;if(j&64){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[b+1|0]=g;A=!g}l:{if(!(j&32)){break l}v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[b|0]=g;if((g-1&255)>>>0<=107){e=Rp(g+24|0);t[b|0]=e;C=Nc(c,i),D=e,t[C+1|0]=D;break l}if((g+127&255)>>>0<=107){e=Rp((g&127)+24|0);t[b|0]=e;C=Nc(c,i),D=e,t[C|0]=D;t[b|0]=0;break l}if((g|0)!=255){break l}t[b|0]=254}if(!(w[b|0]|!w[b+1|0])){e=w[Nc(c,i)+1|0];t[b+1|0]=0;t[b|0]=e}v[114578]=0;g=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(g){C=Nc(c,i),D=0,t[C+5|0]=D}t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;t[f+22|0]=0;if(j&16){t[b+2|0]=1;v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[b+4|0]=g+2>>>2}m:{if(!(j&8)){break m}v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;t[f+27|0]=g;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+24|0]=g;n:{o:{p:{q:{r:{s:{t:{u:{e=w[f+27|0];switch(e-1|0){case 0:break o;case 9:break p;case 5:case 6:case 7:case 8:break q;case 4:break r;case 3:break s;case 2:break t;case 1:break u;default:break n}}t[b|0]=255;break n}C=b,D=w[Nc(c,i)+1|0],t[C|0]=D;C=Nc(c,i),D=0,t[C+5|0]=D;break n}e=Pt(g,w[c+16|0]);t[f+24|0]=e;v:{if(e){t[f+27|0]=20;t[f+24|0]=e|208;break v}t[f+27|0]=0}if(w[b|0]){break m}C=b,D=w[Nc(c,i)+1|0],t[C|0]=D;C=Nc(c,i),D=0,t[C+5|0]=D;break m}t[f|0]=1;e=Pt(g,w[c+16|0]);v[114578]=0;t[f+28|0]=e;g=Q(455,f|0,f+28|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[f+24|0]=w[g|0];t[f+27|0]=15;C=Nc(c,i),D=0,t[C+5|0]=D;break m}break c}w:{if(!k){break w}if((e|0)==w[Nc(c,i)+4|0]){break w}h=_b(n,m);v[114578]=0;g=W(498,f|0,20,(w[f+27|0]+122|160)&255)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}e=Gn(Fn(Ne(g,z),p&65535));v[114578]=0;g=Q(499,h|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break w}e=w[f+27|0];C=Nc(c,i),D=e,t[C+4|0]=D}t[f+27|0]=10;if(!w[b|0]){C=b,D=w[Nc(c,i)+1|0],t[C|0]=D}C=Nc(c,i),D=0,t[C+5|0]=D;break m}t[f+27|0]=20;C=f,D=w[Nc(c,i)+5|0]?-98:-97,t[C+24|0]=D;e=w[Nc(c,i)+5|0];C=Nc(c,i),D=e^1,t[C+5|0]=D;break m}t[b|0]=254}t[f+27|0]=0}q=0;g=0;x:{if(!(j&4)){break x}v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;t[f+26|0]=g;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}g=g<<24>>24;t[f+23|0]=g;e=f;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{h=w[f+26|0];switch(h-1|0){case 11:break A;case 10:break B;case 7:case 8:case 9:break C;case 6:break D;case 5:break E;case 3:case 4:break F;case 2:break G;case 1:break H;case 0:break I;default:break z}}e=(g|0)>-1;t[f+26|0]=e?2:3;if(!e){g=0-g|0;t[f+23|0]=g}J:{if((g&255)>>>0<16){break J}v[114578]=0;g=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break J}K:{if(w[f+26|0]==2){e=w[b|0];v[114578]=0;v[f>>2]=e+(w[f+23|0]>>>4|0);v[f+28>>2]=120;g=Q(464,f|0,f+28|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break K}break c}e=w[b|0];v[114578]=0;v[f>>2]=e-(w[f+23|0]>>>4|0);v[f+28>>2]=1;g=Q(552,f|0,f+28|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}}t[b|0]=v[g>>2];t[f+23|0]=w[f+23|0]&15}v[114578]=0;t[f|0]=15;g=Q(393,f|0,f+23|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[f+23|0]=w[g|0]|240;g=0;break x}break c}e=Pt(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|208;g=1;break x}t[f+26|0]=0;g=1;break x}g=1;break y}e=w[c+16|0];v[114578]=0;g=W(554,g&255,e|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+23|0]=g;t[f+26|0]=w[f+26|0]==4?2:3;g=1;break x}if(!w[b|0]){C=b,D=w[Nc(c,i)|0],t[C|0]=D;g=w[f+23|0]}e=w[c+16|0];v[114578]=0;g=W(554,g&255,e|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+26|0]=4;t[f+23|0]=g;g=1;break x}C=b,D=Rp((g&255)+25|0),t[C|0]=D;t[f+23|0]=255;t[f+26|0]=4;g=1;break x}L:{if(!k){break L}if((h|0)==w[Nc(c,i)+2|0]){break L}h=_b(n,m);v[114578]=0;g=W(498,f|0,20,(w[f+26|0]-8|48)&255)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}e=Gn(Fn(Ne(g,z),p&65535));v[114578]=0;g=Q(499,h|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break L}e=w[f+26|0];C=Nc(c,i),D=e,t[C+2|0]=D}t[f+26|0]=5;e=w[c+16|0];v[114578]=0;g=Q(555,w[f+23|0],e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+23|0]=g;g=1;break x}e=hT(g&255,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=e;g=1;break x}e=Pt(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|192;g=1;break x}t[f+26|0]=0;t[b|0]=254;g=1;break x}g=0}t[e+26|0]=g}M:{if(!(j&2)){break M}v[114578]=0;h=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;t[f+25|0]=h;j=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+22|0]=j;N:{O:{P:{Q:{R:{S:{T:{h=w[f+25|0];switch(h-1|0){case 9:break O;case 7:case 8:break P;case 6:break Q;case 3:case 4:case 5:break R;case 2:break S;case 0:case 1:break T;default:break N}}e=w[c+16|0];v[114578]=0;h=W(556,j|0,e|0,(h|0)==1|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+25|0]=11;t[f+22|0]=h;q=1;break M}e=hT(j,w[c+16|0]);t[f+25|0]=18;t[f+22|0]=e;q=1;break M}U:{if(!k){break U}if((h|0)==w[Nc(c,i)+3|0]){break U}j=_b(n,m);v[114578]=0;h=W(498,f|0,20,(w[f+25|0]-4|64)&255)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}e=Gn(Fn(Ne(h,z),p&65535));v[114578]=0;h=Q(499,j|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!h){break U}e=w[f+25|0];C=Nc(c,i),D=e,t[C+3|0]=D}t[f+25|0]=8;e=w[c+16|0];v[114578]=0;h=Q(555,w[f+22|0],e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+22|0]=h;q=1;break M}t[f+25|0]=9;break M}e=w[c+16|0];v[114578]=0;h=W(556,j|0,e|0,(h|0)==8|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+25|0]=29;t[f+22|0]=h;q=1;break M}t[f+25|0]=27;e=w[c+16|0];v[114578]=0;h=Q(555,j|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+22|0]=h;q=1;break M}t[f+25|0]=0}if(g){gT(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}if(q){gT(b,k,x[d+480188>>1],w[f+25|0],f+22|0)}V:{if(!A){break V}v[114578]=0;g=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break V}e=w[f+26|0];if(!e){t[f+23|0]=255;t[f+26|0]=4;break V}if(w[f+25|0]|(e|0)==4){break V}t[f+22|0]=255;t[f+25|0]=4}W:{if(w[b+2|0]!=1){break W}X:{if(!w[f+26|0]){t[f+26|0]=13;t[f+23|0]=w[b+4|0];break X}if(w[f+25|0]){break W}t[f+25|0]=13;t[f+22|0]=w[b+4|0]}t[b+2|0]=0}v[114578]=0;fa(500,f|0,f+26|0,f+23|0,f+25|0,f+22|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}Y:{if(w[b+2|0]){break Y}e=w[f+26|0];if(!e){break Y}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}Z:{if(w[f+27|0]){v[114578]=0;fa(500,f|0,f+25|0,f+22|0,f+27|0,f+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}_:{if(w[b+2|0]){break _}e=w[f+25|0];if(!e){break _}t[b+2|0]=e;t[b+4|0]=w[f+22|0]}i=f+24|0;g=w[f+27|0];break Z}i=f+22|0;g=w[f+25|0];if(!g){break k}}t[b+3|0]=g;t[b+5|0]=w[i|0];break k}e=wc(o,i);t[e|0]=w[e|0]-1}b=b+6|0;p=p+1|0;i=p&65535;if(s>>>0>=i>>>0){continue}break}}$:{if(!y){break $}g=_b(n,m);v[114578]=0;e=W(498,f|0,17,w[f+32|0])|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Th(Fn(Ne(e,k),0));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}g=_b(n,m);v[114578]=0;e=W(498,f|0,16,w[f+36|0])|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=Th(Ne(e,k));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break $}}break c}aa:{if(!(l&240)){break aa}g=_b(n,m);v[114578]=0;e=W(498,f|0,20,l>>>4|224)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=fT(Ne(e,k));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break aa}}break c}ba:{e=l&15;if(!e){break ba}b=w[c+16|0];g=_b(n,m);b=Fd((B(b,e)>>>0)/15&255,1,15);v[114578]=0;e=W(498,f|0,20,b|96)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=fT(Ne(e,k));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ba}}break c}b=0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}fe(o)}jb=f- -64|0;return m|0}a=P()|0;O()|0;fe(o);S(a|0);L()}function IU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;o=ph(b,11882);a:{if(!o){break a}if(!Qb(b,6)){break a}while(1){b:{k=Cf(b);c:{if((k|0)==(Gj(11887)|0)){break c}i=w[11892]|w[11893]<<8|(w[11894]<<16|w[11895]<<24);if(!(k&1616928864)|k&-2139062144){break c}if((i|0)!=(k|0)){break b}}fg(b,4);break a}l=1;q=hg(b);if(x[a+480192>>1]){while(1){j=v[(((l&65535)<<2)+a|0)+900380>>2];if(j){d:{i=q;m=b;p=k;if((Gj(11872)|0)==(k|0)){$b(m,i);break d}e=p;c=i;d=m;g=0;h=jb-32|0;jb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+23|0]=s;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+18|0]=s;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Qb(d,c)){break n}r=f,s=Mk(d,c),v[r>>2]=s;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+21|0]=s;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;ud(h+16|0,d,c);c=0;while(1){v[114578]=0;d=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}r=dd(e,c),s=d,u[r>>1]=s;c=c+1|0;if(c>>>0<128){continue}break}Bb(h+16|0);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+31|0]=s;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+34|0]=s;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+16|0]=s;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+16>>2]=240;r=h,s=Mk(d,c),v[r>>2]=s;gg(f+68|0,v[Lb(h+16|0,h)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}if(Kb(d)){while(1){v[114578]=0;e=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}r=Pb(d,c),s=e,t[r+2|0]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+82|0]=s;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+27|0]=s;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}if(Kb(d)){while(1){v[114578]=0;e=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}r=Pb(d,c),s=e,u[r>>1]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+83|0]=s;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}r=f,s=B(jq(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[r+40>>2]=s;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+36|0]=s;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}if(Kb(d)){while(1){v[114578]=0;e=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}r=Pb(d,c),s=e,t[r+2|0]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}if(Kb(d)){while(1){v[114578]=0;e=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}r=Pb(d,c),s=e,u[r>>1]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+24|0]=s;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}if(Kb(d)){while(1){v[114578]=0;e=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}r=Pb(d,c),s=e,t[r+2|0]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+62|0]=s;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}if(Kb(d)){while(1){v[114578]=0;e=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}r=Pb(d,c),s=e,u[r>>1]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+63|0]=s;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+15|0]=s;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}ud(h+16|0,d,c);e=Wb(h);if(c){d=0;while(1){v[114578]=0;g=T(378,h+16|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break E}v[114578]=0;Q(379,e|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114578]=0;Q(371,f+492|0,e|0)|0;c=v[114578];v[114578]=0;g=1;if((c|0)==1){break E}yb(e);Bb(h+16|0);break n}if(c>>>0>4){break n}if(!Qb(d,c)){break n}r=f,s=Mk(d,c),v[r+4>>2]=s;g=1;break n}if(c>>>0>4){break n}if(!Qb(d,c)){break n}r=f,s=Mk(d,c),v[r+8>>2]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+61|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f- -64|0,s=jd(d,c),t[r|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+81|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+84|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+101|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+102|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+103|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+104|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+17|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+19|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+20|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+22|0]=s;g=1;break n}if(c>>>0>2){break n}if(!Qb(d,c)){break n}r=f,s=jq(d,c),u[r+28>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+30|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=QB(d,c),t[r+26|0]=s;g=1;break n}if(c>>>0>128){break n}e=f+108|0;ud(h+16|0,d,c);c=0;while(1){v[114578]=0;d=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}r=fc(e,c),s=d,t[r|0]=s;c=c+1|0;if(c>>>0<128){continue}break}Bb(h+16|0);g=1;break n}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(e);break f}if(c>>>0>32){break n}ud(h+16|0,d,c);e=Wb(h);if(c){d=0;while(1){v[114578]=0;g=T(378,h+16|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break m}v[114578]=0;Q(379,e|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114578]=0;Q(371,f+524|0,e|0)|0;c=v[114578];v[114578]=0;g=1;if((c|0)!=1){yb(e);Bb(h+16|0);break n}break m}if(c>>>0>2){break n}if(!Qb(d,c)){break n}r=f,s=jq(d,c),u[r+12>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+25|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+35|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+105|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+85|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+65|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+100|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+80|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=jd(d,c),t[r+60|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=QB(d,c),t[r+33|0]=s;g=1;break n}g=1;c=Mk(d,c);if(!Sn(c)){break n}t[f+14|0]=c;break n}v[h+16>>2]=240;r=h,s=Mk(d,c),v[r>>2]=s;gg(f+48|0,v[Lb(h+16|0,h)>>2]);g=1;break n}v[h+16>>2]=240;r=h,s=Mk(d,c),v[r>>2]=s;gg(f+88|0,v[Lb(h+16|0,h)>>2]);g=1;break n}c=P()|0;O()|0;break f}c=jq(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}jb=h+32|0;break e}c=P()|0;O()|0;yb(e);break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0}Bb(h+16|0);S(c|0);L()}if(!g){$b(m,i);break d}if((Gj(11877)|0)==(p|0)){i=w[j+15|0];t[j+15|0]=0;t[j+100|0]=w[j+100|0]&224|(i>>>5&4|i>>>6&1);t[j+60|0]=i>>>1&2|(i<<1&4|(w[j+60|0]&240|i&1));t[j+80|0]=w[j+80|0]&240|(i>>>4&2|(i>>>2&4|i>>>3&1))}}}l=l+1|0;if(x[a+480192>>1]>=(l&65535)>>>0){continue}break}}if(Qb(b,6)){continue}break}}return o|0}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-720|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Ef(b,d+712|0)){break D}if(!KK(d+712|0)){break D}if(!Bt(b,d+704|0)){break D}if(!JK(d+704|0)){break D}i=1313423693;g=w[d+704|0]|w[d+705|0]<<8|(w[d+706|0]<<16|w[d+707|0]<<24);if((g|0)!=1179012417){i=1414090313;if((g|0)!=538987841){break D}}l=Jk(d+688|0,b);j=xx(d+672|0);E:{F:{G:{H:{I:{J:{K:{L:{M:{if(!c){v[114578]=0;X(1537,d+112|0,l|0,((g|0)==1179012417?1:2)|0,i|0);b=v[114578];v[114578]=0;if((b|0)!=1){break M}a=P()|0;O()|0;break a}v[114578]=0;U(1538,d+112|0,l|0,((g|0)==1179012417?1:2)|0);b=v[114578];v[114578]=0;if((b|0)==1){break L}}b=j;if(v[b>>2]){Id(b);GK(b);up(b);Yf(zb(b),v[b>>2],We(b));m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0}b=d+112|0;El(j,b);v[j>>2]=v[b>>2];v[j+4>>2]=v[b+4>>2];f=v[zb(b)>>2];m=zb(j),n=f,v[m>>2]=n;m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0;sl(d+112|0);v[114578]=0;U(1539,d+656|0,j|0,i|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[114578]=0;b=T(339,d+656|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}f=0;if(!b){break E}v[114578]=0;b=Q(1540,d+656|0,d+576|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break G}if(!b|!w[d+641|0]){break E}b=w[d+641|0];v[114578]=0;f=Q(258,d+656|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break G}if(!f|!c){break E}v[114578]=0;R(449,a|0,8388608);b=v[114578];v[114578]=0;if((b|0)==1){break G}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+640|0]<<4^-1)&16;b=w[d+641|0];v[114578]=0;u[d+112>>1]=b;u[d+480>>1]=127;b=Q(478,d+112|0,d+480|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break K}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+642|0];v[a+480204>>2]=B(w[d+643|0],1e4);v[a+480200>>2]=w[d+648|0]<<1;v[114578]=0;Q(238,a+1304436|0,((g|0)==1179012417?31715:31681)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break G}v[114578]=0;b=Q(2,d+112|0,31749)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}Gb(a+1304448|0,b);yb(b);v[a+1304496>>2]=4;v[114578]=0;U(1541,d+480|0,2,d+576|0);b=v[114578];v[114578]=0;if((b|0)==1){break J}v[114578]=0;R(417,d+112|0,d+480|0);b=v[114578];v[114578]=0;if((b|0)==1){break J}Gb(a+1304400|0,d+112|0);yb(d+112|0);if(!x[a+480188>>1]){break H}b=0;h=(g|0)==1179012417;while(1){v[114578]=0;i=(b<<5)+a|0;e=i+480280|0;Z(434,e|0);f=v[114578];v[114578]=0;N:{O:{P:{Q:{R:{if((f|0)!=1){v[114578]=0;f=T(389,d+656|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break R}if(h){break Q}if(f>>>0<129){break P}break O}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(f<<24>>24<=-1){break O}v[114578]=0;v[d+112>>2]=f<<2;v[d+480>>2]=256;f=Q(464,d+112|0,d+480|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){u[i+480284>>1]=v[f>>2];break N}a=P()|0;O()|0;break b}u[i+480284>>1]=f<<1;break N}v[e>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break H}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[114578]=0;b=Q(1542,j|0,1380209231)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break F}}a=P()|0;O()|0;break b}if(b){v[114578]=0;U(1539,d+112|0,j|0,1380209231);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=T(389,d+112|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}f=Vb(a+484360|0);v[114578]=0;ea(581,f|0,d+112|0,b+1&255,255,254)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}Bb(d+112|0)}if(c&1){v[114578]=0;u[d+40>>1]=0;U(1543,d+480|0,j|0,1414807888);b=v[114578];v[114578]=0;if((b|0)==1){break e}b=nd(d+480|0);v[114578]=0;f=a+484344|0;R(403,f|0,b&65535);b=v[114578];v[114578]=0;if((b|0)==1){break k}m=d,n=bc(d+480|0),v[m+544>>2]=n;m=d,n=cc(d+480|0),v[m+64>>2]=n;if(Jb(d+544|0,d- -64|0)){i=(g|0)!=1179012417;while(1){b=Ze(d+112|0,v[d+544>>2]);v[114578]=0;h=T(389,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}v[114578]=0;u[d+464>>1]=h;h=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}v[114578]=0;U(343,d+560|0,b|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break i}v[114578]=0;X(1544,d+560|0,x[d+464>>1],i|0,a|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}Bb(d+560|0);v[114578]=0;h=Q(454,d+40|0,d+464|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}u[d+40>>1]=x[h>>1];Bb(b);Uf(d+544|0);if(Jb(d+544|0,d- -64|0)){continue}break}}if(x[d+40>>1]){b=0;while(1){v[114578]=0;i=b&65535;h=Q(444,f|0,i|0)|0;e=v[114578];v[114578]=0;S:{if((e|0)!=1){if(h){break S}v[114578]=0;W(404,f|0,i|0,64)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break S}}a=P()|0;O()|0;break f}b=b+1|0;if(x[d+40>>1]>(b&65535)>>>0){continue}break}}gd(d+480|0)}T:{if((g|0)==1179012417){v[114578]=0;U(1543,d- -64|0,j|0,1414745673);b=v[114578];v[114578]=0;if((b|0)==1){break B}m=d,n=bc(d- -64|0),v[m+96>>2]=n;m=d,n=cc(d- -64|0),v[m+24>>2]=n;U:{if(Jb(d+96|0,d+24|0)){f=c&2;i=d+488|0;h=d+112|1;while(1){c=Ze(d+544|0,v[d+96>>2]);v[114578]=0;b=Q(1545,c|0,d+112|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break U}V:{if(!b){break V}b=w[h|0];if((b|0)==255){break V}v[114578]=0;b=W(456,a|0,b+1|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}if(!b){break V}g=x[a+480190>>1];v[114578]=0;U(1546,d+112|0,b|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break A}b=0;if(!w[d+142|0]){break V}while(1){W:{if(!En(a)){break W}v[114578]=0;g=Q(1547,c|0,d+480|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break z}if(!g){break W}g=x[a+480190>>1]+1|0;u[a+480190>>1]=g;if((w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))!=1347240275){break W}v[114578]=0;U(577,d+464|0,2,i|0);e=v[114578];v[114578]=0;X:{Y:{Z:{if((e|0)==1){break Z}v[114578]=0;R(417,d+40|0,d+464|0);e=v[114578];v[114578]=0;if((e|0)==1){break Z}v[114578]=0;g=g&65535;Q(371,((g<<5)+a|0)+946304|0,d+40|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Y}yb(d+40|0);v[114578]=0;g=(B(g,104)+a|0)+484380|0;U(1548,d+480|0,d+112|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!f){break X}v[114578]=0;R(1549,d+40|0,d+480|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+40|0,g|0,c|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break W}}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;yb(d+40|0);break l}g=Bj(g);v[114578]=0;Q(340,c|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break m}}b=b+1|0;if(b>>>0<w[d+142|0]){continue}break}}Bb(c);Uf(d+96|0);if(Jb(d+96|0,d+24|0)){continue}break}}gd(d- -64|0);break T}a=P()|0;O()|0;break l}v[114578]=0;U(1543,d+464|0,j|0,1179011410);b=v[114578];v[114578]=0;if((b|0)==1){break y}m=d,n=bc(d+464|0),v[m+456>>2]=n;m=d,n=cc(d+464|0),v[m+448>>2]=n;if(Jb(d+456|0,d+448|0)){g=c&2;f=d+480|4;c=d+56|4;i=d+112|5;while(1){h=Jk(d+544|0,v[d+456>>2]);v[114578]=0;b=T(392,d+544|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break x}_:{if((b|0)!=538986817){break _}v[114578]=0;b=Q(1550,d+544|0,d+440|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break w}if(!b|(w[d+440|0]|w[d+441|0]<<8|(w[d+442|0]<<16|w[d+443|0]<<24))!=1414745673){break _}v[114578]=0;b=Q(1551,d+544|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break v}if(!b){break _}b=w[i|0];if((b|0)==255){break _}v[114578]=0;b=W(456,a|0,b+1|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break u}if(!b){break _}e=x[a+480190>>1];v[114578]=0;U(1552,d+112|0,b|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}v[114578]=0;U(1538,d+480|0,h|0,2);b=v[114578];v[114578]=0;if((b|0)==1){break C}v[114578]=0;U(1543,d+96|0,d+480|0,1179011410);b=v[114578];v[114578]=0;if((b|0)==1){break t}sl(d+480|0);m=d,n=bc(d+96|0),v[m+88>>2]=n;m=d,n=cc(d+96|0),v[m+80>>2]=n;$:{if(!Jb(d+88|0,d+80|0)){break $}aa:{while(1){b=Ze(d- -64|0,v[d+88>>2]);v[114578]=0;h=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}ba:{ca:{if((h|0)!=538989377){break ca}if(!En(a)){break ca}h=w[d+436|0]|w[d+437|0]<<8;e=h-1|0;t[d+436|0]=e;t[d+437|0]=e>>>8;if(!h){Bb(b);break $}h=x[a+480190>>1]+1|0;u[a+480190>>1]=h;v[114578]=0;e=Q(1550,b|0,d+56|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break r}da:{if(!(!e|(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))!=1347240275)){e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;U(343,d+40|0,b|0,e|0);e=v[114578];v[114578]=0;ea:{if((e|0)!=1){v[114578]=0;e=Q(1553,d+40|0,d+480|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break ba}if(!e){break aa}v[114578]=0;U(746,d+8|0,2,f|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)!=1){break ea}}a=P()|0;O()|0;break p}a=P()|0;O()|0;break o}v[114578]=0;h=h&65535;Q(371,((h<<5)+a|0)+946304|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}yb(d+24|0);v[114578]=0;h=(B(h,104)+a|0)+484380|0;U(1554,d+480|0,d+112|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break ba}if(!g){break da}e=w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24);v[114578]=0;Q(256,d+40|0,e+4|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ba}v[114578]=0;R(1555,d+24|0,d+480|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+24|0,h|0,d+40|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break da}}a=P()|0;O()|0;break p}Bb(b);break $}Bb(d+40|0)}Bb(b);Uf(d+88|0);if(Jb(d+88|0,d+80|0)){continue}break $}break}a=P()|0;O()|0;break p}Bb(d+40|0);Bb(b)}gd(d+96|0)}Bb(d+544|0);Uf(d+456|0);if(Jb(d+456|0,d+448|0)){continue}break}}gd(d+464|0)}f=1}Bb(d+656|0);sl(j);Bb(l)}jb=d+720|0;return f|0}a=P()|0;O()|0;break n}a=P()|0;O()|0;break b}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;sl(d+480|0);break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break o}a=P()|0;O()|0;yb(d+24|0)}Bb(d+40|0)}Bb(b);gd(d+96|0)}Bb(d+544|0);gd(d+464|0);break b}a=P()|0;O()|0}Bb(c);gd(d- -64|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;Bb(d+560|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}Bb(b)}gd(d+480|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(d+112|0);break b}a=P()|0;O()|0}Bb(d+656|0)}sl(j);Bb(l);S(a|0);L()}function Faa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;g=jb-48|0;jb=g;f=a+1074308|0;if(!(v[f>>2]==18284544|y[a+1074308>>2]>=18285126)){wg(a+1074312|0,0)}i=a+1074312|0;Eb(g+32|0,i,0);if(Cb(g+32|0)){q=(v[a+480180>>2]&16777248)!=0}Eb(g+32|0,i,0);if(Cb(g+32|0)){D=v[a+480180>>2]==4}if(y[f>>2]<18874368){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;E=b,F=v[Lb(g+32|0,g+16|0)>>2],t[E+20|0]=F;c:{d:{if(q){if(y[f>>2]<18350080){e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2}if(y[f>>2]<18285314){break d}break c}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2}nO(pu(b,2),4,v[a+480180>>2])}e:{if(!w[b+34|0]|(y[f>>2]<18284544|y[f>>2]>=18285136)){break e}if(!zi(b)){break e}Nb(i,2,1)}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))|y[f>>2]>=18285136){break b}Nb(i,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}f:{if(!(v[a+480180>>2]&16777248)){break f}b=1;if(!x[a+480190>>1]|(q?y[f>>2]>=18285314:0)){break f}while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;h=zO(b);if((h|0)!=(b|0)){while(1){b=c;d=b+32|0;while(1){e=w[b|0];g:{h:{if((e-97&255)>>>0<=5){j=e-32|0;break h}j=99;i:{if(e>>>0<=106){if(e-88>>>0<2){break i}if((e|0)==75){break h}break g}if(e-120>>>0<2){break i}if((e|0)==107){break h}break g}j=122}t[b|0]=j}b=b+1|0;if((d|0)!=(b|0)){continue}break}c=c+32|0;if((h|0)!=(c|0)){continue}break}}}j:{if(v[f>>2]==18874368|y[f>>2]>=18874896|(!(v[a+480180>>2]&16777252)|!x[a+480192>>1])){break j}b=1;c=0;while(1){k:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break k}break j}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Nb(i,3,1)}l:{if(!(v[a+480180>>2]&16777248)|(v[f>>2]==19005440|y[f>>2]>=19006226)){break l}Eb(g+32|0,i,0);if(!Cb(g+32|0)){Eb(g+16|0,i,1);if(!Cb(g+16|0)){break l}}if(!x[a+480192>>1]){break l}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}m:{n:{o:{if(y[f>>2]<19007233){e=a+946300|0;b=a+906300|0;while(1){c=jb-16|0;jb=c;j=b+80|0;Ut(c,1,j);Ic(g+16|0,c);jb=c+16|0;v[114578]=0;X(440,g+32|0,0,7,g+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break n}yb(g+16|0);v[114578]=0;Q(507,j|0,g+32|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}yb(g+32|0);b=b+160|0;if((e|0)!=(b|0)){continue}break}}if(!(v[a+480180>>2]!=4|y[f>>2]<19007257|(v[a+1074372>>2]!=4|y[f>>2]>=19071236))){Ux(a,5)}if(!(!x[a+480192>>1]|(v[f>>2]==19202048|y[f>>2]>=19202055))){c=1;while(1){j=(((c&65535)<<2)+a|0)+900380|0;b=v[j>>2];p:{if(!b|!w[b+20|0]|!w[b+31|0]){break p}b=b+236|0;e=$s(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break p}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[j>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480192>>1]|y[f>>2]>=19267584)){c=1;while(1){b=v[(((c&65535)<<2)+a|0)+900380>>2];q:{if(!b){break q}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2;if(y[f>>2]>=18350080?q:0){break q}t[b+19|0]=w[b+19|0]+3>>>2}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}r:{if(!x[a+480192>>1]|y[f>>2]>=19398674){break r}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Nb(i,94,1);break r}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}s:{if(!x[a+480192>>1]|y[f>>2]>=19399428){break s}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Nb(i,101,1);break s}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=jb-16|0;jb=b;u[g+12>>1]=0;v[g+8>>2]=a;Eb(b+8|0,a+1074312|0,0);E=g,F=Cb(b+8|0),t[E+14|0]=F;jb=b+16|0;b=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=b;c=jb-16|0;jb=c;n=a+484344|0;j=Ce(n);b=v[g+4>>2];e=v[g>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=jb-32|0;jb=e;A=j-1&65535;t:{if(Ce(n)>>>0>A>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(mh(Ge(n,b))){h=bc(Ge(n,b));d=cc(Ge(n,b));b=e;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;j=b+8|0;m=jb-16|0;jb=m;v[m>>2]=d;v[m+8>>2]=h;if(Jb(m+8|0,m)){while(1){d=v[m+8>>2];b=j;o=x[b+4>>1];h=o+1|0;u[b+4>>1]=h;if(x[v[b>>2]+480188>>1]<=(h&65535)>>>0){u[b+4>>1]=0}u:{if(fn(d)){break u}h=v[b>>2];k=v[h+1074308>>2];p=v[h+480180>>2];v:{if((p|0)==2){if(w[d+3|0]!=23|k>>>0>=18415616){break v}Ue(d+5|0,64);break v}if(p&16777248){w:{if(w[b+6|0]|k>>>0>=18874368?k>>>0>=18285314:0){break w}x:{switch(w[d+3|0]-20|0){case 3:Ue(d+5|0,128);break w;case 0:break x;default:break w}}h=w[d+5|0];if((h|0)!=208){if((h|0)!=192){break w}t[d|0]=254;t[d+3|0]=0;break w}t[d+3|0]=0}y:{if(k>>>0>=18350080){h=0;if(w[b+6|0]|k>>>0>=18874368){break y}}l=w[d+3|0]-6&255;h=0;if(l>>>0>23){break y}h=8388643>>>l&1}if(k>>>0>=18874368){h=0-h|0}else{l=w[d+3|0];h=h|((l|0)==24|(l|0)==22)}z:{if(!(h&1)){break z}l=w[d+5|0];h=l&15;if(!h|(h|0)==15){break z}l=l&240;if(!l|(l|0)==240){break z}t[d+5|0]=w[d+3|0]==24?l:h}if(!x[v[b>>2]+480192>>1]|((k|0)==19005440|k>>>0>=19005700)|(w[b+6|0]|x[v[b>>2]+480192>>1]>=w[d+1|0])){break v}t[d+4|0]=0;t[d+2|0]=1;break v}if((p|0)!=4){break v}A:{if(!(k>>>0<18874368?w[b+6|0]?k>>>0>=18285314:0:1)|(w[d+3|0]!=23|k>>>0>=19137026)){break A}if(w[d+5|0]<65){break A}t[d+3|0]=0}if(!(w[d+3|0]!=10|(w[b+6|0]|k>>>0>=18874368?k>>>0>=18415616:0)|w[d+2|0]!=11)){t[d+3|0]=0}B:{if(w[d+2|0]!=11|k>>>0>=18874640|w[d+3|0]!=4){break B}h=w[d+4|0];if(!(w[b+6|0]?1:h)){break B}l=w[d+5|0];if(!l){break B}t[d+2|0]=0;E=d,F=dR(l+(h<<4)|0),t[E+5|0]=F}if(w[d+5|0]|(w[d+3|0]!=16|k>>>0>=19007241)){break v}t[d+3|0]=0}C:{if(k>>>0>=18874368){break C}C=(w[d+5|0]&240)==96;l=w[d+3|0];h=C&(l|0)==20;D:{E:{if(C?(l|0)==28:0){if(!w[b+6|0]|(p|0)!=4){break E}b=h|k>>>0<18350080}else{b=0-h|0}if(!(b&1)){break D}}if(!o){break D}b=d+B(0-o|0,6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}if(!o|(w[d+5|0]&240)!=224|w[d+3|0]!=20){break C}b=d+B(0-o|0,6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}F:{if(w[d+2|0]!=8|k>>>0>=19333175|(k|0)==19333120){break F}G:{H:{I:{J:{b=w[d+3|0];switch(b-5|0){case 1:break F;case 0:break H;case 2:break J;default:break I}}if(!w[d+4|0]){break G}t[d+3|0]=11;break F}if((b|0)!=26){break F}}h=w[d+5|0];if(!(h&15)){t[d+2|0]=0;t[d+3|0]=5;t[d+5|0]=h|w[d+4|0]&15;break F}K:{switch(b-5|0){case 1:break F;case 0:case 2:break G;default:break K}}if((b|0)!=26){break F}}t[d+2|0]=0}if(w[d+3|0]|((p|0)==16777216|w[d+2|0]!=15)){break u}t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3}Dj(m+8|0);if(Jb(m+8|0,m)){continue}break}}b=v[j+4>>2];v[e+16>>2]=v[j>>2];v[e+20>>2]=b;jb=m+16|0}z=z+1|0;if((z&65535)>>>0<=A>>>0){continue}break}v[g+32>>2]=r;v[g+36>>2]=s;break t}j=v[b+4>>2];v[g+32>>2]=v[b>>2];v[g+36>>2]=j}jb=e+32|0;jb=c+16|0;L:{M:{if(!q){break M}b=v[f>>2];if(b>>>0>=19267584){break M}Nb(i,8,(b|0)==18284544|b>>>0>18285313);b=30904;while(1){c=v[f>>2];e=v[b+4>>2];Nb(i,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=31240){continue}break}break L}if(!D){break L}b=v[f>>2];if(b>>>0>=19267584){break L}Nb(i,8,b>>>0>18285313);b=31256;while(1){Nb(i,v[b>>2],y[f>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=31488){continue}break}}N:{if(v[a+480180>>2]&16777248){b=31488;while(1){c=v[f>>2];e=v[b+4>>2];j=e&-65536;if(!(c>>>0<=j>>>0|c>>>0>=e>>>0?c>>>0>=j>>>0:0)){wg(i,v[b>>2])}b=b+8|0;if((b|0)!=31536){continue}break}break N}if(v[a+480180>>2]==4){b=31536;while(1){if(y[f>>2]<y[b+4>>2]){wg(i,v[b>>2])}b=b+8|0;if((b|0)!=31592){continue}break}break N}if(v[a+480180>>2]!=2){break N}b=31600;while(1){if(y[f>>2]<y[b+4>>2]){wg(i,v[b>>2])}b=b+8|0;if((b|0)!=31680){continue}break}}if(!(v[a+480180>>2]!=4|y[f>>2]>=18415616)){Nb(i,98,1)}if(!(y[f>>2]<19333159|y[f>>2]>=19333193)){b=0;while(1){c=b+77|0;Eb(g+32|0,i,c);Nb(i,b+86|0,Cb(g+32|0));wg(i,c);b=b+1|0;if((b|0)!=5){continue}break}}c=8;O:{if(y[f>>2]>=18284544){if(y[f>>2]<18284544|y[f>>2]>18874627){break O}c=6;if(v[f>>2]==18874368){break O}}Nb(i,c,1)}P:{if(y[f>>2]<19136512){wg(i,7);break P}if(!(v[a+480180>>2]&16777248)|(y[f>>2]<19136512|y[f>>2]>=19267584)){break P}Nb(i,7,1)}Eb(g+32|0,i,31);Q:{if(!Cb(g+32|0)|y[f>>2]<19071234|(!x[a+480192>>1]|y[f>>2]>=19398723)){break Q}b=1;while(1){R:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break R}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break R}Nb(i,97,1);break Q}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}S:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break S}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break S}break}if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216|(y[f>>2]<19398688|y[f>>2]>19464277))){Nb(i,109,1)}if(!(v[a+480180>>2]!=2|y[f>>2]>=19464192)){Nb(i,108,1);break S}if(v[a+480180>>2]==2){break S}wg(i,108)}jb=g+48|0;return}a=P()|0;O()|0;yb(g+32|0);break m}a=P()|0;O()|0;yb(g+16|0)}S(a|0);L()}function kF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=jb-144|0;jb=d;x=Rb(d,0,144);v[x+76>>2]=-1;v[x+44>>2]=a;v[x+32>>2]=2423;v[x+84>>2]=a;D=c;i=jb-304|0;jb=i;e=x;d=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(el(a&255)){while(1){a=d;d=d+1|0;if(el(w[a+1|0])){continue}break}Bh(e,0,0);while(1){b=v[e+4>>2];h:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break h}b=$c(e)}if(el(b)){continue}break}d=v[e+4>>2];if(v[e+104>>2]){d=d-1|0;v[e+4>>2]=d}b=d-v[e+8>>2]|0;h=b>>31;k=b;d=n+v[e+124>>2]|0;b=q+v[e+120>>2]|0;d=b>>>0<q>>>0?d+1|0:d;c=b;b=k+b|0;d=d+h|0;q=b;n=b>>>0<c>>>0?d+1|0:d;break g}i:{j:{k:{b=w[d|0];if((b|0)==37){a=w[d+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}Bh(e,0,0);a=((b|0)==37)+d|0;b=v[e+4>>2];l:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break l}b=$c(e)}if((b|0)!=w[a|0]){if(v[e+104>>2]){v[e+4>>2]=v[e+4>>2]-1}if((b|0)>-1){break a}s=0;if(E){break a}break c}b=q+1|0;n=b>>>0<1?n+1|0:n;q=b;break g}l=0;a=d+2|0;break i}if(!(!bh(a)|w[d+2|0]!=36)){a=w[d+1|0]-48|0;b=jb-16|0;v[b+12>>2]=D;a=a>>>0>1?((a<<2)+D|0)-4|0:D;v[b+8>>2]=a+4;l=v[a>>2];a=d+3|0;break i}l=v[D>>2];D=D+4|0;a=d+1|0}s=0;m:{if(!bh(w[a|0])){d=0;break m}d=0;while(1){b=a+1|0;d=(w[a|0]+d|0)-48|0;if(bh(w[a+1|0])){d=B(d,10);a=b;continue}else{a=b}break}}c=w[a|0];if((c|0)==109){o=0;s=(l|0)!=0;c=w[a+1|0];p=0;a=a+1|0}b=a;a=b+1|0;f=3;n:{o:{switch(c-65|0){case 39:c=b+2|0;b=w[b+1|0]==104;a=b?c:a;f=b?-2:-1;break n;case 43:c=b+2|0;b=w[b+1|0]==108;a=b?c:a;f=b?3:1;break n;case 51:case 57:f=1;break n;case 11:f=2;break n;case 41:break n;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break o;default:break d}}f=0;a=b}b=w[a|0];c=(b&47)==3;F=c?1:f;r=c?b|32:b;p:{if((r|0)==91){break p}q:{if((r|0)!=110){if((r|0)!=99){break q}d=(d|0)>1?d:1;break p}lF(l,F,q,n);break g}Bh(e,0,0);while(1){b=v[e+4>>2];r:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break r}b=$c(e)}if(el(b)){continue}break}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}b=b-v[e+8>>2]|0;c=b;h=b>>31;f=n+v[e+124>>2]|0;b=q+v[e+120>>2]|0;f=b>>>0<q>>>0?f+1|0:f;n=b;b=b+c|0;c=f+h|0;q=b;n=b>>>0<n>>>0?c+1|0:c}j=d;k=d>>31;Bh(e,d,k);b=v[e+104>>2];c=v[e+4>>2];s:{if(b>>>0>c>>>0){v[e+4>>2]=c+1;break s}if(($c(e)|0)<0){break d}b=v[e+104>>2]}if(b){v[e+4>>2]=v[e+4>>2]-1}b=16;t:{u:{v:{w:{x:{y:{z:{switch(r-88|0){default:b=r-65|0;if(b>>>0>6|!(1<<b&113)){break t}case 9:case 13:case 14:case 15:oF(i,e,F,0);b=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-b|0)&v[e+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!l){break t}b=v[i+8>>2];c=v[i+12>>2];d=v[i>>2];h=v[i+4>>2];switch(F|0){case 2:break v;case 1:break w;case 0:break x;default:break t};case 3:case 11:case 27:if((r&239)==99){Rb(i+32|0,-1,257);t[i+32|0]=0;if((r|0)!=115){break u}t[i+65|0]=0;t[i+46|0]=0;u[i+42>>1]=0;u[i+44>>1]=0;break u}c=w[a+1|0];h=(c|0)==94;Rb(i+32|0,h,257);t[i+32|0]=0;b=h?a+2|0:a+1|0;A:{B:{C:{a=w[(h?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break C}f=(c|0)!=94;a=b;break A}f=(c|0)!=94;t[i+78|0]=f;break B}f=(c|0)!=94;t[i+126|0]=f}a=b+1|0}while(1){b=w[a|0];D:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break D}break u}b=45;c=w[a+1|0];if(!c|(c|0)==93){break D}h=a+1|0;a=w[a-1|0];E:{if(c>>>0<=a>>>0){b=c;break E}while(1){a=a+1|0;t[a+(i+32|0)|0]=f;b=w[h|0];if(b>>>0>a>>>0){continue}break}}a=h}t[(b+i|0)+33|0]=f;a=a+1|0;continue};case 23:b=8;break y;case 12:case 29:b=10;break y;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break t;case 0:case 24:case 32:break y;case 17:break z}}b=0}g=e;h=0;d=0;j=0;f=0;H=0;G=jb-16|0;jb=G;F:{G:{H:{I:{J:{K:{if(b>>>0<=36){while(1){c=v[g+4>>2];L:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break L}c=$c(g)}if(el(c)){continue}break}M:{N:{switch(c-43|0){case 0:case 2:break N;default:break M}}H=(c|0)==45?-1:0;c=v[g+4>>2];if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break M}c=$c(g)}O:{if(!(b&-17|(c|0)!=48)){c=v[g+4>>2];P:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break P}c=$c(g)}if((c&-33)==88){b=16;c=v[g+4>>2];Q:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break Q}c=$c(g)}if(w[c+59841|0]<16){break J}if(!v[g+104>>2]){break G}v[g+4>>2]=v[g+4>>2]-1;break G}if(b){break O}b=8;break J}b=b?b:10;if(b>>>0>w[c+59841|0]){break O}if(v[g+104>>2]){v[g+4>>2]=v[g+4>>2]-1}Bh(g,0,0);v[114552]=28;b=0;c=0;break F}if((b|0)!=10){break J}j=c-48|0;if(j>>>0<=9){b=0;while(1){h=b+j|0;b=v[g+4>>2];R:{if(b>>>0<y[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break R}c=$c(g)}j=c-48|0;if(!(j>>>0>9|h>>>0>429496728)){b=B(h,10);continue}break}}if(j>>>0>9){break K}f=Hma(h,0,10,0);k=mb;b=j;while(1){c=v[g+4>>2];S:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break S}c=$c(g)}j=c-48|0;m=j>>>0>9;d=k;h=b+f|0;d=h>>>0<b>>>0?d+1|0:d;if((d|0)==429496729&h>>>0>=2576980378|d>>>0>429496729|m){break K}f=Hma(h,d,10,0);k=mb;m=k;b=j;if((m|0)==-1&f>>>0<=(b^-1)>>>0|(m|0)!=-1){continue}break}b=10;break I}v[114552]=28;b=0;c=0;break F}b=10;if(j>>>0<=9){break I}break H}if(b-1&b){f=w[c+59841|0];if(f>>>0<b>>>0){while(1){h=f+j|0;k=h>>>0>119304646;d=b;c=v[g+4>>2];T:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break T}c=$c(g)}f=w[c+59841|0];if(!(k|d>>>0<=f>>>0)){j=B(b,h);continue}break}d=0}if(b>>>0<=f>>>0){break I}j=b;while(1){m=Hma(h,d,j,0);k=mb;f=f&255;if((k|0)==-1&(f^-1)>>>0<m>>>0){break I}c=k;d=f+m|0;c=d>>>0<f>>>0?c+1|0:c;h=d;d=c;k=b;c=v[g+4>>2];U:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break U}c=$c(g)}f=w[c+59841|0];if(k>>>0<=f>>>0){break I}$g(G,j,0,h,d);if(!(v[G+8>>2]|v[G+12>>2])){continue}break}break I}k=t[(B(b,23)>>>5&7)+60097|0];j=w[c+59841|0];if(j>>>0<b>>>0){while(1){h=f|j;m=h>>>0>134217727;d=b;c=v[g+4>>2];V:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break V}c=$c(g)}j=w[c+59841|0];if(!(m|d>>>0<=j>>>0)){f=h<<k;continue}break}d=0}if(b>>>0<=j>>>0){break I}f=k;m=f&31;if((f&63)>>>0>=32){f=0;I=-1>>>m|0}else{f=-1>>>m|0;I=(1<<m)-1<<32-m|-1>>>m}if(!f&h>>>0>I>>>0){break I}while(1){m=j&255;j=h;c=k;h=c&31;if((c&63)>>>0>=32){d=j<<h;c=0}else{d=(1<<h)-1&j>>>32-h|d<<h;c=j<<h}h=m|c;m=b;c=v[g+4>>2];W:{if(c>>>0<y[g+104>>2]){v[g+4>>2]=c+1;c=w[c|0];break W}c=$c(g)}j=w[c+59841|0];if(m>>>0<=j>>>0){break I}if((d|0)==(f|0)&h>>>0<=I>>>0|d>>>0<f>>>0){continue}break}}if(w[c+59841|0]>=b>>>0){break H}while(1){d=v[g+4>>2];X:{if(d>>>0<y[g+104>>2]){v[g+4>>2]=d+1;c=w[d|0];break X}c=$c(g)}if(w[c+59841|0]<b>>>0){continue}break}v[114552]=68;H=0;h=-1;d=-1}if(v[g+104>>2]){v[g+4>>2]=v[g+4>>2]-1}if((h|0)==-1&(d|0)==-1){if(!(H|1)){v[114552]=68;b=-2;c=-1;break F}}b=H;h=b^h;c=b;b=h-b|0;k=d;d=c>>31;c=(k^d)-((c>>>0>h>>>0)+d|0)|0;break F}Bh(g,0,0);b=0;c=0}jb=G+16|0;d=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-d|0)&v[e+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break b}if(!(!l|(r|0)!=112)){v[l>>2]=b;break t}lF(l,F,b,c);break t}J=l,K=mF(d,h,b,c),z[J>>2]=K;break t}J=l,L=iw(d,h,b,c),A[J>>3]=L;break t}v[l>>2]=d;v[l+4>>2]=h;v[l+8>>2]=b;v[l+12>>2]=c;break t}h=(r|0)==99;f=h?d+1|0:31;g=(F|0)!=1;Y:{if(!g){b=l;if(s){b=od(f<<2);if(!b){break e}}v[i+296>>2]=0;v[i+300>>2]=0;d=0;c=s;while(1){p=b;Z:{while(1){b=v[e+4>>2];_:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break _}b=$c(e)}if(!w[(b+i|0)+33|0]){break Z}t[i+27|0]=b;b=so(i+28|0,i+27|0,1,i+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(p){v[(d<<2)+p>>2]=v[i+28>>2];d=d+1|0}if(!(c&(d|0)==(f|0))){continue}break}f=f<<1|1;b=Pq(p,f<<2);if(b){continue}break f}break}if(i+296|0?v[i+296>>2]:0){break f}o=0;break Y}if(s){d=0;b=od(f);if(!b){break e}while(1){o=b;while(1){b=v[e+4>>2];$:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break $}b=$c(e)}if(!w[(b+i|0)+33|0]){p=0;break Y}t[d+o|0]=b;d=d+1|0;if((f|0)!=(d|0)){continue}break}p=0;f=f<<1|1;b=Pq(o,f);if(b){continue}break}break d}d=0;if(l){while(1){b=v[e+4>>2];aa:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break aa}b=$c(e)}if(w[(b+i|0)+33|0]){t[d+l|0]=b;d=d+1|0;continue}else{p=0;o=l;break Y}}}while(1){b=v[e+4>>2];ba:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break ba}b=$c(e)}if(w[(b+i|0)+33|0]){continue}break}o=0;p=0}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}c=b-v[e+8>>2]|0;b=c+v[e+120>>2]|0;f=v[e+124>>2]+(c>>31)|0;f=b>>>0<c>>>0?f+1|0:f;if(!(f|b)|((b|0)!=(j|0)|(f|0)!=(k|0)?(r|0)==99:0)){break b}ca:{if(!s){break ca}if(!g){v[l>>2]=p;break ca}v[l>>2]=o}if(h){break t}if(p){v[(d<<2)+p>>2]=0}if(!o){o=0;break t}t[d+o|0]=0}b=v[e+4>>2]-v[e+8>>2]|0;d=b>>31;k=b;n=n+v[e+124>>2]|0;b=q+v[e+120>>2]|0;n=b>>>0<q>>>0?n+1|0:n;c=b;b=k+b|0;d=d+n|0;q=b;n=b>>>0<c>>>0?d+1|0:d;E=((l|0)!=0)+E|0}d=a+1|0;a=w[a+1|0];if(a){continue}break a}break}o=0;break d}o=0;p=0}if(E){break b}}E=-1}if(!s){break a}Xb(o);Xb(p)}jb=i+304|0;jb=x+144|0;return E}function pF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=jb-192|0;jb=m;y=h;G=i&65535;r=d;n=e&65535;F=(e^i)&-2147483648;l=i>>>16&32767;a:{t=e>>>16&32767;b:{c:{if(l-1>>>0<32766?t-1>>>0<=32765:0){break c}I=e&2147483647;k=I;j=d;if(!(!j&(k|0)==2147418112?!(b|c):k>>>0<2147418112)){L=d;F=e|32768;break b}I=i&2147483647;e=I;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){L=h;F=i|32768;b=f;c=g;break b}if(!(b|j|(k^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;F=2147450880;break b}F=F|2147418112;b=0;c=0;break b}if(!(d|f|(e^2147418112|g))){b=0;c=0;break b}if(!(b|j|(c|k))){break a}if(!(d|f|(e|g))){F=F|2147418112;b=0;c=0;break b}if((k|0)==65535|k>>>0<65535){i=b;d=!(n|r);h=d<<6;j=E(d?b:r)+32|0;b=E(d?c:n);b=h+((b|0)==32?j:b)|0;qf(m+176|0,i,c,r,n,b-15|0);K=16-b|0;r=v[m+184>>2];n=v[m+188>>2];c=v[m+180>>2];b=v[m+176>>2]}if(e>>>0>65535){break c}d=!(y|G);e=d<<6;h=E(d?f:y)+32|0;d=E(d?g:G);d=e+((d|0)==32?h:d)|0;qf(m+160|0,f,g,y,G,d-15|0);K=(d+K|0)-16|0;y=v[m+168>>2];G=v[m+172>>2];f=v[m+160>>2];g=v[m+164>>2]}e=G|65536;I=e;M=y;d=y;j=e<<15|d>>>17;d=d<<15|g>>>17;h=-102865788-d|0;e=j;i=1963258675-(j+(d>>>0>4192101508)|0)|0;$g(m+144|0,d,j,h,i);j=v[m+152>>2];$g(m+128|0,0-j|0,0-(v[m+156>>2]+((j|0)!=0)|0)|0,h,i);h=v[m+136>>2];i=h<<1|v[m+132>>2]>>>31;h=v[m+140>>2]<<1|h>>>31;$g(m+112|0,i,h,d,e);j=h;h=v[m+120>>2];$g(m+96|0,i,j,0-h|0,0-(v[m+124>>2]+((h|0)!=0)|0)|0);h=v[m+104>>2];i=h<<1|v[m+100>>2]>>>31;h=v[m+108>>2]<<1|h>>>31;$g(m+80|0,i,h,d,e);j=h;h=v[m+88>>2];$g(m- -64|0,i,j,0-h|0,0-(v[m+92>>2]+((h|0)!=0)|0)|0);h=v[m+72>>2];i=h<<1|v[m+68>>2]>>>31;h=v[m+76>>2]<<1|h>>>31;$g(m+48|0,i,h,d,e);j=h;h=v[m+56>>2];$g(m+32|0,i,j,0-h|0,0-(v[m+60>>2]+((h|0)!=0)|0)|0);h=v[m+40>>2];i=h<<1|v[m+36>>2]>>>31;h=v[m+44>>2]<<1|h>>>31;$g(m+16|0,i,h,d,e);j=h;h=v[m+24>>2];$g(m,i,j,0-h|0,0-(v[m+28>>2]+((h|0)!=0)|0)|0);K=(t-l|0)+K|0;h=v[m+8>>2];j=v[m+12>>2]<<1|h>>>31;k=h<<1|v[m+4>>2]>>>31;h=k-1|0;k=j-(k>>>0<1)|0;j=0;D=j;i=h;p=e;t=0;q=Hma(h,j,e,t);e=mb;w=e;x=k;l=0;h=d;j=Hma(k,l,d,0);d=j+q|0;k=mb+e|0;e=d;k=d>>>0<j>>>0?k+1|0:k;d=k;k=0;j=(d|0)==(w|0)&e>>>0<q>>>0|d>>>0<w>>>0;q=Hma(x,l,p,t);t=q+d|0;j=mb+(j|k)|0;z=t;w=q>>>0>t>>>0?j+1|0:j;h=Hma(i,D,h,o);d=0+h|0;j=mb+e|0;j=d>>>0<h>>>0?j+1|0:j;A=(e|0)==(j|0)&d>>>0<k>>>0|e>>>0>j>>>0;p=d;h=j;d=g;B=(d&131071)<<15|f>>>17;o=Hma(i,D,B,0);d=mb;u=d;j=f;s=j<<15&-32768;j=Hma(x,l,s,0);e=j+o|0;k=mb+d|0;k=e>>>0<j>>>0?k+1|0:k;d=k;C=Hma(i,D,s,C);s=0+C|0;j=e;k=j+mb|0;k=s>>>0<C>>>0?k+1|0:k;k=(j|0)==(k|0)&s>>>0<J>>>0|j>>>0>k>>>0;j=(d|0)==(u|0)&j>>>0<o>>>0|d>>>0<u>>>0;e=d;d=Hma(x,l,B,H)+d|0;j=j+mb|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=k+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=d+p|0;j=j+h|0;j=d>>>0<e>>>0?j+1|0:j;t=d;q=j;e=(j|0)==(h|0)&d>>>0<p>>>0|h>>>0>j>>>0;d=e+A|0;k=0;k=d>>>0<e>>>0?1:k;e=d;d=d+z|0;j=k+w|0;j=d>>>0<e>>>0?j+1|0:j;e=(t|0)!=0|(q|0)!=0;d=e+d|0;j=d>>>0<e>>>0?j+1|0:j;h=d;o=0-d|0;s=0;w=Hma(o,s,i,D);d=mb;u=d;e=w;p=d;s=Hma(x,l,o,s);d=mb;z=d;A=0-(((h|0)!=0)+j|0)|0;o=0;k=Hma(i,D,A,o);h=k+s|0;j=mb+d|0;j=h>>>0<k>>>0?j+1|0:j;d=j;j=h+p|0;B=0;e=B+e|0;p=e;k=e;j=k>>>0<B>>>0?j+1|0:j;e=j;j=(u|0)==(j|0)&k>>>0<w>>>0|j>>>0<u>>>0;k=(d|0)==(z|0)&h>>>0<s>>>0|d>>>0<z>>>0;h=d;d=Hma(x,l,A,o)+d|0;k=k+mb|0;k=d>>>0<h>>>0?k+1|0:k;h=d;d=j+d|0;j=k;A=d;h=d>>>0<h>>>0?j+1|0:j;B=0-(((t|0)!=0)+q|0)|0;q=0;z=Hma(B,q,i,D);s=mb;u=0-t|0;k=Hma(u,0,x,l);d=k+z|0;j=mb+s|0;t=d;d=d>>>0<k>>>0?j+1|0:j;C=0;u=Hma(i,D,u,H);i=C+u|0;k=t;j=k+mb|0;j=i>>>0<u>>>0?j+1|0:j;j=(j|0)==(k|0)&i>>>0<C>>>0|j>>>0<k>>>0;k=(d|0)==(s|0)&k>>>0<z>>>0|d>>>0<s>>>0;i=d;d=Hma(x,l,B,q)+d|0;k=k+mb|0;k=d>>>0<i>>>0?k+1|0:k;i=d;d=j+d|0;j=k;j=d>>>0<i>>>0?j+1|0:j;i=d;d=d+p|0;k=j+e|0;k=d>>>0<i>>>0?k+1|0:k;i=d;j=d;d=k;k=(e|0)==(k|0)&j>>>0<p>>>0|e>>>0>k>>>0;e=k+A|0;j=h;j=e>>>0<k>>>0?j+1|0:j;k=e;e=i;w=e-2|0;h=w;q=d-(e>>>0<2)|0;e=q;e=(d|0)==(e|0)&h>>>0<i>>>0|d>>>0>e>>>0;d=k+e|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;h=k-(e>>>0<1)|0;e=0;x=e;l=d;i=r;z=i<<2|c>>>30;A=0;p=Hma(d,e,z,A);e=mb;o=e;j=e;e=c;B=(e&1073741823)<<2|b>>>30;t=0;H=h;i=0;e=Hma(B,t,h,i);d=e+p|0;j=mb+j|0;j=d>>>0<e>>>0?j+1|0:j;k=(j|0)==(o|0)&d>>>0<p>>>0|j>>>0<o>>>0;p=d;h=j;e=j;s=q;j=0;q=j;c=k;C=((n&1073741823)<<2|r>>>30)&-262145|262144;j=Hma(s,j,C,0);d=j+d|0;k=mb+e|0;k=d>>>0<j>>>0?k+1|0:k;n=d;e=k;h=(k|0)==(h|0)&d>>>0<p>>>0|h>>>0>k>>>0;d=c+h|0;j=0;j=d>>>0<h>>>0?1:j;h=Hma(H,i,C,J);d=h+d|0;j=mb+j|0;j=d>>>0<h>>>0?j+1|0:j;r=Hma(l,x,C,J);h=mb;c=d;o=Hma(z,A,H,i);d=o+r|0;k=mb+h|0;k=d>>>0<o>>>0?k+1|0:k;o=d;d=k;k=(h|0)==(d|0)&r>>>0>o>>>0|h>>>0>d>>>0;r=c+d|0;j=j+k|0;k=r;h=k>>>0<d>>>0?j+1|0:j;p=n;n=0;d=p+n|0;r=e;j=o+e|0;j=d>>>0<n>>>0?j+1|0:j;e=j;n=(j|0)==(r|0)&d>>>0<p>>>0|j>>>0<r>>>0;j=k+n|0;k=h;u=j;h=j>>>0<n>>>0?k+1|0:k;r=d;n=e;p=Hma(B,t,s,q);e=mb;o=Hma(w,0,z,A);d=o+p|0;j=mb+e|0;j=d>>>0<o>>>0?j+1|0:j;o=d;p=(e|0)==(j|0)&p>>>0>d>>>0|e>>>0>j>>>0;e=j;D=p;k=b;c=k<<2&-4;k=Hma(l,x,c,0);d=k+d|0;j=mb+j|0;j=d>>>0<k>>>0?j+1|0:j;p=d;k=d;d=j;j=(j|0)==(e|0)&k>>>0<o>>>0|e>>>0>j>>>0;e=D+j|0;k=0;k=e>>>0<j>>>0?1:k;o=e;e=r+e|0;j=k+n|0;j=e>>>0<o>>>0?j+1|0:j;o=e;k=e;e=j;n=(j|0)==(n|0)&k>>>0<r>>>0|j>>>0<n>>>0;k=n+u|0;j=h;u=k;n=k>>>0<n>>>0?j+1|0:j;N=Hma(H,i,c,O);H=mb;i=Hma(C,J,w,P);h=i+N|0;k=mb+H|0;k=h>>>0<i>>>0?k+1|0:k;C=h;r=Hma(z,A,s,q);h=h+r|0;i=k;j=k+mb|0;j=h>>>0<r>>>0?j+1|0:j;z=h;k=Hma(l,x,B,t);h=h+k|0;l=j;j=j+mb|0;r=h;j=h>>>0<k>>>0?j+1|0:j;h=j;x=0;D=(j|0)==(l|0)&r>>>0<z>>>0|j>>>0<l>>>0;j=(i|0)==(l|0)&z>>>0<C>>>0|i>>>0>l>>>0;i=j+((i|0)==(H|0)&C>>>0<N>>>0|i>>>0<H>>>0)|0;k=0;i=D+i|0;j=i;k=h|0;i=k+o|0;j=(j|x)+e|0;j=i>>>0<k>>>0?j+1|0:j;k=i;l=j;j=(e|0)==(j|0)&k>>>0<o>>>0|e>>>0>j>>>0;e=j+u|0;k=n;z=e;e=e>>>0<j>>>0?k+1|0:k;o=i;s=Hma(s,q,c,O);q=mb;k=Hma(B,t,w,P);i=k+s|0;j=mb+q|0;j=i>>>0<k>>>0?j+1|0:j;n=j;j=0;k=(n|0)==(q|0)&i>>>0<s>>>0|n>>>0<q>>>0;i=n+p|0;j=(j|k)+d|0;j=i>>>0<n>>>0?j+1|0:j;k=i;i=j;c=(d|0)==(j|0)&k>>>0<p>>>0|d>>>0>j>>>0;j=j+r|0;n=0;h=n+k|0;d=h;j=d>>>0<n>>>0?j+1|0:j;h=(i|0)==(j|0)&d>>>0<k>>>0|i>>>0>j>>>0;d=c+h|0;j=0;j=d>>>0<h>>>0?1:j;h=d;d=d+o|0;k=j+l|0;k=d>>>0<h>>>0?k+1|0:k;h=d;i=k;k=(k|0)==(l|0)&d>>>0<o>>>0|k>>>0<l>>>0;d=k+z|0;j=e;j=d>>>0<k>>>0?j+1|0:j;e=j;d:{if((j|0)==131071|j>>>0<131071){q=0;w=b<<17;l=f;x=0;s=Hma(i,0,l,x);b=mb;z=b;c=0;A=c;t=0;j=Hma(h,c,g,t);c=j+s|0;k=mb+b|0;k=c>>>0<j>>>0?k+1|0:k;b=k;p=q;u=0;o=Hma(l,x,h,A);q=u+o|0;j=c;k=j+mb|0;k=q>>>0<o>>>0?k+1|0:k;o=k;j=(j|0)==(k|0)&u>>>0>q>>>0|j>>>0>k>>>0;H=p-j|0;k=(q|0)!=0|(k|0)!=0;u=H-k|0;w=(w-(j>>>0>p>>>0)|0)-(k>>>0>H>>>0)|0;j=Hma(d,0,l,x);k=mb;l=Hma(h,A,y,0);j=l+j|0;k=mb+k|0;k=j>>>0<l>>>0?k+1|0:k;r=Hma(i,n,g,t);l=r+j|0;j=mb+k|0;j=l>>>0<r>>>0?j+1|0:j;j=((b|0)==(z|0)&c>>>0<s>>>0|b>>>0<z>>>0)+j|0;c=b;b=b+l|0;k=b;b=k>>>0<c>>>0?j+1|0:j;c=Hma(h,i,I,0);j=mb;p=k;l=Hma(f,g,e,0);c=l+c|0;k=mb+j|0;k=c>>>0<l>>>0?k+1|0:k;l=Hma(d,e,g,t);c=l+c|0;j=mb+k|0;k=Hma(i,n,y,G);c=k+c|0;k=c;y=0;c=p+y|0;j=b+k|0;j=c>>>0<y>>>0?j+1|0:j;b=c;y=u-b|0;G=w-((b>>>0>u>>>0)+j|0)|0;K=K-1|0;n=0-q|0;b=0-(((q|0)!=0)+o|0)|0;break d}q=i>>>1|0;w=0;p=b<<16;h=(i&1)<<31|h>>>1;i=d<<31|i>>>1;b=0;s=b;r=0;t=Hma(h,b,g,r);b=mb;A=b;j=n;k=e<<31|d>>>1;n=d<<31|q;H=j|k;o=n;C=0;B=0;k=Hma(n,C,f,B);c=k+t|0;j=mb+b|0;j=c>>>0<k>>>0?j+1|0:j;b=j;u=w;x=0;D=Hma(h,s,f,B);w=x+D|0;j=c;k=j+mb|0;k=w>>>0<D>>>0?k+1|0:k;D=k;j=(j|0)==(k|0)&x>>>0>w>>>0|j>>>0>k>>>0;J=u-j|0;k=(w|0)!=0|(k|0)!=0;x=J-k|0;u=(p-(j>>>0>u>>>0)|0)-(k>>>0>J>>>0)|0;j=Hma(h,i,I,0);p=mb;J=Hma(f,g,e>>>1|0,0);j=J+j|0;k=mb+p|0;k=j>>>0<J>>>0?k+1|0:k;d=(e&1)<<31|d>>>1;e=e>>>1|0;J=Hma(d,e,g,r);p=J+j|0;n=Hma(n,H,y,G);G=n+p|0;n=0;j=Hma(g,r,o,C);r=mb;q=Hma(d,0,f,B);k=q+j|0;j=mb+r|0;l=Hma(h,s,y,0);y=l+k|0;k=mb+(k>>>0<q>>>0?j+1|0:j)|0;j=y;y=l>>>0>j>>>0?k+1|0:k;k=(b|0)==(A|0)&c>>>0<t>>>0|b>>>0<A>>>0;c=b;b=b+j|0;k=k+y|0;k=b>>>0<c>>>0?k+1|0:k;c=b;b=b+n|0;j=k+G|0;j=b>>>0<c>>>0?j+1|0:j;y=x-b|0;G=u-((b>>>0>x>>>0)+j|0)|0;n=0-w|0;b=0-(((w|0)!=0)+D|0)|0}if((K|0)>=16384){F=F|2147418112;b=0;c=0;break b}l=K+16383|0;if((K|0)<=-16383){e:{if(l){break e}l=n;k=b<<1|l>>>31;l=l<<1;c=(g|0)==(k|0)&f>>>0<l>>>0|g>>>0<k>>>0;f=y;k=G<<1|f>>>31;f=f<<1|b>>>31;f=(f|0)==(M|0)&(k|0)==(I|0)?c:(I|0)==(k|0)&f>>>0>M>>>0|k>>>0>I>>>0;b=f+h|0;j=i;j=b>>>0<f>>>0?j+1|0:j;c=j;f=d+((i|0)==(j|0)&b>>>0<h>>>0|i>>>0>j>>>0)|0;k=e&65535;e=f;k=d>>>0>e>>>0?k+1|0:k;d=k;if(!(d&65536)){break e}L=e|L;F=d|F;break b}b=0;c=0;break b}j=i;k=b<<1|n>>>31;r=n<<1;g=(g|0)==(k|0)&f>>>0<=r>>>0|g>>>0<k>>>0;f=y;k=G<<1|f>>>31;c=f<<1|b>>>31;c=(c|0)==(M|0)&(k|0)==(I|0)?g:(I|0)==(k|0)&c>>>0>=M>>>0|k>>>0>I>>>0;b=c+h|0;j=b>>>0<c>>>0?j+1|0:j;c=j;f=d+((i|0)==(j|0)&b>>>0<h>>>0|i>>>0>j>>>0)|0;j=e&65535;e=f;k=(l<<16)+(d>>>0>e>>>0?j+1|0:j)|0;f=0;e=f+e|0;L=L|e;F=F|(e>>>0<f>>>0?k+1|0:k)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=L;v[a+12>>2]=F;jb=m+192|0;return}v[a>>2]=0;v[a+4>>2]=0;b=!(d|f|(e|g));v[a+8>>2]=b?0:L;v[a+12>>2]=b?2147450880:F;jb=m+192|0}function IH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=jb-128|0;jb=h;a:{b:{if(g){Hj(h+112|0,f,32);v[114578]=0;W(800,h+96|0,f|0,32)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break b}c=P()|0;O()|0;break a}Wb(h+112|0);Wb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(Nr(c)){i=b+24|0;b=v[i>>2];v[114578]=0;b=Q(444,b+484344|0,c&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break r}if(b){break q}}v[114578]=0;U(2196,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)!=1){break p}}c=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){v[114578]=0;U(2196,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)!=1){break p}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){v[114578]=0;U(2196,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}break p}v[114578]=0;c=W(2197,b|0,d|0,e&65535)|0;b=v[114578];v[114578]=0;if((b|0)==1){break o}Le(h+112|0);Le(h+96|0);v[114578]=0;b=T(553,c|0)|0;d=v[114578];v[114578]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){F:{G:{if(!b){if(!js(c)){break G}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[114578]=0;X(2198,h- -64|0,b|0,e|0,d|0);d=v[114578];v[114578]=0;b=1;if((d|0)==1){break E}v[114578]=0;U(9,h+80|0,0,h- -64|0);d=v[114578];v[114578]=0;if((d|0)!=1){break F}c=P()|0;O()|0;break B}b=0;v[114578]=0;Q(85,h+80|0,38869)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}}v[114578]=0;Q(1251,h+112|0,h+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break C}yb(h+80|0);if(b){yb(h- -64|0)}v[114578]=0;b=T(553,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}H:{if(b){v[114578]=0;Q(85,h+80|0,38873)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}break H}if(js(c)){v[114578]=0;Q(85,h+80|0,38877)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break H}break e}v[114578]=0;Q(85,h+80|0,38869)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}}v[114578]=0;Q(1251,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break A}yb(h+80|0);j=f-1|0;if(j>>>0<5){break t}v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break z}v[114578]=0;Q(1251,h+112|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break y}yb(b);v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break x}v[114578]=0;Q(1251,h+96|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break w}yb(b);b=c+1|0;I:{if(w[c+1|0]){v[114578]=0;R(838,h+80|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){break I}break f}v[114578]=0;Q(85,h+80|0,38881)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}}v[114578]=0;Q(1251,h+112|0,h+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}yb(h+80|0);J:{if(w[b|0]){v[114578]=0;Q(85,h+80|0,38884)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break J}break g}v[114578]=0;Q(85,h+80|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}}v[114578]=0;Q(1251,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break u}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(h+80|0);if(!b){break c}}yb(h- -64|0);break c}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;yb(h+80|0);break c}yb(h+80|0);if(j>>>0<8){break t}v[114578]=0;b=T(1342,c|0)|0;d=v[114578];v[114578]=0;K:{L:{M:{N:{O:{P:{Q:{if((d|0)!=1){R:{if(b){v[114578]=0;b=Q(85,h+48|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;e=T(1344,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break P}d=0;v[114578]=0;v[h+16>>2]=e&255;R(837,h+32|0,h+16|0);k=v[114578];v[114578]=0;e=1;if((k|0)==1){break P}v[114578]=0;U(138,h+80|0,b|0,h+32|0);b=v[114578];v[114578]=0;if((b|0)!=1){break R}c=P()|0;O()|0;break i}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[114578]=0;b=Q(2199,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break L}v[114578]=0;b=W(800,h+48|0,1,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break L}e=0;v[114578]=0;R(838,h+32|0,c+4|0);k=v[114578];v[114578]=0;d=1;if((k|0)==1){break O}v[114578]=0;U(138,h+80|0,b|0,h+32|0);b=v[114578];v[114578]=0;if((b|0)!=1){break R}c=P()|0;O()|0;yb(h+32|0);break k}e=0;v[114578]=0;Q(85,h+80|0,38901)|0;b=v[114578];v[114578]=0;d=0;if((b|0)==1){break M}}v[114578]=0;Q(1251,h+112|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break N}yb(h+80|0);if(d){yb(h+32|0);yb(h+48|0)}if(e){yb(h+32|0);yb(h+48|0)}v[114578]=0;b=T(1342,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break l}S:{if(b){v[114578]=0;Q(85,h+80|0,38905)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}break S}if(w[c+2|0]){v[114578]=0;Q(85,h+80|0,38909)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break S}break l}v[114578]=0;Q(85,h+80|0,38901)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}}v[114578]=0;Q(1251,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break K}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break h}c=P()|0;O()|0;break k}c=P()|0;O()|0;yb(h+80|0);if(!d){break j}yb(h+32|0);break k}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}yb(h+80|0);if(j>>>0<12){break t}v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{if((d|0)!=1){v[114578]=0;Q(1251,h+112|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break $}yb(b);v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break _}v[114578]=0;Q(1251,h+96|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Z}yb(b);v[114578]=0;b=T(1342,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Y}aa:{if(b){b=0;v[114578]=0;d=T(1343,c|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;v[h+28>>2]=d&4095;R(1062,h+80|0,h+28|0);d=v[114578];v[114578]=0;if((d|0)!=1){break aa}}c=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[114578]=0;b=Q(2200,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break X}v[114578]=0;d=W(800,h+16|0,1,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break X}v[114578]=0;R(838,h|0,c+5|0);e=v[114578];v[114578]=0;b=1;if((e|0)==1){break W}v[114578]=0;U(138,h+80|0,d|0,h|0);d=v[114578];v[114578]=0;if((d|0)!=1){break aa}c=P()|0;O()|0;yb(h);break m}b=0;v[114578]=0;Q(85,h+80|0,38869)|0;d=v[114578];v[114578]=0;if((d|0)==1){break U}}v[114578]=0;Q(1251,h+112|0,h+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break V}yb(h+80|0);if(b){yb(h);yb(h+16|0)}v[114578]=0;b=T(1342,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}ba:{if(b){v[114578]=0;Q(85,h+80|0,38913)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}break ba}if(w[c+3|0]){v[114578]=0;Q(85,h+80|0,38913)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ba}break n}v[114578]=0;Q(85,h+80|0,38869)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}}v[114578]=0;Q(1251,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break T}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break m}c=P()|0;O()|0;yb(h+80|0);if(!b){break c}yb(h);break m}c=P()|0;O()|0;break c}yb(h+80|0);if(!f){break s}}ca:{da:{ea:{fa:{if(Fb(h+112|0)>>>0>f>>>0){v[114578]=0;X(232,h+80|0,h+112|0,0,f|0);b=v[114578];v[114578]=0;if((b|0)!=1){break fa}c=P()|0;O()|0;break c}if(g){b=Fb(h+112|0);v[114578]=0;b=W(800,h+80|0,f-b|0,32)|0;c=v[114578];v[114578]=0;if((c|0)==1){break da}v[114578]=0;Q(1251,h+112|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=P()|0;O()|0;yb(b);break c}yb(b);if(Fb(h+96|0)>>>0>f>>>0){break ca}break ea}if(Fb(h+96|0)>>>0<=f>>>0){break s}break ca}Gb(h+112|0,h+80|0);yb(h+80|0);if(Fb(h+96|0)>>>0>f>>>0){break ca}if(!g){break s}}b=Fb(h+96|0);v[114578]=0;b=W(800,h+80|0,f-b|0,32)|0;c=v[114578];v[114578]=0;ga:{if((c|0)!=1){v[114578]=0;Q(1251,h+96|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ga}yb(b);break s}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}v[114578]=0;X(232,h+80|0,h+96|0,0,f|0);b=v[114578];v[114578]=0;if((b|0)!=1){Gb(h+96|0,h+80|0);yb(h+80|0);break s}c=P()|0;O()|0;break c}v[114578]=0;U(2196,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}}yb(h+96|0);yb(h+112|0);jb=h+128|0;return}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}yb(h+16|0);break c}c=P()|0;O()|0;break c}yb(h+48|0)}if(!e){break c}}yb(h+32|0)}yb(h+48|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0}yb(h+96|0)}yb(h+112|0);S(c|0);L()}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-304|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!et(b,d+208|0)){break j}if(!PP(d+208|0)){break j}if(!Qb(b,hd(OP(d+208|0),mb))){break j}if(!c){n=1;break j}if(!Qc(b,w[d+208|4])){break j}Hd(a,268435456);vi(a);v[a+480208>>2]=4;f=Ub(d+88|0,16651);Gb(a+1304436|0,f);yb(f);f=Ub(d+88|0,16670);Gb(a+1304448|0,f);yb(f);v[a+1304496>>2]=4;Ye(d+16|0,d+208|6,48,3);Ic(d+88|0,d+16|0);Gb(a+1304400|0,d+88|0);yb(d+88|0);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){f=0;while(1){u[((f<<5)+a|0)+480284>>1]=B(w[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;h=jb-16|0;jb=h;k=d+192|0;f=k;v[f>>2]=0;v[f+4>>2]=0;v[114578]=0;v[h+12>>2]=0;W(948,f+8|0,h+12|0,h+8|0)|0;i=v[114578];v[114578]=0;k:{if((i|0)!=1){jb=h+16|0;break k}V(0)|0;O()|0;Ab();L()}l:{if(!e){break l}v[114578]=0;R(946,k|0,e|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;R(947,k|0,e|0);h=v[114578];v[114578]=0;if((h|0)!=1){break l}}a=P()|0;O()|0;LP(f);S(a|0);L()}f=w[d+302|0]|w[d+303|0]<<8;v[114578]=0;W(939,b|0,k|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}r=Jp(d+176|0);o=Jp(d+160|0);f=w[d+301|0];v[114578]=0;W(628,b|0,r|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}h=w[d+300|0];f=0;v[114578]=0;W(628,b|0,o|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break f}if(w[d+300|0]){p=c&2;q=d+88|4;l=d+126|0;m=d+88|6;while(1){v[114578]=0;h=f;f=f+1|0;i=B(f,104)+a|0;j=i+484380|0;R(388,j|0,0);e=v[114578];v[114578]=0;m:{n:{if((e|0)!=1){e=Pb(o,h);if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break m}e=Pb(o,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}if(!e){break m}v[114578]=0;e=Q(940,b|0,d+88|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}if(!e){break m}v[114578]=0;U(746,d+72|0,2,m|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;R(417,d+16|0,d+72|0);e=v[114578];v[114578]=0;if((e|0)!=1){break n}}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}v[114578]=0;Q(371,((f<<5)+a|0)+946304|0,d+16|0)|0;e=v[114578];v[114578]=0;o:{p:{q:{r:{s:{if((e|0)!=1){yb(d+16|0);v[114578]=0;U(941,d+72|0,2,l|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}v[114578]=0;R(417,d+16|0,d+72|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}v[114578]=0;Q(372,i+484423|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break r}yb(d+16|0);if(w[d+138|0]<=15){e=i+484414|0;u[e>>1]=x[e>>1]|32;u[i+484408>>1]=B(w[d+138|0],17)}e=w[d+139|0];v[114578]=0;t[d+16|0]=e;t[d+72|0]=64;e=Q(393,d+16|0,d+72|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}u[i+484412>>1]=w[e|0];v[i+484404>>2]=w[d+141|0]|w[d+142|0]<<8;e=i+484384|0;v[e>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);g=i+484388|0;v[g>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[j>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break p}n=v[e>>2];e=v[g>>2];break o}f=P()|0;O()|0;yb(d+16|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;yb(d+16|0);break b}f=P()|0;O()|0;break b}n=v[e>>2]>>>1|0;v[e>>2]=n;e=v[g>>2]>>>1|0;v[g>>2]=e;v[j>>2]=v[j>>2]>>>1}t:{if(e>>>0<=n>>>0){break t}e=i+484414|0;u[e>>1]=x[e>>1]|2;if(!(w[d+140|0]&2)){break t}u[e>>1]=x[e>>1]|4}v[114578]=0;Z(942,j|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!p){break m}h=Pb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);e=w[q|0];v[114578]=0;Q(256,b|0,e+h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break c}h=ad(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[114578]=0;W(402,h|0,j|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break m}f=P()|0;O()|0;break b}if(w[d+300|0]>f>>>0){continue}break}}n=1;u:{if(!(c&1)){break u}v[d+68>>2]=0;i=a+484360|0;Xp(Vb(i));F=d,G=bc(k),v[F+64>>2]=G;F=d,G=cc(k),v[F+56>>2]=G;j=a+484344|0;if(Jb(d- -64|0,d+56|0)){z=d+88|5;p=d+88|4;while(1){h=v[d- -64>>2];c=h;v:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break v}c=Pb(r,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}if(!c){break v}v[114578]=0;Q(943,b|0,d+88|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}if(!w[p|0]){break v}c=w[h|0]|w[h+1|0]<<8;f=w[h|0]|w[h+1|0]<<8;t[d+16|0]=w[z|0];e=w[d+262|0];g=w[h+2|0];v[114578]=0;t[d+72|0]=e-g;e=Q(393,d+16|0,d+72|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}q=w[e|0];e=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[114578]=0;v[d+52>>2]=e+g;e=Q(394,d+68|0,d+52|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}v[d+68>>2]=v[e>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break v}s=c>>>6|0;e=f&63;A=0;while(1){w:{x:{y:{z:{A:{B:{C:{f=e>>>0>63;s=f+s|0;c=s&65535;if(oc(Vb(i))>>>0<=c>>>0){g=Vb(i);v[114578]=0;R(930,g|0,s+1&65535);g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;g=W(812,j|0,64,0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break C}F=rc(Vb(i),c),G=g,u[F>>1]=G}l=x[rc(Vb(i),c)>>1];v[114578]=0;c=Q(444,j|0,l|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}if(!c){break v}c=_b(j,l);g=w[h+2|0];v[114578]=0;y=f?0:e;f=W(472,c|0,y|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break x}m=0;if(q){break B}break y}f=P()|0;O()|0;break b}while(1){v[114578]=0;R(944,d+72|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break z}g=cd(d+72|0);D=Bf(d+72|0);C=Rh(d+72|0);E=hc(d+72|0);e=0;c=w[d+72|0];if((c-1&255)>>>0<=142){e=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+m|0]=e}t[f|0]=e;c=w[g|0];t[f+2|0]=1;t[f+1|0]=c;c=w[D|0];D:{if((c|0)!=255){t[f+4|0]=c;break D}t[f+2|0]=0}c=w[C|0];E:{if(c>>>0>22){break E}t[f+3|0]=w[c+16688|0];g=w[E|0];t[f+5|0]=g;c=f+5|0;F:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break E;case 4:t[c|0]=g&3|48;break E;case 7:if(Kb(k)>>>0<=g>>>0){break E}g=c;c=Pb(k,w[c|0]);e=w[c|0]|w[c+1|0]<<8;t[g|0]=e>>>6;c=_b(j,l);g=x[a+480188>>1];v[114578]=0;c=W(472,c|0,y|0,g-1&65535)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=e&63;break E}f=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(j,l);e=x[a+480188>>1];v[114578]=0;c=W(472,c|0,y|0,e-1&65535)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break E}f=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break E;case 12:v[114578]=0;t[d+15|0]=15;e=Q(393,c|0,d+15|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c|0]=w[e|0]|208;break E}f=P()|0;O()|0;break b;case 13:v[114578]=0;t[d+15|0]=15;e=Q(393,c|0,d+15|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c|0]=w[e|0]|192;break E}f=P()|0;O()|0;break b;case 14:v[114578]=0;t[d+15|0]=15;e=Q(393,c|0,d+15|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c|0]=w[e|0]|224;break E}f=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break E}e=g&240;if(!e|(e|0)==240){break E}t[c|0]=g|15;break E;case 9:case 18:break F;default:break E}}if(e&255){break E}t[f|0]=w[(d+16|0)+m|0]}f=f+6|0;m=m+1|0;if((q|0)!=(m|0)){continue}break}break y}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(q>>>0>=w[z|0]){break w}c=w[z|0];v[114578]=0;Q(340,b|0,B(c-q|0,5)|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break w}}f=P()|0;O()|0;break b}e=y+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}_d(d- -64|0);if(Jb(d- -64|0,d+56|0)){continue}break}}G:{a=v[d+68>>2];b=a&63;if(!b){break G}c=Vb(i);v[114578]=0;a=a>>>6|0;c=Q(546,c|0,a&65535)|0;f=v[114578];v[114578]=0;if((f|0)!=1){if(!c){break G}a=_b(j,x[rc(Vb(i),a&65535)>>1]);v[114578]=0;aa(945,a|0,b|0,0,1)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break G}}f=P()|0;O()|0;break b}a=Vb(i);F=d,G=bc(a),v[F+88>>2]=G;F=d,G=cc(a),v[F+16>>2]=G;if(!Jb(d+88|0,d+16|0)){break u}e=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){H:{if((e&65535)!=65535){break H}v[114578]=0;e=W(812,j|0,64,0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break H}f=P()|0;O()|0;break b}u[a>>1]=e}te(d+88|0);if(Jb(d+88|0,d+16|0)){continue}break}}Ji(o);Ji(r);NP(k)}jb=d+304|0;return n|0}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0}Ji(o);Ji(r)}NP(k);S(f|0);L()}function dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-240|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!lA(b,d+168|0)){break j}if(!nT(d+168|0)){break j}if(!c){e=1;break j}Hd(a,131072);j=Ub(d+152|0,12688);v[114578]=0;R(219,d+32|0,j|0);e=v[114578];v[114578]=0;k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[114578]=0;U(537,d+104|0,d+32|0,d+168|4);e=v[114578];v[114578]=0;if((e|0)==1){break q}Gb(a+1304436|0,d+104|0);yb(d+104|0);Ib(d+32|0);yb(j);e=Ub(d+104|0,12702);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;HT(d+32|0,3,d+181|0);Ic(d+104|0,d+32|0);Gb(a+1304400|0,d+104|0);yb(d+104|0);Hn(d+72|0,3,d+211|0);Ic(d+32|0,d+72|0);v[114578]=0;U(13,d+104|0,4,d+32|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Gb(a+1304412|0,d+104|0);yb(d+104|0);yb(d+32|0);e=Sp(d+104|0);m=e,n=Fd(w[d+231|0],1,31),v[m+12>>2]=n;m=e,n=Fd(w[d+232|0],1,12)-1|0,v[m+16>>2]=n;v[e+20>>2]=w[d+233|0];j=a+1304500|0;kA(j);mT(j,e);i=d+72|4;e=jb-16|0;jb=e;j=d+88|0;f=j;v[f>>2]=0;v[f+4>>2]=0;v[114578]=0;v[e+12>>2]=0;W(567,f+8|0,e+12|0,e+8|0)|0;f=v[114578];v[114578]=0;r:{if((f|0)!=1){jb=e+16|0;break r}V(0)|0;O()|0;Ab();L()}while(1){v[114578]=0;e=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}if(!e){break k}v[114578]=0;Q(538,b|0,d+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}f=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);e=w[d+172|0];s:{if((e|0)==3){g=2;if((w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))==1431389523){break s}e=w[d+172|0]}if((e&255)==4){g=4;if((w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))==1431389523){break s}e=w[d+172|0]}g=0;if((e&255)>>>0>7){break s}f=(w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))==1146113363?-1:f}v[114578]=0;U(343,d+32|0,b|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}v[114578]=0;W(539,j|0,d+72|0,d+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}Bb(d+32|0);v[114578]=0;Q(340,b|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break p}e=P()|0;O()|0;Ib(d+32|0)}yb(j);break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+32|0);break b}v[114578]=0;b=T(277,d+72|0)|0;e=v[114578];v[114578]=0;t:{u:{v:{if((e|0)!=1){v[114578]=0;U(540,d+32|0,j|0,1431389523);e=v[114578];v[114578]=0;if((e|0)==1){break v}Wd(b,d+32|0);Bb(d+32|0);u[d+70>>1]=0;u[d+68>>1]=65534;if(w[d+172|0]<3){break t}v[114578]=0;e=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break u}break d}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}u[d+70>>1]=e;if(w[d+172|0]<4){break t}v[114578]=0;e=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}u[d+68>>1]=w[d+172|0]==4?e?e:-2:e}e=a+484360|0;f=Vb(e);v[114578]=0;g=T(332,b|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;ea(443,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}f=Vb(e);v[114578]=0;f=T(541,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}jg(d+70|0,f);f=Vb(e);v[114578]=0;f=T(541,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}jg(d+68|0,f);v[114578]=0;U(540,d+32|0,j|0,1414807888);f=v[114578];v[114578]=0;w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){Wd(b,d+32|0);Bb(d+32|0);v[114578]=0;f=T(339,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!f|!(c&1)){break w}v[114578]=0;Q(542,b|0,d- -64|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}m=a,n=Fd(w[d- -64|2],1,32)+1|0,u[m+480188>>1]=n;f=d- -64|0;f=w[f|0]|w[f+1|0]<<8;v[114578]=0;f=Q(397,d|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}m=d,n=bc(f),v[m+16>>2]=n;m=d,n=cc(f),v[m+56>>2]=n;if(Jb(d+16|0,d+56|0)){while(1){i=v[d+16>>2];v[114578]=0;g=w[d+172|0]<3?9:8;Q(340,b|0,g-4|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break B}v[114578]=0;h=T(392,b|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break A}fg(b,g);v[114578]=0;U(343,d+32|0,b|0,g+h|0);g=v[114578];v[114578]=0;if((g|0)==1){break z}Wd(i,d+32|0);Bb(d+32|0);Uf(d+16|0);if(Jb(d+16|0,d+56|0)){continue}break}}g=x[a+480188>>1];v[114578]=0;g=Q(543,d+32|0,g|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break y}i=Vb(e);v[114578]=0;h=T(544,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break f}v[114578]=0;i=a+484344|0;R(403,i|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break f}h=Vb(e);m=d,n=bc(h),v[m+16>>2]=n;m=d,n=cc(h),v[m+56>>2]=n;if(Jb(d+16|0,d+56|0)){while(1){h=v[d+16>>2];k=x[h>>1];if(nd(f)>>>0>k>>>0){k=tc(f,x[h>>1]);v[114578]=0;k=aa(545,k|0,w[d+172|0],g|0,a|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break f}u[h>>1]=k}te(d+16|0);if(Jb(d+16|0,d+56|0)){continue}break}}h=Vb(e);v[114578]=0;h=Q(546,h|0,x[d+68>>1])|0;k=v[114578];v[114578]=0;if((k|0)==1){break f}if(!h){break x}if(!x[d+70>>1]){h=x[d+68>>1];k=Vb(e);v[114578]=0;k=T(541,k|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break f}if(h>>>0>=k>>>0){break x}}e=x[rc(Vb(e),x[d+68>>1])>>1];h=_b(i,e);v[114578]=0;k=W(498,d+16|0,12,w[d+70|0])|0;l=v[114578];v[114578]=0;if((l|0)!=1){e=Gn(Ne(k,v[_b(i,e)+12>>2]-1|0));v[114578]=0;Q(499,h|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break x}}break f}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}eT(g);gd(f)}v[114578]=0;U(540,d+32|0,j|0,1196641603);e=v[114578];v[114578]=0;if((e|0)==1){break h}Wd(b,d+32|0);Bb(d+32|0);v[114578]=0;e=T(339,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}if(e){v[114578]=0;Q(340,b|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;e=T(332,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;ea(547,a+1304424|0,b|0,e|0,40,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}}v[114578]=0;U(540,d+32|0,j|0,1146113363);e=v[114578];v[114578]=0;if((e|0)==1){break g}v[114578]=0;U(540,d+16|0,j|0,1229999443);e=v[114578];v[114578]=0;E:{F:{if((e|0)!=1){Wd(b,d+16|0);Bb(d+16|0);v[114578]=0;f=T(389,b|0)|0;g=v[114578];v[114578]=0;e=1;G:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){i=c&2;c=1;while(1){g=30;H:{I:{J:{if(w[d+172|0]>=2){v[114578]=0;g=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break J}}v[114578]=0;W(548,b|0,((e<<5)+a|0)+946304|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break J}v[114578]=0;Q(549,b|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}v[114578]=0;e=B(e,104)+a|0;g=e+484380|0;R(550,d+16|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break I}f=w[d+172|0];if(f>>>0>=8){v[114578]=0;W(551,b|0,e+484423|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}f=w[d+172|0]}v[114578]=0;Q(340,b|0,((f&255)>>>0>1?6:2)|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}v[114578]=0;f=T(392,d+32|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;U(343,d|0,d+32|0,f|0);f=v[114578];v[114578]=0;if((f|0)!=1){break H}}e=P()|0;O()|0;break F}e=P()|0;O()|0;break F}e=P()|0;O()|0;break F}v[114578]=0;f=T(339,d|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break G}K:{if(!f|!i){break K}e=ad(d+56|0,u[e+484414>>1]&1?16:8,1,0,(w[d+31|0]&12)==4?7:0);v[114578]=0;W(402,e|0,g|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break K}break G}Bb(d);c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}v[114578]=0;Z(477,a|0);c=v[114578];v[114578]=0;e=1;if((c|0)!=1){break E}}e=P()|0;O()|0;break F}e=P()|0;O()|0;Bb(d);break F}e=P()|0;O()|0}Bb(d+32|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;Bb(d+32|0);Bb(b);lT(j)}jb=d+240|0;return e|0}e=P()|0;O()|0;yb(d+32|0);break a}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;eT(g)}gd(f);break c}e=P()|0;O()|0}Bb(b)}lT(j)}S(e|0);L()}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-272|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+112|0;AS(g+8|0,i);h=Hb(g+8|0);e=b;j=nc(e,ac(g,g+8|0));if((h|0)==(j|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(h|0)==(j|0);if(!e){BS(i)}a:{b:{c:{d:{e:{f:{g:{if(!e){break g}if(!DS(d+112|0)){break g}if(!c){f=1;break g}Hd(a,v[((w[d+228|0]|w[d+229|0]<<8)<<2)+12976>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;e=Ub(d+16|0,13016);Gb(a+1304436|0,e);yb(e);e=Ub(d+16|0,13038);Gb(a+1304448|0,e);yb(e);e=Ub(d+80|0,13042);v[114578]=0;R(219,d+96|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;X(429,d+16|0,d+96|0,d+191|0,d+188|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}Gb(a+1304460|0,d+16|0);yb(d+16|0);Ib(d+96|0);yb(e);Mc(a+1304484|0,((w[d+228|0]|w[d+229|0]<<8)<<2)+13072|0);Mc(a+1304472|0,v[((w[d+228|0]|w[d+229|0]<<8)<<2)+77264>>2]);v[a+1304496>>2]=4;yg(d+96|0,2,d+112|4);Ic(d+16|0,d+96|0);Gb(a+1304400|0,d+16|0);yb(d+16|0);yg(d+96|0,2,d+148|0);Ic(d+16|0,d+96|0);h:{i:{j:{if(Et(d+16|0,13112)){v[114578]=0;U(13,d+96|0,4,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break j}Gb(a+1304412|0,d+96|0);yb(d+96|0)}yb(d+16|0);u[a+480188>>1]=32;e=0;k:{while(1){g=(e<<5)+a|0;i=g+480280|0;zg(i);l:{f=d+e|0;if(w[f+193|0]<=15){v[d+16>>2]=w[f+193|0]<<4|8;v[d+96>>2]=256;q=g+480284|0,r=v[de(d+16|0,d+96|0)>>2],u[q>>1]=r;break l}if(w[f+193|0]==16){u[g+480284>>1]=128;v[i>>2]=256;break l}if(w[f+193|0]!=255){break l}u[a+480188>>1]=e;break k}e=e+1|0;if((e|0)!=32){continue}break}e=x[a+480188>>1]}f=0;if(!(e&65535)){break g}v[d+16>>2]=w[d+225|0]<<2;v[d+96>>2]=256;q=a,r=v[Lb(d+16|0,d+96|0)>>2],v[q+480200>>2]=r;v[a+480196>>2]=w[d+226|0];v[a+480204>>2]=B(w[d+227|0],1e4);if(Qc(b,w[d+230|0]|w[d+231|0]<<8|(w[d+232|0]<<16|w[d+233|0]<<24))){Np(Vb(a+484360|0),b,w[d+234|0]+1|0,255,254)}if(!Qc(b,w[d+240|0]|w[d+241|0]<<8|(w[d+242|0]<<16|w[d+243|0]<<24))){break g}u[a+480190>>1]=w[d+248|0]+1;h=d+48|0;e=1;i=1;while(1){g=jb-16|0;jb=g;f=jb-16|0;jb=f;j=d+16|0;gc(g+8|0,j,62);jb=f+16|0;l=Hb(g+8|0);f=b;k=nc(f,ac(g,g+8|0));if((l|0)==(k|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(l|0)==(k|0);if(!f){g=jb-16|0;jb=g;Rb(j,0,62);jb=g+16|0}if(f){f=B(e,104)+a|0;g=f+484380|0;Ed(g,0);yg(d,2,d+16|0);Ic(d+96|0,d);v[114578]=0;Q(371,((e<<5)+a|0)+946304|0,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}yb(d+96|0);Fk(d,2,h);Ic(d+96|0,d);v[114578]=0;Q(372,f+484423|0,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}yb(d+96|0);e=f+484404|0;v[e>>2]=w[d+74|0]|w[d+75|0]<<8;m:{if(!Lp(a)){break m}j=v[e>>2];e=0;while(1){if((j|0)==x[(e<<1)+13120>>1]){t[f+484417|0]=e<<4;break m}e=e+1|0;if((e|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24);if(w[d+73|0]&2){e=f+484414|0;u[e>>1]=x[e>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[d+65|0]|w[d+66|0]<<8|(w[d+67|0]<<16|w[d+68|0]<<24);v[f+484388>>2]=(w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24))-1;if(t[d+73|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}n:{if(w[d+73|0]&4){t[d+96|0]=w[d+76|0];t[d|0]=64;q=f+484410|0,r=w[pc(d+96|0,d)|0]<<2,u[q>>1]=r;break n}e=f+484414|0;u[e>>1]=x[e>>1]|32768}o:{if(!(w[d+73|0]&8)){u[f+484408>>1]=128;break o}e=f+484414|0;u[e>>1]=x[e>>1]|32;g=f+484408|0;if(w[d+77|0]>=16){f=128}else{f=w[d+77|0];v[d>>2]=256;v[d+96>>2]=f<<4|8;f=v[de(d+96|0,d)>>2]}u[g>>1]=f;u[e>>1]=x[e>>1]&65279|(w[d+77|0]==16)<<8}i=i+1|0;e=i&65535;if(e>>>0<=x[a+480190>>1]){continue}}break}p:{if(!(c&2)){break p}if(!Qc(b,w[d+244|0]|w[d+245|0]<<8|(w[d+246|0]<<16|w[d+247|0]<<24))|!x[a+480190>>1]){break p}e=1;while(1){f=B(e&65535,104)+a|0;tg(ad(d+16|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}m=a+484344|0;$f(m,w[d+239|0]+1|0);f=Vo(a);e=jb-16|0;jb=e;v[e+12>>2]=0;os(e+12|0,f);j=v[e+12>>2];jb=e+16|0;Qc(b,w[d+235|0]|w[d+236|0]<<8|(w[d+237|0]<<16|w[d+238|0]<<24));o=c&1;i=0;l=1;while(1){c=hg(b);if(c>>>0>=3){ud(d+16|0,b,c-2|0);q:{if(!o){break q}v[114578]=0;c=T(339,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}if(!c){break q}v[114578]=0;c=W(404,m|0,i&65535,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}k=0;if(!c){break q}while(1){c=_b(m,i);v[114578]=0;p=Q(497,c|0,k|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}r:{s:while(1){t:{v[114578]=0;c=T(389,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}if(!c){break r}e=c&31;if(e>>>0>=x[a+480188>>1]){break r}f=B(e,6)+p|0;if(c&32){v[114578]=0;R(473,d+96|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}g=cd(d+96|0);e=w[d+96|0];if(e){e=(e&127)-1|0;t[d+96|0]=e;t[f|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+13;v[114578]=0;e=T(611,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}l=e&l}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[114578]=0;c=Q(258,d+16|0,2)|0;e=v[114578];v[114578]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((e|0)!=1){if(!c){continue s}n=w[g|0];c=w[f+3|0];v[114578]=0;R(473,d+96|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}h=w[cd(d+96|0)|0];t[g|0]=h;e=w[(w[d+96|0]&31)+13152|0];t[f+3|0]=e;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 9:case 10:case 12:case 14:case 15:case 16:break w;case 4:case 5:break z;case 18:break B;case 13:break C;case 17:break D;case 11:break E;case 1:break F;case 0:break G;default:break A}}break i}if(h>>>0<224){break u}break v}if(h>>>0>=224){break v}break u}v[114578]=0;t[d|0]=64;e=Q(393,g|0,d|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){t[g|0]=w[e|0];v[114578]=0;e=Q(612,j|0,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}if(!e){break x}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=n;e=c;break w}break i}v[114578]=0;e=Q(613,j|0,19)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}if(e){break x}v[114578]=0;Z(614,f|0);e=v[114578];v[114578]=0;if((e|0)!=1){break x}break i}v[114578]=0;e=Q(613,j|0,15)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}if(e){break x}v[114578]=0;e=Q(613,j|0,19)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}if(!e){break x}t[f+3|0]=19;t[g|0]=w[g|0]&15|144;break u}H:{e=h>>>4|0;if((e|0)!=8){if(e){break H}I:{switch(h&15){case 0:case 1:e=h-112|0;break y;case 4:t[f+3|0]=20;t[g|0]=158;break u;case 5:break I;default:break H}}t[f+3|0]=20;t[g|0]=159;break u}v[114578]=0;e=Q(613,j|0,20)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}if(e){break x}t[f+3|0]=19;break u}t[f+3|0]=0;break u}if((e|0)!=31){break w}t[f+3|0]=17;break u}e=h&240;if(!e){break u}}t[g|0]=e}e=w[f+3|0]}if((e&255)!=20){break u}e=w[g|0];if(w[f+2|0]|(e&240)!=128){break u}t[f+2|0]=2;t[f+4|0]=(((e&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=n;break u}t[g|0]=223}if(w[d+96|0]&32){continue}break}continue}break}break i}k=k+1|0;if((k|0)!=64){continue}break}}Bb(d+16|0)}c=w[d+239|0]>i>>>0;i=i+1|0;if(c){continue}break}break h}f=P()|0;O()|0;yb(d+16|0);break a}f=P()|0;O()|0;Bb(d+16|0);break a}c=a;if(v[a+480180>>2]!=1){e=v[a+480208>>2]&-8454145}else{e=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?l&1?8454144:0:0)}v[c+480208>>2]=e;f=1;if(!(w[d+253|0]|w[d+254|0]<<8|(w[d+255|0]<<16|w[d+256|0]<<24))){break g}if(!Qc(b,w[d+249|0]|w[d+250|0]<<8|(w[d+251|0]<<16|w[d+252|0]<<24))){break g}Ny(a+1304424|0,b,w[d+253|0]|w[d+254|0]<<8|(w[d+255|0]<<16|w[d+256|0]<<24),4)}jb=d+272|0;return f|0}f=P()|0;O()|0;yb(d+96|0);break a}f=P()|0;O()|0;yb(d+96|0);break a}f=P()|0;O()|0;Ib(d+96|0);break b}f=P()|0;O()|0}yb(e)}S(f|0);L()}function Lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=jb-336|0;jb=d;a:{if(!Qc(b,1080)){break a}if(!An(b,d+332|0)){break a}Hd(a,1);o=AQ(d+312|0);if(!zQ(d+332|0,o)){break a}e=x[o+8>>1];if((e-1&65535)>>>0>126){break a}if(!c){g=1;break a}u[a+480188>>1]=e;i=w[o+12|0];N=w[o+11|0];e=w[o+10|0];H=1;if(!$d(d+332|0,15619)){H=$d(d+332|0,15624)}if(w[o+13|0]){Nb(a+1074312|0,5,1)}z=a+480188|0;C=N?x[z>>1]==8:0;p=$d(d+332|0,15629);q=1;if(!$d(d+332|0,15634)){q=$d(d+332|0,15639)}Qc(b,0);Wz(b,a+1304400|0,20);u[a+480190>>1]=31;k=(e|0)!=0;g=1;e=p;while(1){h=B(g,104)+a|0;f=h+484380|0;m=pz(b,d+176|0,f,((g<<5)+a|0)+946304|0,x[a+480188>>1]==4);f=v[f>>2];b:{if(q){t[h+484417|0]=0-(w[d+200|0]<<3);break b}k=f>>>0<65536&k}I=w[d+198|0]|w[d+199|0]<<8?!(w[d+204|0]|w[d+205|0]<<8)|I:I;h=e&1;e=0;c:{if(!h){break c}h=j;j=w[d+198|0]|w[d+199|0]<<8;j=h+(((j<<8|j>>>8)&65535)<<1)|0;if(w[d+200|0]){break c}if(!(w[d+198|0]|w[d+199|0]<<8)){e=1;break c}e=w[d+201|0]==64}J=m+J|0;l=f+l|0;g=g+1|0;if((g|0)!=32){continue}break}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{Q=v[o+4>>2];if(Q>>>0>=J>>>0){oz(b,d+176|0);$b(b,4);r=d+176|1;g=w[r|0];f=128;h=a+484360|0;In(Vb(h),d+176|2,128,65535,65535);g=!g&e;m=g?j:0;e=w[d+176|0];n:{if(e>>>0>128){break n}f=e;if(e){break n}e=128;while(1){j=e-1|0;if(!x[rc(Vb(h),j)>>1]){f=1;e=j;if(e>>>0>1){continue}break n}break}f=e}K=(i|0)!=0;i=xQ(b,Vb(h),f&65535,l,z,m,0);if(!(!g|x[a+480188>>1]!=8)){v[o>>2]=15644;K=1}o:{if(!C){break o}e=Vb(h);da=d,ea=bc(e),v[da+160>>2]=ea;da=d,ea=cc(e),v[da+144>>2]=ea;if(!Jb(d+160|0,d+144|0)){break o}while(1){e=v[d+160>>2];u[e>>1]=x[e>>1]>>>1;te(d+160|0);if(Jb(d+160|0,d+144|0)){continue}break}}Oe(Vb(h),w[r|0]);V=f-1&65535;if(!(w[r|0]!=120|x[z>>1]!=4?V>>>0>=w[r|0]:0)){Oe(Vb(h),0)}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;j=0;e=Yb(256/x[a+480188>>1]|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;mj(a,0);t[d+175|0]=0;D=1;q=1;if(!k){p:{if(!i){l=p;break p}s=d+160|5;l=p;k=0;q=0;while(1){e=0;f=0;while(1){h=Qh(d+160|0);lt(b,h);m=CS(h);q:{r:{s:{h=w[d+163|0];if((h-7&255)>>>0<3){l=0;break s}l=m?l:0;t:{u:{v:{switch(h-13|0){case 2:if(w[d+165|0]>31){break u}break q;case 1:break t;case 0:break v;default:break s}}f=f+1|0;if((f&65535)>>>0<2){break q}}l=0;break q}g=w[d+165|0];l=g>>>0>1?0:l;break r}if((h|0)!=8){if((h|0)!=14){break q}g=w[d+165|0];break r}da=d,ea=w[qh(d+175|0,s)|0],t[da+175|0]=ea;h=t[d+165|0];if((h|0)>-1){q=1;break q}k=(h|0)!=-92&(h&255)>>>0>143|k;break q}if((g&240)!=128){break q}t[d+144|0]=g<<4;da=d,ea=w[qh(d+175|0,d+144|0)|0],t[da+175|0]=ea}D=m&D;e=e+1|0;if((e|0)!=256){continue}break}j=j+1|0;if(i>>>0>(j&65535)>>>0){continue}break}j=0;if((q^-1|k)&1){break p}j=w[d+175|0]>47}q=l&1}Qc(b,1084);l=4;l=C?l:x[z>>1];E=a+484344|0;F=i+C&65535;$f(E,F);m=a+1074312|0;w:{x:{y:{if(F){$=j^1;aa=c&1;h=l;while(1){z:{A:{if(C){e=(y&65534)>>>1|0;f=y&1;if(!f){if(!rg(E,e,64)){break z}}j=Xe(_b(E,e),0,f<<2);break A}if(!rg(E,y&65535,64)){break z}j=Xe(_b(E,y),0,0)}if(!j|!aa){break z}e=x[a+480188>>1];t[d+144|0]=0;s=Qt(d+160|0,e,d+144|0);e=x[a+480188>>1];v[114578]=0;t[d+64|0]=0;G=W(886,d+144|0,e|0,d- -64|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}M=0;while(1){ba=n;B:{if(h){k=0;g=0;f=0;while(1){v[114578]=0;i=B(k,6)+j|0;R(887,b|0,i|0);e=v[114578];v[114578]=0;if((e|0)==1){break f}e=w[i+3|0];C:{D:{E:{if(!e){if(w[i+5|0]){break E}break D}if(!N){break E}F:{switch(e-14|0){case 0:t[i+3|0]=0;t[i+5|0]=0;break E;case 1:break F;default:break E}}if(w[i+5|0]<32){break E}t[i+5|0]=31}wj(i);e=1;G:{H:{I:{n=w[i+3|0];switch(n-14|0){case 2:break C;case 0:break H;case 3:break I;default:break G}}X=w[i+5|0]<100|X;g=1;break D}if(!q){break D}t[i+5|0]=0;break D}if(!($|(n|0)!=9)){e=w[i+5|0];if((e|0)==164){t[i+3|0]=20;t[i+5|0]=145;break D}v[114578]=0;e=T(888,e<<1)|0;n=v[114578];v[114578]=0;if((n|0)==1){break f}t[i+5|0]=e;break D}if((n|0)!=19){break D}e=w[i+5|0];if(e>>>0>15){break D}n=e&1;e=!n;ca=!n;n=Y&1;Y=(n|0)==(e|0)?Y:ca;Z=((e|0)!=(n|0))+Z|0}e=f}J:{if(!w[i|0]){if(!w[i+1|0]|C){break J}if(!w[wc(s,k)|0]){break J}if(w[wc(s,k)|0]==w[i+1|0]){break J}n=wc(G,k);f=w[n|0]+1|0;t[n|0]=f;if((f&255)>>>0<4){break J}v[114578]=0;W(479,m|0,85,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}break J}da=wc(G,k),ea=0,t[da|0]=ea}f=w[i+1|0];if(f){da=wc(s,k),ea=f,t[da|0]=ea}f=e;k=k+1|0;if((h|0)!=(k|0)){continue}break}e=e&g;break B}e=0}n=ba|e;j=B(x[z>>1],6)+j|0;M=M+1|0;if((M|0)!=64){continue}break}fe(G);fe(s);y=y+1|0;if((F|0)!=(y|0)){continue}}break}e=F<<8}else{e=0}K:{f=D^1;if((f|I)&1){break K}L:{if($d(d+332|0,15629)){break L}if($d(d+332|0,15656)){break L}if(!$d(d+332|0,15661)){break K}}v[a+480208>>2]=v[a+480208>>2]|2162688;Nb(m,85,1);Nb(m,91,1);Nb(m,92,1);M:{if(w[d+175|0]>47){break M}Nb(m,84,1);if(w[r|0]==127){break M}Nb(m,83,1)}if(!D){break w}break x}if(D){break x}if(p^1|w[r|0]!=127|w[r|0]+1>>>0<V>>>0){break w}v[o>>2]=15666;break w}g=P()|0;O()|0;break e}if((Z|0)>6|K){break w}v[a+480208>>2]=v[a+480208>>2]|8388608}if((p|K)==1){Nb(m,89,1)}if(H){Nb(m,84,1)}N:{if(!(c&2)){k=p^1;break N}Qc(b,B(e,l)+1084|0);k=p^1;f=f|k;g=1;while(1){l=B(g,104)+a|0;c=l+484380|0;if(v[c>>2]){j=d+160|0;if(H){e=2}else{e=wQ(b,15680)?11:0}e=ad(j,8,1,0,e);p=v[b+8>>2]+rS(e,v[c>>2])|0;if(!f){da=c,ea=v[bd(c,l+484388|0)>>2],v[da>>2]=ea}tg(e,c,b);Qc(b,p)}g=g+1|0;if((g|0)!=32){continue}break}}O:{if((X^-1|k|n)&1){break O}b=vQ(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;Cs(d+160|0,a,0,d+24|0);_=A[v[d+160>>2]>>3];Hl(d+160|0);if(_<600){break O}Nb(m,5,1);b=uQ(d+96|0,_);c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;Cs(d+160|0,a,0,d);b=w[v[d+160>>2]+26|0];Hl(d+160|0);if(b){wg(m,5);break O}v[o>>2]=15686}e=d+332|0;c=d+332|0;b=hc(d+332|0);if((c|0)!=(b|0)){while(1){f=w[c|0];t[e|0]=f>>>0>32?f:32;e=e+1|0;c=c+1|0;if((b|0)!=(c|0)){continue}break}}b=Ub(d+80|0,15706);v[114578]=0;R(219,d+144|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break m}c=hc(d+332|0);v[114578]=0;c=W(889,d+48|0,d+332|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}v[114578]=0;U(13,d- -64|0,1,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break k}v[114578]=0;U(247,d+160|0,d+144|0,d- -64|0);e=v[114578];v[114578]=0;if((e|0)==1){break j}Gb(a+1304436|0,d+160|0);yb(d+160|0);yb(d- -64|0);yb(c);Ib(d+144|0);yb(b);b=Ub(d+160|0,15726);Gb(a+1304448|0,b);yb(b);b=v[o>>2];if(b){Mc(a+1304460|0,b)}v[a+1304496>>2]=2}g=J>>>0<=Q>>>0;break a}g=P()|0;O()|0;break g}g=P()|0;O()|0;break h}g=P()|0;O()|0;break i}g=P()|0;O()|0;yb(d- -64|0)}yb(c)}Ib(d+144|0)}yb(b);break d}g=P()|0;O()|0;fe(G)}fe(s)}S(g|0);L()}jb=d+336|0;return g|0}function AU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=jb-176|0;jb=e;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!AB(b,e+128|0)){break h}if(!BB(e+128|0)){break h}if(!c){m=1;break h}Hd(a,2048);vi(a);d=Ub(e+96|0,12026);v[114578]=0;R(219,e+112|0,d|0);i=v[114578];v[114578]=0;if((i|0)==1){break c}v[114578]=0;k=e+128|3;U(385,e+80|0,e+112|0,k|0);i=v[114578];v[114578]=0;if((i|0)==1){break d}Gb(a+1304436|0,e+80|0);yb(e+80|0);Ib(e+112|0);yb(d);d=Ub(e+80|0,12022);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;u[a+480188>>1]=w[e+168|0];u[a+480190>>1]=w[e+164|0];yg(e+112|0,2,e+128|4);Ic(e+80|0,e+112|0);Gb(a+1304400|0,e+80|0);yb(e+80|0);if(w[k|0]<=9){u[a+480188>>1]=4;fg(b,1);mj(a,1)}d=w[k|0];i:{if(w[k|0]>=11){i=d>>>0>11?32:16;d=0;while(1){g=((d<<5)+a|0)+480284|0;h=ou(b)<<1;h=(h|0)>-128?h:-128;j:{if((h|0)<129){d=h+128|0;break j}v[((d<<5)+a|0)+480280>>2]=256;d=128}u[g>>1]=d;f=f+1|0;d=f&65535;if(i>>>0>d>>>0){continue}break}break i}if((d|0)!=10){break i}zB(b,e+80|0);d=0;while(1){u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}k:{if(w[k|0]>=13){dq(e+80|0,b);f=cd(e+80|0);i=a;j=e+80|0;d=w[j|0];if(d>>>0<32){t[j|0]=125;d=125}v[i+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break k}v[a+480196>>2]=6;v[a+480204>>2]=125e4}i=a+484360|0;eg(Vb(i),w[e+165|0]);n=Ql(e+112|0);g=v[b+8>>2];p=w[k|0];l:{if(w[k|0]<14){break l}d=w[e+165|0];v[114578]=0;R(386,n|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break l}b=P()|0;O()|0;break e}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(w[e+165|0]){d=0;while(1){s=rc(Vb(i),d),z=d,u[s>>1]=z;if(w[k|0]>=14){v[114578]=0;f=T(359,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break u}s=rc(n,d),z=f,u[s>>1]=z}f=x[a+480188>>1];v[114578]=0;Q(340,b|0,f<<1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break u}d=d+1|0;if(d>>>0<w[e+165|0]){continue}break}}d=x[a+480190>>1];v[114578]=0;v[e+80>>2]=0;o=W(387,e- -64|0,d|0,e+80|0)|0;d=v[114578];v[114578]=0;f=1;if((d|0)!=1){v[e+60>>2]=0;v:{if(x[a+480190>>1]){i=1;while(1){v[114578]=0;j=B(f,104)+a|0;h=j+484380|0;R(388,h|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break v}v[114578]=0;l=T(389,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;W(390,b|0,((f<<5)+a|0)+946304|0,32)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;W(391,b|0,j+484423|0,13)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;d=T(392,b|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break g}m=f-1|0;s=Pb(o,m),z=d,v[s>>2]=z;w:{if(w[k|0]<=9){v[114578]=0;f=T(359,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break w}break g}v[114578]=0;f=T(392,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}}v[h>>2]=f;v[114578]=0;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[j+484404>>2]=d;v[114578]=0;d=T(389,b|0)|0;f=v[114578];v[114578]=0;x:{y:{z:{if((f|0)!=1){v[114578]=0;t[e+80|0]=d;t[e+48|0]=64;d=Q(393,e+80|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break z}u[j+484410>>1]=w[d|0]<<2;if(w[k|0]>9){break y}v[114578]=0;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[j+484384>>2]=d;v[114578]=0;d=T(359,b|0)|0;break x}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}v[114578]=0;d=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[j+484384>>2]=d;v[114578]=0;d=T(392,b|0)|0}f=v[114578];v[114578]=0;if((f|0)==1){break g}f=j+484388|0;v[f>>2]=d;if(l){l=j+484384|0;A:{if(!(d>>>0<=v[l>>2]+2>>>0|d>>>0>y[h>>2])){d=j+484414|0;u[d>>1]=x[d>>1]|2;break A}v[f>>2]=0;v[l>>2]=0}d=Pb(o,m);v[114578]=0;d=Q(394,e+60|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[e+60>>2]=v[d>>2]}i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}j=cq(e+48|0);d=w[e+166|0]|w[e+167|0]<<8;v[114578]=0;m=W(395,b|0,j|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}if(!m){break m}i=0;B:{if(!md(j)){d=bc(j);i=cc(j);v[114578]=0;d=Q(396,d|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break B}v[e+80>>2]=d;d=v[e+80>>2];i=w[d|0]|w[d+1|0]<<8}v[114578]=0;f=i;l=Q(397,e+32|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){C:{if(f){d=0;while(1){v[114578]=0;Q(398,b|0,e+24|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break s}v[114578]=0;U(343,e+80|0,b|0,B(w[e+24|0]|w[e+25|0]<<8|w[e+26|0]<<16,3)|0);h=v[114578];v[114578]=0;if((h|0)==1){break C}Wd(tc(l,d),e+80|0);Bb(e+80|0);d=d+1|0;if((f|0)!=(d|0)){continue}break}}if(c&2){q=ad(e+24|0,8,1,0,1);v[114578]=0;h=Q(399,e+80|0,o|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break q}d=bc(h);f=cc(h);v[114578]=0;R(400,d|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break r}d=bc(h);f=cc(h);v[114578]=0;d=Q(401,d|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[e+16>>2]=d;s=e,z=bc(h),v[s+8>>2]=z;D:{if(!Jb(e+8|0,e+16|0)){break D}while(1){v[114578]=0;d=Q(258,b|0,1)|0;f=v[114578];v[114578]=0;E:{if((f|0)!=1){if(!d){break D}d=0;if(!x[a+480190>>1]){break E}while(1){v[114578]=0;f=Q(258,b|0,1)|0;r=v[114578];v[114578]=0;if((r|0)==1){break r}if(!f){break E}f=d+1|0;if(v[v[e+8>>2]>>2]!=v[Pb(o,d)>>2]){d=f;if(d>>>0>=x[a+480190>>1]){break E}continue}break}v[114578]=0;W(402,q|0,(B(f,104)+a|0)+484380|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break E}break r}break r}tB(e+8|0);if(Jb(e+8|0,e+16|0)){continue}break}}oe(h)}if(!(c&1)){break n}d=w[e+165|0];c=0;v[114578]=0;h=a+484344|0;R(403,h|0,d|0);d=v[114578];v[114578]=0;F:{if((d|0)!=1){if(!w[e+165|0]){break n}p=g+((p>>>0>13)<<1)|0;while(1){G:{if(oc(n)>>>0<=c>>>0){d=64}else{d=x[rc(n,c)>>1]}v[114578]=0;d=W(404,h|0,c&65535,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}H:{if(d){d=x[a+480188>>1];f=w[k|0];v[114578]=0;Q(256,b|0,p+B(((f>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break F}f=cq(e+80|0);d=x[a+480188>>1];v[114578]=0;d=W(395,b|0,f|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break H}I:{if(!d){break I}d=0;if(!x[a+480188>>1]){break I}while(1){J:{g=rc(f,d);if(!(w[g|0]|w[g+1|0]<<8)){break J}g=rc(f,d);if((w[g|0]|w[g+1|0]<<8)>>>0>(w[e+166|0]|w[e+167|0]<<8)>>>0){break J}g=rc(f,d);g=rc(j,(w[g|0]|w[g+1|0]<<8)-1|0);g=w[g|0]|w[g+1|0]<<8;if(!g|i>>>0<g>>>0){break J}q=_b(h,c);g=tc(l,g-1&65535);v[114578]=0;U(405,q|0,d&65535,g|0);g=v[114578];v[114578]=0;if((g|0)!=1){break J}break G}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}Cj(f)}c=c+1|0;if(c>>>0>=w[e+165|0]){break n}continue}}break}b=P()|0;O()|0;Cj(f);break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break f}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break o}b=P()|0;O()|0;break p}b=P()|0;O()|0;oe(h);break p}b=P()|0;O()|0}gd(l)}Cj(j);break f}gd(l)}Cj(j);oe(o);kf(n)}jb=e+176|0;return m|0}b=P()|0;O()|0}oe(o)}kf(n);break a}b=P()|0;O()|0;Ib(e+112|0);break b}b=P()|0;O()|0}yb(d)}S(b|0);L()}function xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-272|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+120|0;lP(g+8|0,i);h=Hb(g+8|0);e=b;f=nc(e,ac(g,g+8|0));if((h|0)==(f|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(f|0)==(h|0);if(!e){mP(i)}a:{b:{c:{d:{e:{if(!e){break e}if(!wP(d+120|0)){break e}if(!c){k=1;break e}Hd(a,4194304);e=Ub(d+40|0,16870);Gb(a+1304436|0,e);yb(e);e=Ub(d+40|0,16866);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;m=a,n=Fd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[m+480188>>1]=n;e=w[d+189|0];v[a+480228>>2]=(e|0)==255?48:e;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);Ye(d+104|0,d+120|4,59,3);Ic(d+40|0,d+104|0);Gb(a+1304400|0,d+40|0);yb(d+40|0);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Qc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!ph(b,16904)){break f}Np(Vb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Qc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!ph(b,16909)){break g}while(1){e=(k<<5)+a|0;zg(e+480280|0);m=e+480284|0,n=((((Gd(b)^-1)&15)<<8|8)>>>0)/15|0,u[m>>1]=n;k=k+1|0;if((k|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Qc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!ph(b,16914)){break h}ud(d+104|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}g=c&2;k=a+480190|0;i=d+53|0;while(1){v[114578]=0;e=Q(980,d+104|0,d+40|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!e){break i}e=w[d+85|0]|w[d+86|0]<<8;u[d+38>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(De((B(e,104)+a|0)+484380|0)){break j}v[114578]=0;e=Q(454,k|0,d+38|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break c}u[a+480190>>1]=x[e>>1];v[114578]=0;R(981,d+40|0,(B(x[d+38>>1],104)+a|0)+484380|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;U(982,d+8|0,1,i|0);e=v[114578];v[114578]=0;k:{l:{if((e|0)==1){break l}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break l}v[114578]=0;Q(371,((x[d+38>>1]<<5)+a|0)+946304|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}yb(d+24|0);if(!g){break j}e=w[d+77|0]|w[d+78|0]<<8|(w[d+79|0]<<16|w[d+80|0]<<24);v[114578]=0;Q(256,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;R(983,d+24|0,d+40|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+24|0,(B(x[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break j}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d+24|0);break b}j=j+1|0;if((j&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Bb(d+104|0)}k=1;if(!(c&1)){break e}m:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break m}if(!Qc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break m}if(!ph(b,16919)){break m}h=a+484344|0;$f(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break m}i=d+24|2;g=0;while(1){if(!Bt(b,d+24|0)){break m}if((w[d+24|0]|w[d+25|0]<<8)>>>0>3){ud(d+40|0,b,((w[d+24|0]|w[d+25|0]<<8)+15&131056)-4|0);c=w[i|0];v[114578]=0;c=W(404,h|0,g&65535,c|0)|0;e=v[114578];v[114578]=0;n:{if((e|0)!=1){o:{j=0;if(!c){break n}while(1){v[114578]=0;c=Q(258,d+40|0,1)|0;e=v[114578];v[114578]=0;p:{q:{r:{if((e|0)!=1){if(!c|w[i|0]<=j>>>0){break q}v[114578]=0;e=T(389,d+40|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}if(e){break r}j=j+1|0;continue}break o}c=_b(h,g);u[d+104>>1]=e&31;f=x[a+480188>>1];v[114578]=0;u[d+8>>1]=f-1;f=Q(478,d+104|0,d+8|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break o}f=x[f>>1];v[114578]=0;c=W(472,c|0,j|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}if(e&128){v[114578]=0;R(473,d+104|0,d+40|0);f=v[114578];v[114578]=0;if((f|0)==1){break o}f=cd(d+104|0);t[c|0]=w[d+104|0]+36;t[c+1|0]=w[f|0]}if(!(e&64)){break p}t[c+2|0]=1;v[114578]=0;f=T(389,d+40|0)|0;l=v[114578];v[114578]=0;s:{if((l|0)!=1){v[114578]=0;t[d+104|0]=f;t[d+8|0]=64;f=Q(393,d+104|0,d+8|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break s}t[c+4|0]=w[f|0];break p}break o}break o}if(w[i|0]==64){break n}c=_b(h,g);v[114578]=0;e=W(498,d+104|0,14,0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){e=Th(Ne(e,w[i|0]-1|0));v[114578]=0;Q(499,c|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}v[114578]=0;R(473,d+104|0,d+40|0);e=v[114578];v[114578]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){e=w[cd(d+104|0)|0];t[c+5|0]=e;switch(w[d+104|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[114578]=0;e=T(389,d+40|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){t[c+5|0]=e;v[114578]=0;Q(340,d+40|0,1)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break o}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;Bb(d+40|0);break a}Bb(d+40|0)}g=g+1|0;if(g>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Qc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));Ny(a+1304424|0,b,hg(b),4)}jb=d+272|0;return k|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}Bb(d+104|0)}S(b|0);L()}function SV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=jb-1424|0;jb=g;Jc(b);Fq(a);a:{if(!$C(b,g+1408|0)){break a}if(!bD(g+1408|0)){break a}if(!_C(b,g+1392|0)){break a}if(!aD(g+1392|0)){break a}b:{if(!c){break b}C=g+1400|0;c=C;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>Lj(b)>>>0){break a}c=C;r=g+1392|2;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[r|0]|w[r+1|0]<<8)<<2)>>>0>Lj(b)>>>0){break a}bv(a);av(g+40|0);$u(Tg(a)+28|0,g+40|0);Eq(g+40|0);o=v[Tg(a)+28>>2];c=g+1392|4;fv(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));Rb(g+1136|0,0,256);c:{d:{if(w[r|0]|w[r+1|0]<<8){k=g+1112|4;l=g+1128|0;z=g+1130|0;s=g+1126|0;h=g+1124|0;while(1){c=C;if(!Qc(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+(D<<2)|0)){break a}if(!Qb(b,4)){break a}j=Cf(b);if(!Qc(b,j)){break a}if(!_u(b,g+1112|0)){break a}e=w[h|0]|w[h+1|0]<<8;f=jb-16|0;jb=f;q=g+1096|0;c=q;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(269,c+8|0,f+12|0,f+8|0)|0;d=v[114578];v[114578]=0;e:{if((d|0)!=1){jb=f+16|0;break e}V(0)|0;O()|0;Ab();L()}f:{if(!e){break f}v[114578]=0;R(262,q|0,e|0);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;R(263,q|0,e|0);f=v[114578];v[114578]=0;if((f|0)!=1){break f}}a=P()|0;O()|0;WC(c);S(a|0);L()}d=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!(w[h|0]|w[h+1|0]<<8)){break x}y:{while(1){c=Tk(q,d);v[114578]=0;c=Q(254,b|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break y}if(c){d=d+1|0;if(d>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break x}continue}break}break w}c=P()|0;O()|0;break c}c=w[h|0]|w[h+1|0]<<8?v[q>>2]:0;f=w[h|0]|w[h+1|0]<<8;v[114578]=0;e=T(255,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}d=f<<3;f=j+20|0;if(e>>>0>d+f>>>0){e=f+((w[h|0]|w[h+1|0]<<8)<<3)|0;z:{if(!(t[s|0]&1)){j=0;if(!(w[h|0]|w[h+1|0]<<8)){break g}while(1){if(!c){break z}if(!go(o,c)){break z}v[114578]=0;f=Q(256,b|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}if(!f){break z}d=wc(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));f=c;n=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[114578]=0;d=W(257,b|0,d|0,n|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break u}if((d|0)!=(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24))){break z}c=c+8|0;j=j+1|0;if(j>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}break g}A:{B:{C:{D:{if(w[s|0]&4){if(!c){break A}if(!go(o,c)){break A}f=wc(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));y=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);n=w[z|0]|w[z+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[114578]=0;e=Q(256,b|0,d+e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}if(!e){break A}e=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);d=w[l|0]|w[l+1|0]<<8;v[114578]=0;e=Q(258,b|0,e-d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}if(!e){break A}e=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);d=w[l|0]|w[l+1|0]<<8;v[114578]=0;U(259,g+24|0,b|0,e-d|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}e=im(g+40|0,g+24|0);Bb(g+24|0);u=0;j=0;p=0;if(!(w[h|0]|w[h+1|0]<<8)){break j}while(1){E:{v[114578]=0;d=Q(260,e|0,n+1|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break E}i=n&15;A=x[(i<<1)+11024>>1];F:{G:{if(A>>>0<=d>>>0){v[114578]=0;i=w[i+11104|0];m=Q(260,e|0,i|0)|0;B=v[114578];v[114578]=0;if((B|0)==1){break l}d=m+(d-A<<i)|0;if((d|0)!=(n|0)){n=d&15;break F}v[114578]=0;d=Q(260,e|0,4)|0;i=v[114578];v[114578]=0;if((i|0)==1){break l}if((d|0)==15){v[114578]=0;i=Q(260,e|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break l}d=65535;if(!i){break G}Bb(g+40|0);break g}d=d+65520|0}if(d>>>0>65535){break F}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;i=f+j|0;m=i;H:{if(w[s|0]&2){u=d+u|0;d=u;break H}d=w[s+1|0]&2?d:d^32768}t[m|0]=d;t[i+1|0]=d>>>8;j=j+2|0}if(j>>>0>=y>>>0){p=p+1|0;if(p>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break B}f=(p<<3)+c|0;if(!go(o,f)){break D}y=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=0;f=wc(o,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}if((w[h|0]|w[h+1|0]<<8)>>>0>p>>>0){continue}break j}break}c=V(76880)|0;break k}if(!c){break A}if(!go(o,c)){break A}u=wc(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));y=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);n=w[z|0]|w[z+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break A}v[114578]=0;f=Q(256,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}if(!f){break A}f=w[l|0]|w[l+1|0]<<8;v[114578]=0;f=W(261,b|0,g+1136|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}if(f>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break A}f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114578]=0;f=Q(258,b|0,f-e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}if(!f){break A}f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114578]=0;U(259,g+24|0,b|0,f-e|0);f=v[114578];v[114578]=0;if((f|0)==1){break m}i=im(g+40|0,g+24|0);Bb(g+24|0);f=0;j=0;p=0;if(!(w[h|0]|w[h+1|0]<<8)){break p}I:{J:{while(1){K:{v[114578]=0;d=Q(260,i|0,n+1|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break K}E=j+u|0;m=n&7;B=w[m+11056|0];L:{M:{if(B>>>0<=d>>>0){v[114578]=0;m=w[m+11064|0];e=Q(260,i|0,m|0)|0;A=v[114578];v[114578]=0;if((A|0)==1){break r}d=e+(d-B<<m)|0;if((d|0)!=(n|0)){n=d&7;break L}v[114578]=0;d=Q(260,i|0,3)|0;m=v[114578];v[114578]=0;if((m|0)==1){break r}if((d|0)==7){v[114578]=0;d=Q(260,i|0,1)|0;m=v[114578];v[114578]=0;if((m|0)==1){break r}if(d){break J}d=g+1391|0;break M}d=d+248|0}if(d>>>0>255){break L}d=(g+1136|0)+d|0}e=w[d|0];d=e+f|0;m=e;e=(w[s|0]|w[s+1|0]<<8)&2;t[E|0]=e?d:m;f=e?d:f;j=j+1|0}if(j>>>0>=y>>>0){p=p+1|0;if(p>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break I}e=(p<<3)+c|0;if(!go(o,e)){break C}y=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);u=wc(o,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));j=0}if((w[h|0]|w[h+1|0]<<8)>>>0>p>>>0){continue}break p}break}c=V(76880)|0;break q}Bb(g+40|0);break g}Bb(g+40|0);break g}Bb(g+40|0);break w}Bb(g+40|0);break w}Bb(g+40|0);break g}}}}Zu(q);break a}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break n}_(c|0)|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)==1){break o}}Bb(g+40|0);break g}c=P()|0;O()|0}Bb(g+40|0);break c}c=P()|0;O()|0;break c}c=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break h}_(c|0)|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)==1){break i}}Bb(g+40|0);break g}c=P()|0;O()|0}Bb(g+40|0);break c}Zu(q);D=D+1|0;if(D>>>0<(w[r|0]|w[r+1|0]<<8)>>>0){continue}break}}Wi(g+8|0,o);Xu(g+16|0,g+8|0);b=fo(g+40|0,g+16|0,0);Wd(Tg(a)+12|0,b);Bb(b);break b}c=P()|0;O()|0}Zu(q);S(c|0);L()}F=1}jb=g+1424|0;return F|0}function ZZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2490;p=Rd(l+136|0,l+144|0,l+96|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;r=Wb(l+96|0);o=tf(l+80|0);m=tf(l- -64|0);n=tf(l+48|0);q=tf(l+32|0);v[114578]=0;na(2502,c|0,d|0,l+120|0,l+116|0,l+112|0,r|0,o|0,m|0,n|0,l+28|0);b=v[114578];v[114578]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;k=0;e=0;while(1){b=e;b:{c:{d:{e:{if((k|0)==4){break e}v[114578]=0;c=Q(2462,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(t[(l+120|0)+k|0]){case 1:if((k|0)==3){break c}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;c=W(2503,h|0,8192,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(c){v[114578]=0;U(2504,l+16|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[l+16>>2];v[114578]=0;R(112,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((k|0)==3){break c}}while(1){v[114578]=0;c=Q(2462,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break c}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;c=W(2503,h|0,8192,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break c}v[114578]=0;U(2504,l+16|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[l+16>>2];v[114578]=0;R(112,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}if((Fb(m)|0)==(0-Fb(n)|0)){break c}k:{if(Fb(m)){if(Fb(n)){break k}}if(Fb(m)){v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[Tb(m)>>2]){v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:b;break b}t[g|0]=1;break c}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)!=v[Tb(n)>>2]){break c}v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:b;break b}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[Tb(m)>>2]){v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:b;break b}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[Tb(n)>>2]){v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:b;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(b|k>>>0<2)){e=0;if(!((k|0)==2&w[l+123|0]!=0|u)){break b}}y=l,z=Dd(o),v[y+8>>2]=z;c=Md(l+16|0,l+8|0);l:{if(!k|w[(k+l|0)+119|0]>1){break l}m:{while(1){y=l,z=Vj(o),v[y+8>>2]=z;if(!Jb(c,l+8|0)){break m}d=v[v[c>>2]>>2];v[114578]=0;d=W(2503,h|0,8192,d|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if(!d){break m}_d(c);continue}break}break a}y=l,z=Dd(o),v[y+8>>2]=z;c=qt(c,l+8|0);if(Fb(q)>>>0>=c>>>0){y=l,z=Vj(q),v[y+8>>2]=z;c=lO(l+8|0,c);d=Vj(q);e=Dd(o);v[114578]=0;c=CE(c,d,e);d=v[114578];v[114578]=0;if((d|0)==1){break a}if(c){break l}}y=l,z=Dd(o),v[y>>2]=z;Md(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];n:{while(1){y=l,z=Vj(o),v[y>>2]=z;if(!Jb(l+8|0,l)){break n}v[114578]=0;c=Q(2462,a|0,l+552|0)|0;d=v[114578];v[114578]=0;o:{if((d|0)==1){break o}if(!c){break n}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}if((c|0)!=v[v[l+8>>2]>>2]){break n}v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}_d(l+8|0);continue}break}break a}if(!s){break c}y=l,z=Vj(o),v[y>>2]=z;if(!Jb(l+8|0,l)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114578]=0;d=Q(2462,a|0,l+552|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}if(!d){break p}v[114578]=0;e=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;d=W(2503,h|0,2048,e|0)|0;x=v[114578];v[114578]=0;if((x|0)==1){break a}r:{if(d){d=v[j>>2];if((d|0)==v[l+548>>2]){v[114578]=0;U(2506,i|0,j|0,l+548|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[j>>2]}v[j>>2]=d+4;v[d>>2]=e;c=c+1|0;break r}if(!Fb(r)|!c|(e|0)!=v[l+112>>2]){break p}e=v[l+132>>2];if((e|0)==v[l+128>>2]){v[114578]=0;U(2497,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c;c=0}v[114578]=0;T(2466,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break a}e=v[l+132>>2];if(!(!c|(e|0)==v[p>>2])){if(v[l+128>>2]==(e|0)){v[114578]=0;U(2497,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c}s:{if(v[l+28>>2]<1){break s}v[114578]=0;c=Q(2463,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}t:{if(!c){v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[l+116>>2]){break t}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}while(1){if(v[l+28>>2]<1){break s}v[114578]=0;c=Q(2463,a|0,l+552|0)|0;d=v[114578];v[114578]=0;u:{if((d|0)==1){break u}v:{if(!c){v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}v[114578]=0;c=W(2503,h|0,2048,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}if(c){break v}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114578]=0;U(2506,i|0,j|0,l+548|0);c=v[114578];v[114578]=0;if((c|0)==1){break u}}v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}d=v[j>>2];v[j>>2]=d+4;v[d>>2]=c;v[114578]=0;v[l+28>>2]=v[l+28>>2]-1;T(2466,a|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}e=b;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}w:{if(!b){break w}e=1;while(1){if(Fb(b)>>>0<=e>>>0){break w}v[114578]=0;c=Q(2463,a|0,l+552|0)|0;d=v[114578];v[114578]=0;x:{if((d|0)==1){break x}y:{if(!c){v[114578]=0;c=T(2464,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break x}if((c|0)==v[ij(b,e)>>2]){break y}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2466,a|0)|0;c=v[114578];v[114578]=0;e=e+1|0;if((c|0)!=1){continue}}break}break a}z:{if(v[p>>2]==v[l+132>>2]){break z}v[l+16>>2]=0;a=v[p>>2];v[114578]=0;Ee(r,a,v[l+132>>2],l+16|0);a=v[114578];v[114578]=0;if((a|0)!=1){if(!v[l+16>>2]){break z}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}Lc(q);Lc(n);Lc(m);Lc(o);yb(r);Gc(p);jb=l+560|0;return a|0}e=b}k=k+1|0;continue}}}a=P()|0;O()|0;Lc(q);Lc(n);Lc(m);Lc(o);yb(r);Gc(p);S(a|0);L()}function jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=jb-1328|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+752|0;uS(g+8|0,i);j=Hb(g+8|0);e=b;l=nc(e,ac(g,g+8|0));if((j|0)==(l|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(j|0)==(l|0);if(!e){vS(i)}a:{b:{c:{d:{if(!e){break d}if(!zS(d+752|0)){break d}if(!Qb(b,hd(xS(d+752|0),mb))){break d}if(!c){f=1;break d}o=Dt(d+744|0);q=1;e:{while(1){e=(f<<5)+a|0;g=e+480280|0;zg(g);i=(d+752|0)+(f<<4)|0;u[e+480284>>1]=((w[i+78|0]<<8&65280)>>>0)/255;Fk(d+480|0,1,i- -64|0);Ic(d+96|0,d+480|0);v[114578]=0;Q(380,e+480289|0,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}yb(d+96|0);f:{g:{switch(w[i+79|0]){case 0:k=f+1|0;break f;case 1:v[g>>2]=1024;k=h+1|0;break f;case 2:break g;default:break e}}v[g>>2]=1024;Pj(d+96|0,o,f);ge(d+96|0,1)}q=f>>>0<31;h=h+1|0;f=f+1|0;if((f|0)!=32){continue}break}Hd(a,33554432);u[a+480188>>1]=k&255;f=Ub(d+96|0,13326);Gb(a+1304436|0,f);yb(f);f=Ub(d+96|0,13340);Gb(a+1304448|0,f);yb(f);v[a+1304496>>2]=4;h:{if(w[d+831|0]){break h}e=1;while(1){if(w[((e<<4)+d|0)+831|0]!=1){break h}f=1;e=e+1|0;if((e|0)!=16){continue}break}while(1){h=((f<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-1025;f=f+1|0;if((f|0)!=16){continue}break}}yg(d+480|0,1,d+752|0);Ic(d+96|0,d+480|0);Gb(a+1304400|0,d+96|0);yb(d+96|0);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+790|0]|w[d+791|0]<<8)<<4&16;v[a+480196>>2]=w[d+800|0];v[a+480204>>2]=B(w[d+801|0],1e4);k=0;A=a,C=Fd(w[d+802|0],0,64)<<2,v[A+480200>>2]=C;A=a,C=Fd(w[d+803|0],4,127),v[A+480228>>2]=C;f=w[d+788|0]|w[d+789|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=f;iu(b,d+480|0);eq(Vb(a+484360|0),d+480|0,w[d+784|0]|w[d+785|0]<<8,65535,255);r=c&1;if(r){$f(a+484344|0,w[d+786|0]|w[d+787|0]<<8)}if(w[d+786|0]|w[d+787|0]<<8){s=a+484344|0;while(1){f=hg(b);m=hg(b);ud(d+96|0,b,f-4|0);i:{if(!r){break i}v[114578]=0;f=W(404,s|0,k&65535,m|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){j:{if(!f){break i}n=0;j=Qh(d+16|0);if(!m){break i}while(1){k:{v[114578]=0;e=T(389,d+96|0)|0;f=v[114578];v[114578]=0;l:{m:{if((f|0)!=1){if(e){break m}n=n+1|0;break l}break j}f=j;p=e&31;if(p>>>0<x[a+480188>>1]){f=_b(s,k);v[114578]=0;f=W(472,f|0,n|0,p|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break j}}n:{if(!(e&32)){break n}v[114578]=0;R(473,d+32|0,d+96|0);g=v[114578];v[114578]=0;h=f;o:{p:{if((g|0)!=1){i=cd(d+32|0);g=w[d+32|0];t[f|0]=g;t[f+1|0]=w[i|0];if((g|0)!=160){break p}g=255;break o}break j}if((g|0)!=255){t[f|0]=(B(g>>>4|0,12)+(g&15)|0)+13;v[114578]=0;i=T(615,f|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){g=0;if(!i){break o}break n}break j}g=0}t[h|0]=g}h=e&192;q:{if(!h){break q}if((h|0)==192){v[114578]=0;R(595,d+32|0,d+96|0);h=v[114578];v[114578]=0;r:{s:{t:{if((h|0)!=1){i=cd(d+32|0);e=Bf(d+32|0);h=Rh(d+32|0);l=d+32|0;z=w[l|0];if((z|0)!=12){break t}v[114578]=0;t[d+8|0]=64;g=Q(393,i|0,d+8|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[f+4|0]=w[g|0];g=1;break s}break j}g=w[e|0];u:{if((g|0)==12){v[114578]=0;t[d+8|0]=64;h=Q(393,h|0,d+8|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[f+4|0]=w[h|0];g=1;break u}break j}if((z|0)==10){t[f+4|0]=(w[i|0]<<6>>>0)/255;g=2;break s}if((g|0)!=10){break r}t[f+4|0]=(w[h|0]<<6>>>0)/255;g=2}e=l;h=i}t[f+2|0]=g;g=w[e|0]}t[f+3|0]=g;t[f+5|0]=w[h|0];break q}v[114578]=0;R(473,d+32|0,d+96|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}h=cd(d+32|0);t[f+3|0]=w[d+32|0];t[f+5|0]=w[h|0]}if(w[f+3|0]){v[114578]=0;Z(616,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}}Pj(d+32|0,o,p);if(!Cb(d+32|0)){break l}v[114578]=0;h=T(617,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}if(!h){break l}t[f+3|0]=0}if(n>>>0<m>>>0){continue}break i}break}}}f=P()|0;O()|0;Bb(d+96|0);break b}Bb(d+96|0);k=k+1|0;if(k>>>0<(w[d+786|0]|w[d+787|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break e}n=c&2;h=1;k=1;while(1){m=h&65535;f=sL(a,m,0);e=jb-16|0;jb=e;c=jb-16|0;jb=c;g=d+96|0;gc(e+8|0,g,384);jb=c+16|0;i=Hb(e+8|0);c=b;j=nc(c,ac(e,e+8|0));if((i|0)==(j|0)){$b(c,Hb(e+8|0))}jb=e+16|0;c=(i|0)==(j|0);if(!c){e=jb-16|0;jb=e;Rb(g,0,384);jb=e+16|0}if(!(!c|!f)){i=k&65535;c=jb-32|0;jb=c;e=d+96|0;yg(c,1,e);Ic(c+16|0,c);v[114578]=0;Q(371,f+492|0,c+16|0)|0;g=v[114578];v[114578]=0;v:{if((g|0)!=1){yb(c+16|0);w:{if(!(w[e+378|0]|w[e+379|0]<<8)){break w}v[c+16>>2]=120;v[c>>2]=116;if(!v[Lb(c+16|0,c)>>2]){break w}j=f+236|0;g=0;while(1){l=w[(e+g|0)+32|0];A=dd(j,g+12|0),C=i+l|0,u[A>>1]=C;v[c+16>>2]=120;v[c>>2]=116;g=g+1|0;if(g>>>0<y[Lb(c+16|0,c)>>2]){continue}break}}v[f>>2]=w[e+376|0]|w[e+377|0]<<8;Yz(e,f+48|0,0);Yz(e,f+68|0,1);Yz(e,f+88|0,2);e=w[f+100|0];if(e&1){t[f+100|0]=e|16}if(!(v[f>>2]|t[f+60|0]&1)){v[f>>2]=32767}jb=c+32|0;break v}break a}f=0;x:{if(!(w[d+474|0]|w[d+475|0]<<8)){break x}while(1){y:{Op(b,d+32|0);z:{if((w[d+92|0]|w[d+93|0]<<8|(w[d+94|0]<<16|w[d+95|0]<<24))!=808538953){break z}c=f+k|0;j=c&65535;if(j>>>0>3999){break z}u[a+480190>>1]=c;c=jb-32|0;jb=c;l=B(j,104)+a|0;i=l+484380|0;g=i;Ed(g,0);e=d+32|0;Qi(c,1,e);Ic(c+16|0,c);v[114578]=0;Q(372,g+43|0,c+16|0)|0;o=v[114578];v[114578]=0;A:{if((o|0)!=1){yb(c+16|0);v[g>>2]=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[g+4>>2]=w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24);v[g+8>>2]=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);v[g+24>>2]=w[e+28|0]|w[e+29|0]<<8|(w[e+30|0]<<16|w[e+31|0]<<24);u[g+30>>1]=w[e+32|0]<<2;u[g+28>>1]=w[e+33|0];if(t[e+48|0]&1){u[g+34>>1]=x[g+34>>1]|2}if(w[e+48|0]&2){u[g+34>>1]=x[g+34>>1]|4}if(w[e+48|0]&4){u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}if(w[e+48|0]&8){u[g+34>>1]=x[g+34>>1]|32}jb=c+32|0;break A}break a}XB(d+16|0,l+484423|0);v[114578]=0;Q(371,((j<<5)+a|0)+946304|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break y}yb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break z}ud(d+16|0,b,w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24));B:{if(!n){break B}c=ad(d+8|0,u[l+484414>>1]&1?16:8,1,0,0);v[114578]=0;W(402,c|0,i|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break B}f=P()|0;O()|0;Bb(d+16|0);break b}Bb(d+16|0)}f=f+1|0;if(f>>>0<(w[d+474|0]|w[d+475|0]<<8)>>>0){continue}break x}break}f=P()|0;O()|0;yb(d+16|0);break b}k=(w[d+474|0]|w[d+475|0]<<8)+k|0}if(m>>>0>=x[a+480192>>1]){break e}h=h+1|0;continue}}f=!q}jb=d+1328|0;return f&1}f=P()|0;O()|0;yb(d+96|0)}S(f|0);L()}a=P()|0;O()|0;yb(c+16|0);S(a|0);L()}function nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-208|0;jb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;KL(a+900380|0);JL(a+946304|0);f=ML(g+48|0);v[114578]=0;d=a+906300|0;U(1411,d|0,d+4e4|0,f|0);d=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((d|0)!=1){an(f);f:{if(vq(b)){f=0;d=jb-16|0;jb=d;i=g+48|0;h=i;v[h>>2]=0;v[h+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1420,h+8|0,d+12|0,d+8|0)|0;h=v[114578];v[114578]=0;g:{if((h|0)!=1){jb=d+16|0;break g}break a}h:{i:{j:{if(c&16){break j}v[114578]=0;h=(c|0)!=0;e=W(1412,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=4;k:{if(e){break k}v[114578]=0;e=W(1413,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=5;if(e){break k}v[114578]=0;e=W(1414,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=6;if(e){break k}e=0;v[114578]=0;h=W(1415,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=3;if(!h){break j}}if(!c){f=1;break c}if(!md(i)){oQ(b,lu(i,0)+12|0)}e=d}if(c&32){break c}d=77744;l:{m:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[114578]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(f){break l}d=d+12|0;if((d|0)==78200){break m}continue}break}d=V(71180)|0;break h}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break c}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}Sx(i);break f}d=V(71180)|0}a=O()|0;Sx(i);if((ga(71180)|0)!=(a|0)){break d}_(d|0)|0;v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)==1){d=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break d}V(0)|0;O()|0;Ab()}L()}Hd(a,0);v[a+1074304>>2]=19468288}d=0;while(1){b=(d<<5)+a|0;jg(b+480286|0,64);b=b+480284|0;if(x[b>>1]>=257){u[b>>1]=128}qn((B(d,896)+a|0)+1074984|0,a,d&65535);d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1304392|0;f=1;while(1){d=B(f&65535,104)+a|0;b=d+484380|0;n:{if(De(b)){Gy(b,a,0);break n}e=d+484414|0;h=x[e>>1];if(h&16384){break n}v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;u[e>>1]=h&65505}b=d+484412|0;if(x[b>>1]>=65){u[b>>1]=64}o:{if(!(w[d+484415|0]&2)){break o}if(!rj(i)){break o}d=jb-16|0;jb=d;b=a;h=b+1304392|0;if(!sd(h)){j=d+8|0;e=Pe(532);b=v[b+24620>>2];v[114578]=0;k=Q(1421,e|0,b|0)|0;b=v[114578];v[114578]=0;p:{if((b|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=k;W(1425,j|0,b+12|0,b+8|0)|0;e=v[114578];v[114578]=0;q:{if((e|0)!=1){jb=b+16|0;break q}break a}break p}a=P()|0;O()|0;Xb(e);S(a|0);L()}FL(h,Nd(d+8|0));ps(d+8|0)}jb=d+16|0}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;b=0;while(1){e=v[(((d&65535)<<2)+a|0)+900380>>2];if(e){f=v[a+480180>>2];Cc(e,65536);Cc(e+4|0,64);Cc(e+8|0,256);jg(e+28|0,16384);Ue(e+30|0,128);Ue(e+31|0,17);if(w[e+16|0]>=4){t[e+16|0]=0}if(w[e+17|0]>=5){t[e+17|0]=0}if(w[e+18|0]>=3){t[e+18|0]=0}Ue(e+19|0,64);Ue(e+20|0,100);b=-32;i=t[e+26|0];r:{if((i|0)>=-32){b=32;if((i|0)<=32){break r}}t[e+26|0]=b}Ue(e+23|0,64);Ue(e+24|0,64);Iy(e+48|0,64);Iy(e+68|0,64);Iy(e+88|0,(f|0)==4096?255:64);b=e+108|0;f=0;while(1){s:{if(w[fc(b,f)|0]){if(w[fc(b,f)|0]<121){break s}}l=fc(b,f),m=f+1|0,t[l|0]=m}f=f+1|0;if(f>>>0<128){continue}break}if(!Sn(w[e+14|0])){t[e+14|0]=5}b=d}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=b;b=a+480204|0;t:{if(y[a+480204>>2]<1e4){v[b>>2]=125e4;break t}Cc(b,65535e4)}b=v[a+480196>>2];if(!b){v[a+480196>>2]=6;b=6}f=v[a+480220>>2];d=v[a+480216>>2];if(f>>>0<d>>>0){v[a+480220>>2]=d;f=d}v[a+1074416>>2]=b;v[a+1074420>>2]=v[a+480204>>2];v[a+1074412>>2]=f;v[a+1074408>>2]=d;v[a+1074444>>2]=v[a+480200>>2];gy(a+1074376|0);v[a+1074440>>2]=-65536;v[a+1074392>>2]=-2;b=a+1074384|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074432|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;u[a+480276>>1]=0;To(a);qj(a+1304360|0,1);b=a+484360|0;l=g,m=bc(b),v[l+48>>2]=m;l=g,m=cc(b),v[l+32>>2]=m;if(!Jb(g+48|0,g+32|0)){break e}while(1){b=v[g+48>>2];eg(b,sj(b));d=x[b+28>>1];if(oc(b)>>>0<=d>>>0){Oe(b,0)}Dy(g+48|0);if(Jb(g+48|0,g+32|0)){continue}break}break e}d=P()|0;O()|0;an(f);break d}b=jb-16|0;jb=b;f=g+48|0;d=f;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1422,d+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;u:{if((d|0)!=1){jb=b+16|0;break u}break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{if((c&12)==12){d=0;while(1){h=B(d,160)+a|0;e=h+906300|0;b=e;E:{if(!(w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24)|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24)))){break E}v[114578]=0;Q(1416,e|0,a|0)|0;b=v[114578];v[114578]=0;F:{if((b|0)!=1){b=v[e>>2];if(!b){break F}c=v[h+906448>>2];e=v[v[b>>2]+56>>2];v[114578]=0;R(e|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break E}}d=P()|0;O()|0;break v}c=bc(f);i=cc(f);b=jb-32|0;jb=b;v[b+16>>2]=i;v[b+24>>2]=c;v[b+8>>2]=e;G:{if(!Jb(b+24|0,b+16|0)){break G}while(1){c=v[v[b+24>>2]>>2];i=v[b+8>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[i+20|0]|w[i+21|0]<<8|(w[i+22|0]<<16|w[i+23|0]<<24))){i=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=v[b+8>>2];c=(i|0)==(w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))}else{c=0}if(c){break G}_d(b+24|0);if(Jb(b+24|0,b+16|0)){continue}break}}jb=b+32|0;v[g+32>>2]=v[b+24>>2];l=g,m=cc(f),v[l+16>>2]=m;if(Jb(g+32|0,g+16|0)){break E}v[114578]=0;v[g+32>>2]=h+906316;R(1417,f|0,g+32|0);b=v[114578];v[114578]=0;if((b|0)==1){break w}v[114578]=0;b=Q(2,g+16|0,20526)|0;c=v[114578];v[114578]=0;if((c|0)==1){break D}c=BL(e);v[114578]=0;U(6,g|0,0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break C}v[114578]=0;U(3,g+32|0,b|0,g|0);c=v[114578];v[114578]=0;if((c|0)==1){break B}v[114578]=0;U(646,a|0,2,g+32|0);c=v[114578];v[114578]=0;if((c|0)==1){break A}yb(g+32|0);yb(g);yb(b)}d=d+1|0;if((d|0)!=250){continue}break}}b=v[a+1074372>>2];v[114578]=0;R(1418,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break x}b=v[a+480180>>2];H:{if(!b){break H}os(a+8|0,Vo(a));if(!v[a+1074308>>2]){break H}v[114578]=0;Z(1419,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break x}}AL(f);f=(b|0)!=0;break b}d=P()|0;O()|0;break v}d=P()|0;O()|0;break y}d=P()|0;O()|0;break z}d=P()|0;O()|0;yb(g+32|0)}yb(g)}yb(b);break v}d=P()|0;O()|0;break v}d=P()|0;O()|0}AL(f)}S(d|0);L()}Sx(i)}jb=g+208|0;return f|0}V(0)|0;O()|0;Ab();L()}function As(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}k=v[b+104>>2];i=v[b+656>>2];if(!(!i|v[a+480180>>2]!=16777216)){n=v[i+44>>2]!=0}b:{if(!(!i|(c|0)>128)){j=x[dd(i+236|0,c-1|0)>>1];c:{if((j-1&65535)>>>0<=3998){k=(B(j,104)+a|0)+484380|0;break c}Eb(h+16|0,a+1074312|0,43);if(!Cb(h+16|0)){break c}if(!oj(b)){break a}}j=w[fc(i+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=j;break b}j=c}if((j|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(j|0)!=255:0)){dn(a,b);if(d){break d}Eb(h+16|0,a+1074312|0,100);if(!Cb(h+16|0)|!(w[a+480208|0]&4)|!w[b+811|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}Eb(h+16|0,a+1074312|0,50);if(Cb(h+16|0)){break g}}v[b+688>>2]=0}Eb(h+16|0,a+1074312|0,50);if(Cb(h+16|0)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Eb(h+16|0,a+1074312|0,20);if(!Cb(h+16|0)){break a}t[b+819|0]=0;t[b+824|0]=0;break a}h:{i:{j:{if(n){if(d){l=w[b+819|0];if(l){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!k)){v[b+772>>2]=t[k+36|0];v[b+768>>2]=t[k+37|0]}if(k){Eb(h+16|0,a+1074312|0,24);j=0;m=1;if(!Cb(h+16|0)){break h}v[b+704>>2]=v[k+24>>2];break h}j=0;break h}m=v[i+44>>2];u[h>>1]=l;u[h+14>>1]=j;v[h+16>>2]=0;j=(v[h+16>>2]+B(u[m+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+876>>2]|0;v[b+708>>2]=j;v[b+876>>2]=0-j}m=(k|0)!=0;j=1;if(Kh(b)){break h}j=a+1074312|0;Eb(h+16|0,j,54);if(Cb(h+16|0)){v[b+700>>2]=0;break a}Eb(h+16|0,j,39);j=(Cb(h+16|0)^-1)&d}k:{if(Lp(a)){v[h+28>>2]=v[h+28>>2]+v[b+772>>2];ce(h+28|0,12,131);break k}eQ(h+28|0)}l=a+1074312|0;Eb(h+16|0,l,34);d=b;l:{if(Cb(h+16|0)){c=Rp(c);break l}c=v[h+28>>2]}t[d+819|0]=c;t[b+872|0]=w[b+872|0]|8;if(!(v[a+480180>>2]&16777250?0:j)){t[b+825|0]=0}d=ag(a,v[h+28>>2],v[b+768>>2],v[b+704>>2]);t[b+851|0]=0;Eb(h+16|0,l,48);if(Cb(h+16|0)){yM(a,b,i,k)}m:{if(e^1|j){break m}v[b+788>>2]=0;v[b+792>>2]=0;if(!i){break m}Eb(h+16|0,l,29);if(Cb(h+16|0)){t[b+820|0]=w[i+16|0]}if(!(w[i+60|0]&8)){wi(b+724|0)}if(!(w[i+80|0]&8)){wi(b+736|0)}if(!(w[i+100|0]&8)){wi(b+748|0)}if(w[i+20|0]){c=xs(cn(a));o=w[i+20|0];Eb(h+16|0,l,28);p=((B(c,o)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(h+16|0)){o=v[b+764>>2];break n}o=(v[b+688>>2]+1|0)/2|0}u[c+788>>1]=(B(o,p)|0)/199}o:{if(!w[i+19|0]){break o}q=b,r=(B(xs(cn(a)),w[i+19|0])<<16>>16)/32|0,u[q+790>>1]=r;Eb(h+16|0,l,28);if(Cb(h+16|0)|x[b+796>>1]){break o}u[b+796>>1]=x[b+692>>1]+1}c=w[i+23|0];if(c){o=xs(cn(a));p=w[b+857|0];t[b+818|0]=p+1;u[b+792>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[i+24|0];if(!c){break m}o=xs(cn(a));p=w[b+858|0];t[b+817|0]=p+1;u[b+794>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!d){break q}r:{s:{t:{if(j){u:{if(!v[b+700>>2]){v[b+700>>2]=d;if(!n){break u}break t}if(n){break t}}v[b+708>>2]=d;break t}v[b+700>>2]=d;if(n){break s}Eb(h+16|0,l,69);if(Cb(h+16|0)){break s}Eb(h,l,46);if(Cb(h)|v[a+480180>>2]==1){break s}v[b+708>>2]=d;break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=k;c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Eb(h+16|0,l,96);if(!Cb(h+16|0)){break w}}if(w[b+811|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Lb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}c=x[k+34>>1];d=c&1023;n=d|v[b+88>>2]&-525056;v[b+88>>2]=n;x:{y:{if(c&8){v[b+80>>2]=v[k+12>>2];c=v[k+16>>2];v[b+88>>2]=(d&16?n|4:n&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break y}break x}if(!(d&2)){break x}v[b+80>>2]=v[k+4>>2];c=v[k+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break x}}v[b+76>>2]=c}Eb(h+16|0,l,83);if(!(!Cb(h+16|0)|v[b+80>>2])){c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}z:{if(w[b+842|0]>3){break z}Eb(h+16|0,l,21);c=b;A:{if(!(Cb(h+16|0)|!(v[a+480180>>2]&16777248))){d=16;if(!(v[a+480208>>2]&4)){break A}}d=32;if(v[a+480180>>2]==16){break A}if(v[a+480180>>2]&67633152){break z}d=0}t[c+839|0]=d}Eb(h+16|0,l,21);if(Cb(h+16|0)|w[b+845|0]>3){break r}t[b+840|0]=0}d=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=d;d=v[b+80>>2];v[b>>2]=c;v[b+4>>2]=d}if(!j){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}if(!(w[a+480208|0]&8)|!w[b+811|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){yl(b);Eb(h+16|0,l,21);if(!Cb(h+16|0)){t[b+838|0]=0;v[b+780>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(w[b+811|0]|(!m|!(w[a+480208|0]&8)))){m=1;break p}if(w[b+811|0]?0:v[a+480180>>2]&1048580){break p}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}Eb(h+16|0,l,40);B:{C:{D:{E:{if(Cb(h+16|0)){if(m){if(w[b+811|0]?w[a+480208|0]&8:0){break D}v[b+88>>2]=v[b+88>>2]&-4194305;break C}c=v[b+88>>2]&-4196353;break E}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;k=1;if(m){break B}}u[b+862>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Eb(h+16|0,l,23);F:{if(Cb(h+16|0)){break F}Eb(h,l,22);if(Cb(h)){break F}Eb(h+16|0,l,52);if(Cb(h+16|0)){break F}Eb(h,l,71);if(Cb(h)){break F}t[b+859|0]=0;u[b+798>>1]=0}if(e){t[b+838|0]=0;v[b+780>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;G:{if(i){H:{I:{if(!ZB(i)){if(wu(i)){break I}c=!(c>>>13|0);if(c){break H}break G}q=b,r=_B(i),t[q+858|0]=r;if(!wu(i)){break H}}q=b,r=$B(i),t[q+857|0]=r}c=1;d=w[i+25|0];if((d|0)==255){break G}t[b+865|0]=d;break G}v[b+788>>2]=0;v[b+792>>2]=0;c=!c}J:{if(w[b+857|0]>=127){Eb(h+16|0,l,36);if(!Cb(h+16|0)){break J}}k=0;if(!c){break B}if((fp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break B}c=a+1304392|0;if(!sd(c)|(g|0)==65535){break B}lp(v[c>>2],g,w[b+857|0]>>>1|0,1);break B}k=0;break B}v[b+88>>2]=v[b+88>>2]&-4196353}k=1}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}K:{L:{if(w[a+24618|0]&16?c&1024:0){break L}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break L}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break K}}if(f){break K}v[b+700>>2]=0}if(k){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}jb=h+32|0}function e_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2490;p=Rd(l+136|0,l+144|0,l+104|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;r=Wb(l+104|0);o=Wb(l+88|0);m=Wb(l+72|0);n=Wb(l+56|0);q=Wb(l+40|0);v[114578]=0;na(2493,c|0,d|0,l+120|0,l+119|0,l+118|0,r|0,o|0,m|0,n|0,l+36|0);b=v[114578];v[114578]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;b=0;e=0;while(1){k=e;b:{c:{d:{e:{if((b|0)==4){break e}v[114578]=0;c=Q(2430,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(t[(l+120|0)+b|0]){case 1:if((b|0)==3){break c}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(Kg(h,8192,c)){v[114578]=0;U(2494,l+24|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=t[l+24|0];v[114578]=0;R(110,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((b|0)==3){break c}}while(1){v[114578]=0;c=Q(2430,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break c}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!Kg(h,8192,c)){break c}v[114578]=0;U(2494,l+24|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=t[l+24|0];v[114578]=0;R(110,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}if((Fb(m)|0)==(0-Fb(n)|0)){break c}k:{if(Fb(m)){if(Fb(n)){break k}}if(Fb(m)){v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(m,0)|0]==(c&255)){v[114578]=0;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:k;break b}t[g|0]=1;break c}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(n,0)|0]!=(c&255)){break c}v[114578]=0;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:k;break b}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(m,0)|0]==(c&255)){v[114578]=0;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:k;break b}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(n,0)|0]==(c&255)){v[114578]=0;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:k;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(k|b>>>0<2)){e=0;if(!((b|0)==2&w[l+123|0]!=0|u)){break b}}x=l,y=Dd(o),v[x+16>>2]=y;c=Md(l+24|0,l+16|0);l:{if(!b|w[(b+l|0)+119|0]>1){break l}while(1){m:{x=l,y=sf(o),v[x+16>>2]=y;if(!Jb(c,l+16|0)){break m}if(!Kg(h,8192,t[v[c>>2]])){break m}qg(c);continue}break}x=l,y=Dd(o),v[x+16>>2]=y;c=am(c,l+16|0);if(Fb(q)>>>0>=c>>>0){x=l,y=sf(q),v[x+16>>2]=y;c=tz(l+16|0,c);d=sf(q);e=Dd(o);v[114578]=0;c=IE(c,d,e);d=v[114578];v[114578]=0;if((d|0)==1){break a}if(c){break l}}x=l,y=Dd(o),v[x+8>>2]=y;Md(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];n:{while(1){x=l,y=sf(o),v[x+8>>2]=y;if(!Jb(l+16|0,l+8|0)){break n}v[114578]=0;c=Q(2430,a|0,l+552|0)|0;d=v[114578];v[114578]=0;o:{if((d|0)==1){break o}if(!c){break n}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}if(w[v[l+16>>2]]!=(c&255)){break n}v[114578]=0;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}qg(l+16|0);continue}break}break a}if(!s){break c}x=l,y=sf(o),v[x+8>>2]=y;if(!Jb(l+16|0,l+8|0)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114578]=0;d=Q(2430,a|0,l+552|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}if(!d){break p}v[114578]=0;e=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}r:{if(Kg(h,2048,e)){d=v[j>>2];if((d|0)==v[l+548>>2]){v[114578]=0;U(2496,i|0,j|0,l+548|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[j>>2]}v[j>>2]=d+1;t[d|0]=e;c=c+1|0;break r}if(!Fb(r)|!c|w[l+118|0]!=(e&255)){break p}e=v[l+132>>2];if((e|0)==v[l+128>>2]){v[114578]=0;U(2497,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c;c=0}v[114578]=0;T(2434,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break a}e=v[l+132>>2];if(!(!c|(e|0)==v[p>>2])){if(v[l+128>>2]==(e|0)){v[114578]=0;U(2497,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c}s:{if(v[l+36>>2]<1){break s}v[114578]=0;c=Q(2431,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}t:{if(!c){v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[l+119|0]==(c&255)){break t}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}while(1){if(v[l+36>>2]<1){break s}v[114578]=0;c=Q(2431,a|0,l+552|0)|0;d=v[114578];v[114578]=0;u:{if((d|0)==1){break u}v:{if(!c){v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}if(Kg(h,2048,c)){break v}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114578]=0;U(2496,i|0,j|0,l+548|0);c=v[114578];v[114578]=0;if((c|0)==1){break u}}v[114578]=0;c=T(2432,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}d=v[j>>2];v[j>>2]=d+1;t[d|0]=c;v[114578]=0;v[l+36>>2]=v[l+36>>2]-1;T(2434,a|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}e=k;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}w:{if(!k){break w}e=1;while(1){if(Fb(k)>>>0<=e>>>0){break w}v[114578]=0;b=Q(2431,a|0,l+552|0)|0;c=v[114578];v[114578]=0;x:{if((c|0)==1){break x}y:{if(!b){v[114578]=0;b=T(2432,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break x}if(w[kc(k,e)|0]==(b&255)){break y}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2434,a|0)|0;b=v[114578];v[114578]=0;e=e+1|0;if((b|0)!=1){continue}}break}break a}z:{if(v[p>>2]==v[l+132>>2]){break z}v[l+24>>2]=0;a=v[p>>2];v[114578]=0;Ee(r,a,v[l+132>>2],l+24|0);a=v[114578];v[114578]=0;if((a|0)!=1){if(!v[l+24>>2]){break z}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}yb(q);yb(n);yb(m);yb(o);yb(r);Gc(p);jb=l+560|0;return a|0}e=k}b=b+1|0;continue}}}a=P()|0;O()|0;yb(q);yb(n);yb(m);yb(o);yb(r);Gc(p);S(a|0);L()}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=0,T=0,U=0,V=0,W=0,X=C(0),Y=0,Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}j=z[a+4268>>2];NI(a);if(j==z[a+4268>>2]){break a}_w(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!rh(p)){break b}q=Pd(p,0);x=Pd(p,1);m=id(p,0);n=id(p,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}W=a+4960|0;G=a+4648|0;H=a+4672|0;S=a+4936|0;I=a+4696|0;J=a+4720|0;K=a+4744|0;L=a+4768|0;T=a+4840|0;E=a+4504|0;M=a+4528|0;U=a+4912|0;N=a+4552|0;O=a+4576|0;P=a+4600|0;Q=a+4624|0;V=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){j=z[q>>2];j=C(C(C(z[a+5008>>2]-j)*z[a+4276>>2])+j);z[a+5008>>2]=j;_=Dc(u,v[a+4880>>2]),$=j,z[_>>2]=$;j=z[x>>2];j=C(C(C(z[a+5012>>2]-j)*z[a+4276>>2])+j);z[a+5012>>2]=j;_=Dc(s,v[a+4904>>2]),$=j,z[_>>2]=$;j=eh(u,v[a+4356>>2]);f=eh(u,v[a+4360>>2]);e=eh(u,v[a+4364>>2]);g=eh(u,v[a+4368>>2]);j=C(C(C(j*C(.6800000071525574))+C(C(e+eh(u,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=j;j=C(z[Dc(V,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));_=Dc(V,v[a+4832>>2]),$=C(f-C(j*C(.6180340051651001))),z[_>>2]=$}X=z[a+4280>>2];_=a,$=C(eh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;f=C(eh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Dc(Q,v[a+4644>>2])>>2];y=z[a+4444>>2];g=C(z[Dc(Q,v[a+4644>>2])>>2]+C(y*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];h=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(h+l);f=C(C(i*e)+C(z[a+4440>>2]*g));_=Dc(Q,v[a+4640>>2]),$=C(e-C(i*f)),z[_>>2]=$;e=z[a+4976>>2];g=z[Dc(P,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Dc(P,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));_=Dc(P,v[a+4616>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Dc(O,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Dc(O,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));_=Dc(O,v[a+4592>>2]),$=C(e-C(g*f)),z[_>>2]=$;e=z[a+4968>>2];g=z[Dc(N,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Dc(N,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));_=Dc(N,v[a+4568>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(C(f*C(.3499999940395355))+y)+C(e*C(-.3799999952316284)))}_=Dc(U,v[a+4928>>2]),$=e,z[_>>2]=$;k=Dc(U,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Dc(M,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Dc(M,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));_=Dc(M,v[a+4544>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4960>>2];e=z[Dc(E,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Dc(E,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];R=C(C(e*g)+C(z[a+4400>>2]*f));_=Dc(E,v[a+4520>>2]),$=C(g-C(e*R)),z[_>>2]=$;z[a+5020>>2]=R;f=eh(s,v[a+4380>>2]);e=eh(s,v[a+4384>>2]);i=eh(s,v[a+4388>>2]);A=eh(s,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+eh(s,v[a+4396>>2]))*C(-.5)))+C(C(A+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Dc(T,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Dc(T,v[a+4856>>2]),$=C(e-C(f*C(.6180340051651001))),z[_>>2]=$}A=z[a+4280>>2];e=z[a+5004>>2];i=z[Dc(L,v[a+4788>>2])>>2];F=z[a+4492>>2];e=C(z[Dc(L,v[a+4788>>2])>>2]+C(F*C(e-i)));z[a+5004>>2]=e;F=z[a+4272>>2];h=C(h-l);i=C(C(F*h)+C(z[a+4488>>2]*e));_=Dc(L,v[a+4784>>2]),$=C(h-C(F*i)),z[_>>2]=$;e=z[a+5e3>>2];h=z[Dc(K,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Dc(K,v[a+4764>>2])>>2]+C(l*C(e-h)));z[a+5e3>>2]=e;h=z[a+4272>>2];e=C(C(h*i)+C(z[a+4480>>2]*e));_=Dc(K,v[a+4760>>2]),$=C(i-C(h*e)),z[_>>2]=$;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];h=z[Dc(J,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Dc(J,v[a+4740>>2])>>2]+C(l*C(g-h)));z[a+4996>>2]=g;h=z[a+4272>>2];g=C(C(h*e)+C(z[a+4472>>2]*g));_=Dc(J,v[a+4736>>2]),$=C(e-C(h*g)),z[_>>2]=$;e=z[a+4992>>2];h=z[Dc(I,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Dc(I,v[a+4716>>2])>>2]+C(l*C(e-h)));z[a+4992>>2]=e;h=z[a+4272>>2];e=C(C(h*g)+C(z[a+4464>>2]*e));_=Dc(I,v[a+4712>>2]),$=C(g-C(h*e)),z[_>>2]=$;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}Y=x+4|0;Z=q+4|0;g=C(A*f);_=Dc(S,v[a+4952>>2]),$=e,z[_>>2]=$;k=Dc(S,v[a+4956>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-f)*z[a+4500>>2])+f;f=z[a+4988>>2];e=z[Dc(H,v[a+4692>>2])>>2];h=z[a+4460>>2];f=C(z[Dc(H,v[a+4692>>2])>>2]+C(h*C(f-e)));z[a+4988>>2]=f;e=z[a+4272>>2];h=z[a+5032>>2];f=C(C(z[a+4456>>2]*f)+C(e*h));_=Dc(H,v[a+4688>>2]),$=C(h-C(e*f)),z[_>>2]=$;h=z[a+4284>>2];e=z[a+4984>>2];l=z[Dc(G,v[a+4668>>2])>>2];A=z[a+4452>>2];e=C(z[Dc(G,v[a+4668>>2])>>2]+C(A*C(e-l)));z[a+4984>>2]=e;l=z[a+4272>>2];e=C(C(l*f)+C(z[a+4448>>2]*e));_=Dc(G,v[a+4664>>2]),$=C(f-C(l*e)),z[_>>2]=$;z[a+5024>>2]=e;e=C(e*C(.3799999952316284));j=C(C(h*C(C(C(f-R)*C(.3799999952316284))+y))+C(X*j));f=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((W|0)!=(k|0)){continue}break}f=C(C(f*C(i-e))+g);e:{f:{if(w[a+4264|0]&2){q=Z;k=Y;break f}z[m>>2]=C(z[a+5036>>2]+j)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=j;if((r|0)==1){break e}r=r-1|0;q=q+8|0;n=n+4|0;m=m+4|0;k=x+8|0}x=k;z[m>>2]=j;z[n>>2]=f;n=n+4|0;m=m+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}oi(a,b,c,id(p,0),id(p,1),d)}}function iV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-160|0;jb=d;Jc(b);Fq(a);a:{if(!Gu(b,d+120|0)){break a}if(!MK(d+120|0)){break a}e=b;j=d+120|0;n=$e(11555);if(n){q=v[e+8>>2];if(Qc(e,w[j+16|0]|w[j+17|0]<<8|(w[j+18|0]<<16|w[j+19|0]<<24))){b:{if(!(w[j+12|0]|w[j+13|0]<<8|(w[j+14|0]<<16|w[j+15|0]<<24))){break b}i=n?0:-1;while(1){if(!Qb(e,4)){break b}c:{if((w[j+4|0]|w[j+5|0]<<8)>>>0>=64){if((Ih(e)|0)<1){break c}}g=Gd(e);d:{if(g){f=1;l=0;while(1){r=Io(g<<24>>24);o=l>>>0>=n>>>0;h=o&f;g=h;e:{if(o){break e}g=h;if(!(f&1)){break e}g=w[l+11555|0]==(r&255)}f=g;l=l+1|0;g=Gd(e);if(g){continue}break}g=(l|0)==(n|0)&f;break d}g=i}$b(e,4);m=g&1?1:m}p=p+1|0;if(p>>>0<(w[j+12|0]|w[j+13|0]<<8|(w[j+14|0]<<16|w[j+15|0]<<24))>>>0){continue}break}}l=m&1}Qc(e,q)}if(!l){break a}if(!c){k=1;break a}g=jb-16|0;jb=g;e=gh(d+104|0);i=d+120|0;c=i+16|0;f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=b;f=Q(256,c|0,f|0)|0;h=v[114578];v[114578]=0;f:{g:{h:{i:{if((h|0)!=1){if(!f){break f}f=i+12|0;f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114578]=0;v[g>>2]=f;f=T(332,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}v[114578]=0;v[g+12>>2]=(f>>>0)/5;f=Q(333,g|0,g+12|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}f=v[f>>2];m=0;v[114578]=0;R(1534,e|0,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break i}if(!f){break f}i=i+4|0;j:{while(1){v[114578]=0;h=Q(258,c|0,5)|0;j=v[114578];v[114578]=0;k:{if((j|0)!=1){if(h){break k}break f}a=P()|0;O()|0;break g}h=w[i|0]|w[i+1|0]<<8;v[114578]=0;U(1535,g|0,c|0,h|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;R(1536,e|0,g|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}yb(g);m=m+1|0;if((f|0)!=(m|0)){continue}break f}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(g);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}kd(e);S(a|0);L()}jb=g+16|0;c=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;g=v[114578];v[114578]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((g|0)!=1){if(!c){break l}c=jb-16|0;jb=c;g=d+88|0;e=g;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(347,e+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;t:{if((e|0)!=1){jb=c+16|0;break t}V(0)|0;O()|0;Ab();L()}c=w[d+148|0]|w[d+149|0]<<8|(w[d+150|0]<<16|w[d+151|0]<<24);v[114578]=0;v[d+24>>2]=c;c=T(332,b|0)|0;e=v[114578];v[114578]=0;u:{if((e|0)==1){break u}v[114578]=0;v[d+56>>2]=c>>>2;c=Q(333,d+24|0,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break u}e=v[c>>2];v[114578]=0;R(334,g|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break r}c=d+120|4;if(!e){break s}while(1){v[114578]=0;f=Q(258,b|0,4)|0;i=v[114578];v[114578]=0;v:{if((i|0)!=1){if(f){break v}break s}b=P()|0;O()|0;break p}f=w[c|0]|w[c+1|0]<<8;v[114578]=0;f=Q(335,b|0,f|0)|0;i=v[114578];v[114578]=0;w:{if((i|0)!=1){v[d+24>>2]=f;if(yc(d+104|0)>>>0<=f>>>0){break w}v[114578]=0;R(336,g|0,d+24|0);f=v[114578];v[114578]=0;if((f|0)!=1){break w}}b=P()|0;O()|0;break p}k=k+1|0;if((e|0)!=(k|0)){continue}break}break s}b=P()|0;O()|0;break p}b=P()|0;O()|0;break o}e=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);k=0;v[114578]=0;e=Q(256,b|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break q}}b=P()|0;O()|0;break p}if(!e){break m}if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break n}f=d+36|0;x:{y:{z:{A:{B:{C:{while(1){v[114578]=0;e=Q(258,b|0,4)|0;i=v[114578];v[114578]=0;D:{if((i|0)!=1){if(e){break D}break n}b=P()|0;O()|0;break p}e=w[c|0]|w[c+1|0]<<8;v[114578]=0;ma(337,b|0,d+84|0,d+80|0,d+76|0,d+72|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break A}E:{F:{if(v[d+76>>2]<1){break F}e=v[d+84>>2];if((e|0)>-1){break F}e=e^-1;v[d+84>>2]=e;if(Kb(g)>>>0<=e>>>0){break F}if(!Vd(qd(d+104|0,v[Pb(g,v[d+84>>2])>>2]),11555)){break F}v[114578]=0;X(338,d+56|0,b|0,v[d+80>>2],v[d+76>>2]);e=v[114578];v[114578]=0;if((e|0)==1){break z}v[114578]=0;e=T(339,d+56|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break y}if(e){if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[114578]=0;Q(340,d+56|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[114578]=0;Q(340,d+56|0,16)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}}v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}G:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;Q(340,d+56|0,8)|0;break G}if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[114578]=0;Q(340,d+56|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;Q(340,d+56|0,4)|0;break G}if((w[c|0]|w[c+1|0]<<8)>>>0>=62){v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;Q(340,d+56|0,4)|0;break G}v[114578]=0;T(341,d+56|0)|0}e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;i=T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break B}v[114578]=0;e=T(342,d+24|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break E}h=v[d+72>>2];H:{if((h|0)<0){break H}if(yc(d+104|0)>>>0<=h>>>0){break H}h=qd(d+104|0,v[d+72>>2]);v[114578]=0;U(13,d+8|0,2,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break C}Gb(d+24|0,d+8|0);yb(d+8|0)}v[114578]=0;U(343,d+8|0,d+56|0,i|0);i=v[114578];v[114578]=0;if((i|0)==1){break C}Wd(f,d+8|0);Bb(d+8|0);v[114578]=0;R(344,a|0,e|0);i=v[114578];v[114578]=0;if((i|0)==1){break C}Ru(e)}Bb(d+56|0)}k=k+1|0;if(k>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break n}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;Ru(e);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0}Bb(d+56|0)}rC(g)}kd(d+104|0);S(b|0);L()}k=md(a)^1}rC(g)}kd(d+104|0)}jb=d+160|0;return k|0}function Lka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;e=jb-176|0;jb=e;a:{b:{c:{d:{e:{f:{g:{h:{if(!ph(b,14021)){break h}if(d){t[d|0]=1}k=a+1074312|0;Ct(k);o=a+480216|0;p=a+480224|0;l=a+1074372|0;q=a+480200|0;m=a+480248|0;i:{if(!Qb(b,7)){break i}r=a+480220|0;s=a+480228|0;z=a+480232|0;A=a+484360|0;n=a+480268|0;C=a+1304412|0;while(1){f=Cf(b);d=hg(b);if((f|0)==(w[14475]|w[14476]<<8|(w[14477]<<16|w[14478]<<24))){fg(b,6);break i}if(!(f&1616928864)|f&-2139062144){break i}if(!Qb(b,d)){break i}ud(e+160|0,b,d);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)<=1347243309){if((f|0)<=1146367533){if((f|0)<=1130917458){if((f|0)==1127099950){break y}if((f|0)!=1129797166){break j}v[114578]=0;v[e>>2]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break v}v[a+1074304>>2]=v[e>>2];break j}if((f|0)==1130917459){break q}if((f|0)!=1145525806){break j}v[114578]=0;U(671,e+160|0,d|0,q|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}if((f|0)<=1213486400){if((f|0)==1146367534){break A}if((f|0)!=1196316499|d>>>0<3){break j}v[114578]=0;R(672,e+144|0,e+160|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}v[114578]=0;g=W(673,e|0,e+144|0,8)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}yb(e+144|0);v[114578]=0;f=T(255,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}v[114578]=0;U(674,e|0,m|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break m}If(g);break j}if((f|0)==1213486401){break r}if((f|0)==1280530262){break u}if((f|0)!=1297303086){break j}Ct(k);h=0;break l}if((f|0)<=1380994349){if((f|0)<=1380340803){if((f|0)==1347243310){break w}if((f|0)!=1347244882){break j}v[114578]=0;U(675,e+160|0,d|0,n|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}if(Sn(w[n|0])){break j}t[n|0]=5;break j}if((f|0)==1380340804){break z}if((f|0)==1380986414){break s}if((f|0)!=1380991534){break j}v[114578]=0;U(671,e+160|0,d|0,o|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}if((f|0)<=1397768493){if((f|0)==1380994350){break k}if((f|0)!=1397052739|d>>>0<3){break j}v[114578]=0;f=T(359,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}if(!f|f>>>0>x[a+480190>>1]){break j}f=B(f,104)+a|0;d=f+484448|0;j=f+484484|0;while(1){v[114578]=0;g=T(392,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}v[d>>2]=g;d=d+4|0;if((j|0)!=(d|0)){continue}break}break j}if((f|0)==1397768494){break t}if((f|0)==1414344238){break x}if((f|0)!=1448301654){break j}v[114578]=0;U(671,e+160|0,d|0,z|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}v[114578]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[e>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[114578]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[e>>2]%1e4;break j}d=P()|0;O()|0;break a}if(c){break j}v[114578]=0;u[e>>1]=0;U(676,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){D=a,E=Fd(x[e>>1],x[a+480188>>1],127),u[D+480188>>1]=E;break j}d=P()|0;O()|0;break a}v[114578]=0;U(677,e+160|0,d|0,p|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}v[114578]=0;U(678,e+160|0,d|0,l|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}d=P()|0;O()|0;break a}v[114578]=0;v[e>>2]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break f}d=v[e>>2];if(!d){break j}v[a+1074308>>2]=d;break j}v[114578]=0;U(671,e+160|0,d|0,s|0);d=v[114578];v[114578]=0;if((d|0)!=1){break j}break b}if(v[a+480180>>2]==4){break j}v[114578]=0;U(676,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){Oe(Vb(A),x[e>>1]);break j}d=P()|0;O()|0;break a}g=Wb(e);v[114578]=0;f=T(255,e+160|0)|0;d=v[114578];v[114578]=0;B:{if((d|0)==1){break B}v[114578]=0;W(679,e+160|0,g|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}v[114578]=0;U(13,e+144|0,0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break B}Gb(C,e+144|0);yb(e+144|0);yb(g);break j}d=P()|0;O()|0;yb(g);break a}if(d&1|d>>>0>126){break j}u[e>>1]=(d>>>1|0)- -64;v[114578]=0;u[e+144>>1]=127;f=Q(478,e|0,e+144|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}j=x[f>>1];if(j>>>0<65){break j}h=64;while(1){v[114578]=0;R(473,e|0,e+160|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}d=cd(e);f=e;C:{if(w[e|0]==255){break C}d=w[d|0];i=(h<<5)+a|0;g=i+480284|0;u[g>>1]=128;u[i+480286>>1]=d;i=i+480280|0;v[i>>2]=0;v[i>>2]=(w[f|0]&128)<<3;d=w[f|0]&127;t[f|0]=d;if(d>>>0<65){u[g>>1]=d<<2;d=w[f|0]}if((d|0)!=100){break C}v[i>>2]=v[i>>2]|256}h=h+1|0;if((j|0)!=(h|0)){continue}break}break j}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;yb(e+144|0);break a}d=P()|0;O()|0;If(g);break a}D:{E:{F:while(1){v[114578]=0;f=Q(258,e+160|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break E}if(!f|h>>>0>=110){break j}v[114578]=0;g=T(389,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}d=0;while(1){G:{if(!(!(g>>>d&1)|h>>>0>=110)){v[114578]=0;W(479,k|0,h|0,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}}h=h+1|0;d=d+1|0;if((d|0)!=8){continue}continue F}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[114578]=0;U(671,e+160|0,d|0,r|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}}Bb(e+160|0);if(Qb(b,7)){continue}break}}Yn(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(v[a+480224>>2]>=3){v[p>>2]=0}if(v[l>>2]>=6){v[l>>2]=0}Cc(q,256);if(md(m)){break h}Vz(m,v[o>>2],16777216)}jb=e+176|0;return}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0}Bb(e+160|0);S(d|0);L()}function dp(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;i=jb-16|0;jb=i;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;r=v[b+764>>2];h=w[b+824|0];a:{if(!h){Eb(i+8|0,a+1074312|0,11);if(Cb(i+8|0)){break a}}b:{c:{if(!g){break c}if(!be(h)){break c}d:{j=g+236|0;h=h-1|0;if(x[dd(j,h)>>1]){break d}Eb(i+8|0,a+1074312|0,43);if(!Cb(i+8|0)){break d}if(zi(g)){break d}v[b+656>>2]=g;break a}if(w[fc(g+108|0,h)|0]>120){break a}h=x[dd(j,h)>>1];k=(h-1&65535)>>>0<3999?(B(h,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(h>>>0>250){break a}Eb(i+8|0,a+1074312|0,43);if(Cb(i+8|0)){if(g){k=0;if(zi(g)){break b}}t[b+825|0]=0;v[b+656>>2]=0;break a}k=0}h=v[b+656>>2];j=v[b+104>>2];l=(j|0)!=0&(j|0)!=(k|0);j=!l;p=!g|v[a+480180>>2]!=16777216?p:v[g+44>>2]!=0;if(!(j?1:!d|!p|v[b+656>>2]!=(g|0))){break a}q=d^1;e:{if(j|q){break e}j=a+1074312|0;Eb(i+8|0,j,32);if(!(!Cb(i+8|0)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|(g|0)!=(h|0):1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Kh(b)){break f}}Eb(i+8|0,j,79);if(!Cb(i+8|0)){break e}if(!Kh(b)){break e}}m=1}g:{if(!v[b+16>>2]|(!l|(!x[a+480192>>1]|(g|0)!=(h|0)))){break g}Eb(i+8|0,a+1074312|0,87);if(!Cb(i+8|0)){break g}m=Tf(b+810|0)^1|m}h:{i:{j:{k:{if(!(Kh(b)|!(v[a+480180>>2]&16777248))){if(!g){break k}if(!zi(g)){break k}}if((g|0)==(h|0)){break j}}l:{m:{if(!d){break m}Eb(i+8|0,a+1074312|0,61);if(!Cb(i+8|0)){break m}j=v[b+656>>2];if(j){break l}j=0;h=v[b+104>>2];if(h){break h}}n=1;break i}h=v[b+104>>2];break h}n=0}v[b+656>>2]=g;h=k;j=g}n:{if(!e){break n}o=b;o:{p:{q:{if(v[a+480180>>2]&3){if(h){if(De(h)){break q}}if(!oj(b)){break n}}if(!h){break p}}if(u[h+34>>1]<0){break n}g=x[h+30>>1];break o}g=0;if(!j|!w[j+34|0]){break o}g=b;k=v[b+656>>2];r:{if(k){g=v[k+4>>2]<<2;break r}g=v[g+688>>2]}}v[o+688>>2]=g}if(m){if(!((h|0)!=0&l)){break a}Eb(i+8|0,a+1074312|0,85);if(Cb(i+8|0)){v[b+768>>2]=t[h+37|0]}if(v[a+480180>>2]!=2){break a}if(!De(h)){break a}v[b+704>>2]=v[h+24>>2];break a}t[b+825|0]=0;s:{if(!j){break s}Eb(i+8|0,a+1074312|0,29);if(s=0,z=(C=Cb(i+8|0),D=1,E=h,E?C:D),A=w[j+34|0]!=0|n,A?s:z){break s}t[b+820|0]=w[j+16|0]}g=j;o=64;k=b;v[b+764>>2]=64;m=h;if(h){o=x[m+32>>1];v[k+764>>2]=o}if(g){v[k+764>>2]=B(v[g+4>>2],o)>>>6}t:{if(!(v[a+480180>>2]&1048580?e:1)){break t}Eb(i+8|0,a+1074312|0,48);if(Cb(i+8|0)){break t}yM(a,b,j,h)}u:{v:{w:{if(!f){break w}e=a+1074312|0;Eb(i+8|0,e,19);x:{y:{z:{A:{B:{C:{D:{E:{if(Cb(i+8|0)){if(!v[b+76>>2]){g=1;break D}if(!(!c|q)){g=(w[a+480208|0]&8)>>>3|0;if(g){break D}break E}g=0;if(c){break E}break D}g=1;F:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break F}g=0;if(!(w[b+89|0]&16)){break F}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!j|n)){break B}if(!g){break A}g=v[b+88>>2];c=g&6144;break C}if(d){break D}if(!(w[b+89|0]&24)){g=0;break D}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|n){break B}if(!g){break A}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!j){break x}if(c){break y}if(!(w[j+60|0]&8)){wi(b+724|0)}if(!(w[j+80|0]&8)){wi(b+736|0)}if(w[j+100|0]&8){break x}wi(b+748|0);break x}if(g){break z}}if(j){if(t[j+60|0]&1){break w}Eb(i+8|0,e,32);if(Cb(i+8|0)){wi(b+724|0);break w}yl(b);break w}g=0;if(!h){break v}break u}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break x}}yl(b)}Eb(i+8|0,e,21);if(Cb(i+8|0)){break w}t[b+838|0]=0;v[b+780>>2]=0}g=0;if(h){break u}if(!j){break v}g=1;if(zi(j)){break u}}v[b+764>>2]=0;v[b+104>>2]=0;break a}c=b;G:{H:{I:{J:{K:{if(!(!d|!h|v[b+104>>2]!=(h|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break K}Eb(i+8|0,a+1074312|0,40);if(!Cb(i+8|0)|w[b+811|0]){break K}d=v[b+88>>2];break J}v[b+88>>2]=v[b+88>>2]&-6145;f=a+1074312|0;Eb(i+8|0,f,18);c=b;L:{if(s=Cb(i+8|0),z=1,A=v[a+480180>>2]&16777248,A?s:z){e=-640;if(!(v[b+104>>2]!=(h|0)|n)){break L}}e=-768}v[c+88>>2]=e&v[b+88>>2];M:{if(!j){break M}t[b+724|0]=w[j+60|0];t[b+736|0]=w[j+80|0];t[b+748|0]=w[j+100|0];N:{if((w[j+100|0]&17)!=17){break N}Eb(i+8|0,f,36);if(Cb(i+8|0)|w[b+857|0]){break N}t[b+857|0]=127}if(wu(j)){s=b,z=$B(j),t[s+857|0]=z}if(!ZB(j)){break M}s=b,z=_B(j),t[s+858|0]=z}if(g){break I}if(!d){break G}break H}d=v[b+88>>2]&-6145}v[c+88>>2]=d&-640;if(!g){break H}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break G}c=a+1074312|0;Eb(i+8|0,c,54);if(!Cb(i+8|0)){Eb(i,c,39);if(!Cb(i)){break G}}v[b+8>>2]=0;v[b+12>>2]=0}O:{if(w[b+810|0]!=255){break O}Eb(i+8|0,a+1074312|0,100);if(!Cb(i+8|0)|(!(v[a+480208>>2]&4)|!l)){break O}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+764>>2]=r;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}Ys(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];d=a+1074312|0;Eb(i+8|0,d,83);if(!(!Cb(i+8|0)|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;Eb(i+8|0,d,21);if(Cb(i+8|0)){t[b+838|0]=0;v[b+780>>2]=0}c=b;P:{Q:{if(p){v[b+704>>2]=v[h+24>>2];t[b+872|0]=w[b+872|0]|8;e=0;break Q}if(!(v[a+480180>>2]&5?l|q:1)){break P}v[b+704>>2]=v[h+24>>2];e=t[h+37|0]}v[c+768>>2]=e}c=b;if(Lp(a)){e=t[h+36|0]}else{e=0}v[c+772>>2]=e;Eb(i+8|0,d,69);if(!(Cb(i+8|0)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+876>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}R:{if(!(g&2)){g=v[b+76>>2];break R}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break R}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}jb=i+16|0}function dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-352|0;jb=d;Qc(b,60);i=15;a:{if(!ph(b,17213)){Qc(b,124);i=31;if(!ph(b,17218)){break a}}Hd(a,536870912);u[a+480190>>1]=i;Jc(b);b:{if(x[a+480190>>1]){while(1){f=tA(b);v[(d+224|0)+(e<<2)>>2]=f;if(f>>>0>131072){break b}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;e=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;mj(a,1);$b(b,4);f=Wp(b);if(f>>>0<178){break a}e=a;o=177693e5/+(f>>>0);c:{if(o<4294967296&o>=0){f=~~o>>>0;break c}f=0}v[e+480204>>2]=f;$b(b,14);d:{e:{f:{if(x[a+480190>>1]){p=d+78|0;j=1;i=0;m=1;while(1){tQ(b,d+56|0);e=v[((j<<2)+d|0)+220>>2];l=jb-16|0;jb=l;h=(B(j,104)+a|0)+484380|0;Ed(h,1);v[h>>2]=e;e=d+56|0;t[h+37|0]=w[e+24|0]<<4;t[l+15|0]=w[e+25|0];t[l+14|0]=64;q=h,r=w[pc(l+15|0,l+14|0)|0]<<2,u[q+30>>1]=r;f=e+26|0;g=w[f|0]|w[f+1|0]<<8;e=e+28|0;f=v[h>>2];g:{if(!f){break g}e=w[e|0]|w[e+1|0]<<8;g=(g<<8|g>>>8)&65535;v[h+4>>2]=g;e=(((e<<8|e>>>8)&65535)<<1)+g|0;v[h+8>>2]=e;if(f>>>0<=g>>>0){g=f-1|0;v[h+4>>2]=g}if(e>>>0>f>>>0){v[h+8>>2]=f;e=f}if(!(e-g>>>0>3?!(e>>>0<4|e>>>0<g>>>0):0)){v[h+4>>2]=0;v[h+8>>2]=0;break g}if(e>>>0<=g>>>0){break g}u[h+34>>1]=x[h+34>>1]|2}jb=l+16|0;e=d+56|0;while(1){if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;i=i+1|0}e=e+1|0;if((p|0)!=(e|0)){continue}break}if(i>>>0>127){break b}Tl(d+192|0,3,d+56|0);Ic(d+208|0,d+192|0);v[114578]=0;Q(371,((j<<5)+a|0)+946304|0,d+208|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}yb(d+208|0);m=m+1|0;j=m&65535;if(j>>>0<=x[a+480190>>1]){continue}break}}f=Ub(d+56|0,17223);v[114578]=0;e=a+946336|0;h=Q(1003,e|0,f|0)|0;j=v[114578];v[114578]=0;i=1;h:{i:{j:{k:{if((j|0)!=1){if(!h){v[114578]=0;h=Q(85,d+208|0,17234)|0;i=v[114578];v[114578]=0;if((i|0)==1){break k}v[114578]=0;i=Q(1003,e|0,h|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}yb(h)}yb(f);e=0;if(!oz(b,d+56|0)){break a}if(!dP(d+56|0)){break a}if(c){break h}break d}e=P()|0;O()|0;break i}e=P()|0;O()|0;break i}e=P()|0;O()|0;yb(h)}yb(f);break e}u[d+54>>1]=0;if(w[d+56|0]){while(1){u[d+208>>1]=w[(d+e|0)+58|0]+1;q=d,r=x[Si(d+54|0,d+208|0)>>1],u[q+54>>1]=r;e=e+1|0;if(e>>>0<w[d+56|0]){continue}break}}e=d+56|1;f=w[e|0];h=w[d+56|0];j=a+484360|0;Oe(Vb(j),f>>>0<h>>>0?w[e|0]:0);In(Vb(j),d+56|2,w[d+56|0],65535,65535);if(x[a+480190>>1]==31){$b(b,4)}j=0;v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;l=c&1;if(l){$f(a+484344|0,x[d+54>>1])}if(x[d+54>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(rg(h,j&65535,64)){break m}}$b(b,1024);break l}while(1){p=Xe(_b(h,j),m,0);e=0;while(1){Sl(d+208|0,b);f=p+B(e,6)|0;n:{o:{if(w[fc(d+208|0,0)|0]!=255){break o}t[(d+48|0)+e|0]=0;t[(d+40|0)+e|0]=0;p:{if(!i){break p}if(w[fc(d+208|0,1)|0]!=252){break p}q=fc(d+208|0,1),r=254,t[q|0]=r}q:{switch(w[fc(d+208|0,1)|0]-252|0){case 2:t[f+3|0]=13;break n;case 1:break n;case 0:break q;default:break o}}t[f+3|0]=14;t[d+39|0]=9;break n}g=v[d+208>>2];v[d+32>>2]=g;v[d+12>>2]=g;kt(d+12|0,f);g=w[f|0];r:{if(!g){break r}t[(d+40|0)+e|0]=0;t[(d+48|0)+e|0]=g;if(g>>>0>48){break r}t[d+192|0]=8;q=d,r=w[qh(d+39|0,d+192|0)|0],t[q+39|0]=r}s:{t:{u:{v:{w:{x:{switch(w[f+3|0]){case 1:t[f+3|0]=1;break n;case 2:g=w[f+5|0];if(g&240){t[f+3|0]=3;t[f+5|0]=g>>>4;break n}g=g&15;if(g){t[f+3|0]=2;t[f+5|0]=g;break n}t[f+5|0]=0;break t;case 3:if(w[(d+40|0)+e|0]){break u}t[f+3|0]=19;t[f+5|0]=0;break n;case 4:if(w[(d+40|0)+e|0]){break u}t[f+3|0]=19;t[f+5|0]=1;break n;case 5:if(!w[f+1|0]){break u}t[f+3|0]=13;t[d+192|0]=63;t[d+31|0]=w[f+5|0]+(x[(B(w[f+1|0],104)+a|0)+484410>>1]>>>2|0);q=f,r=w[pc(d+192|0,d+31|0)|0],t[q+5|0]=r;if(!w[(d+40|0)+e|0]){break w}t[f+2|0]=1;t[f+4|0]=w[f+5|0];t[f+5|0]=0;break t;case 6:g=w[f+1|0];if(!g){break u}t[f+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;k=w[f+5|0];g=g>>>0<k>>>0?0:g-k|0;t[f+5|0]=g;if(!w[(d+40|0)+e|0]){break w}t[f+4|0]=g;t[f+2|0]=1;t[f+5|0]=0;break t;case 8:k=w[(d+48|0)+e|0];g=w[f+5|0];n=k+(g>>>4|0)|0;t[(d+44|0)+e|0]=n;t[f+3|0]=2;g=g&15;t[(d+40|0)+e|0]=g;q=f,r=cP(g,k,n&255),t[q+5|0]=r;break w;case 9:t[d+192|0]=8;q=d,r=w[qh(d+39|0,d+192|0)|0],t[q+39|0]=r;break t;case 0:break v;case 7:break x;default:break t}}g=w[(d+48|0)+e|0];k=w[f+5|0];n=g-(k>>>4|0)|0;t[(d+44|0)+e|0]=n;t[f+3|0]=3;k=k&15;t[(d+40|0)+e|0]=k;q=f,r=cP(k,n&255,g),t[q+5|0]=r}if(!w[f+3|0]){break s}break n}if(!w[f+5|0]){break s}break t}t[f+5|0]=0}t[f+3|0]=0}k=w[(d+40|0)+e|0];if(!k){break n}n=(d+44|0)+e|0;g=w[n|0];if(g){t[(d+48|0)+e|0]=g;t[f|0]=g;t[f+5|0]=k;t[n|0]=0}t[f+3|0]=4}e=e+1|0;if((e|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}j=j+1|0;if(j>>>0<x[d+54>>1]){continue}break}}y:{z:{A:{B:{C:{D:{if(c&2){i=x[a+480190>>1];if(!i){break C}e=1;while(1){c=(B(e&65535,104)+a|0)+484380|0;if(v[c>>2]){tg(ad(d+208|0,8,1,0,0),c,b);i=x[a+480190>>1]}e=e+1|0;if((e&65535)>>>0<=(i&65535)>>>0){continue}break}break D}i=x[a+480190>>1]}if((i&65535)!=15){break C}b=Ub(d+16|0,17243);v[114578]=0;R(219,d+192|0,b|0);c=v[114578];v[114578]=0;e=1;if((c|0)==1){break z}v[114578]=0;U(537,d+208|0,d+192|0,d+39|0);c=v[114578];v[114578]=0;if((c|0)!=1){break B}e=P()|0;O()|0;Ib(d+192|0);break y}e=0;v[114578]=0;Q(2,d+208|0,17256)|0;b=v[114578];v[114578]=0;if((b|0)==1){break A}}Gb(a+1304436|0,d+208|0);yb(d+208|0);if(e){Ib(d+192|0);yb(d+16|0)}Mc(a+1304448|0,x[a+480190>>1]==15?17287:17291);v[a+1304496>>2]=2;break d}e=P()|0;O()|0;break e}e=P()|0;O()|0}yb(b);break e}e=P()|0;O()|0;yb(d+208|0)}S(e|0);L()}e=1;break a}e=0}jb=d+352|0;return e|0}function e1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;l=jb-560|0;jb=l;v[l+44>>2]=0;o(+b);n=j(1)|0;j(0)|0;a:{if((n|0)<-1?1:(n|0)<=-1){z=1;A=55648;b=-b;o(+b);n=j(1)|0;j(0)|0;break a}if(e&2048){z=1;A=55651;break a}z=e&1;A=z?55654:55649;H=!z}b:{if((n&2146435072)==2146435072){p=z+3|0;Jf(a,32,c,p,e&-65537);Qe(a,A,z);d=f&32;Qe(a,b!=b?d?55675:55679:d?55667:55671,3);break b}x=l+16|0;c:{d:{e:{b=rG(b,l+44|0);b=b+b;if(b!=0){g=v[l+44>>2];v[l+44>>2]=g-1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}q=v[l+44>>2];m=(d|0)<0?6:d;break d}q=g-29|0;v[l+44>>2]=q;b=b*268435456;m=(d|0)<0?6:d}s=(q|0)<0?l+48|0:l+336|0;h=s;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((q|0)<1){d=q;g=h;i=s;break f}i=s;d=q;while(1){p=(d|0)<29?d:29;g=h-4|0;g:{if(i>>>0>g>>>0){break g}k=p;d=0;n=0;while(1){u=g;G=v[g>>2];r=k&31;if((k&63)>>>0>=32){F=G<<r;r=0}else{F=(1<<r)-1&G>>>32-r;r=G<<r}r=r+d|0;F=n+F|0;n=r;d=Kma(n,d>>>0>n>>>0?F+1|0:F,1e9,0);r=Hma(d,mb,1e9,0);v[u>>2]=n-r;g=g-4|0;if(i>>>0<=g>>>0){n=0;continue}break}if(!d){break g}i=i-4|0;v[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[l+44>>2]-p|0;v[l+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(m+25|0)/9|0;if((d|0)<=-1){r=h+1|0;E=(C|0)==102;while(1){u=(d|0)<-9?9:0-d|0;h:{if(g>>>0>i>>>0){n=1e9>>>u|0;k=-1<<u^-1;d=0;h=i;while(1){p=d;d=v[h>>2];v[h>>2]=p+(d>>>u|0);d=B(n,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}i=v[i>>2]?i:i+4|0;if(!d){break h}v[g>>2]=d;g=g+4|0;break h}i=v[i>>2]?i:i+4|0}d=v[l+44>>2]+u|0;v[l+44>>2]=d;h=E?s:i;g=(r|0)<g-h>>2?h+(r<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=i>>>0){break i}h=B(s-i>>2,9);k=v[i>>2];if(k>>>0<10){break i}d=100;while(1){h=h+1|0;if(d>>>0>k>>>0){break i}d=B(d,10);continue}}d=(m-((C|0)==102?0:h)|0)-((C|0)==103&(m|0)!=0)|0;if((d|0)<(B(g-s>>2,9)-9|0)){n=d+9216|0;k=(n|0)/9|0;p=((k<<2)+((q|0)<0?l+48|4:l+340|0)|0)-4096|0;d=10;j:{k=n-B(k,9)|0;if((k|0)>7){break j}d=100;while(1){k=k+1|0;if((k|0)==8){break j}d=B(d,10);continue}}n=v[p>>2];q=(n>>>0)/(d>>>0)|0;k:{r=n-B(d,q)|0;k=p+4|0;if(!((k|0)==(g|0)?r:1)){break k}b=(g|0)==(k|0)?1:1.5;k=d>>>1|0;y=k>>>0>r>>>0?.5:(k|0)==(r|0)?b:1.5;b=q&1?9007199254740994:9007199254740992;if(!(w[A|0]!=45|H)){y=-y;b=-b}k=n-r|0;v[p>>2]=k;if(b+y==b){break k}d=d+k|0;v[p>>2]=d;if(d>>>0>=1e9){while(1){v[p>>2]=0;p=p-4|0;if(p>>>0<i>>>0){i=i-4|0;v[i>>2]=0}d=v[p>>2]+1|0;v[p>>2]=d;if(d>>>0>999999999){continue}break}}h=B(s-i>>2,9);k=v[i>>2];if(k>>>0<10){break k}d=100;while(1){h=h+1|0;if(d>>>0>k>>>0){break k}d=B(d,10);continue}}d=p+4|0;g=d>>>0<g>>>0?d:g}while(1){q=g;k=g>>>0<=i>>>0;if(!k){g=q-4|0;if(!v[g>>2]){continue}}break}l:{if((C|0)!=103){u=e&8;break l}g=m?m:1;d=(g|0)>(h|0)&(h|0)>-5;m=(d?h^-1:-1)+g|0;f=(d?-1:-2)+f|0;u=e&8;if(u){break l}g=-9;m:{if(k){break m}d=v[q-4>>2];if(!d){break m}g=0;if((d>>>0)%10|0){break m}k=0;g=100;while(1){if(!((d>>>0)%(g>>>0)|0)){k=k+1|0;g=B(g,10);continue}break}g=k^-1}d=B(q-s>>2,9);if((f&-33)==70){u=0;d=(d+g|0)-9|0;d=(d|0)>0?d:0;m=(d|0)>(m|0)?m:d;break l}u=0;d=((d+h|0)+g|0)-9|0;d=(d|0)>0?d:0;m=(d|0)>(m|0)?m:d}r=(m|u)!=0;d=a;k=c;n=f&-33;if((n|0)==70){f=(h|0)>0?h:0}else{g=h>>31;g=Hm(g+h^g,0,x);if((x-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((x-g|0)<2){continue}break}}E=g-2|0;t[E|0]=f;t[g-1|0]=(h|0)<0?45:43;f=x-E|0}p=(f+(r+(m+z|0)|0)|0)+1|0;Jf(d,32,k,p,e);Qe(a,A,z);Jf(a,48,c,p,e^65536);n:{o:{p:{if((n|0)==70){d=l+16|8;h=l+16|9;f=i>>>0>s>>>0?s:i;i=f;while(1){g=Hm(v[i>>2],0,h);q:{if((f|0)!=(i|0)){if(l+16>>>0>=g>>>0){break q}while(1){g=g-1|0;t[g|0]=48;if(l+16>>>0<g>>>0){continue}break}break q}if((g|0)!=(h|0)){break q}t[l+24|0]=48;g=d}Qe(a,g,h-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}g=0;if(!r){break o}Qe(a,55683,1);if((m|0)<1|i>>>0>=q>>>0){break p}while(1){g=Hm(v[i>>2],0,h);if(g>>>0>l+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(l+16>>>0<g>>>0){continue}break}}Qe(a,g,(m|0)<9?m:9);g=m-9|0;i=i+4|0;if(q>>>0<=i>>>0){break o}d=(m|0)>9;m=g;if(d){continue}break}break o}r:{if((m|0)<0){break r}f=i>>>0<q>>>0?q:i+4|0;k=l+16|9;d=l+16|8;h=i;while(1){g=Hm(v[h>>2],0,k);if((k|0)==(g|0)){t[l+24|0]=48;g=d}s:{if((h|0)!=(i|0)){if(l+16>>>0>=g>>>0){break s}while(1){g=g-1|0;t[g|0]=48;if(l+16>>>0<g>>>0){continue}break}break s}Qe(a,g,1);g=g+1|0;if(u?0:(m|0)<=0){break s}Qe(a,55683,1)}q=g;g=k-g|0;Qe(a,q,(g|0)<(m|0)?g:m);m=m-g|0;h=h+4|0;if(f>>>0<=h>>>0){break r}if((m|0)>-1){continue}break}}Jf(a,48,m+18|0,18,0);Qe(a,E,x-E|0);break n}g=m}Jf(a,48,g+9|0,9,0)}break b}m=f&32;q=m?A+9|0:A;t:{if(d>>>0>11){break t}g=12-d|0;if(!g){break t}y=8;while(1){y=y*16;g=g-1|0;if(g){continue}break}if(w[q|0]==45){b=-(y+(-b-y));break t}b=b+y-y}g=v[l+44>>2];h=g>>31;g=Hm(h^g+h,0,x);if((x|0)==(g|0)){t[l+15|0]=48;g=l+15|0}k=z|2;h=v[l+44>>2];n=g-2|0;t[n|0]=f+15;t[g-1|0]=(h|0)<0?45:43;g=e&8;i=l+16|0;while(1){f=i;s=m;if(D(b)<2147483648){h=~~b}else{h=-2147483648}t[i|0]=s|w[h+55632|0];b=(b-+(h|0))*16;i=f+1|0;if(!(!(g?1:(d|0)>0|b!=0)|(i-(l+16|0)|0)!=1)){t[f+1|0]=46;i=f+2|0}if(b!=0){continue}break}f=!d|((i-l|0)-18|0)>=(d|0)?(x-(n+(l+16|0)|0)|0)+i|0:((d+x|0)-n|0)+2|0;p=f+k|0;Jf(a,32,c,p,e);Qe(a,q,k);Jf(a,48,c,p,e^65536);d=i-(l+16|0)|0;Qe(a,l+16|0,d);g=d;d=x-n|0;Jf(a,48,f-(g+d|0)|0,0,0);Qe(a,n,d)}Jf(a,32,c,p,e^8192);jb=l+560|0;return((c|0)>(p|0)?c:p)|0}function aM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0),s=0,y=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=C(0),M=0,N=0,O=C(0),P=0;i=jb-48|0;jb=i;m=x[a+480192>>1]?v[(B(b,896)+a|0)+1075640>>2]:m;E=a+1074312|0;g=B(b,896)+a|0;F=g+1075805|0;I=g+1075672|0;J=g+1075772|0;G=g+1075748|0;H=g+1075744|0;K=g+1075704|0;p=g+1075676|0;q=g+1075668|0;s=g+1075648|0;y=g+1075792|0;A=g+1075072|0;k=e&127;L=C(k>>>0);j=g+1075855|0;r=C(w[j|0]);g=1;while(1){e=w[d+o|0];if(e){l=e-48|0;a:{b:{if((l&255)>>>0<10){break b}if((e-65&255)>>>0<=5){l=e-55|0;break b}c:{d:{e:{switch(e-97|0){case 2:f:{e=wl(a,b,3,0);if(!e|e-251>>>0<5){break f}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break f}e=ov(e,79864,79872);if(!e){break f}e=nb[v[v[e>>2]+184>>2]](e,b)|0;h=(e|0)!=255;l=h?e:0;if(h|!m){break b}break c}if(m){break c}l=0;break b;case 13:e=0;if(!be(w[F|0])){break d}e=w[F|0]-1|0;break d;case 21:Eb(i+8|0,E,28);g:{if(!Cb(i+8|0)){Eb(i,E,1);h=0;if(!Cb(i)){break g}}h=u[J>>1]}e=B(v[G>>2],v[H>>2]);l=e;n=e>>31;e=B(v[a+1074444>>2],h+v[I>>2]|0);e=Yb((Ac(Ima(Hma(l,n,e,e>>31),mb,1048576,0),mb)|0)/2|0,1,127);break d;case 23:v[i+8>>2]=v[p>>2]/2;v[i>>2]=127;e=v[de(i+8|0,i)>>2];break d;case 24:v[i+8>>2]=v[q>>2]/2;v[i>>2]=127;e=v[de(i+8|0,i)>>2];break d;case 0:e=0;if(!m){break d}h=x[m+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!m){break d}h=x[m+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=v[s>>2]>>>8|0;break d;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[y|0]-1|0}e=e&127;break d;case 12:e=v[A>>2]>>>7&1;break d;case 15:e=0;if(!m){break d}h=w[m+30|0];if(!h){break d}e=h-1&127;break d;case 25:h=j;e=k;h:{if(!c){break h}e=k;if(t[j|0]<0){break h}i:{if(f>>>0<3){break i}n=(i+16|0)+f|0;if(w[n-3|0]!=240){break i}e=k;if(w[n-2|0]>239){break h}}D=Yo(a,r,L);if(D<C(4294967296)&D>=C(0)){e=~~D>>>0;break h}e=0}t[h|0]=e;break d;case 18:e=f;j:{if(!e){e=0;break j}while(1){e=e-1|0;if(w[e+(i+16|0)|0]==240){break j}if(e){continue}break}}if(w[(i+16|0)+e|0]!=240|f-e>>>0<5){break a}l=0;e=e+5|0;if((f|0)==(e|0)){e=0}else{while(1){l=w[(i+16|0)+e|0]+l|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}e=0-l|0}e=e&127;break d;case 20:break e;default:break a}}e=B(v[G>>2],v[H>>2]);h=e;l=e>>31;e=B(v[a+1074444>>2],v[K>>2]);e=Yb((Ac(Ima(Hma(h,l,e,e>>31),mb,67108864,0),mb)|0)/2|0,1,127)}h=g^-1;g=1;f=(h&1)+f|0;t[f+(i+16|0)|0]=e;f=f+1|0;break a}l=m;e=a;n=0;h=b;k:{l:{if(h>>>0>=256){break l}if(w[l+31|0]==17){e=x[(e+B(h,896)|0)+1075792>>1];l=(e?e-1|0:h)&15;break k}if(!zi(l)){break l}n=w[l+31|0]-1&15}l=n}}e=(i+16|0)+f|0;m:{if(g&1){t[e|0]=l;break m}t[e|0]=w[e|0]<<4|l;f=f+1|0}g=(g^-1)&1}o=o+1|0;if((o|0)!=31){continue}}break}e=((g^-1)&1)+f|0;n:{if(!e){break n}l=0;g=0;while(1){q=(i+16|0)+g|0;d=t[q|0];o:{p:{q:{if((d|0)==-16){if(e-g>>>0>=4){o=4;if((w[(g+i|0)+17|0]&254)==240){break p}}o=g;r:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break r}if(w[(i+16|0)+o|0]!=247){continue}break}d=o-g|0;o=d+1|0;if(o>>>0>=d>>>0){break p}}t[(i+16|0)+e|0]=247;e=e+1|0;o=e-g|0;break q}if((d|0)>=0){if(l&255){g=g-1|0;t[g+(i+16|0)|0]=l;break o}g=g+1|0;l=0;break o}M=i,N=CO(d&255),v[M+8>>2]=N;v[i>>2]=e-g;o=v[Lb(i+8|0,i)>>2]}if(!o){break n}d=w[q|0];l=d>>>0<240?d:l}j=a;n=b;h=c;s=0;p=jb-32|0;jb=p;k=o;v[p+28>>2]=k;s:{if(!k){break s}d=w[q|0];f=d-250|0;if(!(f>>>0>5|!(1<<f&37))){if(x[j+480188>>1]){f=0;while(1){d=(j+B(f,896)|0)+1075841|0;t[d|0]=127;t[d+1|0]=0;f=f+1|0;if(f>>>0<x[j+480188>>1]){continue}break}}d=w[q|0]}t:{if((d&255)!=240){break t}y=w[q+1|0];if((y&254)!=240){break t}if(k>>>0<4){break s}A=(j+B(n,896)|0)+1074984|0;m=w[q+2|0];f=t[q+3|0];if(!(m|(y|0)==241|(f|0)<0)){m=j+B(n,896)|0;k=m+1075841|0;d=k;if(h){f=$L(Yo(j,C(w[k|0]),C((f&255)>>>0)))}t[d|0]=f;t[m+1075802|0]=0;s=4;d=m+1075072|0;k=fp(j,A,!(v[d>>2]&32768),256);if((k|0)<0|!(w[d+1|0]&2)){break s}d=j+1304392|0;if(!sd(d)){break s}lp(v[d>>2],n,k>>>2&255,1);break s}if(!((y|0)==241|(m|0)!=1|(f|0)<0)){k=j+B(n,896)|0;d=k+1075842|0;u:{if(!h){break u}r=Yo(j,C(w[d|0]),C((f&255)>>>0));if(r<C(4294967296)&r>=C(0)){f=~~r>>>0;break u}f=0}t[d|0]=f;t[k+1075801|0]=0;fp(j,A,!(v[k+1075072>>2]&32768),256);s=4;break s}if(!((y|0)==241|(m|0)!=2)){s=4;if((f&255)>>>0>31){break s}d=j+B(n,896)|0;t[d+1075849|0]=(f&240)>>>4;fp(j,A,!(v[d+1075072>>2]&32768),256);break s}if(!((y|0)==241|(m|0)!=3)){s=4;d=wl(j,n,3,0);if((f|0)<0|(d+5&255)>>>0<6){break s}d=(j+B(d,160)|0)+906284|0;r=C(C(((f^127)&255)>>>0)*C(.007874015718698502));if(!h){z[d>>2]=r;break s}M=d,O=Yo(j,z[d>>2],r),z[M>>2]=O;break s}if(!((y|0)!=241?m&128:1)){break s}s=4;d=wl(j,n,3,0);if((d+5&255)>>>0<6){break s}k=v[(j+B(d,160)|0)+906140>>2];if(!k|(f|0)<0){break s}d=(y|0)==241?m+128|0:m&127;r=C(C((f&255)>>>0)*C(.007874015718698502));if(!h){nb[v[v[k>>2]+44>>2]](k,d,r);break s}N=k,P=d,O=Yo(j,C(nb[v[v[k>>2]+48>>2]](k,d)),r),M=v[v[k>>2]+44>>2],nb[M](N|0,P|0,C(O));break s}v:{w:{if(n>>>0<x[j+480188>>1]){f=n+1|0;break w}f=x[(j+B(n,896)|0)+1075792>>1];if(!f){break v}}if(w[(j+B(n,896)|0)+1075075|0]&4|x[j+480188>>1]<(f&65535)>>>0){break v}d=wl(j,n,3,0);if(!d|d-251>>>0<5){break v}f=v[(j+B(d,160)|0)+906140>>2];if(!f){break v}d=w[q|0];if((d|0)==240){gc(p+16|0,Db(q),k);nb[v[v[f>>2]+72>>2]](f,p+16|0)|0;break v}M=p,P=CO(d),v[M+12>>2]=P;d=v[Lb(p+12|0,p+28|0)>>2];v[p+12>>2]=0;lc(p+12|0,q,d);nb[v[v[f>>2]+68>>2]](f,v[p+12>>2])|0}s=v[p+28>>2]}jb=p+32|0;g=(s?s:o)+g|0}if(e>>>0>g>>>0){continue}break}}jb=i+48|0}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=jb-1824|0;jb=d;Jc(b);i=jb-16|0;jb=i;h=d+1224|0;iQ(i+8|0,h);j=Hb(i+8|0);e=b;l=nc(e,ac(i,i+8|0));if((j|0)==(l|0)){$b(e,Hb(i+8|0))}jb=i+16|0;e=(j|0)==(l|0);if(!e){jQ(h)}a:{if(!e){break a}if(!sQ(d+1224|0)){break a}if(!nz(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;g=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=g;Hd(a,1);e=a+1074312|0;wg(e,83);Nb(e,84,1);Nb(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Qc(b,20);l=a+480188|0;g=1;i=1;while(1){h=B(g,104)+a|0;j=h+484380|0;e=((g<<5)+a|0)+946304|0;pz(b,d+16|0,j,e,1);n=v[j>>2];b:{if(!w[fc(e,0)|0]){break b}c:{if(pd(e,15730,3)){if(pd(e,15734,3)){break c}}if(w[fc(e,5)|0]==58){break b}}i=0}e=w[d+44|0]|w[d+45|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>=2){e=w[d+42|0]|w[d+43|0]<<8;v[h+484384>>2]=(e<<8|e>>>8)&65535;e=w[d+42|0]|w[d+43|0]<<8;k=(e<<8|e>>>8)&65535;e=w[d+44|0]|w[d+45|0]<<8;v[h+484388>>2]=k+(((e<<8|e>>>8)&65535)<<1);on(j)}e=w[d+38|0]|w[d+39|0]<<8;d:{if(((e<<8|e>>>8)&65535)>>>0<=4999){e=w[d+42|0]|w[d+43|0]<<8;if(((e<<8|e>>>8)&65535)>>>0<1e4){break d}}v[d+1064>>2]=5;y=d,z=v[zf(d+1196|0,d+1064|0)>>2],v[y+1196>>2]=z}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}oz(b,d+1064|0);o=a+484360|0;In(Vb(o),d+1064|2,128,65535,65535);g=0;n=xQ(b,Vb(o),w[d+1064|0],f,l,0,1);e=d+1064|1;if(!(n>>>0<2?w[e|0]|w[d+1064|0]:1)){break a}if(nf(b)+65536>>>0<(n<<10)+f>>>0){break a}if(!c){g=1;break a}if(!w[e|0]){t[e|0]=120}if(!pd(d+1200|0,15738,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;q=145364549.18032786/+(240-w[e|0]|0);f:{if(q<4294967296&q>=0){e=~~q>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=i&1?4:5;y=d,z=v[zf(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z;break e}v[d+16>>2]=i&1?1:2;y=d,z=v[zf(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;Hn(d+1048|0,3,d+1200|0);Ic(d+16|0,d+1048|0);Gb(a+1304400|0,d+16|0);yb(d+16|0);h=0;mj(a,0);r=v[b+8>>2];u[d+1046>>1]=0;g:{h:{if(!n){i=0;break h}s=i&1;i=0;while(1){y=d,z=lz(bc(Vb(o)),cc(Vb(o)),d+1046|0),v[y+16>>2]=z;y=d,z=cc(Vb(o)),v[y+1048>>2]=z;f=Jb(d+16|0,d+1048|0);rQ(b,d+16|0);if(f){h=kz(d+16|0,0)+h|0;if(h>>>0>512){break g}}j=0;f=0;l=0;while(1){g=0;while(1){e=f;m=Ve(qQ(d+16|0,j),g);p=w[fc(m,2)|0]&15;k=w[fc(m,3)|0];f=0;i:{if(!(e&255)|(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){break i}f=e+1|0;if((f&255)>>>0<33){break i}v[d+1196>>2]=6}j:{k:{l:{switch(p-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1?k>>>0>=32:0){break k}m=(p|0)!=1;if(!(m|!k|k>>>0>2)){v[d+1048>>2]=2;y=d,z=v[zf(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break j}if(m){break j}if((k|0)!=55){if((k|0)!=71){break j}if((e|0)<3){break k}break j}if((e|0)<=2){break k}break j;case 10:v[d+1196>>2]=6;break j;case 11:case 12:case 13:v[d+1048>>2]=2;y=d,z=v[zf(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;if((p|0)!=13){break j}l=((j|k)!=0)+l|0;f=1;break j;case 14:break l;default:break j}}v[d+1048>>2]=3;y=d,z=v[zf(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break j}v[d+1196>>2]=s}g=g+1|0;if((g|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}if((l-1&255)>>>0<2){v[d+1196>>2]=6}i=(l&255)+i|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(n>>>0>(f&65535)>>>0){continue}break}}if(!(v[d+1196>>2]!=6|n+32>>>0>=i>>>0)){v[d+1196>>2]=5}Qc(b,r);o=c&1;if(o){$f(a+484344|0,n)}if(n){m=a+484344|0;i=0;while(1){rQ(b,d+16|0);m:{if(!o){break m}if(!rg(m,i&65535,64)){break m}v[d+1048>>2]=0;l=0;while(1){p=Xe(_b(m,i),l,0);h=0;while(1){f=Ve(qQ(d+16|0,l),h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=p+B(h,6)|0;kt(d+8|0,e);n:{o:{p:{q:{f=w[e+5|0];if(f){j=e+3|0;k=(d+1048|0)+h|0;g=w[e+3|0];if((g|0)!=14){break q}t[k|0]=0;g=14;break p}j=(d+1048|0)+h|0;t[j|0]=0;g=w[e+3|0];if(!g){break o}j=e+3|0;break p}k=w[k|0];if(!k){break p}if(k>>>0>=16){t[e+2|0]=3;t[e+4|0]=k>>>4;break p}t[e+2|0]=4;t[e+4|0]=k}r:{s:{t:{u:{v:{switch(g-12|0){case 1:k=v[d+1196>>2];if((k|0)==6){break s}g=10;t[j|0]=10;break t;case 0:f=f&127;t[e+5|0]=f;g=12;break u;case 2:if(v[d+1196>>2]>3?f>>>0<=1:0){break r}g=10;t[j|0]=10;t[(d+1048|0)+h|0]=f;break u;case 3:break v;default:break u}}g=15;f=f&15;t[e+5|0]=f}k=v[d+1196>>2]}if((k|0)>1){break r}w:{x:{y:{switch(g|0){case 0:if(f>>>0>2){break x}break;case 2:break w;case 1:break x;default:break y}}t[j|0]=0;break n}t[j|0]=1;break n}g=f&15;if(g){t[j|0]=2;t[e+5|0]=g;break n}if(!(f&240)){break n}t[j|0]=3;t[e+5|0]=f>>>4;break n}t[e+5|0]=0}wj(e);break n}t[j|0]=0}h=h+1|0;if((h|0)!=4){continue}break}l=l+1|0;if((l|0)!=64){continue}break}}i=i+1|0;if((n|0)!=(i|0)){continue}break}}f=v[d+1196>>2];if(f>>>0>=7){f=15744}else{f=v[(f<<2)+77304>>2]}e=Ub(d+16|0,16009);Gb(a+1304436|0,e);yb(e);e=Ub(d+16|0,16022);Gb(a+1304448|0,e);yb(e);Mc(a+1304460|0,f);v[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=B(h,104)+a|0;f=c+484384|0;$b(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;ad(d+16|0,8,1,1,0);tg(d+16|0,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}jb=d+1824|0;return g|0}function Dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-224|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{if(!It(b,d+208|0)){break f}if(!pQ(d+208|0)){break f}h=Xh(d+192|0);i=fd(d+176|0);Rb(d+112|0,0,64);v[114578]=0;e=Q(890,b|0,d+104|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}g:{if(!e){break g}e=d+104|4;g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);g=(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))-4|0;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);t[e|0]=g;t[e+1|0]=g>>>8;t[e+2|0]=g>>>16;t[e+3|0]=g>>>24;g=0;h:{i:{j:{while(1){f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=(f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))-8|0;f=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;k:{if(c){break k}f=d+104|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=1413764176){break k}g=1;break g}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;U(343,d+24|0,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24));f=v[114578];v[114578]=0;l:{m:{n:{o:{p:{if((f|0)!=1){v[114578]=0;f=T(339,d+24|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}if(f){break p}Bb(d+24|0);break l}a=P()|0;O()|0;break a}f=d+104|0;f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);f=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);if((f|0)<=1347699795){if((f|0)==1129139796){break n}if((f|0)!=1229866575){break m}v[114578]=0;k=Q(891,d+24|0,d+112|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}break m}if((f|0)!=1347699796){if((f|0)!=1447383635){break m}v[114578]=0;Q(340,d+24|0,4)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}v[114578]=0;f=Q(892,d+24|0,16119)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}if(!f){break m}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if((f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))>>>0<7){break m}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;aa(893,d+24|0,i|0,2,(f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))-6|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}break m}v[114578]=0;g=W(894,a|0,d+24|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break m}}a=P()|0;O()|0;Bb(d+24|0);break a}oQ(h,d+24|0)}Bb(d+24|0);v[114578]=0;f=Q(890,b|0,d+104|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break j}if(f){continue}}break}if(Wc(i)){v[114578]=0;b=Q(2,d+24|0,16122)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}Gb(i,b);yb(b)}c=g&1;if(!c|(k^1)&1){break h}b=d+154|0;b=w[b|0]|w[b+1|0]<<8;v[114578]=0;e=b&1;W(479,a+1074312|0,5,!e|0)|0;b=v[114578];v[114578]=0;q:{r:{s:{if((b|0)!=1){b=d+150|0;if(w[b|0]|w[b+1|0]<<8){u[d+24>>1]=64;b=w[b|0]|w[b+1|0]<<8;v[114578]=0;u[d+88>>1]=b<<8|b>>>8;b=Q(478,d+24|0,d+88|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}v[a+480228>>2]=x[b>>1]}b=d+152|0;if(!(!(w[b|0]|w[b+1|0]<<8)|!e)){b=w[b|0]|w[b+1|0]<<8;v[a+480204>>2]=B((b<<8|b>>>8)&65535,1e4)}if(w[d+112|0]){v[114578]=0;U(746,d+88|0,2,d+112|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(417,d+24|0,d+88|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}Gb(a+1304400|0,d+24|0);yb(d+24|0)}b=x[d+158>>1];u[d+86>>1]=b;u[d+22>>1]=b;if(!wp(d+22|0,1,12)){break h}b=x[d+156>>1];u[d+84>>1]=b;u[d+20>>1]=b;if(!wp(d+20|0,1,31)){break h}b=x[d+162>>1];u[d+82>>1]=b;u[d+18>>1]=b;if(!wp(d+18|0,0,23)){break h}b=x[d+164>>1];u[d+80>>1]=b;u[d+16>>1]=b;if(!wp(d+16|0,0,59)){break h}b=x[d+166>>1];u[d+78>>1]=b;u[d+14>>1]=b;if(wp(d+14|0,0,59)){break q}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}b=Sp(d+24|0);e=d+160|0;e=w[e|0]|w[e+1|0]<<8;v[b+20>>2]=(e<<8|e>>>8)&65535;e=d+158|0;e=w[e|0]|w[e+1|0]<<8;v[b+16>>2]=((e<<8|e>>>8)&65535)-1;e=d+156|0;e=w[e|0]|w[e+1|0]<<8;v[b+12>>2]=(e<<8|e>>>8)&65535;e=d+162|0;e=w[e|0]|w[e+1|0]<<8;v[b+8>>2]=(e<<8|e>>>8)&65535;e=d+164|0;e=w[e|0]|w[e+1|0]<<8;v[b+4>>2]=(e<<8|e>>>8)&65535;e=d+166|0;e=w[e|0]|w[e+1|0]<<8;v[b>>2]=(e<<8|e>>>8)&65535;v[114578]=0;R(662,a+1304500|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(c){v[114578]=0;b=T(339,h|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}if(b){b=Wb(d+24|0);v[114578]=0;W(482,h|0,b|0,32)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}if(Et(b,16126)){v[114578]=0;U(13,d+88|0,2,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}Gb(a+1304412|0,d+88|0);yb(d+88|0)}v[114578]=0;c=T(895,h|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}if(!c){v[114578]=0;c=T(332,h|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;ea(547,a+1304424|0,h|0,c|0,40,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}}yb(b)}v[114578]=0;b=Q(2,d+88|0,16141)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}v[114578]=0;U(721,d+24|0,b|0,i|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}Gb(a+1304460|0,d+24|0);yb(d+24|0);yb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[114578]=0;a=a+1074312|0;W(479,a|0,84,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;W(479,a|0,83,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(480,a|0,85)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}}yb(i);Bb(h)}jb=d+224|0;return g&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b)}yb(i);Bb(h);S(a|0);L()}function _H(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-448|0;jb=e;a:{if(nj(b)){break a}f=w[fk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}Cd(e+184|0);f=v[e+184>>2];Cd(e+416|0);h=ek(f,v[e+420>>2],b);Cd(e+184|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=qc(e+432|0,38235);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Hc(e+16|0,e+8|0)){a=ba(8)|0;v[114578]=0;d=Q(2143,e+416|0,c|0)|0;b=v[114578];v[114578]=0;f:{g:{h:{if((b|0)!=1){v[114578]=0;U(2120,e+184|0,39300,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}mc(a,e+184|0);c=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}yb(d);if(!c){break c}}ca(a|0);break c}if(!d){break e}d=ba(8)|0;v[114578]=0;f=Q(2143,e+384|0,b|0)|0;b=v[114578];v[114578]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[114578]=0;U(2120,e+400|0,39179,f|0);a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;U(2138,e+416|0,e+400|0,39315);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break p}v[114578]=0;c=Q(2143,e+368|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break o}v[114578]=0;U(138,e+184|0,e+416|0,c|0);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break n}mc(d,e+184|0);v[114578]=0;U(2010,d|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}yb(c)}yb(e+416|0)}yb(e+400|0)}yb(f)}if(!a){break c}ca(d|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=qc(e+352|0,38235);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Hc(e+176|0,e+168|0)){a=ba(8)|0;v[114578]=0;d=Q(2143,e+416|0,c|0)|0;b=v[114578];v[114578]=0;r:{s:{t:{if((b|0)!=1){v[114578]=0;U(2120,e+184|0,39300,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break t}mc(a,e+184|0);c=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);break s}b=P()|0;O()|0;break r}b=P()|0;c=1;O()|0}yb(d);if(!c){break c}}ca(a|0);break c}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=qc(e+336|0,39058);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Hc(e+160|0,e+152|0)){b=v[c+4>>2];v[e+328>>2]=v[c>>2];v[e+332>>2]=b;b=qc(e+320|0,39251);d=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=d;d=v[b+4>>2];v[e+56>>2]=v[b>>2];v[e+60>>2]=d;if(Hc(e- -64|0,e+56|0)){v[a+52>>2]=0;break e}b=v[c+4>>2];v[e+312>>2]=v[c>>2];v[e+316>>2]=b;b=qc(e+304|0,39259);d=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=d;d=v[b+4>>2];v[e+40>>2]=v[b>>2];v[e+44>>2]=d;if(Hc(e+48|0,e+40|0)){v[a+52>>2]=1;break e}b=v[c+4>>2];v[e+296>>2]=v[c>>2];v[e+300>>2]=b;b=qc(e+288|0,39268);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Hc(e+32|0,e+24|0)){v[a+52>>2]=2;break e}a=ba(8)|0;v[114578]=0;d=Q(2143,e+416|0,c|0)|0;b=v[114578];v[114578]=0;u:{v:{w:{if((b|0)!=1){v[114578]=0;U(2120,e+184|0,39362,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break w}mc(a,e+184|0);c=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);break v}b=P()|0;O()|0;break u}b=P()|0;c=1;O()|0}yb(d);if(!c){break c}}ca(a|0);break c}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=qc(e+272|0,39101);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Hc(e+144|0,e+136|0)){break e}b=v[c+4>>2];v[e+264>>2]=v[c>>2];v[e+268>>2]=b;b=qc(e+256|0,39273);d=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=d;d=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=d;b=0;x:{if(Hc(e+128|0,e+120|0)){break x}b=v[c+4>>2];v[e+248>>2]=v[c>>2];v[e+252>>2]=b;b=qc(e+240|0,39278);d=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=d;d=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=d;b=1;if(Hc(e+112|0,e+104|0)){break x}b=v[c+4>>2];v[e+232>>2]=v[c>>2];v[e+236>>2]=b;b=qc(e+224|0,39284);d=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=d;d=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=d;b=2;if(Hc(e+96|0,e+88|0)){break x}b=v[c+4>>2];v[e+216>>2]=v[c>>2];v[e+220>>2]=b;b=qc(e+208|0,39295);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Hc(e+80|0,e+72|0)){break x}a=ba(8)|0;v[114578]=0;c=Q(85,e+184|0,39387)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break e}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=HH(v[a+56>>2]),v[i+204>>2]=j;if(!Uw(e+184|0,v[b>>2]+24648|0)){break e}Kx(v[b>>2],e+184|0)}jb=e+448|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function ow(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0;h=jb-80|0;jb=h;v[h+76>>2]=b;z=h+55|0;s=h+56|0;b=0;a:while(1){b:{if((q|0)<0){break b}if((2147483647-q|0)<(b|0)){v[114552]=61;q=-1;break b}q=b+q|0}c:{d:{e:{f:{g:{h:{i:{m=h;j:{k:{l:{n=v[h+76>>2];b=n;i=w[b|0];if(i){while(1){m:{i=i&255;n:{if(!i){i=b;break n}if((i|0)!=37){break m}i=b;while(1){if(w[b+1|0]!=37){break n}j=b+2|0;v[h+76>>2]=j;i=i+1|0;k=w[b+2|0];b=j;if((k|0)==37){continue}break}}b=i-n|0;if(a){Qe(a,n,b)}if(b){continue a}j=!bh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(j|w[b+2|0]!=36){break l}r=t[b+1|0]-48|0;y=1;b=b+3|0;break k}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}o=q;if(a){break d}if(!y){break j}b=1;while(1){a=v[(b<<2)+e>>2];if(a){pG((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break d}break}o=1;if(b>>>0>=10){break d}while(1){if(v[(b<<2)+e>>2]){break e}b=b+1|0;if((b|0)!=10){continue}break}break d}r=-1;b=b+1|0}v[m+76>>2]=b;m=0;k=t[b|0];i=k-32|0;o:{if(i>>>0>31){break o}i=1<<i;if(!(i&75913)){break o}while(1){p:{j=b+1|0;v[h+76>>2]=j;k=t[b+1|0];b=k-32|0;if(b>>>0>=32){break p}b=1<<b;if(!(b&75913)){break p}i=b|i;b=j;continue}break}b=j;m=i}q:{if((k|0)==42){j=h;r:{s:{if(!bh(t[b+1|0])){break s}b=v[h+76>>2];if(w[b+2|0]!=36){break s}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;p=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break r}if(y){break e}y=0;p=0;if(a){b=v[c>>2];v[c>>2]=b+4;p=v[b>>2]}b=v[h+76>>2]+1|0}v[j+76>>2]=b;if((p|0)>-1){break q}p=0-p|0;m=m|8192;break q}p=oG(h+76|0);if((p|0)<0){break e}b=v[h+76>>2]}l=-1;t:{if(w[b|0]!=46){break t}if(w[b+1|0]==42){u:{if(!bh(t[b+2|0])){break u}b=v[h+76>>2];if(w[b+3|0]!=36){break u}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;l=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break t}if(y){break e}if(a){b=v[c>>2];v[c>>2]=b+4;l=v[b>>2]}else{l=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break t}v[h+76>>2]=b+1;l=oG(h+76|0);b=v[h+76>>2]}i=0;while(1){x=i;o=-1;if(t[b|0]-65>>>0>57){break d}k=b+1|0;v[h+76>>2]=k;i=t[b|0];b=k;i=w[(i+B(x,58)|0)+55103|0];if(i-1>>>0<8){continue}break}if((i|0)==19){break h}if(!i){break d}if((r|0)>=0){v[(r<<2)+e>>2]=i;b=(r<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break g}if(a){break i}}o=0;break d}pG(h- -64|0,i,c,g);k=v[h+76>>2];break f}if((r|0)>-1){break d}}b=0;if(!a){continue}}j=m&-65537;i=m&8192?j:m;o=0;r=55136;m=s;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{b=t[k-1|0];b=x?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break v;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break c;case 9:case 13:case 14:case 15:break w;case 27:break B;case 12:case 17:break E;case 23:break F;case 0:case 32:break G;case 24:break H;case 22:break I;case 29:break J;default:break K}}L:{switch(b-65|0){case 1:case 3:break c;case 0:case 4:case 5:case 6:break w;case 2:break z;default:break L}}if((b|0)==83){break A}break c}k=v[h+64>>2];j=v[h+68>>2];r=55136;break D}b=0;M:{switch(x&255){case 0:v[v[h+64>>2]>>2]=q;continue;case 1:v[v[h+64>>2]>>2]=q;continue;case 2:i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue;case 3:u[v[h+64>>2]>>1]=q;continue;case 4:t[v[h+64>>2]]=q;continue;case 6:v[v[h+64>>2]>>2]=q;continue;case 7:break M;default:continue}}i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue}l=l>>>0>8?l:8;i=i|8;b=120}n=s;C=b&32;x=v[h+68>>2];j=x;k=v[h+64>>2];if(j|k){while(1){n=n-1|0;t[n|0]=C|w[(k&15)+55632|0];x=j;j=j>>>4|0;k=(x&15)<<28|k>>>4;if(k|j){continue}break}}if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break C}r=(b>>>4|0)+55136|0;o=2;break C}b=s;n=v[h+68>>2];j=n;k=v[h+64>>2];if(j|k){while(1){b=b-1|0;t[b|0]=k&7|48;n=j;j=j>>>3|0;k=(n&7)<<29|k>>>3;if(k|j){continue}break}}n=b;if(!(i&8)){break C}b=s-n|0;l=(b|0)<(l|0)?l:b+1|0;break C}b=v[h+68>>2];j=b;k=v[h+64>>2];if((b|0)<-1?1:(b|0)<=-1){j=0-(j+((k|0)!=0)|0)|0;k=0-k|0;v[h+64>>2]=k;v[h+68>>2]=j;o=1;r=55136;break D}if(i&2048){o=1;r=55137;break D}o=i&1;r=o?55138:55136}n=Hm(k,j,s)}i=(l|0)>-1?i&-65537:i;b=v[h+68>>2];j=b;k=v[h+64>>2];if(!((k|0)!=0|(b|0)!=0|l)){l=0;n=s;break c}b=!(j|k)+(s-n|0)|0;l=(b|0)<(l|0)?l:b;break c}b=v[h+64>>2];n=b?b:55146;b=Ar(n,0,l);m=b?b:l+n|0;i=j;l=b?b-n|0:l;break c}m=v[h+64>>2];if(l){break y}b=0;Jf(a,32,p,0,i);break x}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];v[h+64>>2]=h+8;l=-1;m=h+8|0}b=0;N:{while(1){j=v[m>>2];if(!j){break N}j=sG(h+4|0,j);n=(j|0)<0;if(!(n|j>>>0>l-b>>>0)){m=m+4|0;b=b+j|0;if(l>>>0>b>>>0){continue}break N}break}o=-1;if(n){break d}}Jf(a,32,p,b,i);if(!b){b=0;break x}m=0;k=v[h+64>>2];while(1){j=v[k>>2];if(!j){break x}j=sG(h+4|0,j);m=j+m|0;if((m|0)>(b|0)){break x}Qe(a,h+4|0,j);k=k+4|0;if(b>>>0>m>>>0){continue}break}}Jf(a,32,p,b,i^8192);b=(b|0)<(p|0)?p:b;continue}b=nb[f|0](a,A[h+64>>3],p,l,i,b)|0;continue}t[h+55|0]=v[h+64>>2];l=1;n=z;i=j;break c}o=-1}jb=h+80|0;return o}m=m-n|0;k=(l|0)<(m|0)?m:l;j=k+o|0;b=(j|0)>(p|0)?j:p;Jf(a,32,b,j,i);Qe(a,r,o);Jf(a,48,b,j,i^65536);Jf(a,48,k,m,0);Qe(a,n,m);Jf(a,32,b,j,i^8192);continue}}function SG(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=C(0),A=0,D=0,E=C(0),F=C(0),G=C(0),H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0,R=0;if((d|0)>=1){while(1){x=B(v,2304)+b|0;l=0;s=jb-128|0;q=c;if((q|0)>=1){while(1){n=x+(l<<2)|0;j=s;o=0;while(1){i=z[B(31-o|0,72)+n>>2];w=B(o,72)+n|0;h=z[w>>2];m=C(i+h);k=z[w+1152>>2];y=z[B(15-o|0,72)+n>>2];E=C(k+y);z[j>>2]=m+E;w=B(o,12)+49040|0;i=C(z[w+4>>2]*C(h-i));h=C(z[w>>2]*C(y-k));z[j+64>>2]=i+h;k=z[w+8>>2];z[j+32>>2]=k*C(m-E);z[j+96>>2]=C(i-h)*k;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=1;j=s;while(1){m=z[j+28>>2];k=z[j>>2];i=C(m+k);y=z[j+16>>2];E=z[j+12>>2];h=C(y+E);F=C(i+h);G=z[j+24>>2];J=z[j+4>>2];K=C(G+J);L=z[j+20>>2];M=z[j+8>>2];N=C(L+M);O=C(K+N);z[j>>2]=F+O;z[j+16>>2]=C(F-O)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(K-N))*C(.7071067690849304));z[j+24>>2]=C(i-h)*C(1.3065630197525024);z[j+8>>2]=C(h+i)*C(.5411961078643799);h=C(J-G);F=C(M-L);G=C(C(h+F)*C(.7071067690849304));i=C(k-m);m=C(G+i);h=C(i+h);k=C(C(C(E-y)+F)+C(h*C(-.1989123672246933)));h=C(C(k*C(.3826834261417389))+h);z[j+28>>2]=C(m-h)*C(2.562915563583374);z[j+4>>2]=C(h+m)*C(.509795606136322);h=C(k+C(h*C(-.1989123672246933)));i=C(i-G);z[j+20>>2]=C(h+i)*C(.8999761939048767);z[j+12>>2]=C(i-h)*C(.601344883441925);if((o|0)!=4){j=j+32|0;o=o+1|0;continue}break}o=0;i=z[s+32>>2];h=z[s+96>>2];k=z[s+64>>2];while(1){j=n;z[j>>2]=z[s+(o<<2)>>2];o=o+1|0;n=s+(o<<2)|0;m=z[n+96>>2];y=C(m+h);z[j+72>>2]=y+k;h=z[n+32>>2];z[j+144>>2]=h+i;k=z[n- -64>>2];z[j+216>>2]=y+k;n=j+288|0;i=h;h=m;if((o|0)!=7){continue}break}z[j+288>>2]=z[s+28>>2];i=z[s+124>>2];z[j+360>>2]=i+z[s+92>>2];h=z[s+60>>2];z[j+504>>2]=i;z[j+432>>2]=h;l=l+1|0;if((q|0)!=(l|0)){continue}break}}v=v+1|0;if((v|0)!=(d|0)){continue}break}}I=lc(f,a,3840);if((c|0)>=1){P=d<<5;v=0;while(1){n=jb-32|0;jb=n;o=(v<<8)+I|0;w=(v<<2)+b|0;z[o+4080>>2]=z[w+1152>>2];j=d;f=j-1|0;x=w+B(f,2304)|0;z[o+4084>>2]=z[x+1152>>2];z[o+4088>>2]=z[w>>2];z[o+4092>>2]=z[x>>2];z[o+4336>>2]=z[w+1156>>2];z[o+4340>>2]=z[x+1156>>2];z[o+4344>>2]=z[w+4>>2];z[o+4348>>2]=z[x+4>>2];A=(B(v,P)<<1)+e|0;D=A+(f<<1)|0;Dr(D,j,o+244|0);f=j<<6;Dr(f+D|0,j,o+500|0);Dr(A,j,o+240|0);Dr(f+A|0,j,o+496|0);q=49136;H=o+3840|0;f=14;while(1){s=f;g=f<<4;l=g+H|0;p=B(31-f|0,72);m=z[p+w>>2];z[l>>2]=m;z[(g|4)+H>>2]=z[p+x>>2];p=p|4;z[(g|8)+H>>2]=z[p+w>>2];z[(g|12)+H>>2]=z[p+x>>2];p=B(f,72);r=p+76|0;z[l+256>>2]=z[r+w>>2];z[l+260>>2]=z[r+x>>2];p=p+72|0;z[l-248>>2]=z[p+w>>2];z[l-244>>2]=z[p+x>>2];i=z[q>>2];p=g+o|0;k=z[p>>2];h=z[q+4>>2];z[n+16>>2]=C(m*i)-C(k*h);z[n>>2]=C(k*i)+C(m*h);r=f<<2;f=1;while(1){g=f<<2;m=z[g+l>>2];k=z[g+p>>2];z[g+(n+16|0)>>2]=C(m*i)-C(k*h);z[g+n>>2]=C(k*i)+C(m*h);f=f+1|0;if((f|0)!=4){continue}break}l=(r<<2)+H|0;p=l-3584|0;r=l-256|0;i=z[q+12>>2];h=z[q+8>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(m*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-3328|0;r=l-512|0;i=z[q+20>>2];h=z[q+16>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(k*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-3072|0;r=l-768|0;i=z[q+28>>2];h=z[q+24>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(m*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-2816|0;r=l-1024|0;i=z[q+36>>2];h=z[q+32>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(k*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-2560|0;r=l-1280|0;i=z[q+44>>2];h=z[q+40>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(m*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-2304|0;r=l-1536|0;i=z[q+52>>2];h=z[q+48>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(k*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=l-2048|0;p=l-1792|0;i=z[q+60>>2];h=z[q+56>>2];f=0;while(1){l=f<<2;r=l+n|0;m=z[g+l>>2];k=z[l+p>>2];z[r>>2]=C(C(m*h)+C(k*i))+z[r>>2];l=l+(n+16|0)|0;z[l>>2]=C(C(m*i)-C(k*h))+z[l>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(j,15-s|0)<<1;Q=f+D|0,R=li(z[n+20>>2]),u[Q>>1]=R;l=B(j,s+17|0)<<1;Q=l+D|0,R=li(z[n+4>>2]),u[Q>>1]=R;Q=f+A|0,R=li(z[n+16>>2]),u[Q>>1]=R;Q=l+A|0,R=li(z[n>>2]),u[Q>>1]=R;f=B(j,47-s|0)<<1;Q=f+D|0,R=li(z[n+28>>2]),u[Q>>1]=R;l=B(j,s+49|0)<<1;Q=l+D|0,R=li(z[n+12>>2]),u[Q>>1]=R;Q=f+A|0,R=li(z[n+24>>2]),u[Q>>1]=R;Q=l+A|0,R=li(z[n+8>>2]),u[Q>>1]=R;f=s-1|0;q=q- -64|0;if(s){continue}break}jb=n+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+I>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}lc(a,(b<<2)+I|0,3840)}}function lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=jb-768|0;jb=d;Jc(b);f=jb-16|0;jb=f;g=d+160|0;hP(f+8|0,g);i=Hb(f+8|0);e=b;h=nc(e,ac(f,f+8|0));if((i|0)==(h|0)){$b(e,Hb(f+8|0))}jb=f+16|0;e=(h|0)==(i|0);if(!e){iP(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!kP(d+160|0)){break n}if(!Qb(b,hd(jP(d+160|0),mb))){break n}if(!c){o=1;break n}Hd(a,262144);Ht(d+104|0,2,d+160|0);Ic(d+24|0,d+104|0);Gb(a+1304400|0,d+24|0);yb(d+24|0);e=Ub(d+24|0,16992);Gb(a+1304436|0,e);yb(e);e=Ub(d+24|0,17004);Gb(a+1304448|0,e);yb(e);f=Ub(d+144|0,17008);v[114578]=0;R(219,d+104|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}t[d+8|0]=w[d+190|0];e=w[d+189|0];v[114578]=0;t[d+127|0]=e;R(994,d+128|0,d+127|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=0;v[114578]=0;X(453,d+24|0,d+104|0,d+8|0,d+128|0);g=v[114578];v[114578]=0;if((g|0)==1){break f}Gb(a+1304460|0,d+24|0);yb(d+24|0);yb(d+128|0);Ib(d+104|0);yb(f);v[a+480208>>2]=12;v[a+1304496>>2]=4;u[a+480188>>1]=w[d+198|0]|w[d+199|0]<<8;u[d+24>>1]=w[d+194|0]|w[d+195|0]<<8;u[d+104>>1]=3999;A=a,C=x[lf(d+24|0,d+104|0)>>1],u[A+480190>>1]=C;_z(Vb(a+484360|0),d+256|0,w[d+192|0]|w[d+193|0]<<8,255,254);if(x[a+480188>>1]){while(1){f=(e<<5)+a|0;zg(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}ud(d+104|0,b,B(w[d+194|0]|w[d+195|0]<<8,80));if(x[a+480190>>1]){g=c&2;i=d+72|0;e=0;while(1){v[114578]=0;Q(995,d+104|0,d+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}v[114578]=0;U(577,d+8|0,2,i|0);f=v[114578];v[114578]=0;o:{p:{q:{if((f|0)==1){break q}v[114578]=0;R(417,d+128|0,d+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break q}v[114578]=0;e=e+1|0;Q(371,((e<<5)+a|0)+946304|0,d+128|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}yb(d+128|0);v[114578]=0;f=(B(e,104)+a|0)+484380|0;U(996,d+128|0,d+24|0,f|0);h=v[114578];v[114578]=0;r:{if((h|0)==1){break r}if(!g|!v[f>>2]){break o}h=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[114578]=0;h=Q(256,b|0,h|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break r}if(!h){break o}v[114578]=0;W(402,d+128|0,f|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break o}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(d+128|0);break g}if(x[a+480190>>1]>e>>>0){continue}break}}o=1;s:{if(!(c&1)){break s}c=w[d+196|0]|w[d+197|0]<<8;i=0;v[114578]=0;k=a+484344|0;R(403,k|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break l}if(!(w[d+196|0]|w[d+197|0]<<8)){break s}p=d+24|4;q=d+24|2;r=d+24|5;s=d+24|3;y=d+24|1;while(1){v[114578]=0;c=W(404,k|0,i&65535,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(i<<1)+d|0;e=c+512|0;if(!(w[e|0]|w[e+1|0]<<8)){break t}c=w[c+512|0]|w[c+513|0]<<8;v[114578]=0;c=Q(256,b|0,c<<4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}if(!c){break t}l=0;c=_b(k,i);v[114578]=0;m=W(472,c|0,0,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}while(1){v[114578]=0;c=Q(258,b|0,1)|0;e=v[114578];v[114578]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}v[114578]=0;h=T(389,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break w}if(h){break v}l=l+1|0;m=B(x[a+480188>>1],6)+m|0;break u}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}u[d+28>>1]=0;v[d+24>>2]=0;c=h&31;f=B(c,6)+m|0;n=Qh(d+24|0);g=c>>>0<x[a+480188>>1];x:{y:{z:{A:{B:{C:{D:{if(!(h&32)){break D}v[114578]=0;R(473,d+128|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break C}e=cd(d+128|0);j=g?f:d+24|0;c=w[d+128|0];t[j|0]=c;t[(g?f+1|0:y)|0]=w[e|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}t[j|0]=c}if(!(h&64)){break x}v[114578]=0;R(473,d+128|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break j}z=cd(d+128|0);c=g?f+3|0:s;e=w[d+128|0];t[c|0]=e;j=g?f+5|0:r;t[j|0]=w[z|0];if(e>>>0>15){break B}v[114578]=0;Z(574,(g?f:n)|0);e=v[114578];v[114578]=0;if((e|0)!=1){break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}if(e>>>0>23){break y}n=c;c=w[e+17010|0];t[n|0]=c;break z}c=w[c|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}c=w[j|0];F:{G:{if(c>>>0>=136){e=c&127;break G}e=128;if(c>>>0<129){break F}}t[j|0]=e;c=e}t[j|0]=(B(c&127,255)>>>0)/127;break x}v[114578]=0;t[d+8|0]=64;c=Q(393,j|0,d+8|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[j|0]=w[c|0]<<1;break x}a=P()|0;O()|0;break g}t[c|0]=0}if(!(h&128)){break u}t[(g?f+2|0:q)|0]=1;v[114578]=0;c=T(389,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}t[(g?f+4|0:p)|0]=c}if(l>>>0<64){continue}break}}i=i+1|0;if(i>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Bb(d+104|0)}jb=d+768|0;return o|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}Bb(d+104|0);break a}a=P()|0;O()|0;yb(d+128|0);break d}a=P()|0;O()|0}Ib(d+104|0);break b}a=P()|0;O()|0}yb(f)}S(a|0);L()}function iU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-128|0;jb=e;Jc(b);a:{if(!SA(b,12168)){break a}if(!eu(b,e+112|0)){break a}if(!UA(e+112|0)){break a}if(!Qb(b,hd(TA(e+112|0),mb))){break a}if(!$b(b,w[e+121|0]|w[e+122|0]<<8)){break a}b:{if(!c){break b}Hd(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[e+112|2]&31)+1;f=e+112|3;u[a+480190>>1]=w[f|0];mj(a,1);d=Ub(e+56|0,12176);Gb(a+1304436|0,d);yb(d);d=Ub(e+56|0,12194);Gb(a+1304448|0,d);yb(d);d=Ub(e+80|0,12198);v[114578]=0;R(219,e+96|0,d|0);i=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((i|0)!=1){v[114578]=0;X(429,e+56|0,e+96|0,e+112|1,e+112|0);i=v[114578];v[114578]=0;if((i|0)==1){break o}Gb(a+1304460|0,e+56|0);yb(e+56|0);Ib(e+96|0);yb(d);v[a+1304496>>2]=4;f=w[f|0];d=jb-16|0;jb=d;i=e+96|0;v[i>>2]=0;v[i+4>>2]=0;v[d+12>>2]=0;Zc(i+8|0,d+12|0,d+8|0);if(f){lq(i,f);YB(i,f,0)}jb=d+16|0;if(x[a+480190>>1]){f=1;d=1;while(1){v[114578]=0;Q(430,b|0,e+56|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break k}v[114578]=0;R(431,e+56|0,(B(f,104)+a|0)+484380|0);h=v[114578];v[114578]=0;if((h|0)==1){break k}h=w[e+72|0];ee(e+40|0,i,f-1|0);ge(e+40|0,(h&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}v[114578]=0;W(432,b|0,a+1304400|0,-1)|0;f=v[114578];v[114578]=0;d=1;if((f|0)!=1){if(x[a+480190>>1]){while(1){v[114578]=0;W(433,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[114578]=0;f=(d<<5)+a|0;Z(434,f+480280|0);h=v[114578];v[114578]=0;if((h|0)==1){break e}v[114578]=0;W(435,b|0,f+480289|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+112|4;h=w[f|0]|w[f+1|0]<<8;d=0;v[114578]=0;k=a+484344|0;R(403,k|0,h|0);h=v[114578];v[114578]=0;if((h|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break n}b=P()|0;O()|0;Ib(e+96|0)}yb(d);break c}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){while(1){v[114578]=0;W(436,b|0,e+56|0,-1)|0;h=v[114578];v[114578]=0;p:{q:{if((h|0)==1){break q}v[114578]=0;h=W(404,k|0,d&65535,64)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}if(!h){break p}h=_b(k,d);v[114578]=0;Q(437,h|0,e+56|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break p}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[114578]=0;g=T(359,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}r:{if(!g){break r}v[114578]=0;d=Q(258,b|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break f}if(!d){break r}h=rq(e+56|0);v[114578]=0;W(438,b|0,h|0,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}d=Wb(e+40|0);v[114578]=0;R(111,d|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}l=e,m=bc(h),v[l>>2]=m;l=e,m=cc(h),v[l+32>>2]=m;if(Jb(e,e+32|0)){while(1){s:{g=w[v[e>>2]];if(g&128){l=e,m=sf(d),v[l+16>>2]=m;Md(e+24|0,e+16|0);v[114578]=0;aa(439,d|0,v[e+24>>2],g&127,32)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break s}break i}v[114578]=0;R(110,d|0,g<<24>>24);g=v[114578];v[114578]=0;if((g|0)!=1){break s}break i}qg(e);if(Jb(e,e+32|0)){continue}break}}v[114578]=0;X(440,e|0,4,5,d|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}Gb(d,e);yb(e);g=Tb(d);v[114578]=0;g=T(441,g|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break i}j=Fb(d);v[114578]=0;ea(442,a+1304424|0,g|0,j|0,76,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}yb(d);fe(h)}h=Vb(a+484360|0);d=e+112|6;g=w[d|0]|w[d+1|0]<<8;d=0;v[114578]=0;ea(443,h|0,b|0,g|0,65535,65535)|0;h=v[114578];v[114578]=0;if((h|0)==1){break f}t:{u:{v:{w:{if(!(w[f|0]|w[f+1|0]<<8)){break w}h=c&1;while(1){v[114578]=0;g=Q(258,b|0,4)|0;j=v[114578];v[114578]=0;x:{if((j|0)!=1){if(g){break x}break w}b=P()|0;O()|0;break d}v[114578]=0;g=T(392,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break u}v[114578]=0;U(343,e+56|0,b|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break t}y:{if(!h){break y}v[114578]=0;g=Q(444,k|0,d&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break v}if(!g){break y}g=_b(k,d);v[114578]=0;U(445,g|0,0,e+56|0);g=v[114578];v[114578]=0;if((g|0)==1){break v}}Bb(e+56|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){f=1;d=1;while(1){c=B(f,104)+a|0;h=x[c+484414>>1];ee(e+56|0,i,f-1|0);f=ad(e+40|0,h&1?16:8,1,0,Cb(e+56|0)?6:0);v[114578]=0;W(402,f|0,c+484380|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}ke(i);break b}b=P()|0;O()|0;Bb(e+56|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d);break g}b=P()|0;O()|0}fe(h);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}ke(i)}S(b|0);L()}f=1}jb=e+128|0;return f|0}function rd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=jb-96|0;jb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;qf(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;qf(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=Hma(d,0,b,s);b=mb;G=b;e=f;A=e<<15&-32768;k=p;g=Hma(A,0,k,0);f=g+q|0;e=mb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=Hma(c,s,A,B);f=i+g|0;b=j;j=j+mb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=Hma(d,r,k,H);K=mb;p=m;f=Hma(A,B,m,0);b=f+N|0;j=mb+K|0;O=b;m=Hma(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+mb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=Hma(d,r,p,P);G=mb;f=A;I=y|65536;A=o;i=Hma(f,B,I,o);f=i+Q|0;j=mb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=Hma(C,S,k,H);i=f+B|0;o=j;f=j+mb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=Hma(c,s,D,0);c=L+i|0;s=f;j=f+mb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=Hma(p,P,C,S);e=mb;r=Hma(d,r,I,A);d=r+f|0;j=mb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=Hma(D,T,k,H);d=f+d|0;j=mb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=Hma(D,T,I,A);b=e+b|0;j=mb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=Hma(D,T,p,P);f=mb;p=Hma(C,S,I,A);b=p+k|0;j=mb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;qf(l+48|0,u,g,h,i,j);qf(l+32|0,d,e,b,c,j);Gm(l+16|0,u,g,h,i,f);Gm(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;jb=l+96|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=jb-208|0;jb=g;Jc(b);a:{b:{c:{d:{e:{if(!Zz(b,g+160|0)){break e}if(!QO(g+160|0)){break e}if(!c){h=1;break e}if(!Qb(b,hd(PO(g+160|0),mb))){break e}Hd(a,128);yg(g+144|0,2,g+175|0);Ic(g+72|0,g+144|0);Gb(a+1304400|0,g+72|0);yb(g+72|0);d=Ub(g+72|0,17473);Gb(a+1304436|0,d);yb(d);d=Ub(g+72|0,17486);Gb(a+1304448|0,d);yb(d);d=Ub(g+144|0,17490);v[114578]=0;U(1028,g+72|0,d|0,v[(w[g+174|0]<<2)+77148>>2]);e=v[114578];v[114578]=0;h=1;if((e|0)==1){break b}Gb(a+1304460|0,g+72|0);yb(g+72|0);yb(d);v[a+480208>>2]=12;v[a+1304496>>2]=4;My(a+1304424|0,b,w[g+207|0]<<5,32,0);y=a,z=Gd(b),u[y+480190>>1]=z;if(x[a+480190>>1]){j=1;while(1){f:{if(w[g+174|0]>=52){lA(b,g+72|0);break f}e=jb-16|0;jb=e;v[e+12>>2]=64;v[e>>2]=66;d=b;i=v[Lb(e+12|0,e)>>2];if(!Qb(d,i)){i=nf(d)}f=g+72|0;Lt(e,f);xg(d,v[e>>2],i);Lt(e,f);Rb(v[e>>2]+i|0,0,66-i|0);$b(d,v[e+12>>2]);jb=e+16|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=jb-32|0;jb=i;e=(B(h,104)+a|0)+484380|0;Ed(e,0);d=g+72|0;Fk(i,2,d+32|0);Ic(i+16|0,i);v[114578]=0;Q(372,e+43|0,i+16|0)|0;f=v[114578];v[114578]=0;g:{if((f|0)!=1){yb(i+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=e,z=v[Lb(i+16|0,e)>>2],v[y+16>>2]=z;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Vs(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}jb=i+32|0;break g}a=P()|0;O()|0;yb(i+16|0);S(a|0);L()}yg(g+56|0,2,g+72|0);Ic(g+144|0,g+56|0);v[114578]=0;Q(371,((h<<5)+a|0)+946304|0,g+144|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}yb(g+144|0);j=j+1|0;h=j&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}Np(Vb(a+484360|0),b,256,255,254);h=0;d=Gd(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Gd(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(h<<5)+a|0;zg(e+480280|0);i=e+480284|0;i:{if(w[g+174|0]>=51){e=(Gd(b)<<4|8)&248;break i}e=h&1?192:64}u[i>>1]=e;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}m=a+484344|0;$f(m,r);h=0;j=0;while(1){e=j&65535;if(!rg(m,e,64)){break e}j=j+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=Qh(g+72|0);n=0;while(1){if(Qb(b,5)){j=0;h=Xe(_b(m,n),0,o&65535);while(1){s=64-j|0;l=w[g+174|0];f=jb-16|0;jb=f;p=1;d=i;q=d;e=b;k=Gd(e);if((k|0)==252){p=Gd(e);k=Gd(e)}t[q|0]=(k-1&255)>>>0<60?k+36|0:0;Sl(f+8|0,e);e=cd(f+8|0);k=Bf(f+8|0);q=Rh(f+8|0);t[d+1|0]=w[f+8|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[k|0];t[f+4|0]=w[q|0];OO(f+7|0,f+5|0,l);OO(f+6|0,f+4|0,l);j:{k:{l:{m:{k=w[f+7|0];l=(k|0)!=10;e=w[f+6|0];if(!(l|(e|0)!=10)){t[f+7|0]=0;y=f,z=Nk((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[y+5|0]=z;break m}if(!l){y=f,z=Nk(w[f+5|0]<<2),t[y+5|0]=z;break m}if((e|0)==10){y=f,z=Nk(w[f+4|0]<<2),t[y+4|0]=z;break m}if((e|0)!=(k|0)){break m}t[f+6|0]=0;break l}e=w[f+6|0];if((e|0)==13){break k}if(e){break j}k=w[f+7|0]}if((k&255)==13){break j}}lh(f+7|0,f+6|0);lh(f+5|0,f+4|0)}tx(f+6|0,f+4|0,f+7|0,f+5|0);sx(f,f+7|0,f+5|0,f+6|0,f+4|0);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];jb=f+16|0;e=j+p|0;j=e>>>0>64?s:p;if(j){while(1){d=v[g+72>>2];t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=x[g+76>>1];t[h+4|0]=d;t[h+5|0]=d>>>8;h=B(x[a+480188>>1],6)+h|0;j=j-1|0;if(j){continue}break}d=e>>>0<64;j=d?e:64;if(d){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;i=ht(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[114578]=0;U(1030,i|0,e|0,0);e=v[114578];v[114578]=0;if((e|0)==1){a=P()|0;O()|0;ke(i);S(a|0);L()}v[114578]=0;U(1029,g+32|0,m|0,d|0);e=v[114578];v[114578]=0;h=1;if((e|0)==1){break d}ke(g+32|0);ke(d);if(!(c&2)|!x[a+480190>>1]){break e}j=1;while(1){c=B(j&65535,104)+a|0;tg(ad(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);j=j+1|0;if(x[a+480190>>1]>=(j&65535)>>>0){continue}break}}jb=g+208|0;return h|0}h=P()|0;O()|0;ke(d);break a}h=P()|0;O()|0;yb(g+144|0);break a}h=P()|0;O()|0;yb(d)}S(h|0);L()}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb+-64|0;jb=e;a:{if(!Qb(c,8)){break a}$b(c,4);while(1){m=vt(c);if(m){break a}o=jb-288|0;jb=o;i=sN(o);h=jb-368|0;jb=h;sN(h+80|0);j=lc(i,h+80|0,282);f=0;i=c;if(ph(c,20108)){fg(i,4);l=Ze(h- -64|0,i);v[114578]=0;g=Q(1202,l|0,j|0)|0;k=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{if((k|0)==1){break g}if(!g){break b}g=w[j+26|0];v[114578]=0;g=Q(258,l|0,g|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break g}if(!g){break b}h:{i:{j:{if(w[j+26|0]){g=0;while(1){v[114578]=0;k=T(377,l|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break i}t[(f+j|0)+27|0]=k;g=g+k|0;f=f+1|0;if(f>>>0<w[j+26|0]){continue}break}g=g&65535;break j}g=0}f=0;v[114578]=0;k=Q(258,l|0,g|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break d}if(k){break h}break b}f=P()|0;O()|0;break c}v[114578]=0;Q(340,l|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}fg(l,tN(j));v[114578]=0;k=T(1203,h+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}rN(h+80|0);v[114578]=0;Q(1204,l|0,h+80|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;u[h+102>>1]=0;u[h+104>>1]=0;W(1205,k|0,h+80|0,h+107|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}f=w[j+26|0];v[114578]=0;Q(340,l|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}f=w[j+26|0];v[114578]=0;n=j+27|0;W(1205,k|0,n|0,f+n|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;U(343,h+40|0,l|0,g|0);g=v[114578];v[114578]=0;k:{l:{m:{if((g|0)!=1){v[114578]=0;R(860,h+16|0,h+40|0);g=v[114578];v[114578]=0;if((g|0)==1){break m}v[114578]=0;R(1207,h+8|0,h+16|0);g=v[114578];v[114578]=0;if((g|0)==1){break l}v[114578]=0;Q(1208,k|0,h+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break l}Ec(h+16|0);Bb(h+40|0);f=0;v[114578]=0;g=T(1209,k|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break e}if((g|0)!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break b}g=tN(j);v[114578]=0;Q(340,i|0,g|0)|0;i=v[114578];v[114578]=0;f=1;if((i|0)!=1){break b}break d}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;Ec(h+16|0)}Bb(h+40|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}Bb(l);S(f|0);L()}Bb(l)}jb=h+368|0;jb=o+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|m;Jc(c);n:{o:{p:{q:{r:{s:{if(m){d=Cf(c);ud(e+48|0,c,nf(c));u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[114578]=0;v[e+44>>2]=0;v[e+40>>2]=0;R(860,e+16|0,e+48|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}v[114578]=0;c=T(414,e+16|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){d=v[e+16>>2];v[114578]=0;b=T(857,c|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}v[114578]=0;i=T(858,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;b=ea(859,b|0,i|0,e+44|0,e+40|0,0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}v[114578]=0;Q(340,e+48|0,v[e+44>>2])|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}if(!b){break q}i=v[e+44>>2];v[114578]=0;T(466,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}m=d-i|0;i=c+i|0;c=v[e+40>>2];d=0;while(1){t:{if(c){if(!m|(c|0)!=1){break r}if(y[a>>2]>d>>>0){break t}break r}if(y[a>>2]<=d>>>0){break r}}if(!De(a)){break r}v[114578]=0;v[e+12>>2]=0;v[e+8>>2]=0;c=T(857,i|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;g=T(858,m|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break p}v[114578]=0;c=ka(861,b|0,c|0,g|0,e+12|0,e+4|0,e+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;v[e+44>>2]=c;Q(340,e+48|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break p}c=v[a>>2];v[114578]=0;g=v[e+44>>2];c=T(862,c-d|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break p}Ti(e+8|0,c);u:{if(v[e+8>>2]<1){break u}if(v[e+12>>2]!=(ue(a)|0)){break u}c=0;if(v[e+12>>2]<=0){break u}while(1){v:{if(t[a+34|0]&1){h=v[a+20>>2];f=ue(a);j=v[v[e+4>>2]+(c<<2)>>2];v[114578]=0;fa(863,h+(B(d,f)<<1)|0,j|0,v[e+12>>2],v[e+8>>2],c|0);h=v[114578];v[114578]=0;if((h|0)!=1){break v}break p}h=v[a+20>>2];f=ue(a);j=v[v[e+4>>2]+(c<<2)>>2];v[114578]=0;fa(864,h+B(d,f)|0,j|0,v[e+12>>2],v[e+8>>2],c|0);h=v[114578];v[114578]=0;if((h|0)==1){break p}}c=c+1|0;if((c|0)<v[e+12>>2]){continue}break}}v[114578]=0;h=v[e+8>>2];c=T(865,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}m=m-g|0;i=g+i|0;v[e+40>>2]=c;d=d+h|0;continue}}break p}tg(b,a,c);c=1;break n}c=P()|0;O()|0;break o}v[114578]=0;Z(866,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){break q}break p}c=(b|0)!=0;Ec(e+16|0);Bb(e+48|0);break n}c=P()|0;O()|0;Ec(e+16|0)}Bb(e+48|0);S(c|0);L()}jb=e- -64|0;return c|0}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-192|0;jb=d;Jc(b);a:{if(!Zz(b,d+144|0)){break a}if(!$O(d+144|0)){break a}if(!Qb(b,hd(_O(d+144|0),mb))){break a}b:{if(!c){break b}Hd(a,256);Hn(d+16|0,2,d+144|0);Ic(d+48|0,d+16|0);Gb(a+1304400|0,d+48|0);yb(d+48|0);e=Ub(d+48|0,17296);Gb(a+1304436|0,e);yb(e);e=Ub(d+48|0,17313);Gb(a+1304448|0,e);yb(e);g=Ub(d+128|0,17317);v[114578]=0;R(219,d+16|0,g|0);e=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){v[114578]=0;R(452,d+112|0,d+175|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}v[114578]=0;X(453,d+48|0,d+16|0,d+174|0,d+112|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}Gb(a+1304460|0,d+48|0);yb(d+48|0);yb(d+112|0);Ib(d+16|0);yb(g);v[a+1304496>>2]=4;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+176|0];if(w[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}g=(f&255?f:96)&255;e=zM(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=e;if(w[d+175|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;yb(d+112|0)}Ib(d+16|0)}yb(g);break c}t[d+48|0]=64;p=a,q=w[pc(d+178|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;zg(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){it(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break k}i=jb-32|0;jb=i;h=(B(f,104)+a|0)+484380|0;Ed(h,0);g=d+16|0;Fk(i,2,g);Ic(i+16|0,i);v[114578]=0;Q(372,h+43|0,i+16|0)|0;e=v[114578];v[114578]=0;l:{m:{if((e|0)!=1){yb(i+16|0);e=g+24|0;v[h+24>>2]=w[e|0]|w[e+1|0]<<8;t[i+16|0]=w[g+22|0];t[i|0]=64;p=h,q=w[pc(i+16|0,i)|0]<<2,u[p+30>>1]=q;e=g+16|0;v[h>>2]=w[e|0]|w[e+1|0]<<8;e=g+18|0;v[h+4>>2]=w[e|0]|w[e+1|0]<<8;e=g+20|0;j=w[e|0]|w[e+1|0]<<8;v[h+8>>2]=j;g=v[h>>2];if(g>>>0>1){break m}v[h>>2]=0;break l}a=P()|0;O()|0;yb(i+16|0);S(a|0);L()}e=v[h+4>>2];if(g>>>0<=e>>>0|e>>>0>=j>>>0|(j|0)==65535){break l}u[h+34>>1]=2;p=h,q=v[Lb(h+8|0,h)>>2],v[p+8>>2]=q}jb=i+32|0;Fk(d,2,d+16|0);Ic(d+112|0,d);v[114578]=0;Q(371,((f<<5)+a|0)+946304|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}yb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;Np(Vb(e),b,w[d+175|0]?128:64,65535,65535);e=Vb(e);p=d,q=bc(e),v[p+16>>2]=q;p=d,q=cc(e),v[p+112>>2]=q;if(Jb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];g=x[e>>1];n:{if(!((g|0)!=99?(g|0)!=255:0)){u[e>>1]=65535;break n}if(g>>>0>63){break k}}te(d+16|0);if(Jb(d+16|0,d+112|0)){continue}break}}i=c&1;if(i){$f(a+484344|0,w[d+177|0])}if(w[d+177|0]){n=a+484344|0;while(1){o:{p:{if(i){if(rg(n,l&65535,64)){break p}}f=0;while(1){if((Gd(b)+5&255)>>>0>=3){$b(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break o}p=d,q=bc(_b(n,l)),v[p+112>>2]=q;v[d>>2]=63;k=65535;m=0;while(1){f=0;while(1){g=f;j=0;f=0;o=0;h=0;q:{r:{s:{t:{u:{v:{e=Gd(b);switch(e-251|0){case 1:break q;case 0:break t;case 2:break v;default:break u}}t[v[d+112>>2]]=254;break q}hq(d+16|0,b);f=w[fc(d+16|0,0)|0];o=w[fc(d+16|0,1)|0];h=w[fc(d+16|0,2)|0];j=254;if((e|0)==254){break s}j=e;if(e>>>0>95){break r}}j=(B(j>>>4|0,12)+(j&15)|0)+37|0}e=j;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=o>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(o&15)+17344|0];t[v[d+112>>2]+5|0]=h;w:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:j=v[d+112>>2];e=w[j+5|0];if(w[v[d+112>>2]+5|0]&15){t[j+5|0]=e&15;break q}t[j+5|0]=e&240;break q;case 3:t[v[d+112>>2]+5|0]=B(w[v[d+112>>2]+5|0]&240,10)|w[v[d+112>>2]+5|0]&15;x:{if((k|0)!=65535){if(w[v[d+112>>2]+5|0]){break x}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=k}k=65535}Cc(d,m);break q;case 1:k=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break q;case 5:if(w[d+175|0]<=20){t[v[d+112>>2]+5|0]=w[v[d+112>>2]+5|0]%10|w[v[d+112>>2]+5|0]/10<<4}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0;break q;case 7:break q;default:break w}}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0}Dj(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}m=m+1|0;if((m|0)!=64){continue}break}if((k|0)==65535){break o}ql(_b(n,l),Gn(Ne(Qn(d+16|0,12,k&255),v[d>>2])))}l=l+1|0;if(l>>>0<w[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}g=ad(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;y:{if(!v[e>>2]|!x[c+484410>>1]){break y}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break y}if(!Qc(b,c<<4)){break y}tg(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;yb(d+112|0)}S(f|0);L()}f=1}jb=d+192|0;return f|0}function OT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-3040|0;jb=e;Jc(b);g=jb-16|0;jb=g;i=e+1080|0;wA(g+8|0,i);k=Hb(g+8|0);f=b;j=nc(f,ac(g,g+8|0));if((k|0)==(j|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(j|0)==(k|0);if(!f){xA(i)}a:{if(!f){break a}if(!BA(e+1080|0)){break a}if(!c){d=1;break a}if(!Qb(b,hd(1024,0))){break a}AA(b,e+560|0);AA(b,e+48|0);while(1){f=h<<2;g=f+(e+560|0)|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0>16777215){break a}f=f+(e+48|0)|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3|(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>4096){break a}if(!zA(b,((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)+2978|0)){break a}h=h+1|0;if((h|0)!=128){continue}break}Hd(a,2);vi(a);d=Ub(e+16|0,12301);Gb(a+1304436|0,d);yb(d);d=Ub(e+16|0,12306);Gb(a+1304448|0,d);yb(d);d=Ub(e+16|0,12310);Gb(a+1304460|0,d);yb(d);v[a+1304496>>2]=4;d=w[e+1080|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;i=a+484360|0;Oe(Vb(i),w[e+1081|0]);v[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){f=d+1|0;h=B(f,104)+a|0;g=h+484380|0;Ed(g,2);Qi(e+32|0,1,(B(d,13)+e|0)+1082|0);Ic(e+16|0,e+32|0);v[114578]=0;Q(371,((f<<5)+a|0)+946304|0,e+16|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break e}yb(e+16|0);j=g;d=(e+1080|0)+(d<<4)|0;g=d+422|0;v[j>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[h+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[h+484414>>1]=2;v[h+484388>>2]=d}v[h+484404>>2]=8287;d=f;if((d|0)!=32){continue}break}h=0;while(1){d=h+33|0;f=(B(d,104)+a|0)+484380|0;Ed(f,2);Qi(e+32|0,1,(B(h,13)+e|0)+2010|0);Ic(e+16|0,e+32|0);v[114578]=0;Q(371,((d<<5)+a|0)+946304|0,e+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}yb(e+16|0);v[e+24>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;d=(e+1080|0)+B(h,11)|0;g=w[d+1347|0];o=fc(e+16|0,0),p=g,t[o|0]=p;g=w[d+1352|0];o=fc(e+16|0,1),p=g,t[o|0]=p;g=w[d+1348|0];o=fc(e+16|0,2),p=g,t[o|0]=p;g=w[d+1353|0];o=fc(e+16|0,3),p=g,t[o|0]=p;g=w[d+1349|0];o=fc(e+16|0,4),p=g,t[o|0]=p;g=w[d+1354|0];o=fc(e+16|0,5),p=g,t[o|0]=p;g=w[d+1350|0];o=fc(e+16|0,6),p=g,t[o|0]=p;g=w[d+1355|0];o=fc(e+16|0,7),p=g,t[o|0]=p;g=w[d+1351|0];o=fc(e+16|0,8),p=g,t[o|0]=p;g=w[d+1356|0];o=fc(e+16|0,9),p=g,t[o|0]=p;d=w[d+1346|0];o=fc(e+16|0,10),p=d,t[o|0]=p;v[e+8>>2]=v[e+24>>2];d=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=d;op(f,1,e);h=h+1|0;if((h|0)!=32){continue}break}eq(Vb(i),e+2778|0,256,255,65535);k=a+484344|0;$f(k,128);n=c&1;h=0;f:{while(1){f=h<<2;d=f+(e+560|0)|0;Qc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=f+(e+48|0)|0;ud(e+16|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));g:{if(!n){break g}v[114578]=0;d=W(404,k|0,h&65535,64)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!d){break g}d=0;g=_b(k,h);while(1){v[114578]=0;f=Q(258,e+16|0,1)|0;i=v[114578];v[114578]=0;h:{i:{if((i|0)!=1){if(!f){break g}v[114578]=0;f=T(389,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}if(f>>>0>12){break i}v[114578]=0;i=W(472,g|0,d|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[114578]=0;R(473,e+32|0,e+16|0);j=v[114578];v[114578]=0;if((j|0)==1){break c}j=cd(e+32|0);l=e+32|0;m=w[l|0];f=f>>>0>3;t[i|0]=((m&15)+(f?13:37)|0)+B(m>>>4&7,12);t[i+1|0]=((w[j|0]>>>4|0)+(f?33:1)|0)+(w[l|0]>>>3&16);yA(i,w[j|0],f);break h}break c}i=f-32|0;if((i&255)>>>0<=12){v[114578]=0;i=W(472,g|0,d|0,i&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[114578]=0;j=T(389,e+16|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break c}yA(i,j,f>>>0>35);break h}if((f|0)!=64){if((f|0)!=96){break f}if(!d){break g}v[114578]=0;d=W(472,g|0,d-1|0,0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}t[d+3|0]=14;break g}v[114578]=0;f=T(389,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}d=d+f|0}if(d>>>0<64){continue}break}}Bb(e+16|0);h=h+1|0;if((h|0)!=128){continue}break}d=1;if(!(c&2)){break a}h=1;while(1){tg(ad(e+16|0,8,1,0,1),(B(h,104)+a|0)+484380|0,b);h=h+1|0;if((h|0)!=33){continue}break}break a}Bb(e+16|0);d=0;break a}d=P()|0;O()|0;yb(e+16|0);break b}d=P()|0;O()|0;yb(e+16|0);break b}d=P()|0;O()|0;Bb(e+16|0)}S(d|0);L()}jb=e+3040|0;return d|0}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-80|0;jb=e;Jc(b);a:{b:{c:{d:{e:{if(TP(b,16628)){g=Mp(e- -64|0);h=Mp(e+48|0);l=ht(e+32|0);v[114578]=0;R(449,a|0,32768);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;d=Q(2,e+8|0,16637)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}Gb(a+1304436|0,d);yb(d);v[114578]=0;d=Q(2,e+8|0,16647)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=2;j=a+484360|0;i=e+24|4;f:{g:{h:{i:{j:{while(1){v[114578]=0;d=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}k:{l:{m:{n:{if(!d){break n}v[114578]=0;d=Q(928,b|0,e+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}if(!d){break n}d=i;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;U(343,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=v[114578];v[114578]=0;if((d|0)==1){break l}v[114578]=0;d=T(339,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(d){break k}Bb(e+8|0)}if(x[a+480188>>1]){break j}d=0;break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=e+24|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(nd(g)>>>0>255){break p}v[114578]=0;R(601,g|0,e+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(x[a+480190>>1]|(d|0)!=1396788560){break p}v[114578]=0;U(929,e+8|0,l|0,a|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(d>>>0<2){break p}v[114578]=0;d=T(485,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}o=a,p=Fd(d,1,255),v[o+480196>>2]=p;break p}if(x[a+480188>>1]){break p}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}f=0;if(d>>>0<8){break p}while(1){v[114578]=0;k=T(389,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}v[114578]=0;m=T(389,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}d=x[a+480188>>1];if(k|m){v[114578]=0;Z(434,((d<<5)+a|0)+480280|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}k=x[a+480188>>1];d=k+1|0;u[a+480188>>1]=d;u[((k<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}v[114578]=0;Z(434,(((d&65535)<<5)+a|0)+480280|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}d=x[a+480188>>1];u[a+480188>>1]=d+1;u[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break p}Bb(e+8|0);break g}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(d>>>0<2){break p}v[114578]=0;n=T(485,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}break p}d=Vb(j);v[114578]=0;f=T(255,e+8|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break e}v[114578]=0;ea(581,d|0,e+8|0,f|0,255,254)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break p}break e}if(nd(h)>>>0>3998){break p}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(!d){break p}v[114578]=0;R(601,h|0,e+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}}Bb(e+8|0);continue}break}break e}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Vb(j);v[114578]=0;R(930,b|0,n&65535);b=v[114578];v[114578]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=nd(g);v[114578]=0;R(403,a+484344|0,b&65535);b=v[114578];v[114578]=0;if((b|0)==1){break b}if(!nd(g)){break u}b=0;while(1){d=tc(g,d);v[114578]=0;U(931,d|0,b&65535,a|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(nd(g)>>>0>d>>>0){continue}break}}f=1;if(x[a+480190>>1]<2){break g}i=c&2;b=0;v:{while(1){if(!i|nd(h)>>>0<=b>>>0){break g}w:{c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){d=tc(h,b);v[114578]=0;d=T(255,d|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break w}Cc(c,d);ee(e+8|0,l,f-1|0);d=ad(e+24|0,8,1,1,Cb(e+8|0)?10:0);j=tc(h,b);v[114578]=0;W(402,d|0,c|0,j|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break f}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=1}ke(l);gd(h);gd(g)}jb=e+80|0;return d|0}a=P()|0;O()|0;Bb(e+8|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ke(l);gd(h);gd(g);S(a|0);L()}function bI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-416|0;jb=e;t[e+415|0]=c;a:{if(nj(b)){break a}c=w[fk(b)|0];if((c|0)==33){d=1}else{if((c|0)!=63){break a}d=0}rk(e+160|0,b,v[b+4>>2]-1|0);c=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=c}Cd(e+160|0);c=v[e+160>>2];Cd(e+376|0);g=ek(c,v[e+380>>2],b);Cd(e+160|0);c=v[b>>2];f=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((g|0)==v[e+164>>2]){v[e+400>>2]=c;v[e+404>>2]=f;a=qc(e+392|0,38235);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Hc(e+8|0,e)){c=ba(8)|0;v[114578]=0;R(2142,e+376|0,e+415|0);a=v[114578];v[114578]=0;if((a|0)==1){break g}v[114578]=0;U(2120,e+160|0,39300,e+376|0);a=v[114578];v[114578]=0;if((a|0)==1){break f}mc(c,e+160|0);d=0;v[114578]=0;U(2010,c|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+160|0);break e}if(!d){break h}c=ba(8)|0;v[114578]=0;a=Q(2143,e+344|0,b|0)|0;b=v[114578];v[114578]=0;d=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[114578]=0;U(2120,e+360|0,39179,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break q}v[114578]=0;U(2138,e+376|0,e+360|0,39315);b=v[114578];v[114578]=0;if((b|0)==1){break p}v[114578]=0;R(2142,e+328|0,e+415|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}v[114578]=0;U(138,e+160|0,e+376|0,e+328|0);b=v[114578];v[114578]=0;if((b|0)==1){break n}mc(c,e+160|0);v[114578]=0;U(2010,c|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+160|0);d=0;break m}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}yb(e+328|0)}yb(e+376|0)}yb(e+360|0)}yb(a)}if(d){break d}break c}v[e+320>>2]=c;v[e+324>>2]=f;c=qc(e+312|0,38235);d=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=d;d=v[c+4>>2];v[e+144>>2]=v[c>>2];v[e+148>>2]=d;if(Hc(e+152|0,e+144|0)){c=ba(8)|0;v[114578]=0;R(2142,e+376|0,e+415|0);a=v[114578];v[114578]=0;r:{s:{if((a|0)!=1){v[114578]=0;U(2120,e+160|0,39300,e+376|0);a=v[114578];v[114578]=0;if((a|0)==1){break s}mc(c,e+160|0);d=0;v[114578]=0;U(2010,c|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+160|0);break r}b=P()|0;O()|0;break d}b=P()|0;d=1;O()|0}yb(e+376|0);if(d){break d}break c}c=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=c;c=qc(e+296|0,38917);d=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=d;d=v[c+4>>2];v[e+128>>2]=v[c>>2];v[e+132>>2]=d;t:{if(!Hc(e+136|0,e+128|0)){c=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=c;c=qc(e+280|0,39214);d=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=d;d=v[c+4>>2];v[e+112>>2]=v[c>>2];v[e+116>>2]=d;if(!Hc(e+120|0,e+112|0)){break t}}t[a+60|0]=w[e+415|0];break h}c=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=c;c=qc(e+264|0,38935);d=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=d;d=v[c+4>>2];v[e+96>>2]=v[c>>2];v[e+100>>2]=d;u:{if(!Hc(e+104|0,e+96|0)){c=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=c;c=qc(e+248|0,39232);d=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=d;d=v[c+4>>2];v[e+80>>2]=v[c>>2];v[e+84>>2]=d;if(!Hc(e+88|0,e+80|0)){break u}}t[a+61|0]=w[e+415|0];break h}c=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=c;c=qc(e+232|0,38954);d=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=d;d=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=d;if(Hc(e+72|0,e- -64|0)){t[a+62|0]=w[e+415|0];break h}c=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=c;c=qc(e+216|0,38972);d=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=d;d=v[c+4>>2];v[e+48>>2]=v[c>>2];v[e+52>>2]=d;if(Hc(e+56|0,e+48|0)){t[a+63|0]=w[e+415|0];break h}c=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=c;c=qc(e+200|0,38996);d=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=d;d=v[c+4>>2];v[e+32>>2]=v[c>>2];v[e+36>>2]=d;if(Hc(e+40|0,e+32|0)){t[a+64|0]=w[e+415|0];break h}c=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=c;b=qc(e+184|0,39070);c=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=c;c=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=c;if(!Hc(e+24|0,e+16|0)){break h}c=a+24|0;b=v[c>>2];d=b+24664|0;f=v[d+4>>2];v[e+176>>2]=v[d>>2];v[e+180>>2]=f;d=b+24656|0;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;d=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=d;b=e;if(w[e+415|0]){a=HH(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!Uw(e+160|0,v[c>>2]+24648|0)){break h}Kx(v[c>>2],e+160|0)}jb=e+416|0;return}b=P()|0;O()|0;break d}b=P()|0;d=1;O()|0}yb(e+376|0);if(!d){break c}}ca(c|0)}S(b|0)}L()}function fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-256|0;jb=f;Jc(b);a:{if(!lA(b,f+184|0)){break a}if(!WP(f+184|0)){break a}if(!Qb(b,hd(VP(f+184|0),mb))){break a}b:{if(!c){break b}Hd(a,16);Hn(f,2,f+184|4);Ic(f+16|0,f);Gb(a+1304400|0,f+16|0);yb(f+16|0);u[a+480190>>1]=w[f+214|0];u[a+480188>>1]=w[f+217|0];e=Ub(f+16|0,16588);Gb(a+1304436|0,e);yb(e);e=Ub(f+16|0,16601);Gb(a+1304448|0,e);yb(e);d=Ub(f+168|0,16605);v[114578]=0;R(219,f|0,d|0);e=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=f+184|3;v[f+152>>2]=w[e|0]>>>4;e=w[e|0];v[114578]=0;v[f+164>>2]=e&15;X(534,f+16|0,f|0,f+152|0,f+164|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Gb(a+1304460|0,f+16|0);yb(f+16|0);Ib(f);yb(d);v[a+1304496>>2]=4;if(x[a+480190>>1]){e=1;i=1;while(1){CB(b,f+16|0);h=jb-16|0;jb=h;d=(B(e,104)+a|0)+484380|0;Ed(d,0);g=f+16|0;u[h+14>>1]=w[g+35|0]<<2;u[h+12>>1]=256;p=d,q=x[lf(h+14|0,h+12|0)>>1],u[p+30>>1]=q;j:{if((w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24))>>>0<3){break j}v[d>>2]=w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24);v[d+4>>2]=w[g+26|0]|w[g+27|0]<<8|(w[g+28|0]<<16|w[g+29|0]<<24);v[h+8>>2]=w[g+30|0]|w[g+31|0]<<8|(w[g+32|0]<<16|w[g+33|0]<<24);v[h+4>>2]=1;p=d,q=v[bd(h+8|0,h+4|0)>>2]-1|0,v[p+8>>2]=q;Cc(d+8|0,v[d>>2]);k:{if(y[d+8>>2]<=v[d+4>>2]+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;break k}u[d+34>>1]=x[d+34>>1]|2}t[d+37|0]=w[g+34|0];p=d,q=Xs(0,t[g+34|0]<<4),v[p+24>>2]=q;if(!(t[g+36|0]&1)){break j}u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}jb=h+16|0;Tl(f+152|0,2,f+16|0);Ic(f,f+152|0);v[114578]=0;Q(371,((e<<5)+a|0)+946304|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}yb(f);i=i+1|0;e=i&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){e=0;while(1){d=(e<<5)+a|0;zg(d+480280|0);u[d+480284>>1]=(w[(f+e|0)+218|0]<<4|8)&248;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}d=f+16|0;g=jb-16|0;jb=g;e=b;l:{if(Qb(e,128)){ER(g+8|0,d);Bd(e,g+8|0);break l}e=jb-16|0;jb=e;h=jb-16|0;jb=h;i=d+128|0;while(1){ff(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}jb=h+16|0;jb=e+16|0}jb=g+16|0;KB(Vb(a+484360|0),f+16|0,w[f+211|0]+1|0);if(w[f+216|0]){break g}j=64;break f}e=P()|0;O()|0;break h}e=P()|0;O()|0;Ib(f)}yb(d);break c}j=w[f+216|0]}ud(f,b,B(w[f+208|0]|w[f+209|0]<<8,192));e=c&1;if(e){d=w[f+210|0];v[114578]=0;R(403,a+484344|0,d+1|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}}m:{n:{if(!e){break n}n=a+484344|0;while(1){v[114578]=0;d=W(404,n|0,k&65535,j|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}e=0;if(!d){break n}while(1){v[114578]=0;d=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}l=e;o:{if(!d|d>>>0>(w[f+208|0]|w[f+209|0]<<8)>>>0){break o}e=l&65535;if(e>>>0>=x[a+480188>>1]){break o}v[114578]=0;Q(256,f|0,B(d,192)-192|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}d=_b(n,k);v[114578]=0;e=W(472,d|0,0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}m=0;if(!j){break o}while(1){v[114578]=0;R(807,f+152|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}i=cd(f+152|0);h=Bf(f+152|0);g=e;d=w[f+152|0];if(d>>>0>=4){t[e|0]=(d>>>2|0)+37;d=w[f+152|0]}t[g+1|0]=d<<4&48|w[i|0]>>>4;d=w[h|0];g=0;h=0;p:{q:{r:{s:{t:{u:{i=w[i|0]&15;switch(i-8|0){case 0:break r;case 6:break t;case 2:break u;default:break s}}d=d&240?d&-16:d&15;i=10;break q}i=14;o=(d+16&240)>>>4|0;if(o>>>0>8){break q}if(1<<o&435){break r}break q}g=i;h=d}d=h;i=g;if(!((d|g)&255)){break p}}t[e+5|0]=d;t[e+3|0]=i;v[114578]=0;Z(574,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){break p}break d}e=B(x[a+480188>>1],6)+e|0;m=m+1|0;if((m|0)!=(j|0)){continue}break}}e=l+1|0;if((l&65535)>>>0<31){continue}break}e=w[f+210|0]>k>>>0;k=k+1|0;if(e){continue}break}}if(w[f+212|0]|w[f+213|0]<<8){e=w[f+212|0]|w[f+213|0]<<8;v[114578]=0;ea(547,a+1304424|0,b|0,e|0,39,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;e=ad(f+152|0,u[c+484414>>1]&1?16:8,1,0,1);v[114578]=0;W(402,e|0,c+484380|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;Bb(f);break b}break d}e=P()|0;O()|0;yb(f);break c}e=P()|0;O()|0;Bb(f)}S(e|0);L()}e=1}jb=f+256|0;return e|0}function Hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-336|0;jb=d;Jc(b);a:{if(!It(b,d+320|0)){break a}if(!US(d+320|0)){break a}if(v[d+320>>2]==1179472708){$b(b,4)}if(!Ef(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}i=d+312|4;g=i;MA(b,d+120|0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Hd(a,8192);e=Ub(d+40|0,12774);Gb(a+1304436|0,e);yb(e);e=Ub(d+40|0,12786);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;Ht(d+104|0,2,d+120|0);Ic(d+40|0,d+104|0);Gb(a+1304400|0,d+40|0);yb(d+40|0);u[d+40>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+104>>1]=1;p=a,q=x[Si(d+40|0,d+104|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+40|0]=w[d+164|0];t[d+104|0]=64;e=w[pc(d+40|0,d+104|0)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+40>>2]=256/x[a+480188>>1];v[d+104>>2]=128;g=v[Lb(d+40|0,d+104|0)>>2];break b}g=w[d+165|0]&127}v[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;zg(g+480280|0);f=d+e|0;if(w[f+168|0]<=128){u[g+480284>>1]=w[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;In(Vb(e),d+184|0,w[d+156|0]|w[d+157|0]<<8,255,254);if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){Oe(Vb(e),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Ef(b,d+312|0)){break a}m=c&2;j=a+484344|0;n=c&1;o=d+76|0;while(1){c=i;ud(d+104|0,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c:{d:{e:{if(!(!n|v[d+312>>2]!=1414807888)){v[114578]=0;l=k&65535;c=W(404,j|0,l|0,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}if(!c){break c}v[114578]=0;Q(340,d+104|0,2)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}Ph(d+40|0);g=0;f:{while(1){v[114578]=0;c=Q(258,d+104|0,1)|0;e=v[114578];v[114578]=0;g:{h:{if((e|0)!=1){if(!(c&g>>>0<64)){break f}v[114578]=0;e=T(389,d+104|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}if(e){break g}g=g+1|0;continue}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}c=d+40|0;i:{j:{k:{f=e&15;l:{if(f>>>0<x[a+480188>>1]){c=_b(j,l);v[114578]=0;c=W(472,c|0,g|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}}m:{if(!(e&128)){break m}v[114578]=0;f=T(389,d+104|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break k}if(!f){break m}t[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break i}v[114578]=0;f=T(389,d+104|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break j}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}t[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(e&32){t[c+2|0]=1;v[114578]=0;f=T(389,d+104|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break u}v[114578]=0;t[d+24|0]=f;t[d+8|0]=64;f=Q(393,d+24|0,d+8|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break t}t[c+4|0]=w[f|0]}if(!(e&16)){continue}v[114578]=0;R(473,d+24|0,d+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}h=cd(d+24|0);f=d+24|0;e=w[f|0];switch(e-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}e=e&15;break o}t[f|0]=33;t[h|0]=145;e=w[f|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}t[f|0]=e}t[c+3|0]=e;t[c+5|0]=w[h|0];v[114578]=0;Z(574,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break d}k=k+1|0;break c}if(v[d+312>>2]!=1414745673){break c}if(!En(a)){break c}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[114578]=0;Q(575,d+104|0,d+40|0)|0;e=v[114578];v[114578]=0;v:{w:{x:{if((e|0)==1){break x}v[114578]=0;c=(B(c&65535,104)+a|0)+484380|0;R(576,d+40|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break x}v[114578]=0;U(577,d+8|0,2,o|0);e=v[114578];v[114578]=0;if((e|0)==1){break w}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break w}e=x[a+480190>>1];v[114578]=0;Q(371,((e<<5)+a|0)+946304|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break v}yb(d+24|0);if(!m){break c}v[114578]=0;R(578,d+24|0,d+40|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+24|0,c|0,d+104|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break c}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d+24|0);break d}b=P()|0;O()|0}Bb(d+104|0);S(b|0);L()}Bb(d+104|0);e=1;if(Ef(b,d+312|0)){continue}break}}jb=d+336|0;return e|0}function uL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-16|0;jb=h;a:{b:{if(!be(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}d=v[d+44>>2];if(!d){break b}u[h+14>>1]=c-61;b=jb-80|0;jb=b;e=u[d+28>>1];f=h+14|0;c=u[f>>1];g=d+4|0;Kb(g);c:{d:{if((c|0)>=(e|0)){if((c|0)<=(x[d+28>>1]+Kb(g)<<16)-65536>>16){break d}}fd(a);break c}e:{e=u[d+30>>1];if(!e){c=d+52|0;m=b,n=kx(c,f),v[m+56>>2]=n;m=b,n=Hi(c),v[m+40>>2]=n;if(!Gi(b+56|0,b+40|0)){break e}Af(a,jh(b+56|0)+4|0);break c}c=b;g=u[f>>1];f:{if((g|0)>=0){e=(g|0)%(e|0)|0;break f}e=e+((g^-1)%(e|0)^-1)|0}u[c+78>>1]=e;c=fd(a);v[114578]=0;a=d+52|0;e=Q(1601,a|0,b+78|0)|0;g=v[114578];v[114578]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((g|0)==1){break w}v[b+72>>2]=e;a=Hi(a);v[114578]=0;v[b+56>>2]=a;a=Q(1602,b+72|0,b+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}if(a){v[114578]=0;a=T(1603,b+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break w}v[114578]=0;Q(237,c|0,a+4|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break w}a=u[d+30>>1];d=u[f>>1];x:{if((d|0)>=0){a=(d|0)/(a|0)|0;break x}a=((d+1|0)/(a|0)|0)-1|0}v[114578]=0;v[b+40>>2]=a+5;R(234,b+56|0,b+40|0);a=v[114578];v[114578]=0;y:{if((a|0)!=1){v[114578]=0;Q(192,c|0,b+56|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break y}yb(b+56|0);break c}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(b+56|0);break g}if(u[d+30>>1]>26){break t}v[114578]=0;e=W(800,b+40|0,1,(w[b+78|0]<<24)+1090519040>>24)|0;a=v[114578];v[114578]=0;if((a|0)==1){break v}v[114578]=0;U(13,b+56|0,0,e|0);a=v[114578];v[114578]=0;if((a|0)==1){break u}Gb(c,b+56|0);yb(b+56|0);yb(e);v[114578]=0;Q(235,c|0,32403)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break s}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(e);break g}v[114578]=0;v[b+36>>2]=u[b+78>>1]%16;R(1604,b+40|0,b+36|0);a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;v[b+20>>2]=(u[b+78>>1]/16<<16>>16)%16;R(1604,b+24|0,b+20|0);a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;U(3,b+56|0,b+40|0,b+24|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}Gb(c,b+56|0);yb(b+56|0);yb(b+24|0);yb(b+40|0);if(u[b+78>>1]<256){break s}v[114578]=0;U(9,b+8|0,0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[114578]=0;R(1605,b+40|0,b+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;U(13,b+56|0,0,b+40|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}Gb(c,b+56|0);yb(b+56|0);yb(b+40|0);yb(b+8|0)}a=u[d+30>>1];d=u[f>>1];if((d|0)<0){break j}a=(d|0)/(a|0)|0;break i}a=P()|0;O()|0;break g}a=P()|0;O()|0;break o}a=P()|0;O()|0;yb(b+24|0)}yb(b+40|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break k}a=P()|0;O()|0;yb(b+40|0)}yb(b+8|0);break g}a=((d+1|0)/(a|0)|0)-1|0}v[114578]=0;v[b+40>>2]=a+5;R(234,b+56|0,b+40|0);a=v[114578];v[114578]=0;z:{if((a|0)!=1){v[114578]=0;Q(192,c|0,b+56|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break z}yb(b+56|0);break c}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(b+56|0);break g}a=P()|0;O()|0}yb(c);S(a|0);L()}j=jb-16|0;jb=j;c=a;a=jb-16|0;jb=a;d=a;e=jb-144|0;jb=e;g=dh(e+8|0);i=v[v[g>>2]-12>>2];v[114578]=0;k=da(122)|0;l=v[114578];v[114578]=0;A:{B:{if((l|0)==1){break B}v[114578]=0;U(123,e|0,i+(e+8|0)|0,k|0);i=v[114578];v[114578]=0;if((i|0)==1){break B}Ob(e);v[114578]=0;R(131,g|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break B}v[114578]=0;R(125,d|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break B}Yd(g);jb=e+144|0;break A}a=P()|0;O()|0;Yd(g);S(a|0);L()}v[114578]=0;U(13,c|0,0,a|0);c=v[114578];v[114578]=0;C:{if((c|0)!=1){yb(a);jb=a+16|0;break C}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=j+16|0}jb=b+80|0;break a}f=v[b>>2];b=jb-32|0;jb=b;D:{if(vL(c)){v[b+16>>2]=v[5144];d=v[5141];v[b>>2]=v[5140];v[b+4>>2]=d;d=v[5143];v[b+8>>2]=v[5142];v[b+12>>2]=d;Ub(a,(b+(c<<2)|0)-1004|0);break D}if(be(c)){d=fd(b);v[114578]=0;e=c-1|0;c=(e<<16>>16)/12|0;f=Q(1435,d|0,f+(e-B(c,12)<<16>>16<<2)|0)|0;e=v[114578];v[114578]=0;E:{if((e|0)==1){break E}v[114578]=0;c=W(1436,f|0,1,c+48&65535)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}v[114578]=0;Q(4,a|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break E}yb(d);break D}a=P()|0;O()|0;yb(d);S(a|0);L()}if(!c){Ub(a,20580);break D}Ub(a,20584)}jb=b+32|0}jb=h+16|0}function gla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-704|0;jb=k;a:{b:{if(d>>>0<=511){d=0;a=jb-16|0;jb=a;h=jb-16|0;jb=h;g=k+24|0;gc(a+8|0,g,554);jb=h+16|0;h=Hb(a+8|0);i=nc(b,ac(a,a+8|0));if((h|0)==(i|0)){$b(b,Hb(a+8|0))}jb=a+16|0;a=(h|0)==(i|0);if(!a){b=jb-16|0;jb=b;Rb(g,0,554);jb=b+16|0}if(!a){break b}d=jb-32|0;jb=d;c:{d:{a=k+24|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}yu(d,3,a+32|0);Ic(d+16|0,d);v[114578]=0;Q(371,c+492|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}yb(d+16|0);Qi(d,1,a+4|0);Ic(d+16|0,d);v[114578]=0;Q(371,c+524|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}yb(d+16|0);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];i=c+108|0;e=c+236|0;b=0;h=a- -64|0;while(1){f=b<<1;g=w[f+h|0];f=w[h+(f|1)|0];o=dd(e,b),p=f,u[o>>1]=p;o=fc(i,b),p=(g>>>0<120?g:b)+1|0,t[o|0]=p;b=b+1|0;if((b|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;i=c+61|0;t[i|0]=w[a+18|0];e=c+62|0;t[e|0]=w[a+19|0];f=c+63|0;t[f|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];h=c+48|0;gg(h,25);b=0;while(1){f:{l=b<<1;g=w[(l+a|0)+504|0];o=Pb(h,b),p=g,u[o>>1]=p;if((g|0)==255){gg(h,b);break f}g=w[(a+(l|1)|0)+504|0];o=Pb(h,b),p=g,t[o+2|0]=p;b=b+1|0;if((b|0)!=25){continue}}break}a=w[qh(i,e)|0];if(Kb(h)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[qh(f,j)|0];if(Kb(h)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}jb=d+32|0;break c}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}d=554;break b}h=v[b+8>>2];g=jb-16|0;jb=g;v[g+12>>2]=674;v[g>>2]=674;d=b;i=v[Lb(g+12|0,g)>>2];if(!Qb(d,i)){i=nf(d)}e=k+24|0;RR(g,e);xg(d,v[g>>2],i);RR(g,e);Rb(v[g>>2]+i|0,0,674-i|0);$b(d,v[g+12>>2]);jb=g+16|0;g=b;i=c;d=c;l=v[a+480180>>2];a=0;f=jb-32|0;jb=f;g:{h:{j=k+24|0;e=j;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){yu(f,3,e+32|0);Ic(f+16|0,f);v[114578]=0;Q(371,d+492|0,f+16|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break h}yb(f+16|0);Qi(f,1,e+4|0);Ic(f+16|0,f);v[114578]=0;Q(371,d+524|0,f+16|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break h}yb(f+16|0);v[d>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[d+4>>2]=w[e+24|0]>>>1;Cc(d+4|0,64);a=w[e+25|0]&127;v[d+8>>2]=a>>>0>64?128:a<<2;t[d+15|0]=w[d+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[f+16|0]=w[e+26|0];t[f|0]=100;o=d,p=w[pc(f+16|0,f)|0],t[o+20|0]=p;t[f+16|0]=w[e+27|0];t[f|0]=64;o=d,p=w[pc(f+16|0,f)|0],t[o+19|0]=p;t[d+16|0]=w[e+17|0];t[d+17|0]=w[e+18|0];t[d+18|0]=w[e+19|0];t[d+26|0]=w[e+22|0];t[d+27|0]=w[e+23|0];uu(d,w[e+58|0]&127,w[e+58|0]>>>7|0);tu(d,w[e+59|0]&127,w[e+59|0]>>>7|0);i:{j:{k:{if(!((w[e+28|0]|w[e+29|0]<<8)==514|(w[e+28|0]|w[e+29|0]<<8)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break k}}if(w[e+61|0]==255){break k}if(w[e+61|0]<=128){t[d+30|0]=w[e+61|0]}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break j}break i}a=0;if(t[e+61|0]>=0){t[d+30|0]=w[e+61|0]+1}a=t[e+62|0]>=0?w[e+62|0]+1|0:a;if(t[e+63|0]<0){break j}a=(w[e+63|0]<<7)+a|0}u[d+28>>1]=a}a=t[e+60|0];t[d+31|0]=a;if((a|0)<=-1){t[d+31|0]=0;t[d+34|0]=a^128}a=0;l=l&16777216?240:25;Au(e+304|0,d+48|0,0,l);Au(e+386|0,d+68|0,32,l);Au(e+468|0,d+88|0,32,l);t[d+100|0]=w[d+100|0]&239|w[e+468|0]>>>3&16;l=d+108|0;n=d+236|0;d=e- -64|0;while(1){m=a<<1;e=w[m+d|0];m=w[d+(m|1)|0];o=dd(n,a),p=m,u[o>>1]=p;o=fc(l,a),p=(e>>>0<120?e:a)+1|0,t[o|0]=p;a=a+1|0;if((a|0)!=120){continue}break}a=554}jb=f+32|0;break g}a=P()|0;O()|0;yb(f+16|0);S(a|0);L()}if(a){if(!((w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1297110104?(w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1481920589:0)){d=i+236|0;a=0;while(1){i=w[(a+j|0)+554|0];e=dd(d,a);u[e>>1]=x[e>>1]|i<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Qc(g,h+d|0);if(!ph(b,13380)){break b}ud(k+8|0,b,Cf(b));v[114578]=0;b=T(255,k+8|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}v[114578]=0;a=Q(618,k+8|0,13385)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}if(a){v[114578]=0;a=T(389,k+8|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}t[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;Bb(k+8|0)}jb=k+704|0;return d|0}a=P()|0;O()|0;Bb(k+8|0);S(a|0);L()}function JH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb-48|0;jb=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Nr(c)){h=b+24|0;if(dg(v[h>>2]+484344|0,c&65535)){break j}}c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}b=_b(v[h>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}if(!(x[v[h>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}if(f>>>0>=6){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}b=Xe(b,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!Tf(b)){if(!js(b)){break n}}uL(g+16|0,v[h>>2],w[b|0],w[b+1|0]);v[114578]=0;U(9,g+32|0,0,g+16|0);c=v[114578];v[114578]=0;d=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}d=0;v[114578]=0;Q(85,g+32|0,38869)|0;c=v[114578];v[114578]=0;if((c|0)==1){break l}}v[114578]=0;c=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}o:{if(c){v[114578]=0;Q(85,g|0,38873)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}break o}if(js(b)){v[114578]=0;Q(85,g|0,38877)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break o}break c}v[114578]=0;Q(85,g|0,38869)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}}Fh(a,g+32|0,g);yb(g);yb(g+32|0);if(!d){break i}yb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:c=b+1|0;p:{if(w[b+1|0]){nt(g+32|0,c);break p}Ub(g+32|0,38881)}q:{if(w[c|0]){v[114578]=0;Q(85,g+16|0,38884)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break q}break d}v[114578]=0;Q(85,g+16|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 2:r:{if(fn(b)){Ub(g+32|0,38887);break r}if(w[b+2|0]){Hj(g+32|0,1,zK(v[v[h>>2]+8>>2],w[b+2|0]));break r}Ub(g+32|0,38887)}v[114578]=0;c=T(1342,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}s:{if(c){v[114578]=0;Q(85,g+16|0,38887)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}break s}if(w[b+2|0]){v[114578]=0;Q(85,g+16|0,38889)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break s}break e}v[114578]=0;Q(85,g+16|0,38887)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 4:t:{if(fn(b)){i=g,j=iy(b)&255,v[i>>2]=j;wz(g+32|0,g);break t}if(w[b+2|0]){nt(g+32|0,b+4|0);break t}Ub(g+32|0,38881)}v[114578]=0;c=T(1342,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}u:{if(c){v[114578]=0;Q(85,g+16|0,38891)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}break u}if(w[b+2|0]){v[114578]=0;Q(85,g+16|0,38891)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break u}break f}v[114578]=0;Q(85,g+16|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 3:v:{if(fn(b)){i=g,j=(Bs(b)&3840)!=0,t[i|0]=j;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;d=jb-16|0;jb=d;v[d+12>>2]=w[g|0];Xw(g+32|0,d+12|0,c);jb=d+16|0;jb=c+32|0;break v}if(w[b+3|0]){Hj(g+32|0,1,yK(v[v[h>>2]+8>>2],w[b+3|0]));break v}Ub(g+32|0,38894)}v[114578]=0;c=T(1342,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}w:{if(c){v[114578]=0;Q(85,g+16|0,38896)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}break w}if(w[b+3|0]){v[114578]=0;Q(85,g+16|0,38896)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break w}break g}v[114578]=0;Q(85,g+16|0,38894)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 5:x:{if(fn(b)){i=g,j=Bs(b)&255,v[i>>2]=j;wz(g+32|0,g);break x}if(w[b+3|0]){nt(g+32|0,b+5|0);break x}Ub(g+32|0,38881)}v[114578]=0;c=T(1342,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}y:{if(c){v[114578]=0;Q(85,g+16|0,38898)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}break y}if(w[b+3|0]){v[114578]=0;Q(85,g+16|0,38898)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break y}break h}v[114578]=0;Q(85,g+16|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;default:break k}}c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a)}jb=g+48|0;return}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);if(!d){break a}}yb(g+16|0)}S(c|0);L()}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-144|0;jb=e;d=-1;a:{b:{c:{if(!Jt(v[v[b>>2]-12>>2]+b|0)){b=$k(e+40|0,b);v[114578]=0;d=Q(683,e+24|0,32412)|0;f=v[114578];v[114578]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){v[114578]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(684,b|0,d|0,e+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break F}Ib(d);v[114578]=0;t[e+15|0]=0;d=Q(683,e+24|0,32422)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}v[114578]=0;W(685,b|0,e+15|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}Ib(d);v[114578]=0;f=w[e+15|0];d=Q(683,e+24|0,32427)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;f=f?0:c;X(1607,b|0,a+40|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break B}Ib(d);v[114578]=0;u[e+12>>1]=65535;c=Q(683,e+24|0,32429)|0;d=v[114578];v[114578]=0;if((d|0)==1){break A}v[114578]=0;W(1184,b|0,e+12|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break z}Ib(c);v[114578]=0;u[e+10>>1]=0;c=Q(683,e+24|0,32431)|0;d=v[114578];v[114578]=0;if((d|0)==1){break y}v[114578]=0;W(1184,b|0,e+10|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break x}Ib(c);u[a>>1]=x[e+10>>1];v[114578]=0;c=Q(683,e+24|0,32433)|0;d=v[114578];v[114578]=0;if((d|0)==1){break w}v[114578]=0;X(1608,b|0,a+52|0,c|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break v}Ib(c);v[114578]=0;c=Q(683,e+24|0,32435)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}v[114578]=0;W(1573,b|0,a+36|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}Ib(c);v[114578]=0;c=Q(683,e+24|0,32437)|0;d=v[114578];v[114578]=0;if((d|0)==1){break s}v[114578]=0;f=a+4|0;aa(1609,b|0,f|0,c|0,1610)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}Ib(c);v[114578]=0;c=Q(683,e+24|0,32442)|0;d=v[114578];v[114578]=0;if((d|0)==1){break q}v[114578]=0;g=a+28|0;W(1611,b|0,g|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break p}Ib(c);v[114578]=0;c=Q(683,e+24|0,32447)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}v[114578]=0;W(1611,b|0,a+30|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}Ib(c);v[114578]=0;c=Q(683,e+24|0,32452)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}v[114578]=0;W(1612,b|0,a+32|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break l}Ib(c);v[114578]=0;u[e+8>>1]=0;c=Q(683,e+24|0,32457)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;W(1184,b|0,e+8|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break k}Ib(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break d}c=v[a+36>>2];v[114578]=0;c=T(862,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break j}v[114578]=0;v[e+24>>2]=c;v[e+16>>2]=0;c=W(1241,e+24|0,e+16|0,32408)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}v[a+36>>2]=v[c>>2];if(Kb(f)>>>0>32767){break d}switch(x[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(u[e+8>>1]<1){break d}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114578]=0;u[e+16>>1]=c;u[e+18>>1]=(c+x[e+8>>1]|0)-1;a=aa(1613,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}if(u[e+8>>1]<1){break d}z[e+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114578]=0;u[e+16>>1]=c;u[e+18>>1]=(c+x[e+8>>1]|0)-1;a=ea(1614,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}v[114578]=0;Z(1615,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}}d=1}vg(b)}jb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}vg(b);S(a|0);L()}function uM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=jb-16|0;jb=i;a:{if(!be(d&255)){break a}j=(B(b,896)+a|0)+1074984|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(oj(j)){break b}c=B(b,896)+a|0;d=c+1075060|0;if(!v[d>>2]){break a}c=v[c+1075072>>2];if(c&1024){break a}e=B(b,896)+a|0;f=e+1075004|0;e=e+1075008|0;if(!(v[f>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1304392|0;if(!sd(c)){break c}yi(v[c>>2],b,0);break a}c=fy(a,b);if((c|0)==65535){break a}l=B(c,896);c=a+1074984|0;a=l+c|0;vs(a,j);t[a+851|0]=0;t[a+827|0]=0;u[a+808>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;gt(a+810|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,896)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[f>>2]=0;v[e>>2]=0;break a}e=B(b,896)+a|0;m=v[e+1075088>>2];c=x[a+480192>>1]<c>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}h=d-1|0;c=x[dd(g+236|0,h)>>1];f=a+1074312|0;Eb(i+8|0,f,104);e:{if(Cb(i+8|0)){Eb(i,f,34);if(Cb(i)){break e}}d=w[fc(g+108|0,h)|0]}if((c-1&65535)>>>0<=3998){m=(B(c,104)+a|0)+484380|0;break d}Eb(i+8|0,f,43);if(!Cb(i+8|0)){break d}if(!zi(g)){break a}}if(w[e+1075073|0]&4){break a}f=a+1304392|0;n=a+1074312|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)?x[a+480188>>1]>c>>>0:0){break f}e=B(c,896)+a|0;if((b|0)!=(c|0)?x[e+1075792>>1]!=(q|0):0){break f}p=e+1075640|0;h=v[p>>2];if(!h){break f}k=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(w[h+17|0]-1|0){case 0:if(!d){break f}l=w[e+1075803|0]==(d|0)&(g|0)==(h|0);o=l;if(!g){break l}if(l){break i}break f;case 1:if(!m|v[e+1075088>>2]!=(m|0)){break f}if((g|0)==(h|0)){break g}Eb(i+8|0,n,104);if(!Cb(i+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}o=(g|0)==(h|0)}if(o){break g}break f}if(!g){break f}l=w[g+34|0];if(!l){break f}if((l|0)==w[h+34|0]){break h}break f}if((g|0)!=(h|0)){break f}}if(!w[g+34|0]){break g}}if(!w[e+1075803|0]|w[h+18|0]>2){break g}Eb(i+8|0,n,34);xl(a,c&65535,qO(k,Cb(i+8|0))+255|0,0);t[e+1075806|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:dn(a,k);v[e+1075672>>2]=0;if(!(w[e+1075073|0]&2)){break n}if(!sd(f)){break n}yi(v[f>>2],c&65535,1);break n;case 1:dn(a,k);if(!(w[e+1075073|0]&2)){break n}if(!sd(f)){break n}tk(v[f>>2],c&65535);break n;case 2:break o;default:break n}}k=e+1075072|0;h=v[k>>2];v[k>>2]=h|4096;if(!(h&512)){break n}if(!sd(f)){break n}Eb(i+8|0,n,105);if(Cb(i+8|0)){break n}tk(v[f>>2],c&65535)}if(v[e+1075672>>2]){break f}v[e+1075680>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;d=0;p:{if(!oj(j)){break p}if(!be(w[(B(b,896)+a|0)+1075803|0])){break p}q:{c=wl(a,b,2,1);if(c-251>>>0<5){break q}if(!c){break p}d=v[(B(c,160)+a|0)+906140>>2];if(!d){break q}Eb(i+8|0,n,34);e=(s=d,y=qO(j,Cb(i+8|0)),z=b,r=v[v[d>>2]+96>>2],nb[r](s|0,y|0,z|0)|0);break p}d=0}if(!(r=1,z=Kh(j),y=e,y?r:z)){break a}g=fy(a,b);if((g|0)==65535){break a}h=B(g,896)+a|0;c=h+1075072|0;m=h+1074984|0;r:{if(!(w[h+1075073|0]&2)){break r}if(!sd(f)){break r}yi(v[f>>2],g,1)}vs(m,j);v[c>>2]=v[c>>2]&-917505;t[h+1075835|0]=0;k=x[a+480188>>1];t[h+1075811|0]=0;u[h+1075792>>1]=b>>>0<k>>>0?b+1|0:0;s:{if(!((d|0)!=0&e)){break s}d=w[(B(b,896)+a|0)+1075804|0];if(d>>>0>3|(d|0)==1){break s}xl(a,b,255,0);t[(B(b,896)+a|0)+1075806|0]=0}t:{u:{switch(w[(B(b,896)+a|0)+1075804|0]){case 2:dn(a,m);if(!(w[c+1|0]&2)){break t}if(!sd(f)){break t}tk(v[f>>2],b);Eb(i+8|0,n,105);if(!Cb(i+8|0)){break t}zy(v[f>>2],b,g);break t;case 0:v[(B(g,896)+a|0)+1075680>>2]=0;d=v[c>>2];v[c>>2]=d|4096;if(!(d&512)){break t}if(!sd(f)){break t}yi(v[f>>2],b,1);break t;case 3:d=v[c>>2];v[c>>2]=d|4096;if(!(d&512)){break t}if(!sd(f)){break t}Eb(i+8|0,n,105);e=Cb(i+8|0);d=v[f>>2];if(e){zy(d,b,g);break t}tk(d,b);break t;case 1:break u;default:break t}}if(!(w[c+1|0]&2)){break t}if(!sd(f)){break t}zy(v[f>>2],b,g)}if(!v[(B(g,896)+a|0)+1075672>>2]){v[(B(g,896)+a|0)+1075680>>2]=0;v[c>>2]=v[c>>2]|2101248}a=B(b,896)+a|0;v[a+1075060>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075076|0;v[a>>2]=0;v[a+4>>2]=0}jb=i+16|0}function yI(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=jb-48|0;jb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Xb(k);v[j>>2]=0}v[114578]=0;Y(81);k=v[114578];v[114578]=0;b:{c:{if((k|0)==1){m=ab(71204,83324,83336,83440,71360,71464,71412,71304,71292,71608,71576,71544,71532,71180,0)|0;d:{e:{n=O()|0;if((n|0)==(ga(71204)|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=277;if((j|0)==1){break e}break b}if((ga(83324)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(83336)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(83440)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71360)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71464)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71412)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71304)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71292)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71608)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71576)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71544)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71532)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2109,j|0,k|0);j=v[114578];v[114578]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}o=ga(71180)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[114578]=0;R(2109,j|0,m|0);j=v[114578];v[114578]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}$()}o=!g;if(d){j=nb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=Zd(m);break f}o=Zd(34181)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=Zd(g);break g}g=Zd(34181)}v[i>>2]=g}g=v[l+44>>2];if(g){Xb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[114578]=0;R(1991,l+32|0,a|0);g=v[114578];v[114578]=0;i:{j:{if((g|0)!=1){k:{if(f){v[114578]=0;R(1992,f|0,l+32|0);g=v[114578];v[114578]=0;if((g|0)!=1){break k}break j}g=Tb(l+32|0);if(b){v[114578]=0;R(b|0,g|0,c|0);g=v[114578];v[114578]=0;if((g|0)==1){break j}break k}Wr(g,l)}yb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;yb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+4>>2]=248;v[l>>2]=37537;v[l+8>>2]=a?a:34181;a=v[13922];nG(a,37407,l);zr(a);$()}jb=l+48|0}function w9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=jb-128|0;jb=d;h=-1;a:{b:{c:{d:{if(!Gf(v[v[b>>2]-12>>2]+b|0)){break d}pf(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];bm(d+104|0);ak(b,d+104|0,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=Og(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;ej(b,d+8|0);break d}u[d+86>>1]=0;xf(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}bm(d+78|0);ak(b,d+78|0,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;xf(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Wb(d+112|0);v[114578]=0;f=W(722,b|0,e|0,65535)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}if(!f){break j}v[114578]=0;U(13,d- -64|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)!=1){break k}break b}e=Wb(d+112|0);v[114578]=0;f=W(724,b|0,e|0,255)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}if(!f){break i}v[114578]=0;U(13,d- -64|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}}Gb(a+40|0,d- -64|0);yb(d- -64|0);yb(e);u[d+62>>1]=0;xf(b,d+62|0);u[d+60>>1]=0;xf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Fi(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=gA(e);u[d+58>>1]=e;break l}xf(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Wb(d+112|0);v[114578]=0;u[d+40>>1]=0;Q(1618,b|0,d+40|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[114578]=0;g=W(722,b|0,e|0,65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}if(g){break q}break e}v[114578]=0;g=W(724,b|0,e|0,255)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}if(!g){break e}}v[114578]=0;U(13,d- -64|0,c|0,e|0);g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;g=Q(1619,i|0,d+40|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}Gb(g,d- -64|0);yb(d- -64|0);yb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}bm(d- -64|0);ak(b,d- -64|0,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(ZJ(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(d- -64|0);break f}if(!YJ(b,c)){break d}}c=a+16|0;r:{if(u[d+86>>1]<=2){if(ZJ(b,c)){break r}break d}if(!YJ(b,c)){break d}}l=a,m=Kb(a+16|0),v[l+36>>2]=m;u[d+56>>1]=0;xf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c+200&65535)>>>0>400){break d}u[d+54>>1]=0;xf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break d}v[d+48>>2]=0;Lo(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}bm(d+40|0);ak(b,d+40|0,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(Kb(c)>>>0>32767){break d}f=a+32|0;s:{if(!(z[f>>2]>C(0)?u[a+30>>1]>=1:0)){if(!x[a>>1]){break s}break d}t:{switch(x[a>>1]-1|0){case 0:case 2:break t;default:break s}}if(Kb(c)>>>0<u[a+30>>1]>>>0){break d}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=mt(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[Js(d+112|0,d+32|0,32408)>>2],v[l+36>>2]=m;Mo(a);h=1;if(x[a>>1]!=3){break d}if((cK(Kb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=kk(d+112|0);h=0;if(u[a+30>>1]>0){while(1){b=Pb(c,h-u[a+28>>1]|0);v[114578]=0;R(1620,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;c=Kb(c);v[114578]=0;u[d+34>>1]=(b+c|0)-1;u[d+30>>1]=0;ea(1614,a|0,e|0,f|0,d+32|0,d+30|0)|0;a=v[114578];v[114578]=0;h=1;if((a|0)!=1){Sf(e);break d}break h}yb(e);break d}yb(e);break d}b=P()|0;O()|0;Sf(e);break a}b=P()|0;O()|0}yb(e);break a}yb(e)}jb=d+128|0;return h|0}b=P()|0;O()|0;yb(e);break a}b=P()|0;O()|0;yb(e)}S(b|0);L()}function wG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;i=jb-560|0;jb=i;g=c;c=(c-3|0)/24|0;r=(c|0)>0?c:0;l=g+B(r,-24)|0;n=v[(e<<2)+52288>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=r-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+52304>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=l-24|0;h=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(i+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;a:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;o=(g|0)<1;if(!o){while(1){k=(i+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;b:{if(D(f)<2147483648){j=~~f;break b}j=-2147483648}f=+(j|0);m=m+f*-16777216;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}v[k>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=_h(f,q);f=f+H(f*.125)*-8;d:{if(D(f)<2147483648){k=~~f;break d}k=-2147483648}f=f-+(k|0);e:{f:{g:{u=(q|0)<1;h:{if(!u){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>t;s=h;h=j-(c<<t)|0;v[s+476>>2]=h;k=c+k|0;j=h>>y;break h}if(q){break g}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<1){break e}break f}j=2;if(f>=.5){break f}j=0;break e}i:{if(o){h=0;break i}c=0;w=1;while(1){h=(i+480|0)+(c<<2)|0;o=v[h>>2];s=h;j:{if(w){h=0;if(!o){break j}h=16777216-o|0}else{h=16777215-o|0}v[s>>2]=h;h=1}c=c+1|0;if((g|0)==(c|0)){break i}w=!h;continue}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+i|0;v[o+476>>2]=v[o+476>>2]&c}k=k+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-_h(1,q)}if(f==0){h=0;m:{c=g;if((n|0)>=(c|0)){break m}while(1){c=c-1|0;h=v[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break m}l=q;while(1){l=l-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break a}c=1;while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(r+g<<2)+52304>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=_h(f,24-l|0);n:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=q}v[(i+480|0)+(g<<2)>>2]=c}f=_h(1,l);q:{if((g|0)<=-1){break q}c=g;while(1){A[(c<<3)+i>>3]=f*+v[(i+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}if((g|0)<=-1){break q}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){r:{f=f+A[(c<<3)+55072>>3]*A[(a+c<<3)+i>>3];if((c|0)>=(n|0)){break r}h=c>>>0<d>>>0;c=c+1|0;if(h){continue}}break}A[(i+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<1){break v}f=A[(i+160|0)+(g<<3)>>3];c=g;while(1){m=f;a=c-1|0;d=(i+160|0)+(a<<3)|0;x=A[d>>3];f=x+f;A[(i+160|0)+(c<<3)>>3]=m+(x-f);A[d>>3]=f;d=(c|0)>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=A[(i+160|0)+(g<<3)>>3];c=g;while(1){m=f;a=c-1|0;d=(i+160|0)+(a<<3)|0;p=A[d>>3];f=p+f;A[(i+160|0)+(c<<3)>>3]=m+(p-f);A[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}p=0;if((g|0)<=1){break v}while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break t}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(i+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break s}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}jb=i+560|0;return k&7}function gda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-11360|0;jb=f;Jc(c);a:{b:{if(!Qb(c,4)){break b}c:{while(1){d:{vB(c,f+16|0);e:{if(!pd(f+16|0,20249,3)){d=f+4648|0;i=jb-16|0;jb=i;g=c;f:{if(Qb(c,7)){Yt(i+8|0,d);Bd(g,i+8|0);break f}g=jb-16|0;jb=g;k=jb-16|0;jb=k;h=d+7|0;while(1){ff(d);d=d+1|0;if((h|0)!=(d|0)){continue}break}jb=k+16|0;jb=g+16|0}jb=i+16|0;h=3;d=0;while(1){g=w[(f+4648|0)+h|0];if(g&128){break c}d=g|d<<7;h=h+1|0;if((h|0)!=7){continue}break}$b(c,d);break e}g:{if(pd(f+16|0,20253,3)){break g}if(!wQ(c,20257)){break g}$b(c,Cf(c)+16|0);break e}if(!pd(f+16|0,20263,3)){break e}if(!pd(f+16|0,20267,3)){break e}if(w[f+16|0]){break d}fg(c,2)}if(Qb(c,4)){continue}break b}break}if(yO(f+16|0)){break b}}h=0;break a}Jc(c);Rz(f+11336|0,c);h=v[f+11336>>2];v[114578]=0;c=T(414,f+11336|0)|0;d=v[114578];v[114578]=0;h:{i:{if((d|0)!=1){v[114578]=0;c=T(857,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break i}}h=P()|0;O()|0;break h}d=jb-16|0;jb=d;j=f+11320|0;v[j>>2]=0;v[j+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(358,j+8|0,d+12|0,d+8|0)|0;g=v[114578];v[114578]=0;j:{if((g|0)!=1){jb=d+16|0;break j}V(0)|0;O()|0;Ab();L()}Rb(f+4648|0,0,6668);v[114578]=0;Z(1239,f+4648|0);d=v[114578];v[114578]=0;k:{l:{m:{if((d|0)!=1){d=f+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=f+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[f+4624>>2]=0;v[f+4628>>2]=0;g=0;d=0;n:{o:{p:{while(1){v[114578]=0;i=Gg(460,h,l);k=v[114578];v[114578]=0;if((k|0)==1){break n}v[114578]=0;m=ea(1240,f+4648|0,c|0,i|0,f+16|0,f+4624|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break n}if((m|0)<0){break l}i=v[f+4624>>2];if((i|0)<0){break l}o=(m|0)<1;if(!(i?1:o)|!(i|m)){break l}q:{if((i|0)>=1){k=v[f+4636>>2];if((k|0)!=(g|0)?g:0){break l}i=v[f+4632>>2];if((i|0)!=(d|0)?d:0){break l}if((k|0)<1|i-1>>>0>1){break m}v[114578]=0;v[f+8>>2]=0;d=Gg(460,h,l);g=v[114578];v[114578]=0;if((g|0)==1){break q}v[114578]=0;v[f+4>>2]=d;d=W(1241,f+4624|0,f+8|0,f+4|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}d=v[d>>2];v[114578]=0;v[f+8>>2]=0;g=Gg(460,h,l);n=v[114578];v[114578]=0;if((n|0)==1){break p}v[114578]=0;v[f+4>>2]=g;g=W(1241,f+4624|0,f+8|0,f+4|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break p}c=c+d|0;d=h;g=v[g>>2];h=d-g|0;l=l-((g>>31)+(d>>>0<g>>>0)|0)|0;if(!o){p=f,q=cc(j),v[p+8>>2]=q;Md(f,f+8|0);v[114578]=0;aa(1242,j|0,v[f>>2],f+16|0,(f+16|0)+(B(i,m)<<1)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}}g=k;d=i}if((oc(j)>>>0)/(d>>>0)>>>0>268435456){break l}if((l|0)>0?1:(l|0)>=0?h:0){continue}break l}break}h=P()|0;O()|0;break k}h=P()|0;O()|0;break k}h=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break k}_(h|0)|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;g=k;d=i;if((c|0)!=1){break l}h=P()|0;O()|0;break k}h=P()|0;O()|0;break k}h=P()|0;O()|0;break k}g=k;d=i}h=0;r:{s:{t:{u:{v:{if(!g|!d){break v}if(md(j)){break v}if((oc(j)>>>0)/(d>>>0)>>>0>268435456){break v}v[114578]=0;Q(1243,a|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break r}if(!e){v[114578]=0;c=Q(85,f+16|0,20271)|0;i=v[114578];v[114578]=0;if((i|0)==1){break u}v[114578]=0;Q(371,((b<<5)+a|0)+946304|0,c|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break t}yb(c);v[114578]=0;c=B(b,104)+a|0;R(388,c+484380|0,0);i=v[114578];v[114578]=0;if((i|0)==1){break r}v[c+484404>>2]=g}g=B(b,104)+a|0;c=g+484380|0;p=c,q=(oc(j)>>>0)/(d>>>0)|0,v[p>>2]=q;i=g+484414|0;g=x[i>>1];u[i>>1]=(d|0)==2?g|65:g&65470|1;v[114578]=0;T(466,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}if(De(c)){d=bc(j);g=cc(j);b=v[(B(b,104)+a|0)+484400>>2];v[114578]=0;W(1244,d|0,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}}if(!e){b=v[a+480180>>2];v[114578]=0;U(1245,c|0,32,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}v[114578]=0;U(1246,c|0,a|0,0);a=v[114578];v[114578]=0;if((a|0)==1){break r}}h=De(c)}kC(j);Ec(f+11336|0);break a}h=P()|0;O()|0;break k}h=P()|0;O()|0;yb(c);break k}h=P()|0;O()|0;break k}h=P()|0;O()|0}kC(j)}Ec(f+11336|0);S(h|0);L()}jb=f+11360|0;return h|0}function YY(){var a=0,b=0,c=0,d=0,e=0;Ld(463264);v[115816]=64704;v[114578]=0;b=Q(2514,463280,28)|0;a=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[114578]=0;c=Q(85,463440,64693)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}Kb(b);rE(b);qE(b);Ld(462944);v[115736]=66128;v[114578]=0;R(2515,463264,462944);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462952);v[115738]=66160;v[114578]=0;R(2516,463264,462952);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462960);t[462972]=0;v[115742]=0;v[115740]=64724;d=462968,e=mo(),v[d>>2]=e;v[114578]=0;R(2517,463264,462960);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462976);v[115744]=65308;v[114578]=0;R(2518,463264,462976);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462984);v[115746]=65456;v[114578]=0;R(2519,463264,462984);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;Y(2520);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2521,463264,462992);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463008);v[115752]=65604;v[114578]=0;R(2522,463264,463008);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463016);v[115754]=65720;v[114578]=0;R(2523,463264,463016);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463024);u[231516]=11310;v[115756]=64824;Wb(463036);v[114578]=0;R(2524,463264,463024);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463056);v[115766]=46;v[115767]=44;v[115764]=64864;Wb(463072);v[114578]=0;R(2525,463264,463056);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463088);v[115772]=66192;v[114578]=0;R(2526,463264,463088);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463096);v[115774]=66436;v[114578]=0;R(2527,463264,463096);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463104);v[115776]=66648;v[114578]=0;R(2528,463264,463104);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463112);v[115778]=66880;v[114578]=0;R(2529,463264,463112);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;pE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2531,463264,463120);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463128);v[115782]=68012;v[114578]=0;R(2532,463264,463128);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463136);v[115784]=68128;v[114578]=0;R(2533,463264,463136);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463144);v[115786]=68244;v[114578]=0;R(2534,463264,463144);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;oE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2536,463264,463152);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;nE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2538,463264,463160);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;mE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2540,463264,463168);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;lE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2542,463264,463176);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463184);v[115798]=70404;v[115796]=67080;v[115798]=67128;v[114578]=0;R(2543,463264,463184);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463200);v[115802]=70440;v[115800]=67344;v[115802]=67392;v[114578]=0;R(2544,463264,463200);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;Y(2545);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2546,463264,463216);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;Y(2547);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2548,463264,463232);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;kE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2550,463264,463248);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463256);v[115814]=69136;v[114578]=0;R(2551,463264,463256);a=v[114578];v[114578]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c)}vE(b)}S(a|0);L()}v[115410]=463264;return 461640}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0,C=0;f=jb-48|0;jb=f;a:{b:{c:{d:{if(!c){break d}B=f,C=Gd(a),t[B+32|0]=C;g=f+32|0;d=b;e:{if(y[d+4>>2]<y[zb(d)>>2]){h=jb-16|0;jb=h;e=Mi(h,d,1);d=zb(d);j=v[e+4>>2];v[114578]=0;U(882,d|0,j|0,g|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[e+4>>2]=v[e+4>>2]+1;Mb(e);jb=h+16|0;break e}a=P()|0;O()|0;Mb(e);break a}h=jb-32|0;jb=h;j=zb(d);e=nh(h+8|0,Ki(d,xc(d)+1|0),xc(d),j);k=v[e+8>>2];v[114578]=0;U(882,j|0,k|0,g|0);g=v[114578];v[114578]=0;f:{g:{if((g|0)==1){break g}v[e+8>>2]=v[e+8>>2]+1;v[114578]=0;R(366,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}Rg(e);jb=h+32|0;break f}a=P()|0;O()|0;Rg(e);break a}}j=c-1|0;if(!j){break c}c=0;while(1){h:{i:{i=c&254;j:{if(!i){if(!Je(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){break j}break i}if((c&65535)>>>0<256){break i}}e=1;while(1){k:{l:{m:{c=i<<1&254;n:{if(c){h=i>>>0>127}else{if(!Je(a,f+32|0)){break n}d=w[f+32|0]<<1|1;c=d&255;h=d>>>0>255}e=h|e<<1;i=c<<1&254;if(i){break l}if(Je(a,f+32|0)){break m}}i=0;break k}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break k}if(c>>>0>127){continue}}break}o:{if((e|0)<=2){d=0;g=e-2|0;break o}c=Je(a,f+32|0);if(!c){break d}c=c?(w[f+32|0]|e<<8)-768|0:p;d=((c|0)>1279?2:1)+((c|0)>31999)|0;p=c^-1;g=0}c=i<<1&254;if(c){e=i>>>0>127}else{if(!Je(a,f+32|0)){break d}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}h=j;i=c<<1&254;if(i){c=c>>>0>127}else{if(!Je(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(g<<2|(e?2:0));if(!c){e=1;while(1){p:{q:{r:{c=i<<1&254;s:{if(c){g=i>>>0>127}else{if(!Je(a,f+32|0)){break s}g=w[f+32|0]<<1|1;c=g&255;g=g>>>0>255}e=g|e<<1;i=c<<1&254;if(i){break q}if(Je(a,f+32|0)){break r}}i=0;break p}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break p}if(c>>>0>127){continue}}break}c=e+2|0}g=h;h=c+d|0;e=0;if(g>>>0<h>>>0|(h|0)<1|(p|0)>-1){break b}e=0;if((0-xc(b)|0)>(p|0)){break b}B=f,C=cc(b),v[B+32>>2]=C;Md(f+40|0,f+32|0);t[f+24|0]=0;k=f+24|0;n=jb-32|0;jb=n;v[n+24>>2]=v[f+40>>2];c=b;d=v[c>>2];B=n,C=bc(c),v[B>>2]=C;e=am(n+24|0,n)+d|0;t:{u:{g=h;v:{if(!g){break v}d=v[zb(c)>>2];l=v[c+4>>2];if(g>>>0<=d-l>>>0){d=g;m=l-e|0;if(d>>>0>m>>>0){Pp(c,g-m|0,k);d=m;if(!d){break v}}q=jb-16|0;jb=q;u=c;x=l;s=v[c+4>>2];z=e;m=e+(s-(e+g|0)|0)|0;o=Mi(q,c,l-m|0);w:{x:{if(l>>>0>m>>>0){l=m;while(1){r=zb(u);A=v[o+4>>2];v[114578]=0;U(882,r|0,A|0,l|0);r=v[114578];v[114578]=0;if((r|0)==1){break x}v[o+4>>2]=v[o+4>>2]+1;l=l+1|0;if(x>>>0>l>>>0){continue}break}}Mb(o);Fp(z,m,s);jb=q+16|0;break w}a=P()|0;O()|0;Mb(o);break a}l=e;if(e>>>0<=k>>>0){k=y[c+4>>2]>k>>>0?g+k|0:k}Sh(l,d,k);break v}d=zb(c);d=nh(n,Ki(c,xc(c)+g|0),e-v[c>>2]|0,d);v[114578]=0;U(702,d|0,g|0,k|0);g=v[114578];v[114578]=0;if((g|0)==1){break u}v[114578]=0;e=W(877,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break u}Rg(d)}Ng(e);jb=n+32|0;break t}a=P()|0;O()|0;Rg(d);break a}B=f,C=cc(b),v[B+16>>2]=C;B=f,C=tz(f+16|0,h),v[B+24>>2]=C;B=f,C=cf(f+24|0,p),v[B+32>>2]=C;B=f,C=cc(b),v[B+16>>2]=C;B=f,C=tz(f+16|0,h),v[B+24>>2]=C;c=h;while(1){B=f,C=lw(f+32|0),v[B+16>>2]=C;d=w[v[f+16>>2]];B=f,C=lw(f+24|0),v[B+8>>2]=C;t[v[f+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}j=j-h|0;break h}if(!Je(a,f+32|0)){break d}e=f+32|0;c=b;y:{if(v[c+4>>2]!=v[zb(c)>>2]){g=jb-16|0;jb=g;d=Mi(g,c,1);c=zb(c);h=v[d+4>>2];v[114578]=0;U(571,c|0,h|0,e|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[d+4>>2]=v[d+4>>2]+1;Mb(d);jb=g+16|0;break y}a=P()|0;O()|0;Mb(d);break a}g=jb-32|0;jb=g;h=zb(c);d=nh(g+8|0,Ki(c,xc(c)+1|0),xc(c),h);k=v[d+8>>2];v[114578]=0;U(571,h|0,k|0,e|0);e=v[114578];v[114578]=0;z:{A:{if((e|0)==1){break A}v[d+8>>2]=v[d+8>>2]+1;v[114578]=0;R(366,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break A}Rg(d);jb=g+32|0;break z}a=P()|0;O()|0;Rg(d);break a}}j=j-1|0}if(!j){break c}c=i<<1;continue}}e=0;break b}e=1}jb=f+48|0;return e|0}S(a|0);L()}function vba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+4>>2]=0;v[a>>2]=20768;v[a+8>>2]=v[19815];b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;rp(a+24604|0);NL(a+24648|0,0);b=a+393352|0;v[b>>2]=8;v[b+4>>2]=0;u[b+4128>>1]=0;d=b+4120|0;v[d>>2]=0;v[d+4>>2]=0;d=b+4112|0;v[d>>2]=0;v[d+4>>2]=0;v[b+4104>>2]=0;v[b+4108>>2]=0;Rb(b+4132|0,0,40);uO(b+8|0,1024);Rb(b+4172|0,0,49824);Rb(b+53996|0,0,32832);v[a+480224>>2]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;l=Yx(a+480248|0);v[a+480272>>2]=0;d=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{while(1){v[114578]=0;b=T(1392,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}b=b+32|0;if((d|0)!=(b|0)){continue}break}b=jb-16|0;jb=b;f=a+484344|0;d=f;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1438,d+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;n:{if((d|0)!=1){jb=b+16|0;break n}break a}v[f+12>>2]=a;v[114578]=0;m=Q(1393,a+484360|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}d=a+900380|0;b=a+484380|0;while(1){v[114578]=0;b=Q(1013,b|0,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}b=b+104|0;if((d|0)!=(b|0)){continue}break}v[114578]=0;T(1394,a+901404|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break j}g=a+946300|0;h=a+906300|0;b=0;while(1){v[114578]=0;d=(B(b,160)+a|0)+906300|0;T(1395,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}b=b+1|0;if((b|0)!=250){continue}break}v[a+946300>>2]=0;d=a+1074304|0;i=a+946304|0;b=i;while(1){v[114578]=0;b=T(1163,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;Xx(a+1074312|0);v[114578]=0;b=da(1396)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;b=T(1397,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[a+1074328>>2]=b;v[114578]=0;T(1398,a+1074332|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;T(1399,a+1074376|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;n=W(1334,a+1304360|0,a|0,255)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}d=jb-16|0;jb=d;v[114578]=0;v[d+12>>2]=0;b=a+1304392|0;W(1402,b|0,d+12|0,d+8|0)|0;c=v[114578];v[114578]=0;o:{if((c|0)!=1){jb=d+16|0;break o}break a}d=b;c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=0;b=a+1304396|0;W(1403,b|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;p:{if((e|0)!=1){jb=c+16|0;break p}break a}o=Wb(a+1304400|0);p=fd(a+1304412|0);j=a+1304424|0;Wb(j);q=LL(a+1304436|0);c=jb-16|0;jb=c;k=a+1304500|0;e=k;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1404,e+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;q:{if((e|0)!=1){jb=c+16|0;break q}break a}t[a+1304512|0]=0;c=a+1304520|0;v[c>>2]=0;v[c+4>>2]=0;v[c+32>>2]=0;v[c+36>>2]=1072693248;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[a+1304560>>2]=0;Wo(a+12|0);sp(a+8204|0);sp(a+12300|0);c=a+1074408|0;v[c>>2]=4;v[c+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;KL(a+900380|0);v[114578]=0;Z(1400,i|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[114578]=0;c=T(1401,12)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}v[c>>2]=0;v[c+4>>2]=0;v[c+8>>2]=0;b=jb-16|0;jb=b;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1439,c+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;r:{if((d|0)!=1){jb=b+16|0;break r}break a}v[a+4>>2]=c;return a|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;if(!b){break d}while(1){d=an(d-160|0);if((h|0)!=(d|0)){continue}break}break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Wx(k);rs(q);yb(j);yb(p);yb(o);qs(b);ps(d);$o(n)}while(1){g=an(g-160|0);if((h|0)!=(g|0)){continue}break}}Rs(m)}Vx(f)}oe(l);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function j_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb+-64|0;jb=h;v[h+56>>2]=b;v[e>>2]=0;Bc(h,d);v[114578]=0;i=T(2457,h|0)|0;j=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Ob(h);S(a|0);L()}PE(a,f+24|0,h+56|0,c,e,i);break b}OE(a,f+16|0,h+56|0,c,e,i);break b}b=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=cj(a,v[h+56>>2],c,d,e,f,Tb(b),Tb(b)+(Fb(b)<<2)|0),v[k+56>>2]=l;break b}a=e;b=bi(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[16127];v[h+24>>2]=v[16126];v[h+28>>2]=g;g=v[16125];v[h+16>>2]=v[16124];v[h+20>>2]=g;g=v[16123];v[h+8>>2]=v[16122];v[h+12>>2]=g;g=v[16121];v[h>>2]=v[16120];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[16135];v[h+24>>2]=v[16134];v[h+28>>2]=g;g=v[16133];v[h+16>>2]=v[16132];v[h+20>>2]=g;g=v[16131];v[h+8>>2]=v[16130];v[h+12>>2]=g;g=v[16129];v[h>>2]=v[16128];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=bi(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=bi(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=bi(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=bi(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=bi(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=h+56|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!kr(a,b+8|0)){break H}if(!$j(i,8192,fl(a))){break H}Cm(a);continue}break}if(_j(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+56|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=er(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=lc(h,64544,44);k=g,l=cj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[16152];g=v[16151];v[h+8>>2]=v[16150];v[h+12>>2]=g;g=v[16149];v[h>>2]=v[16148];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=bi(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[16163];v[h+24>>2]=v[16162];v[h+28>>2]=g;g=v[16161];v[h+16>>2]=v[16160];v[h+20>>2]=g;g=v[16159];v[h+8>>2]=v[16158];v[h+12>>2]=g;g=v[16157];v[h>>2]=v[16156];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=bi(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=cj(a,v[h+56>>2],c,d,e,f,Tb(b),Tb(b)+(Fb(b)<<2)|0),v[k+56>>2]=l;break b}NE(f+20|0,h+56|0,c,e,i);break b}a=bi(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(_j(c,a+8|0)){break M}b=4;if((vm(i,fl(c))|0)!=37){break M}b=2;if(!_j(Cm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+56>>2]}jb=h- -64|0;return a|0}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=jb-976|0;jb=e;Jc(b);f=jb-16|0;jb=f;h=e+872|0;GS(f+8|0,h);j=Hb(f+8|0);d=b;i=nc(d,ac(f,f+8|0));if((j|0)==(i|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){HS(h)}a:{if(!d){break a}if(!KS(e+872|0)){break a}if(!Qb(b,hd(JS(e+872|0),mb))){break a}b:{if(!c){break b}Hd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480200>>2]=256;v[a+480204>>2]=8e5;d=Ub(e+96|0,12920);Gb(a+1304436|0,d);yb(d);d=Ub(e+96|0,12939);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;IS(e+24|0,2,e+872|4);Ic(e+96|0,e+24|0);Gb(a+1304400|0,e+96|0);yb(e+96|0);while(1){d=(g<<5)+a|0;f=d+480280|0;zg(f);h=f;f=(e+872|0)+g|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;g=g+1|0;if((g|0)!=16){continue}break}if(w[e+968|0]|w[e+969|0]<<8){My(a+1304424|0,b,w[e+968|0]|w[e+969|0]<<8,132,0)}g=0;f=jb-16|0;jb=f;d=jb-16|0;jb=d;h=e+96|0;gc(f+8|0,h,771);jb=d+16|0;j=Hb(f+8|0);d=b;i=nc(d,ac(f,f+8|0));if((j|0)==(i|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){f=jb-16|0;jb=f;Rb(h,0,771);jb=f+16|0}if(!d){break a}d=a+484360|0;_z(Vb(d),e+96|0,w[e+353|0],255,254);Oe(Vb(d),w[e+354|0]);Qc(b,w[e+919|0]|w[e+920|0]<<8);j=a+484344|0;o=c&1;c:{d:{while(1){d=(g<<1)+e|0;if(w[d+355|0]|w[d+356|0]<<8){ud(e+24|0,b,w[d+355|0]|w[d+356|0]<<8);d=w[d+355|0]|w[d+356|0]<<8;h=(d-2|0)/64|0;e:{if(!o){break e}v[114578]=0;f=W(404,j|0,g&65535,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!f){break e}v[114578]=0;i=T(389,e+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;Q(340,e+24|0,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}if(d>>>0>=66){p=h>>>0>1?h:1;k=0;while(1){d=_b(j,g);v[114578]=0;q=Q(497,d|0,k|0)|0;d=v[114578];v[114578]=0;l=0;if((d|0)==1){break d}while(1){v[114578]=0;R(595,e+80|0,e+24|0);d=v[114578];v[114578]=0;f:{g:{h:{if((d|0)!=1){d=B(l,6)+q|0;r=cd(e+80|0);f=Bf(e+80|0);m=Rh(e+80|0);n=w[e+80|0];if((n-1&255)>>>0>71){break h}t[d|0]=n+36;t[d+1|0]=w[r|0]+1;break g}break d}if(!(w[d|0]|w[f|0])){break f}}t[d+2|0]=1;s=d,z=(Fd(w[f|0],1,16)<<2)-4|0,t[s+4|0]=z}f=w[m|0]&15;t[d+5|0]=f;i:{j:{switch((w[m|0]>>>4|0)-3|0){case 0:t[d+5|0]=f<<2;break i;case 1:t[d+5|0]=(6/(f+1>>>0)|0)+1;break i;case 3:case 4:t[d+5|0]=f<<3;break i;case 7:t[d+4|0]=(f<<2)+4;t[d+2|0]=1;break i;case 8:t[d+5|0]=f|128;break i;case 9:break j;default:break i}}t[d+5|0]=(6/(f+1>>>0)|0)+1|13}t[d+3|0]=w[(w[m|0]>>>4|0)+12944|0];l=l+1|0;if((l|0)!=16){continue}break}k=k+1|0;if((p|0)!=(k|0)){continue}break}}d=_b(j,g);v[114578]=0;f=W(498,e+80|0,14,0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break d}f=Th(Ne(f,i?i>>>0<h-2>>>0?i+1|0:-1:-1));v[114578]=0;Q(499,d|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}}Bb(e+24|0)}g=g+1|0;if((g|0)!=256){continue}break}g=1;if(!(c&2)){break a}CT(b,e+72|0);g=0;while(1){k:{l:{if(!(w[e+72+(g>>>3)|0]>>>(g&7)&1)){g=g+1|0;break l}if(!Zz(b,e+24|0)){break b}g=g+1|0;u[a+480190>>1]=g;yg(e+8|0,1,e+24|0);Ic(e+80|0,e+8|0);c=x[a+480190>>1];v[114578]=0;Q(371,((c<<5)+a|0)+946304|0,e+80|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}yb(e+80|0);f=(B(g,104)+a|0)+484380|0;d=f;Ed(d,0);c=e+24|0;v[d>>2]=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d+4>>2]=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}if(!(!(w[c+47|0]&8)|y[d+8>>2]<=y[d+4>>2])){u[d+34>>1]=x[d+34>>1]|2}ad(e+80|0,t[e+70|0]&1?16:8,1,0,0);tg(e+80|0,f,b)}if((g|0)!=64){continue}break b}break}g=P()|0;O()|0;yb(e+80|0);break c}g=P()|0;O()|0;Bb(e+24|0)}S(g|0);L()}g=1}jb=e+976|0;return g|0}function $H(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=jb-256|0;jb=e;A[e+248>>3]=c;a:{if(nj(b)){break a}f=w[fk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}Cd(e+216|0);f=v[e+216>>2];Cd(e+200|0);h=ek(f,v[e+204>>2],b);Cd(e+216|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=qc(e+232|0,38235);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Hc(e+16|0,e+8|0)){d=ba(8)|0;v[114578]=0;R(2145,e+200|0,e+248|0);a=v[114578];v[114578]=0;f:{g:{h:{if((a|0)!=1){v[114578]=0;U(2120,e+216|0,39300,e+200|0);a=v[114578];v[114578]=0;if((a|0)==1){break h}mc(d,e+216|0);a=0;v[114578]=0;U(2010,d|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+216|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}yb(e+200|0);if(!a){break c}}ca(d|0);break c}if(!d){break e}d=ba(8)|0;v[114578]=0;f=Q(2143,e+168|0,b|0)|0;b=v[114578];v[114578]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[114578]=0;U(2120,e+184|0,39179,f|0);a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;U(2138,e+200|0,e+184|0,39315);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break p}v[114578]=0;R(2145,e+152|0,e+248|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}v[114578]=0;U(138,e+216|0,e+200|0,e+152|0);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break n}mc(d,e+216|0);v[114578]=0;U(2010,d|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+216|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}yb(e+152|0)}yb(e+200|0)}yb(e+184|0)}yb(f)}if(!a){break c}ca(d|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=qc(e+136|0,38235);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Hc(e+80|0,e+72|0)){d=ba(8)|0;v[114578]=0;R(2145,e+200|0,e+248|0);a=v[114578];v[114578]=0;r:{s:{t:{if((a|0)!=1){v[114578]=0;U(2120,e+216|0,39300,e+200|0);a=v[114578];v[114578]=0;if((a|0)==1){break t}mc(d,e+216|0);a=0;v[114578]=0;U(2010,d|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+216|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}yb(e+200|0);if(!a){break c}}ca(d|0);break c}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=qc(e+120|0,39022);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Hc(e- -64|0,e+56|0)){if(!w[a+28|0]){break e}c=A[e+248>>3];if(c<=4?c<=0:1){a=ba(8)|0;v[114578]=0;d=Q(85,e+216|0,39320)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}mc(a,d);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d);break c}b=yk(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;To(v[a>>2]);break e}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=qc(e+104|0,39040);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Hc(e+48|0,e+40|0)){if(!w[a+28|0]){break e}c=A[e+248>>3];if(c<=4?c<=0:1){a=ba(8)|0;v[114578]=0;d=Q(85,e+216|0,39341)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,d);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d);break c}b=P()|0;O()|0;ca(a|0);break c}b=yk(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;To(v[a>>2]);break e}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=qc(e+88|0,39137);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Hc(e+32|0,e+24|0)){break e}b=nn(A[e+248>>3]*65536);v[v[a+24>>2]+480236>>2]=b}jb=e+256|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function p_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=b;v[e>>2]=0;Bc(h+8|0,d);v[114578]=0;i=T(21,h+8|0)|0;j=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Ob(h+8|0);S(a|0);L()}SE(a,f+24|0,h+24|0,c,e,i);break b}RE(a,f+16|0,h+24|0,c,e,i);break b}b=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=dj(a,v[h+24>>2],c,d,e,f,Tb(b),Tb(b)+Fb(b)|0),v[k+24>>2]=l;break b}a=e;b=ci(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=ci(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=ci(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=ci(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=ci(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=ci(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=h+24|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!to(a,b+8|0)){break H}if(!Kg(i,8192,bk(a))){break H}hl(a);continue}break}if(gj(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+24|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=gr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[64463]|w[64464]<<8|(w[64465]<<16|w[64466]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[64460]|w[64461]<<8|(w[64462]<<16|w[64463]<<24);v[h+8>>2]=w[64456]|w[64457]<<8|(w[64458]<<16|w[64459]<<24);v[h+12>>2]=g;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[64471];v[h+8>>2]=w[64467]|w[64468]<<8|(w[64469]<<16|w[64470]<<24);k=h,l=dj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=ci(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=ci(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=dj(a,v[h+24>>2],c,d,e,f,Tb(b),Tb(b)+Fb(b)|0),v[k+24>>2]=l;break b}QE(f+20|0,h+24|0,c,e,i);break b}a=ci(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(gj(c,a+8|0)){break M}b=4;if((wm(i,bk(c))|0)!=37){break M}b=2;if(!gj(hl(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+24>>2]}jb=h+32|0;return a|0}function ne(a,b){var c=C(0),d=0,e=C(0),f=0,g=0,h=0,i=C(0),k=0,m=C(0),n=C(0),o=0,r=0,s=C(0),t=C(0),u=C(0);i=C(1);a:{b:{c:{h=(p(b),j(2));d=h&2147483647;d:{if(!d){break d}k=(p(a),j(2));if((k|0)==1065353216){break d}g=k&2147483647;c=C(a+b);if(!(d>>>0<2139095041?g>>>0<=2139095040:0)){break a}e:{f:{if((k|0)>-1){break f}o=2;if(d>>>0>1266679807){break e}if(d>>>0<1065353216){break f}f=150-(d>>>23|0)|0;r=d>>>f|0;o=0;if((d|0)!=r<<f){break e}o=2-(r&1)|0;break e}o=0}f=o;g:{if((d|0)!=1065353216){if((d|0)!=2139095040){break g}if((g|0)==1065353216){break d}c=(h|0)>-1?b:C(0);if(g>>>0>=1065353217){break a}c=(h|0)>-1?C(0):C(-b);break a}c=(h|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((h|0)==1073741824){break a}c=C(K(a));if(!((h|0)!=1056964608|(k|0)<0)){break a}e=C(D(a));if(!(g?(k&1073741823)!=1065353216:0)){i=(h|0)<0?C(C(1)/e):e;if((k|0)>-1){break d}if(!(f|g-1065353216)){a=C(i-i);c=C(a/a);break a}c=(f|0)==1?C(-i):i;break a}h:{if((k|0)>-1){break h}i:{switch(f|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}i=C(-1)}j:{if(d>>>0>=1291845633){c=(h|0)<0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(g>>>0<=1065353207){break a}c=(h|0)>0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(g>>>0>=1065353224){break a}a=C(e+C(-1));c=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));e=c;a=C(a*C(1.44268798828125));c=(l(2,(p(C(c+a)),j(2))&-4096),q());e=C(e-C(c-a));break j}d=g>>>0<8388608;k=d?(p(C(e*C(16777216))),j(2)):g;g=k&8388607;f=g|1065353216;k=(k>>23)+(d?-151:-127)|0;d=0;k:{if(g>>>0<1885298){break k}if(g>>>0<6140887){d=1;break k}f=g|1056964608;k=k+1|0}g=d<<2;a=z[g+52224>>2];n=(l(2,f),q());m=C(C(1)/C(a+n));s=C(n-a);e=C(s*m);c=(l(2,(p(e),j(2))&-4096),q());t=C(c*c);u=m;m=(l(2,((f>>>1&536866816)+(d<<21)|0)+541065216|0),q());n=C(u*C(C(s-C(m*c))-C(C(n-C(m-a))*c)));a=C(e*e);m=C(C(n*C(e+c))+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(t+C(3))+m)),j(2))&-4096),q());e=C(C(n*a)+C(e*C(m-C(C(a+C(-3))-t))));c=C(c*a);a=(l(2,(p(C(e+c)),j(2))&-4096),q());n=z[g+52240>>2];e=C(z[g+52232>>2]+C(C(C(e-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(a*C(.9619140625));m=C(k|0);c=(l(2,(p(C(C(n+C(e+a))+m)),j(2))&-4096),q());e=C(e-C(C(C(c-m)-n)-a))}n=(l(2,h&-4096),q());a=C(c*n);b=C(C(e*b)+C(C(b-n)*c));c=C(a+b);f=(p(c),j(2));if((f|0)>=1124073473){break c}l:{m:{if((f|0)==1124073472){o=134;if(!(C(b+C(4.299566569443414e-8))>C(c-a))){break m}break c}h=f&2147483647;if(!(!(b<=C(c-a))|(f|0)!=-1021968384)|h>>>0>=1125515265){break b}d=0;if(h>>>0<1056964609){break l}o=h>>>23|0}h=(8388608>>>o-126|0)+f|0;g=h>>>23&255;d=(h&8388607|8388608)>>>150-g|0;d=(f|0)<0?0-d|0:d;a=C(a-(l(2,h&-8388608>>g-127),q()));f=(p(C(b+a)),j(2))}c=(l(2,f&-32768),q());e=C(c*C(.693145751953125));c=C(C(c*C(14286065379565116e-22))+C(C(b-C(c-a))*C(.6931471824645996)));a=C(e+c);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));m=C(C(a*b)/C(b+C(-2)));b=C(c-C(a-e));a=C(C(a-C(m-C(b+C(a*b))))+C(1));f=(p(a),j(2))+(d<<23)|0;n:{if((f|0)<=8388607){a=zG(a,d);break n}a=(l(2,f),q())}i=C(i*a)}c=i;break a}c=C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function pda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-48|0;jb=e;a:{b:{c:{i=a+24|0;d:{if(sd(i)){break d}h=a+4|0;k=Fb(h);a=jb-48|0;jb=a;g=a+40|0;b=g;v[b>>2]=-1;v[b+4>>2]=-1;e:{if(t[85360]&1){break e}if(!wd(85360)){break e}v[114578]=0;T(108,85356)|0;b=v[114578];v[114578]=0;if((b|0)!=1){vd(85360);break e}a=P()|0;O()|0;pe(85360);S(a|0);L()}b=jb-48|0;jb=b;v[114578]=0;c=Q(2839,0,b+32|0)|0;d=v[114578];v[114578]=0;f:{g:{h:{if((d|0)==1){break h}if(c){v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break h}a=v[114552];v[114578]=0;R(2826,a|0,70697);a=v[114578];v[114578]=0;if((a|0)!=1){break g}break h}c=Sq(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;d=Sq(b+8|0,b+4|0);v[114578]=0;c=vD(2841,c,d);d=mb;f=v[114578];v[114578]=0;if((f|0)!=1){break f}}V(0)|0;O()|0;Ab()}L()}v[b+24>>2]=c;v[b+28>>2]=d;c=pk(b+40|0,b+24|0);d=v[c+4>>2];jb=b+48|0;v[a+8>>2]=v[c>>2];v[a+12>>2]=d;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;c=jb-16|0;jb=c;b=jb-16|0;jb=b;l=b,m=Hma(v[a+16>>2],v[a+20>>2],1e3,0),v[l>>2]=m;v[b+4>>2]=mb;d=pk(b+8|0,b);f=v[d+4>>2];jb=b+16|0;jb=c+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;b=v[a+24>>2];f=b<<8&16711680|b<<24;c=v[a+28>>2];j=(c<<24|b>>>8)&65280;d=((c&255)<<24|b>>>8)&-16777216|((c&16777215)<<8|b>>>24)&16711680|(c>>>8&65280|c>>>24);t[a+32|0]=d;t[a+33|0]=d>>>8;t[a+34|0]=d>>>16;t[a+35|0]=d>>>24;b=(c<<8|b>>>24)&255|j|f;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;NM(g,a+24|0,zb(a+24|0));b=jb-48|0;jb=b;v[114578]=0;c=Q(2839,1,b+32|0)|0;d=v[114578];v[114578]=0;i:{j:{k:{if((d|0)==1){break k}if(c){v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break k}a=v[114552];v[114578]=0;R(2826,a|0,70734);a=v[114578];v[114578]=0;if((a|0)!=1){break j}break k}c=Sq(b+16|0,b+32|0);d=Sq(b+8|0,b+32|4);v[114578]=0;c=vD(2842,c,d);d=mb;f=v[114578];v[114578]=0;if((f|0)!=1){break i}}V(0)|0;O()|0;Ab()}L()}v[b+24>>2]=c;v[b+28>>2]=d;c=pk(b+40|0,b+24|0);d=v[c+4>>2];jb=b+48|0;v[a+8>>2]=v[c>>2];v[a+12>>2]=d;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;c=jb-16|0;jb=c;b=jb-16|0;jb=b;d=v[a+20>>2];v[b>>2]=v[a+16>>2];v[b+4>>2]=d;d=pk(b+8|0,b);f=v[d+4>>2];jb=b+16|0;jb=c+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;b=v[a+24>>2];f=b<<8&16711680|b<<24;c=v[a+28>>2];j=(c<<24|b>>>8)&65280;d=((c&255)<<24|b>>>8)&-16777216|((c&16777215)<<8|b>>>24)&16711680|(c>>>8&65280|c>>>24);t[a+32|0]=d;t[a+33|0]=d>>>8;t[a+34|0]=d>>>16;t[a+35|0]=d>>>24;b=(c<<8|b>>>24)&255|j|f;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;NM(g,a+24|0,zb(a+24|0));c=v[g>>2];g=v[g+4>>2];jb=a+48|0;if(k){b=jn(e+32|0);v[114578]=0;v[e+16>>2]=g;R(87,b|0,e+16|0);a=v[114578];v[114578]=0;l:{m:{n:{if((a|0)!=1){v[114578]=0;v[e+16>>2]=c;R(87,b|0,e+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}if(Fb(h)){a=0;while(1){c=w[kc(h,a)|0];v[114578]=0;v[e+16>>2]=c;R(87,b|0,e+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}a=a+1|0;if(Fb(h)>>>0>a>>>0){continue}break}}a=bc(b);c=cc(b);v[114578]=0;c=W(88,e+16|0,a|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;R(89,e+8|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}Fs(i,e+8|0);wf(e+8|0);oe(c);oe(b);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;oe(c);break a}mb=c;v[e+16>>2]=g;v[e+20>>2]=mb;b=e+32|0;a=jn(b);v[114578]=0;U(93,b|0,e+16|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)==1){b=P()|0;O()|0;oe(a);S(b|0);L()}v[114578]=0;R(89,e+8|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}Fs(i,e+8|0);wf(e+8|0);oe(b)}jb=e+48|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}oe(b);S(a|0);L()}function mM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;d=c&15;f=B(b,896)+a|0;e=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(v[a+480180>>2]==33554432){c=B(b,896)+a|0;e=c+1075684|0;if(!v[e>>2]){break a}c=v[c+1075088>>2];if(!c){break a}f=B(b,896)+a|0;d=x[B(d,24)+21024>>1];b=v[c+24>>2];g=Hma(b,b>>31,1712,0);c=(d>>>1|0)+g|0;b=mb;b=Ac(Ima(c,c>>>0<g>>>0?b+1|0:b,d,0),mb);v[f+1075688>>2]=b;k=e,l=ag(a,w[f+1075803|0],0,b),v[k>>2]=l;break a}if(v[a+480180>>2]!=64){b=B(b,896)+a|0;c=d<<28>>24;v[b+1075752>>2]=c;d=x[(d<<1)+21456>>1];v[b+1075688>>2]=d;e=b+1075684|0;if(!v[e>>2]){break a}k=e,l=ag(a,w[b+1075803|0],c,d),v[k>>2]=l;break a}a=B(b,896)+a|0;b=v[a+1075088>>2];if(!b){break a}v[a+1075688>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075826|0]=c&3;break a}Eb(h+8|0,a+1074312|0,21);if(Cb(h+8|0)){t[(B(b,896)+a|0)+1075826|0]=d>>>0<4?d:0;break a}t[(B(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075829|0]=c&3;break a}Eb(h+8|0,a+1074312|0,21);if(Cb(h+8|0)){t[(B(b,896)+a|0)+1075829|0]=d>>>0<4?d:0;break a}t[(B(b,896)+a|0)+1075829|0]=c&7;break a;case 4:Eb(h+8|0,a+1074312|0,21);if(Cb(h+8|0)){a=B(b,896)+a|0;t[a+1075825|0]=0;t[a+1075832|0]=d>>>0<4?d:0;break a}t[(B(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];if(d>>>0>255){break a}e=a+1304392|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(d,896)+a|0;c:{if((i|0)!=x[c+1075792>>1]){break c}d:{e:{switch(j|0){case 0:dn(a,c+1074984|0);if(!(w[c+1075073|0]&2)){break d}if(!sd(e)){break d}tk(v[e>>2],d&65535);break d;case 1:g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!sd(e)){break d}tk(v[e>>2],d&65535);break d;default:break e}}v[c+1075680>>2]=0;g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!sd(e)){break d}yi(v[e>>2],d&65535,1)}f=v[c+1075640>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}nb[v[v[g>>2]+88>>2]](g,f,w[c+1075803|0]+255|0,0,b)}d=d+1|0;if((d&65535)!=256){continue}break}break a}oO(e,d,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}zl(a,e,d,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(d&15){case 0:v[e+88>>2]=v[e+88>>2]&-257;break f;case 1:v[e+692>>2]=128;v[e+88>>2]=v[e+88>>2]|256;break f;case 8:v[e+88>>2]=v[e+88>>2]&-25165825|16777216;break f;case 9:v[e+88>>2]=v[e+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[e+88>>2]=v[e+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[e+76>>2]|(v[e>>2]|v[e+4>>2])){break h}if(!(k=Tf(e+810|0),l=1,m=w[e+88|0]&2,m?k:l)){break h}a=e;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[e+88>>2]=v[e+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,896)+a|0;t[c+1075840|0]=d;Eb(h+8|0,a+1074312|0,35);if(Cb(h+8|0)){break a}if(!Tf(c+1075794|0)){break a}b=v[(B(b,896)+a|0)+1075060>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 11:i:{if(d){break i}if(v[a+480180>>2]&16777248){d=1;break i}if(v[a+480180>>2]==2){break a}d=0}Eb(h+8|0,a+1074312|0,30);c=a;if(Cb(h+8|0)){a=1}else{a=v[a+480180>>2]==2}dy(c,b,d,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,896)+a|0)+1075848|0]=d}jb=h+16|0}function C2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-352|0;jb=d;a:{if(nj(b)){break a}e=w[fk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}rk(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}Cd(d+320|0);e=v[d+320>>2];Cd(d+304|0);e=ek(e,v[d+308>>2],b);Cd(d+320|0);b:{c:{d:{e:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=qc(d+336|0,38235);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114578]=0;c=Q(85,d+320|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}e=0;if(!c){break e}a=ba(8)|0;v[114578]=0;c=Q(2143,d+304|0,b|0)|0;b=v[114578];v[114578]=0;f:{g:{h:{if((b|0)!=1){v[114578]=0;U(2120,d+320|0,39179,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}mc(a,d+320|0);e=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(d+320|0);break g}b=P()|0;O()|0;break f}b=P()|0;e=1;O()|0}yb(c);if(!e){break c}}ca(a|0);break c}if(v[e+4>>2]){a=ba(8)|0;v[114578]=0;c=Q(85,d+320|0,39193)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=qc(d+288|0,38235);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Hc(d+152|0,d+144|0)){a=ba(8)|0;v[114578]=0;c=Q(85,d+320|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=qc(d+272|0,38917);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;i:{if(!Hc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=qc(d+256|0,39214);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Hc(d+120|0,d+112|0)){break i}}e=w[a+60|0]!=0;break e}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=qc(d+240|0,38935);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;j:{if(!Hc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=qc(d+224|0,39232);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Hc(d+88|0,d+80|0)){break j}}e=w[a+61|0]!=0;break e}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=qc(d+208|0,38954);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Hc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break e}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=qc(d+192|0,38972);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break e}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=qc(d+176|0,38996);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break e}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=qc(d+160|0,39070);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Hc(d+24|0,d+16|0)){break e}e=v[v[a+24>>2]+24668>>2]!=0}jb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-272|0;jb=e;d=e+24|0;g=jb-48|0;jb=g;Rz(g+24|0,b);v[114578]=0;R(703,g+8|0,g+24|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){break b}v[114578]=0;R(704,g+16|0,g+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=v[g+16>>2];f=v[g+20>>2];v[114578]=0;W(705,d|0,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}Ec(g+24|0);jb=g+48|0;break a}a=P()|0;O()|0;Ec(g+24|0);S(a|0);L()}v[114578]=0;g=W(673,e+128|0,e+24|0,8)|0;b=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((b|0)!=1){yb(e+24|0);if(c>>>0<2189){break i}v[114578]=0;b=Q(682,e+24|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}v[114578]=0;c=Q(683,e+8|0,14349)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}v[114578]=0;v[e>>2]=19468288;v[e+4>>2]=0;U(684,b|0,c|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break A}Ib(c);v[114578]=0;t[e|0]=0;c=Q(683,e+8|0,14357)|0;d=v[114578];v[114578]=0;if((d|0)==1){break k}d=0;v[114578]=0;W(685,b|0,e|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break z}Ib(c);if(!w[e|0]){v[114578]=0;d=T(686,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[114578]=0;c=Q(683,e+8|0,14368)|0;h=v[114578];v[114578]=0;if((h|0)==1){break x}v[114578]=0;X(687,b|0,f|0,c|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break w}Ib(c);v[114578]=0;c=Q(683,e+8|0,14370)|0;f=v[114578];v[114578]=0;if((f|0)==1){break v}v[114578]=0;X(688,b|0,a|0,c|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break u}Ib(c);v[114578]=0;c=Q(683,e+8|0,14372)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}v[114578]=0;d=a+484360|0;aa(689,b|0,d|0,c|0,690)|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}Ib(c);v[114578]=0;c=Q(683,e+8|0,14374)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[114578]=0;aa(691,b|0,a+484344|0,c|0,692)|0;f=v[114578];v[114578]=0;if((f|0)==1){break q}Ib(c);v[114578]=0;f=T(686,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break p}v[114578]=0;c=Q(683,e+8|0,14380)|0;h=v[114578];v[114578]=0;if((h|0)==1){break o}v[114578]=0;X(693,b|0,d|0,c|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break n}Ib(c);if(v[b>>2]&1073741824){v[114578]=0;c=Q(2,e+8|0,14388)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}v[114578]=0;U(646,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}yb(c)}vg(b);break h}a=P()|0;O()|0;yb(e+24|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;yb(c);break j}a=P()|0;O()|0}vg(b);break d}b=fd(e+24|0);d=v[a+4>>2];v[114578]=0;f=T(686,a|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}v[114578]=0;d=aa(694,d|0,g|0,b|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}C:{if((d|0)!=1){v[114578]=0;c=Q(2,e+8|0,14437)|0;d=v[114578];v[114578]=0;D:{if((d|0)!=1){v[114578]=0;U(646,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break D}yb(c);break C}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(c);break f}v[114578]=0;d=T(686,a|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;X(695,g|0,a|0,d|0,c>>>0<2188|0);a=v[114578];v[114578]=0;if((a|0)==1){break g}}yb(b)}If(g);jb=e+272|0;return}a=P()|0;O()|0}yb(b);break d}a=P()|0;O()|0}If(g)}S(a|0);L()}function GU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-576|0;jb=e;Jc(b);g=jb-16|0;jb=g;f=e+72|0;HB(g+8|0,f);i=Hb(g+8|0);d=b;h=nc(d,ac(g,g+8|0));if((i|0)==(h|0)){$b(d,Hb(g+8|0))}jb=g+16|0;d=(h|0)==(i|0);if(!d){IB(f)}a:{if(!d){break a}if(!NB(e+72|0)){break a}b:{if(!c){break b}if(!Qb(b,hd(MB(e+72|0),mb))){break a}Hd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;d=Ub(e+40|0,11897);Gb(a+1304436|0,d);yb(d);d=Ub(e+40|0,11910);Gb(a+1304448|0,d);yb(d);Mc(a+1304460|0,x[e+72>>1]==26217?11897:11914);v[a+1304496>>2]=4;d=w[e+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){g=1;i=1;while(1){h=jb-16|0;jb=h;d=jb-16|0;jb=d;f=e+40|0;gc(h+8|0,f,25);jb=d+16|0;k=Hb(h+8|0);d=b;j=nc(d,ac(h,h+8|0));if((k|0)==(j|0)){$b(d,Hb(h+8|0))}jb=h+16|0;if((j|0)!=(k|0)){d=jb-16|0;jb=d;t[f|0]=0;t[f+1|0]=0;t[f+2|0]=0;t[f+3|0]=0;t[f+4|0]=0;t[f+5|0]=0;t[f+6|0]=0;t[f+7|0]=0;t[f+24|0]=0;t[f+16|0]=0;t[f+17|0]=0;t[f+18|0]=0;t[f+19|0]=0;t[f+20|0]=0;t[f+21|0]=0;t[f+22|0]=0;t[f+23|0]=0;t[f+8|0]=0;t[f+9|0]=0;t[f+10|0]=0;t[f+11|0]=0;t[f+12|0]=0;t[f+13|0]=0;t[f+14|0]=0;t[f+15|0]=0;jb=d+16|0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}d=(B(g,104)+a|0)+484380|0;Ed(d,0);v[d+24>>2]=8363;v[d>>2]=w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24);v[d+4>>2]=w[e+57|0]|w[e+58|0]<<8|(w[e+59|0]<<16|w[e+60|0]<<24);f=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);f=f>>>0>y[d>>2]?v[d+4>>2]?f:0:f;v[d+8>>2]=f;if(f){u[d+34>>1]=2;on(d)}Qi(e+8|0,2,e+40|0);Ic(e+24|0,e+8|0);v[114578]=0;Q(371,((g<<5)+a|0)+946304|0,e+24|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}yb(e+24|0);i=i+1|0;g=i&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}d=e+72|2;LB(e+24|0,3,d,36);Ic(e+40|0,e+24|0);Gb(a+1304400|0,e+40|0);yb(e+40|0);g=0;xO(a+1304424|0,Db(d),108,36,0);d=a+484360|0;KB(Vb(d),e+185|0,128);if(x[rc(Vb(d),w[e+184|0])>>1]<w[e+183|0]){break d}break c}a=P()|0;O()|0;yb(e+24|0);S(a|0);L()}Oe(Vb(d),w[e+184|0])}while(1){d=(g<<5)+a|0;zg(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;if((g|0)!=8){continue}break}h=a+484344|0;$f(h,w[e+183|0]);m=1;if(w[e+183|0]){n=c&1;f=0;while(1){f:{g:{if(n){if(rg(h,f&65535,64)){break g}}$b(b,1536);break f}v[e+24>>2]=-1;v[e+28>>2]=-1;k=0;while(1){g=Rn(_b(h,f),k);i=0;while(1){hq(e+40|0,b);d=cd(e+40|0);l=Bf(e+40|0);j=w[d|0];d=w[e+40|0];if(d>>>0<=253){t[g|0]=(d>>>2|0)+37;t[g+1|0]=(d<<4&48|j>>>4)+1;t[(e+24|0)+i|0]=255;d=w[e+40|0]}if((d|0)!=255){t[g+2|0]=1;t[g+4|0]=(((j&15)<<6|8)>>>0)/15}j=(e+24|0)+i|0;h:{i:{d=w[l|0];j:{if((d|0)!=255){t[j|0]=d;if(d&15|(d|0)==48){break j}break i}d=w[j|0];if((d|0)==255){break h}}l=d&15;t[g+5|0]=l;k:{if(d<<24>>24<0){break k}d=d>>>4|0;t[g+3|0]=w[d+11923|0];l:{switch(d-3|0){case 0:t[g+5|0]=l|32;break i;case 1:t[g+5|0]=B(l,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(l|0){case 0:t[g+5|0]=79;break h;case 1:break m;default:break k}}t[g+5|0]=244;break h}t[g+3|0]=0;break h}t[j|0]=255}g=g+6|0;i=i+1|0;if((i|0)!=8){continue}break}k=k+1|0;if((k|0)!=64){continue}break}d=(e+72|0)+f|0;g=d;if(w[d+369|0]<63){ql(_b(h,f),Th(Ne(Qn(e+40|0,14,0),w[g+369|0])))}ql(_b(h,f),Th(Qn(e+40|0,16,w[d+241|0])))}f=f+1|0;if(f>>>0<w[e+183|0]){continue}break}}if(!(c&2)){break a}g=1;c=ad(e+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){tg(c,(B(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}}m=1}jb=e+576|0;return m|0}function fS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-144|0;jb=f;i=jb-16|0;jb=i;j=i+8|0;e=jb-16|0;jb=e;v[114578]=0;k=f+128|0;h=k;T(726,h+4|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{if((g|0)!=1){v[114578]=0;v[e+12>>2]=0;W(727,h+8|0,e+12|0,j|0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break c}break b}break b}m=h,n=hc(h),v[m>>2]=n;jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=i+16|0;d:{e:{f:{if(d){v[114578]=0;U(711,a|0,k|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break f}break e}v[114578]=0;U(712,a|0,k|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break e}}h=Gv(f+112|0);if(x[b+480192>>1]){c=1;j=1;while(1){v[114578]=0;u[f+110>>1]=0;Q(713,a|0,f+110|0)|0;d=v[114578];v[114578]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){v[114578]=0;d=Q(714,k|0,f+110|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}v[f+104>>2]=d;i=((c<<2)+b|0)+900380|0;if(!v[i>>2]){break g}c=Hi(k);v[114578]=0;v[f+88>>2]=c;c=Q(715,f+104|0,f+88|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break E}if(!c){break k}v[114578]=0;c=T(716,f+104|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}v[114578]=0;c=Q(4,f+88|0,c+4|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}v[114578]=0;d=Q(2,f+72|0,14549)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}e=Hp(c,d);yb(d);if(e){break v}d=v[b+4>>2];v[114578]=0;d=Q(717,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break B}v[v[i>>2]+44>>2]=d;if(!v[v[i>>2]+44>>2]){break C}break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}v[114578]=0;d=Q(2,f+72|0,14569)|0;e=v[114578];v[114578]=0;if((e|0)==1){break A}F:{G:{if(Hp(c,d)){yb(d);break G}v[114578]=0;e=Q(2,f+56|0,14595)|0;g=v[114578];v[114578]=0;if((g|0)==1){break z}g=Hp(c,e);yb(e);yb(d);if(!g){break F}}v[114578]=0;R(718,f+72|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break y}e=v[b+4>>2];d=Gp(f+48|0,f+72|0);v[114578]=0;e=Q(719,e|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break x}bg(d);bg(f+72|0);if(e){break h}}g=bc(h);l=cc(h);d=c;e=jb-16|0;jb=e;v[e>>2]=l;v[e+8>>2]=g;H:{if(!Jb(e+8|0,e)){break H}while(1){if(Hp(v[e+8>>2],d)){break H}zn(e+8|0);if(Jb(e+8|0,e)){continue}break}}jb=e+16|0;v[f+72>>2]=v[e+8>>2];m=f,n=cc(h),v[m+56>>2]=n;if(!rl(f+72|0,f+56|0)){break v}v[114578]=0;R(720,h|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){break w}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;yb(d);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;bg(d);bg(f+72|0);break l}v[114578]=0;d=Q(2,f+16|0,14601)|0;e=v[114578];v[114578]=0;if((e|0)==1){break u}v[114578]=0;U(721,f+32|0,d|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break t}v[114578]=0;e=Q(2,f|0,14610)|0;g=v[114578];v[114578]=0;if((g|0)==1){break s}v[114578]=0;U(3,f+56|0,f+32|0,e|0);g=v[114578];v[114578]=0;if((g|0)==1){break r}g=Ky(f+72|0,f+56|0);v[114578]=0;R(624,b|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break q}yb(f+72|0);yb(f+56|0);yb(e);yb(f+32|0);yb(d)}v[v[i>>2]+44>>2]=0;break h}b=P()|0;O()|0;break l}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;break p}b=P()|0;O()|0;yb(f+72|0);yb(f+56|0)}yb(e)}yb(f+32|0)}yb(d);break l}b=P()|0;O()|0}yb(c);break i}if(!v[i>>2]){break g}v[v[i>>2]+44>>2]=0;break g}b=P()|0;O()|0}bl(h);break d}yb(c)}j=j+1|0;c=j&65535;if(c>>>0<=x[b+480192>>1]){continue}break}}bl(h);_R(k);jb=f+144|0;return}b=P()|0;O()|0}_R(k);S(b|0);L()}function _f(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=jb-112|0;jb=k;l=h;o=i&2147483647;m=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(m|0)==-1;r=d;p=(c|0)==(m|0)&b>>>0>j>>>0|c>>>0>m>>>0;n=d+p|0;m=e&2147483647;j=m;j=n>>>0<p>>>0?j+1|0:j;p=n-1|0;a:{b:{j=j-(n>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;n=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(n|0)!=-1;p=(g|0)==(n|0)&f>>>0>j>>>0|g>>>0>n>>>0;n=p+l|0;j=o;j=n>>>0<p>>>0?j+1|0:j;p=n;n=n-1|0;j=j-(p>>>0<1)|0;if((n|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(n|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(m|0)==2147418112?!(b|c):m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|m))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}q=(l|0)==(r|0)&(m|0)==(o|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:(m|0)==(o|0)&l>>>0>r>>>0|m>>>0<o>>>0;j=q;n=j?f:b;o=j?g:c;l=j?i:e;r=l;m=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|m);i=d<<6;l=E(d?n:m)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;qf(k+96|0,n,o,m,j,d-15|0);m=v[k+104>>2];n=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;qf(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=m;d=j<<3|b>>>29;m=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}qf(k- -64|0,b,c,h,i,128-d|0);Gm(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=m;p=s|524288;b=n;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1?1:(q|0)<=-1){o=e;b=c-e|0;m=h;n=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=n-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<m>>>0)+i|0)|0)-(e>>>0>n>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;qf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;l=l+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}if((l|0)>=1){e=l}else{qf(k+16|0,b,c,h,i,l+127|0);Gm(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2];e=0}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;e:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break e}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;jb=k+112|0}function ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-720|0;jb=e;Jc(b);f=jb-16|0;jb=f;i=e+104|0;pT(f+8|0,i);h=Hb(f+8|0);g=b;j=nc(g,ac(f,f+8|0));if((h|0)==(j|0)){$b(g,Hb(f+8|0))}jb=f+16|0;g=(h|0)==(j|0);if(!g){qT(i)}a:{if(!g){break a}if(!rT(e+104|0)){break a}b:{if(!c){break b}Hd(a,67108864);vi(a);d=w[e+129|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Ub(e,12631);Gb(a+1304436|0,d);yb(d);d=Ub(e,12643);Gb(a+1304448|0,d);yb(d);g=Ub(e+88|0,12648);v[114578]=0;R(219,e- -64|0,g|0);d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[e+84>>2]=w[e+128|0]>>>4;d=w[e+128|0];v[114578]=0;v[e+80>>2]=d&15;X(534,e|0,e- -64|0,e+84|0,e+80|0);d=v[114578];v[114578]=0;if((d|0)!=1){Gb(a+1304460|0,e);yb(e);Ib(e- -64|0);yb(g);v[a+1304496>>2]=2;In(Vb(a+484360|0),e+152|0,w[e+151|0]+1|0,65535,65535);g=0;while(1){d=g+1|0;i=B(d,104)+a|0;j=i+484380|0;Ed(j,1);f=(e+104|0)+(g<<2)|0;h=w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24);v[j>>2]=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);h=w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24);k=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);v[i+484384>>2]=k;h=w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24);v[i+484388>>2]=k+(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24));if(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24)){f=i+484414|0;u[f>>1]=x[f>>1]|2}on(j);g=(e+104|0)+g|0;t[e|0]=w[g+548|0];t[e+64|0]=64;o=i+484410|0,p=w[pc(e,e- -64|0)|0]<<2,u[o>>1]=p;t[i+484417|0]=w[g+579|0]<<4;g=d;if((d|0)!=31){continue}break}uA(b,a+1304400|0,32);d=1;while(1){wB(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){$f(a+484344|0,w[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){i=Xh(e- -64|0);f:{if(w[e+130|0]){v[114578]=0;g=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;U(343,e|0,b|0,g|0);break f}g=x[a+480188>>1];v[114578]=0;U(343,e|0,b|0,g<<8)}g=v[114578];v[114578]=0;if((g|0)==1){break e}f=d;Wd(i,e);Bb(e);g:{if(!k){break g}v[114578]=0;d=W(404,j|0,f&65535,64)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}if(!d){break g}if(!w[e+130|0]){d=0;if(!x[a+480188>>1]){break g}while(1){g=0;while(1){h=_b(j,f);v[114578]=0;h=W(472,h|0,g|0,d&65535)|0;l=v[114578];v[114578]=0;if((l|0)==1){break e}v[114578]=0;R(535,i|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break e}g=g+1|0;if((g|0)!=64){continue}break}d=d+1|0;if(x[a+480188>>1]>(d&65535)>>>0){continue}break}break g}h=0;v[114578]=0;Q(536,i|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}while(1){d=_b(j,f);v[114578]=0;l=Q(497,d|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(x[a+480188>>1]){m=e+h|0;d=128;g=0;while(1){h:{if(!(w[m|0]&d)){break h}v[114578]=0;R(535,i|0,l+B(g,6)|0);n=v[114578];v[114578]=0;if((n|0)!=1){break h}break e}d=d>>>1|0;g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break}}Bb(i);d=f+1|0;if(f>>>0<w[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=ad(e,8,1,1,0);while(1){tg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=P()|0;O()|0;Bb(i);break c}d=P()|0;O()|0;Ib(e- -64|0);break d}d=P()|0;O()|0}yb(g)}S(d|0);L()}d=1}jb=e+720|0;return d|0}function p9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-176|0;jb=e;pf(e+160|0,b);m=a;k=c;g=d;h=jb-48|0;jb=h;v[h+44>>2]=0;f=b;Fi(f,h+44|0);a:{b:{c:{if(v[h+44>>2]!=(Gj(32545)|0)){break c}v[h+40>>2]=0;Fi(f,h+40|0);i=-1;j=v[h+40>>2];if(j-1>>>0>1){break c}d:{e:{f:{if((j|0)<=1){j=Wb(h+24|0);v[114578]=0;l=W(722,f|0,j|0,256)|0;n=v[114578];v[114578]=0;if((n|0)==1){break b}if(!l){break e}v[114578]=0;U(13,h+8|0,g|0,j|0);l=v[114578];v[114578]=0;if((l|0)!=1){break f}break b}j=Wb(h+24|0);v[114578]=0;l=W(724,f|0,j|0,255)|0;n=v[114578];v[114578]=0;if((n|0)==1){break b}if(!l){break d}v[114578]=0;U(13,h+8|0,g|0,j|0);l=v[114578];v[114578]=0;if((l|0)==1){break b}}Gb(k,h+8|0);yb(h+8|0);yb(j);u[h+8>>1]=0;xf(f,h+8|0);v[h+24>>2]=0;Fi(f,h+24|0);k=v[h+24>>2];if(k>>>0>50){break c}g:{if(!k){break g}k=1;while(1){if(!SJ(m,f,g)){break c}if(y[h+24>>2]<=k>>>0){break g}k=k+1|0;continue}}v[h+24>>2]=0;Fi(f,h+24|0);i=v[h+24>>2]==(Gj(32550)|0)?1:-1;break c}yb(j);break c}yb(j)}jb=h+48|0;f=i;break a}a=P()|0;O()|0;yb(j);S(a|0);L()}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!f){Dn(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;ej(b,e);b=$k(e+56|0,b);v[114578]=0;f=Q(683,e+40|0,32531)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}v[114578]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(684,b|0,f|0,e+32|0);g=v[114578];v[114578]=0;if((g|0)==1){break j}Ib(f);v[114578]=0;t[e+31|0]=0;f=Q(683,e+40|0,32534)|0;g=v[114578];v[114578]=0;if((g|0)==1){break k}v[114578]=0;W(685,b|0,e+31|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break l}Ib(f);v[114578]=0;f=w[e+31|0];g=T(1626,b|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break m}v[114578]=0;i=T(1627,b|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break n}v[e+32>>2]=i;v[e+24>>2]=g;if(Jb(e+24|0,e+32|0)){f=f?0:d;while(1){v[114578]=0;u[e+22>>1]=65535;d=Q(683,e+40|0,32539)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}v[114578]=0;g=W(1628,b|0,e+24|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}Ib(d);t:{if(!g){v[114578]=0;X(1629,b|0,e+24|0,c|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}break t}v[114578]=0;d=Q(683,e+40|0,32541)|0;g=v[114578];v[114578]=0;u:{v:{if((g|0)!=1){v[114578]=0;g=W(1628,b|0,e+24|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break v}Ib(d);if(g){break u}v[114578]=0;W(1630,b|0,e+24|0,e+22|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break t}break o}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(d);break h}v[114578]=0;d=Q(683,e+40|0,32543)|0;g=v[114578];v[114578]=0;if((g|0)==1){break s}v[114578]=0;g=W(1628,b|0,e+24|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break r}Ib(d);if(g){break t}v[114578]=0;X(1631,b|0,e+24|0,a|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}}Uf(e+24|0);if(Jb(e+24|0,e+32|0)){continue}break}}a=v[b>>2];vg(b);f=a&1073741824?-1:1}jb=e+176|0;return f|0}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(f);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(f);break h}a=P()|0;O()|0}vg(b);S(a|0);L()}function NI(a){var b=0,c=C(0),d=C(0),e=0,f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=C(0),q=0,r=C(0),s=C(0),u=0,w=0,x=C(0);k=jb-16|0;jb=k;u=a,w=Ai(C(z[a+4256>>2]*C(3))),v[u+4264>>2]=w;u=a,x=C(Se(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[u+4268>>2]=x;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);u=k,x=ne(C(10),C(C(MI(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[k+8>>2]=1065353216;u=a,x=C(z[nl(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=x;e=a;d=ne(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(d!=C(1)){c=yo(C(C(LI(a)*C(6.2831854820251465))/z[a+4268>>2]));i=C(d+d);f=C(d*d);d=C(d*C(8));c=hn(C(C(C(C(c*i)+C(-2))+C(K(C(C(C(f*C(-4))+d)+C(C(C(C(f*C(4))*c)-d)*c)))))/C(i+C(-2))),C(0),C(1))}else{c=C(0)}z[e+4276>>2]=c;j=jb-16|0;jb=j;e=a;d=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;b=a;i=z[ex(j+12|0,j+8|0)>>2];f=C(d*C(C(c+C(.007000000216066837))+i));a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}v[b+4352>>2]=h;b=1;while(1){l=((B(b&1,24)+e|0)+(b<<1&-4)|0)+4352|0;f=C(C(C(z[(b<<2)+33600>>2]*i)+c)*d);b:{if(C(D(f))<C(2147483648)){h=~~f;break b}h=-2147483648}v[l>>2]=h;b=b+1|0;if((b|0)!=12){continue}break}z[j+12>>2]=C(C(z[e+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[j+8>>2]=1065353216;c=C(z[nl(j+12|0,j+8|0)>>2]*d);i=C(c*C(.07500000298023224));c=C(c*C(.06700000166893005));b=0;while(1){h=(b<<2)+e|0;q=h+4316|0;f=ne(C(.9300000071525574),C(o|0));g=C(i*f);c:{if(C(D(g))<C(2147483648)){l=~~g;break c}l=-2147483648}v[q>>2]=l;l=h+4292|0;f=C(c*f);d:{if(C(D(f))<C(2147483648)){h=~~f;break d}h=-2147483648}v[l>>2]=h;b=b+1|0;if((b|0)!=6){o=b+o|0;continue}break}h=e+4348|0;c=C(d*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){b=~~c;break e}b=-2147483648}v[h>>2]=b;h=e+4344|0;c=C(d*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){b=~~c;break f}b=-2147483648}v[h>>2]=b;h=e+4340|0;d=C(d*C(.009999999776482582));g:{if(C(D(d))<C(2147483648)){b=~~d;break g}b=-2147483648}v[h>>2]=b;b=0;while(1){OI((B(b,24)+e|0)+4504|0,v[((b<<2)+e|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}jb=j+16|0;b=jb-16|0;jb=b;c=Mg(a,5);f=Mg(a,11);d=C(c*Mg(a,4));i=C(C(d*C(.03999999910593033))+C(c*C(.02250000089406967)));c=C(f*Mg(a,10));f=C(C(c*C(.03999999910593033))+C(f*C(.02250000089406967)));if(t[a+4264|0]&1){g=Mg(e,3);m=Mg(e,9);g=C(g*d);d=C(Mg(e,2)*g);i=C(C(C(g*C(.12250000238418579))+i)+C(d*C(.1444000005722046)));g=C(m*c);c=C(Mg(e,8)*g);f=C(C(C(g*C(.12250000238418579))+f)+C(c*C(.1444000005722046)))}Mg(e,12);g=z[e+4496>>2];m=Mg(e,1);n=Mg(e,7);r=Mg(e,0);s=Mg(e,6);u=b,x=ne(C(10),C(C(MI(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[b+8>>2]=1065353216;p=z[nl(b+12|0,b+8|0)>>2];g=C(g*g);c=C(n*C(g*c));n=C(s*c);d=C(m*C(g*d));g=C(r*d);m=C(C(C(n+g)*C(-.5))+C(1));z[e+4284>>2]=p*C(K(C(m/C(C(C(g+c)*C(.1444000005722046))+i))));z[e+4288>>2]=p*C(K(C(m/C(C(C(n+d)*C(.1444000005722046))+f))));jb=b+16|0;t[a+5046|0]=0;jb=k+16|0}function Xb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[115890]){break a}a=a+b|0;if(v[115891]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=463544,j=v[115886]&Lma(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+463848|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=463548,j=v[115887]&Lma(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[115888]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[115892]==(f|0)){v[115892]=d;a=v[115889]+a|0;v[115889]=a;v[d+4>>2]=a|1;if(v[115891]!=(d|0)){break a}v[115888]=0;v[115891]=0;return}if(v[115891]==(f|0)){v[115891]=d;a=v[115888]+a|0;v[115888]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=463544,j=v[115886]&Lma(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+463848|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=463548,j=v[115887]&Lma(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[115891]!=(d|0)){break f}v[115888]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;k:{if(!(c&a)){v[115886]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+463848|0;l:{m:{c=v[115887];b=1<<e;n:{if(!(c&b)){v[115887]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[115894]-1|0;v[115894]=a?a:-1}}function by(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;f=jb-16|0;jb=f;j=B(b,896)+a|0;l=j+1075782|0;i=x[l>>1];k=a+1074312|0;Eb(f+8|0,k,23);g=c&15;a:{b:{c:{d:{e:{f:{if(Cb(f+8|0)){if(!(v[a+1074392>>2]|!w[(B(b,896)+a|0)+1075794|0])){u[l>>1]=g;break f}e=x[l>>1];if(e){h=e-1|0;u[l>>1]=h;e=0;if(h&65535){break c}}u[l>>1]=g;e=1;break c}Eb(f+8|0,k,52);h=c&256;if(!(!Cb(f+8|0)|!h)){g:{if(!(w[a+480209|0]&16)){break g}e=B(b,896)+a|0;if(w[e+1075795|0]){i=wS(e+1075794|0)?1:i}if(w[e+1075796|0]!=1){break g}if(w[(B(b,896)+a|0)+1075798|0]){break b}}e=0;if(i<<16>>16<(g|0)){break c}if(w[a+480209|0]&16){if(Tf((B(b,896)+a|0)+1075794|0)){break c}}i=0;e=1;break c}if(v[a+480180>>2]&16777250){e=!(i&65535?(i<<16>>16)%((g?g:1)|0)|0:1);i=i+1|0;break c}if(v[a+480180>>2]!=1){break d}e=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!e){if(Tf((B(b,896)+a|0)+1075794|0)){break a}}if(g){break e}}e=0;break c}e=!((e>>>0)%(g>>>0)|0);break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}h:{i:{j:{k:{l:{if(h){e=B(b,896)+a|0;if(w[e+1075796|0]==1){g=(w[e+1075799|0]>15)+g|0}g=g?g:1;break l}if(h?0:w[a+480209|0]&16){break i}g=g?g:1;if(v[a+1074416>>2]){break k}}e=0;break j}e=!(y[a+1074392>>2]%(g>>>0)|0)}i=i+1|0;break h}i=v[a+480180>>2]&1048580?0:i}if(!(!(w[(B(b,896)+a|0)+1075794|0]|!h?v[a+1074392>>2]:1)|i<<16>>16<(g|0))){e=1}Eb(f+8|0,k,52);if(!Cb(f+8|0)|c){break c}e=!v[a+1074392>>2]}g=j+1074984|0;j=(B(b,896)+a|0)+1075060|0;m:{if(v[j>>2]){break m}Eb(f+8|0,k,38);if(!Cb(f+8|0)){break m}if(!oj(g)){break a}}Eb(f+8|0,k,106);if(z=0,A=Cb(f+8|0),C=v[(B(b,896)+a|0)+1075680>>2],C?z:A){break a}if(e){e=B(b,896)+a|0;p=e+1075672|0;v[f+4>>2]=v[p>>2];h=c>>>4&15;if(h){Eb(f+8|0,k,52);n:{if(z=Cb(f+8|0),A=0,C=w[(B(b,896)+a|0)+1075796|0]==1,C?z:A){break n}m=t[h+21872|0];if(m){v[f+4>>2]=B(m,v[f+4>>2])>>4;break n}v[f+4>>2]=v[f+4>>2]+(t[h+21888|0]<<2)}ce(f+4|0,0,256);h=(B(b,896)+a|0)+1075072|0;v[h>>2]=v[h>>2]|2097152}q=e+1075684|0;m=v[q>>2];e=w[e+1075808|0];o:{if(!v[j>>2]|(e-1&255)>>>0>119){break o}if(!(!(w[(B(b,896)+a|0)+1075073|0]&2)|v[a+480180>>2]!=2)){Eb(f+8|0,k,108);if(!Cb(f+8|0)){break o}}uM(a,b,0,e,1)}h=0;p:{if(!(v[a+480180>>2]&1048580)){break p}j=w[(B(b,896)+a|0)+1075795|0];h=(c|0)<256;if(!j|(c|0)>255){break p}dp(a,g,j,0,0,1);h=1}j=B(b,896)+a|0;n=j+1075644|0;r=v[n>>2];v[n>>2]=0;o=j+1075072|0;s=v[o>>2];Eb(f+8|0,k,23);As(a,g,e,Cb(f+8|0),h,0,b);if(!w[j+1075795|0]){v[n>>2]=r}if(!(!(s&4096)|v[a+480180>>2]!=4)){v[o>>2]=v[o>>2]|4096}h=j+1075794|0;v[p>>2]=v[f+4>>2];if(x[a+480192>>1]){t[h|0]=e;_K(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[h|0]|!m))){v[q>>2]=m}e=v[a+480180>>2];Eb(f+8|0,k,23);if(Cb(f+8|0)){v[g>>2]=0;v[g+4>>2]=0}e=e&16777250;q:{if(d-1>>>0>9){break q}h=v[(B(b,896)+a|0)+1075088>>2];if(!h){break q}r:{if((d|0)==1){b=v[(B(b,896)+a|0)+1075648>>2];break r}j=(B(b,896)+a|0)+1075648|0;b=v[(h+(d<<2)|0)+60>>2];v[j>>2]=b}cp(a,g,b)}i=e?i:0}Eb(f+8|0,k,52);a=Cb(f+8|0);Eb(f+8|0,k,23);if(Cb(f+8|0)){break a}i=(a&(c&256)>>>8)+i|0}u[l>>1]=i}jb=f+16|0}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(b){h=a+327720|0;c=jb-400|0;jb=c;nN(c+384|0,8);v[114578]=0;ra(1211,c+368|0,9);g=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((g|0)!=1){v[114578]=0;g=Q(1212,c+352|0,14)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}v[114578]=0;R(1213,c+384|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break k}v[114578]=0;R(1213,c+368|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break k}mN(c+280|0,4900);mN(c+208|0,32e3);jN(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[114578]=0;f=Q(1214,c+104|0,c+384|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}Ls(c+120|0,c+280|0,f);Mf(f);v[114578]=0;f=Q(1214,c+72|0,c+368|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break i}Ls(c+88|0,c+208|0,f);Mf(f);v[114578]=0;f=Q(1214,c+40|0,c+120|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break h}Ls(c+56|0,c+136|0,f);Mf(f);v[114578]=0;f=Q(1214,c+8|0,c+88|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}Ls(c+24|0,c+136|0,f);Mf(f);kp(c+120|0);kp(c+56|0);kp(c+88|0);kp(c+24|0);kp(c+368|0);jp(c+120|0,xi(h,0));jp(c+56|0,xi(h,1));jp(c+88|0,xi(h,2));jp(c+24|0,xi(h,3));jp(c+368|0,xi(h,4));Mf(c+24|0);Mf(c+56|0);Mf(c+88|0);Mf(c+120|0);ip(g);Mf(c+368|0);Mf(c+384|0);jb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Mf(c+56|0)}Mf(c+88|0)}Mf(c+120|0)}ip(g)}Mf(c+368|0)}Mf(c+384|0);S(a|0);L()}Bx(a+131112|0,9.6377,.97);Bx(a+196648|0,8.5,.5);Bx(a+262184|0,2.7625,.425)}g=a+368680|0;if(!(r=0,s=TK(g,a),t=b,t?r:s)){i=a+24|0;o=A[a+8>>3];c=w[a+16|0];f=jb+-64|0;jb=f;while(1){p=+(k-4096|0)*.0001220703125;l=0;b=0;while(1){j=o;h=c;d=1;m=f+(b<<3)|0;e=+(b|0)-p;n=e+-3.5;if(!(D(n)<1e-8)){m:{n:{switch(h|0){case 0:d=.5-ze(e*.8975979010256552)*.5;break m;case 1:d=ze(e*.8975979010256552)*-.46+.54;break m;case 2:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.5+.42+e*.08;break m;case 3:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49364+.44959+e*.05677;break m;case 4:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49755+.42323+e*.07922;break m;case 5:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.48829+.35875+e*.14128+ze(d*3)*-.01168;break m;case 6:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49703+.40217+e*.09392+ze(d*3)*-.00183;break m;case 7:break n;default:break m}}d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49804+.40243+e*.09831+ze(d*3)*-.00122}e=n*3.141592653589793;j=hi(e*j)/e}j=j*d;A[m>>3]=j;l=j+l;b=b+1|0;if((b|0)!=8){continue}break}j=1/l;m=k<<3;b=0;while(1){q=i+(b+m<<1)|0;d=G(F(H(A[f+(b<<3)>>3]*32768*j+.5),32768),-32768);o:{if(D(d)<2147483648){h=~~d;break o}h=-2147483648}u[q>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}jb=f- -64|0;b=v[a+20>>2];v[g+16>>2]=v[a+16>>2];v[g+20>>2]=b;b=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=b;b=v[a+4>>2];v[g>>2]=v[a>>2];v[g+4>>2]=b}}function gv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-96|0;jb=d;l=a;n=a;a:{b:{c:{d:{e:{if(o=1,p=xd(a,11),q=v[a+4>>2],q?o:p){e=v[a+28>>2];f=v[a+12>>2];c=v[a+64>>2];h=c+v[a+8>>2]|0;h=Og(d+80|0,h,c>>>0>h>>>0?f+1|0:f);c=v[h+12>>2];b=d;v[b+32>>2]=v[h+8>>2];v[b+36>>2]=c;b=v[h+4>>2];v[d+24>>2]=v[h>>2];v[d+28>>2]=b;ej(e,d+24|0);b=v[a+28>>2];if(Jt(v[v[b>>2]-12>>2]+b|0)){Jg(a,1073741826);break a}c=v[a+92>>2];i=a+44|0;g=i;b=nd(g);f:{if(c>>>0>b>>>0){h=jb-32|0;jb=h;g:{m=c-b|0;h:{if(m>>>0<=v[zb(g)>>2]-v[g+4>>2]>>4>>>0){e=jb-16|0;jb=e;i:{f=mm(e,g,m);if(v[f+4>>2]!=v[f+8>>2]){while(1){c=zb(g);b=v[f+4>>2];v[114578]=0;R(216,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}b=v[f+4>>2]+16|0;v[f+4>>2]=b;if((b|0)!=v[f+8>>2]){continue}break}}Mb(f);jb=e+16|0;break h}a=P()|0;O()|0;Mb(f);S(a|0);L()}b=zb(g);c=Lq(g,nd(g)+m|0);e=nd(g);f=jb-16|0;jb=f;v[f+12>>2]=0;j=h+8|0;Tc(j+12|0,b);if(c){b=c;if(b>>>0>268435455){Fc(6967);L()}k=sc(b<<4,4)}v[j>>2]=k;b=(e<<4)+k|0;v[j+8>>2]=b;v[j+4>>2]=b;o=ec(j),p=(c<<4)+k|0,v[o>>2]=p;jb=f+16|0;v[114578]=0;R(211,j|0,m|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;R(212,g|0,j|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}pD(j)}jb=h+32|0;break f}a=P()|0;O()|0;pD(j);S(a|0);L()}if(b>>>0>c>>>0){c=v[g>>2]+(c<<4)|0;nd(g);oD(g,c);nD(g)}}c=a+32|0;wv(c,v[a+92>>2]<<2);if(v[a+92>>2]){e=0;while(1){b=v[a+28>>2];if(Jt(v[v[b>>2]-12>>2]+b|0)){Jg(a,1073741828);break a}b=x[a+16>>1];u[d+78>>1]=b;if((b|0)==65535){hv(v[a+28>>2],d+78|0)}o=d,p=xc(c),v[o+72>>2]=p;j:{if(!x[d+78>>1]){k=0;break j}k=x[d+78>>1];b=v[d+72>>2];if(k>>>0>-1-b>>>0){break j}fv(c,b+k|0);ak(v[a+28>>2],wc(c,v[d+72>>2]),x[d+78>>1]);k=x[d+78>>1]}o=tc(i,e),p=k,u[o+12>>1]=p;b=v[d+72>>2];o=tc(i,e),p=b,v[o>>2]=p;if(xd(a,6)){Nj(v[a+28>>2],d+56|0);if(y[d+60>>2]>2147483647){break e}b=v[d+56>>2];o=tc(i,e),p=b,v[o+4>>2]=p}b=v[a+4>>2];k:{if(b){o=tc(i,e),p=b,v[o+8>>2]=p;break k}if(!xd(a,7)){break k}Nj(v[a+28>>2],d+56|0);if(y[d+60>>2]>2147483647){break d}b=v[d+56>>2];o=tc(i,e),p=b,v[o+8>>2]=p}l:{if(v[tc(i,e)+8>>2]==-1){break l}if(xd(a,6)){break l}if(e){b=e-1|0;b=v[tc(i,b)+4>>2]+v[tc(i,b)+8>>2]|0}else{b=0}o=tc(i,e),p=b,v[o+4>>2]=p}if(xd(a,8)){u[d+56>>1]=0;hv(v[a+28>>2],d+56|0);b=xd(a,9);gl(v[a+28>>2],x[d+56>>1]<<b,-1)}e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}}pf(d+56|0,v[a+28>>2]);b=v[d+68>>2];v[a+72>>2]=v[d+64>>2];v[a+76>>2]=b}Oj(a,4,1);b=v[a+88>>2];if((b|0)!=v[a+64>>2]){break c}c=v[a+76>>2];b=v[a+72>>2];break b}Jg(a,1073741829);break a}Jg(a,1073741829);break a}c=v[a+12>>2];e=b+v[a+8>>2]|0;c=e>>>0<b>>>0?c+1|0:c;b=e}v[n+80>>2]=b;v[l+84>>2]=c;l=v[a+28>>2];c=Og(d+40|0,b,c);b=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=b;b=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=b;ej(l,d+8|0);if(xd(a,6)){break a}if(!(o=1,p=xd(a,7),q=v[a+4>>2],q?o:p)|!v[a+92>>2]){break a}c=a+44|0;l=v[a+80>>2];b=v[a+8>>2];l=l-b|0;e=0;while(1){b=tc(c,e);v[b+4>>2]=l+v[b+4>>2];e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}}jb=d+96|0}function II(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);LM(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=Se(v[a+16>>2]);o=ne(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));b=C(C(c*C(6.2831854820251465))/C(d>>>0));c=yG(b);r=yo(b);s=a;t=c;k=C(C(C(b*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());c=C(((d|0)<=22?C(C(C(1)-g)+C(c-e)):C(C(c-C(e+g))+C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+52272>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=zG(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(b*o);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function bV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-32|0;jb=e;v[e+28>>2]=b;if((d|0)<1){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Lb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;wv(c,v[Lb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){a:{f=Bg(e+8|0,a);b=Bg(e+8|0,a+4|0);i=Bg(e+8|0,a+5|0);r=e,s=Bg(e+8|0,a+6|0)<<8|Bg(e+8|0,a+7|0),v[r+24>>2]=s;b=i|b<<8;p=a+8|0;b:{c:{d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break b}b=ba(8)|0;v[114578]=0;T(354,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break d}break c}while(1){r=e,s=Bg(e+8|0,i+p|0),t[r+20|0]=s;ko(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break b;case 1:break e;default:break a}}Ti(e+24|0,d);i=v[e+24>>2];m=Bg(e+8|0,a+10|0);t[e+20|0]=m;ko(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break b}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=Wf(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!Wf(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!Wf(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!Wf(h,a,1,e+8|0)){break n}f=Wf(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;o:{p:{q:{f=((k<<3)+f|0)-17|0;r:{if((f|0)<=-1){a=ba(8)|0;v[114578]=0;T(354,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break q}break r}if(f>>>0<56){break o}a=ba(8)|0;v[114578]=0;T(354,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break p}}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(a|0,77224,265);L()}ha(a|0,77224,265);L()}k=w[f+11680|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];s:{if((g|0)<1){break s}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=Bg(f,g);m=m-((Bg(f,g+1|0)<<8|q<<16|Bg(f,g+2|0))<<(b-(l<<3)|0)+8>>32-k)|0;t[e+20|0]=m;ko(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if((a|0)<1){break s}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}t:{u:{a=f+1|0;if(!Wf(h,a,1,e+8|0)){f=2;break u}a=f+2|0;if(!Wf(h,a,1,e+8|0)){f=4;break u}a=f+3|0;if(!Wf(h,a,1,e+8|0)){f=6;break u}a=f+5|0;if(!Wf(h,f+4|0,1,e+8|0)){b=f+8|0;a=Wf(h,a,3,e+8|0)+8|0;break t}b=f+10|0;a=Wf(h,a,5,e+8|0)+16|0;break t}b=a+2|0;a=Wf(h,a+1|0,1,e+8|0)+f|0}v:{if(Wf(h,b,1,e+8|0)){f=-256;g=12;break v}b=b+1|0;g=Wf(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=Wf(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=(j|0)>0?j-1|0:0}f=xc(c)+((l^-1)+f|0)|0;if(f>>>0<xc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<1|(g|0)<=0){break g}while(1){m=w[wc(c,f)|0];t[e+20|0]=m;ko(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if((a|0)<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}b=ba(8)|0;v[114578]=0;T(354,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}ha(b|0,77224,265);L()}n=n-(n>>3)|0;if((g|0)>0){continue}break}break b}ha(b|0,77224,265);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=md(c)^1}jb=e+32|0;return a|0}function Oq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[115891]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=463544,j=v[115886]&Lma(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+463848|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=463548,j=v[115887]&Lma(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[115888]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[115892]==(f|0)){v[115892]=a;b=v[115889]+b|0;v[115889]=b;v[a+4>>2]=b|1;if(v[115891]!=(a|0)){break a}v[115888]=0;v[115891]=0;return}if(v[115891]==(f|0)){v[115891]=a;b=v[115888]+b|0;v[115888]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=463544,j=v[115886]&Lma(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+463848|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=463548,j=v[115887]&Lma(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[115891]!=(a|0)){break g}v[115888]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+463584|0;d=v[115886];b=1<<b;l:{if(!(d&b)){v[115886]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+463848|0;m:{d=v[115887];c=1<<e;n:{if(!(d&c)){v[115887]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}
function ZC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=jb-144|0;jb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(v[19056]>=(c|0)){Ou(a+96|0,c);v[114578]=0;c=Q(2,a+80|0,1024)|0;d=v[114578];v[114578]=0;if((d|0)==1){break E}v[114578]=0;U(3,a+112|0,a+96|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break D}v[114578]=0;d=Q(4,a+48|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break C}v[114578]=0;e=Q(2,a+32|0,1027)|0;f=v[114578];v[114578]=0;if((f|0)==1){break B}v[114578]=0;U(5,a- -64|0,d|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break A}v[114578]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[114578];v[114578]=0;if((f|0)==1){break z}yb(a- -64|0);yb(e);yb(d);yb(a+112|0);yb(c);yb(a+96|0);c=v[b>>2]?v[b>>2]:1030;v[114578]=0;U(6,a+112|0,1,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break t}c=v[b+4>>2]?v[b+4>>2]:1030;v[114578]=0;U(6,a+96|0,1,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break s}b=v[b+8>>2];v[114578]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;b=Q(8,460904,1031)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}v[114578]=0;U(9,a- -64|0,0,a+112|0);c=v[114578];v[114578]=0;if((c|0)==1){break p}v[114578]=0;b=Q(10,b|0,a- -64|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}v[114578]=0;b=Q(8,b|0,1044)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}v[114578]=0;U(9,a+32|0,0,a+80|0);c=v[114578];v[114578]=0;if((c|0)==1){break n}v[114578]=0;b=Q(10,b|0,a+32|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[114578]=0;b=Q(8,b|0,1046)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[114578]=0;b=Q(8,b|0,1024)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[114578]=0;U(9,a+16|0,0,a+128|0);c=v[114578];v[114578]=0;if((c|0)==1){break l}v[114578]=0;b=Q(10,b|0,a+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}v[114578]=0;b=Q(8,b|0,1048)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}v[114578]=0;U(9,a|0,0,a+96|0);c=v[114578];v[114578]=0;if((c|0)==1){break j}v[114578]=0;b=Q(10,b|0,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;b=Q(8,b|0,1051)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;Q(11,b|0,12)|0;b=v[114578];v[114578]=0;if((b|0)==1){break i}yb(a);yb(a+16|0);yb(a+32|0);yb(a- -64|0);yb(a+80|0);yb(a+96|0);yb(a+112|0);yb(a+128|0)}jb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(a- -64|0)}yb(e)}yb(d)}yb(a+112|0)}yb(c)}yb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;yb(a)}yb(a+16|0)}yb(a+32|0)}yb(a- -64|0)}yb(a+80|0)}yb(a+96|0)}yb(a+112|0)}yb(a+128|0)}S(b|0);L()}function jL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=0,n=C(0),o=0,p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){So(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;wL(a)}iL(a+24648|0);s=v[a+24620>>2];h=jb-144|0;jb=h;f=a+393352|0;c=v[f+4>>2];a:{if(c>>>0<=28){g=B(c,44)+82048|0;break a}v[f+4>>2]=0;g=82048}if(!(b?0:(g|0)==v[f+4112>>2])){v[f+4112>>2]=g;r=C(s>>>0);i=r;c=h+8|0;d=v[g+24>>2];v[c>>2]=d;e=v[g+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[g+4>>2];l=(d|0)>(e|0)?d:e;if((l|0)<=-601){j=e;e=l+600|0;v[c+4>>2]=j-e;v[c>>2]=d-e}e=c;k=C(z[g+36>>2]*C(79.30999755859375));b:{if(C(D(k))<C(2147483648)){d=~~k;break b}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(z[g+32>>2]*C(117.9612045288086))+C(4915.05029296875));c:{if(C(D(k))<C(2147483648)){e=~~k;break c}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;l=0;k=z[g+8>>2];e=c;n=C(C(F(z[g+20>>2],C(.10000000149011612)))*i);d:{if(C(D(n))<C(2147483648)){d=~~n;break d}d=-2147483648}j=(d|0)<96;o=j?96:d;p=(o|0)>7500;n=C(z[g+28>>2]*i);e:{if(C(D(n))<C(2147483648)){m=~~n;break e}m=-2147483648}d=(m+(j?d-96|0:0)|0)+(p?o-7500|0:0)|0;j=(d|0)<128;m=j?128:d;t=(m|0)>3800;w=t?3800:m;v[e+24>>2]=w;j=j?d-128|0:0;e=c;i=C(k*i);f:{if(C(D(i))<C(2147483648)){d=~~i;break f}d=-2147483648}j=(d+j|0)+(t?m-3800|0:0)|0;v[e+32>>2]=j;o=p?7500:o;while(1){e=B(l,12);d=e+c|0;e=e+34032|0;u[d+42>>1]=x[e+10>>1];u[d+36>>1]=x[e+4>>1];p=x[e+6>>1]|x[e+8>>1]<<16;u[d+38>>1]=p;u[d+40>>1]=p>>>16;v[d+44>>2]=o+((B(v[e>>2],w)+50|0)/100|0);l=l+1|0;if((l|0)!=8){continue}break}e=c;i=C(j|0);k=C(ne(C(.0010000000474974513),(j|0)<4721?C(1):C(C(4720)/i))*C(32768));g:{if(C(D(k))<C(2147483648)){d=~~k;break g}d=-2147483648}v[e+12>>2]=d;i=C(z[g+12>>2]*i);A=c,E=ne(C(.0010000000474974513),i>C(4720)?C(C(4720)/i):C(1)),z[A+28>>2]=E;v[f+4124>>2]=v[h+40>>2];c=AI(BI(v[h+16>>2]),r);u[f+4190>>1]=c;u[f+4188>>1]=c;c=x[h+24>>1]<<1;u[f+4198>>1]=c;u[f+4196>>1]=c;while(1){c=(q<<4)+f|0;g=(h+8|0)+B(q,12)|0;d=v[g+44>>2];v[c+4204>>2]=d;v[c+4208>>2]=d;u[c+4212>>1]=x[g+36>>1];u[c+4214>>1]=x[g+42>>1];u[c+4216>>1]=x[g+40>>1];u[c+4218>>1]=x[g+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+53996>>2]=v[h+32>>2];e=f+4184|0;c=v[h+12>>2];if((c|0)>-9e3){c=zI(c)}else{c=0}v[e>>2]=c;e=f+54052|0;c=v[h+8>>2];if((c|0)>=-8999){c=zI(c)}else{c=0}v[e>>2]=c;c=v[h+28>>2];g=f+54036|0;v[g>>2]=268464128;v[g+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+54010>>1]=c;u[f+54008>>1]=c;u[f+54006>>1]=c;u[f+54004>>1]=c;v[h+4>>2]=v[h+20>>2];ce(h+4|0,0,32752);c=x[h+4>>1];u[f+54018>>1]=c;g=f+54014|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54012>>1]=c;i=z[h+36>>2];A=h,G=AI(C(i*i),r),v[A>>2]=G;ce(h,256,32512);c=x[h>>1];u[f+54026>>1]=c;g=f+54022|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54020>>1]=c}if(b){v[f+4120>>2]=0;DI(f)}b=B(s,5);if(b>>>0>y[f+4124>>2]){v[f+4124>>2]=b}jb=h+144|0;b=a+1304392|0;if(sd(b)){xN(v[b>>2],v[a+24620>>2])}}function aI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-224|0;jb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(nj(b)){break a}c=w[fk(b)|0];if((c|0)==33){e=1}else{if((c|0)!=63){break a}e=0}rk(f+184|0,b,v[b+4>>2]-1|0);c=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=c}Cd(f+184|0);c=v[f+184>>2];Cd(f+168|0);g=ek(c,v[f+172>>2],b);Cd(f+184|0);c=v[b>>2];d=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((g|0)==v[f+188>>2]){v[f+208>>2]=c;v[f+212>>2]=d;a=qc(f+200|0,38235);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Hc(f+16|0,f+8|0)){a=ba(8)|0;v[114578]=0;R(2144,f+168|0,f+216|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2120,f+184|0,39300,f+168|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}mc(a,f+184|0);e=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+184|0);break e}if(!e){break h}a=ba(8)|0;v[114578]=0;c=Q(2143,f+136|0,b|0)|0;b=v[114578];v[114578]=0;e=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[114578]=0;U(2120,f+152|0,39179,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break q}v[114578]=0;U(2138,f+168|0,f+152|0,39315);b=v[114578];v[114578]=0;if((b|0)==1){break p}v[114578]=0;R(2144,f+120|0,f+216|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}v[114578]=0;U(138,f+184|0,f+168|0,f+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break n}mc(a,f+184|0);v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+184|0);e=0;break m}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}yb(f+120|0)}yb(f+168|0)}yb(f+152|0)}yb(c)}if(e){break d}break c}v[f+112>>2]=c;v[f+116>>2]=d;c=qc(f+104|0,38235);d=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=d;d=v[c+4>>2];v[f+56>>2]=v[c>>2];v[f+60>>2]=d;if(Hc(f- -64|0,f+56|0)){a=ba(8)|0;v[114578]=0;R(2144,f+168|0,f+216|0);b=v[114578];v[114578]=0;r:{s:{if((b|0)!=1){v[114578]=0;U(2120,f+184|0,39300,f+168|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}mc(a,f+184|0);e=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+184|0);break r}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}yb(f+168|0);if(e){break d}break c}c=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=c;c=qc(f+88|0,39014);d=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=d;d=v[c+4>>2];v[f+40>>2]=v[c>>2];v[f+44>>2]=d;if(Hc(f+48|0,f+40|0)){PH(a,Ac(v[f+216>>2],v[f+220>>2]));break h}c=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=c;b=qc(f+72|0,39162);c=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=c;c=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=c;if(!Hc(f+32|0,f+24|0)){break h}b=Ac(v[f+216>>2],v[f+220>>2]);v[v[a+32>>2]+40>>2]=b>>>0>3?1:b}jb=f+224|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}yb(f+168|0);if(!e){break c}}ca(a|0)}S(b|0)}L()}function _3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-160|0;jb=d;h=d+144|0;ZH(h);v[h>>2]=83592;g=jb-16|0;jb=g;e=h+4|0;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[g+12>>2]=0;W(2202,e+8|0,g+12|0,g+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}g=a+24|0;Pm(v[g>>2],h);e=w[a+62|0];f=w[a+61|0];i=w[a+60|0];j=v[g>>2];b=Ze(d+128|0,b);v[114578]=0;i=i?13:15;f=f?i&14:i;e=W(2146,j|0,b|0,(e?f&3:f)|0)|0;f=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((f|0)!=1){Bb(b);if(!e){b=ba(8)|0;v[114578]=0;c=Q(85,d+112|0,38611)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}a=P()|0;O()|0;yb(c);break c}a=P()|0;O()|0;ca(b|0);break c}s:{if(w[a+63|0]){break s}v[114578]=0;R(2147,a|0,a+36|0);b=v[114578];v[114578]=0;if((b|0)!=1){break s}a=P()|0;O()|0;break c}t[a+28|0]=1;Pm(v[g>>2],v[a+4>>2]);v[114578]=0;R(2148,d+112|0,h|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}k=d,l=bc(d+112|0),v[k+104>>2]=l;k=d,l=cc(d+112|0),v[k+96>>2]=l;if(Jb(d+104|0,d+96|0)){g=a+68|0;while(1){b=v[d+104>>2];e=v[b>>2];v[114578]=0;f=e;e=b+4|0;U(2149,a|0,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}b=v[b>>2];v[114578]=0;R(2150,d+32|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(9,d+48|0,0,d+32|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}v[114578]=0;b=Q(85,d+16|0,38630)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}v[114578]=0;U(138,d- -64|0,d+48|0,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break m}v[114578]=0;U(802,d+80|0,d- -64|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break o}v[114578]=0;R(1536,g|0,d+80|0);e=v[114578];v[114578]=0;if((e|0)==1){break p}yb(d+80|0);yb(d- -64|0);yb(b);yb(d+48|0);yb(d+32|0);Uf(d+104|0);if(Jb(d+104|0,d+96|0)){continue}break}}k=d,l=vn(c),v[k+80>>2]=l;k=d,l=Hi(c),v[k+64>>2]=l;t:{while(1){v[114578]=0;b=Q(2151,d+80|0,d- -64|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}if(!b){break q}v[114578]=0;c=T(2152,d+80|0)|0;b=v[114578];v[114578]=0;u:{if((b|0)==1){break u}v[114578]=0;b=Q(120,d|0,c|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break u}v[114578]=0;X(2082,a|0,b|0,c+12|0,0);c=v[114578];v[114578]=0;if((c|0)==1){break t}yb(b);v[114578]=0;T(2153,d+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}break e}break}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(b);break d}a=P()|0;O()|0;Bb(b);break c}a=P()|0;O()|0;break c}Sw(d+112|0);Rr(h);jb=d+160|0;return}a=P()|0;O()|0;yb(d+80|0);break n}a=P()|0;O()|0}yb(d- -64|0);break l}a=P()|0;O()|0}yb(b);break j}a=P()|0;O()|0}yb(d+48|0);break h}a=P()|0;O()|0}yb(d+32|0);break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0}Sw(d+112|0)}Rr(h);S(a|0)}L()}function _9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-48|0;jb=c;if(mh(b)){h=lk(b);j=v[b+12>>2];f=c+32|0;e=Uz(f);a:{d=h;if(!d){break a}v[114578]=0;R(680,f|0,d|0);g=v[114578];v[114578]=0;if((g|0)!=1){v[114578]=0;R(1570,f|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;At(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[114578]=0;d=T(1577,a+d|0)|0;e=v[114578];v[114578]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[114578]=0;t[c+31|0]=0;Q(1578,a|0,c+31|0)|0;d=v[114578];v[114578]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[114578]=0;Q(1578,a|0,c+30|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;Ph(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[114578]=0;g=W(472,b|0,i|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[114578]=0;Q(1578,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=Nc(f,d),m=e,t[l|0]=m}l=g,m=w[Nc(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[114578]=0;Q(1578,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=Nc(f,d),m=e,t[l+1|0]=m}l=g,m=w[Nc(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[114578]=0;Q(1578,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=Nc(f,d),m=e,t[l+2|0]=m}l=g,m=w[Nc(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[114578]=0;Q(1578,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=Nc(f,d),m=e,t[l+4|0]=m}l=g,m=w[Nc(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[114578]=0;Q(1578,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=Nc(f,d),m=e,t[l+3|0]=m}l=g,m=w[Nc(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[114578]=0;Q(1578,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=Nc(f,d),m=e,t[l+5|0]=m}l=g,m=w[Nc(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[114578]=0;Q(1578,a|0,c+15|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=w[c+15|0];v[114578]=0;W(1579,a|0,d|0,-1)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;Ll(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}Ll(f)}jb=c+48|0}function y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-192|0;jb=d;a:{if(nj(b)){break a}e=w[fk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}rk(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}Cd(d+160|0);e=v[d+160>>2];Cd(d+144|0);e=ek(e,v[d+148>>2],b);Cd(d+160|0);b:{c:{d:{e:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=qc(d+176|0,38235);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114578]=0;c=Q(85,d+160|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}f=0;if(!c){break e}a=ba(8)|0;v[114578]=0;e=Q(2143,d+144|0,b|0)|0;b=v[114578];v[114578]=0;f:{g:{h:{if((b|0)!=1){v[114578]=0;U(2120,d+160|0,39179,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}mc(a,d+160|0);c=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(d+160|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}yb(e);if(!c){break c}}ca(a|0);break c}if(v[e+4>>2]!=2){a=ba(8)|0;v[114578]=0;c=Q(85,d+160|0,39193)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=qc(d+128|0,38235);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Hc(d+72|0,d- -64|0)){a=ba(8)|0;v[114578]=0;c=Q(85,d+160|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=qc(d+112|0,39022);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=qc(d+96|0,39040);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=qc(d+80|0,39137);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Hc(d+24|0,d+16|0)){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}jb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function a4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-128|0;jb=e;a:{if(Wc(b)){break a}f=w[dI(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}br(e+112|0,b,0,Fb(b)-1|0);Gb(b,e+112|0);yb(e+112|0)}Cd(e+112|0);f=v[e+112>>2];Cd(e+96|0);f=cI(f,v[e+100>>2],b);Cd(e+112|0);b:{c:{d:{e:{f:{if((f|0)==v[e+116>>2]){if(Vd(b,38235)){a=ba(8)|0;v[114578]=0;U(2137,e+112|0,39300,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}mc(a,e+112|0);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(e+112|0);break d}if(!d){break f}a=ba(8)|0;v[114578]=0;U(2137,e+80|0,39179,b|0);b=v[114578];v[114578]=0;g:{h:{i:{j:{k:{if((b|0)!=1){v[114578]=0;U(2138,e+96|0,e+80|0,39315);b=v[114578];v[114578]=0;if((b|0)==1){break k}v[114578]=0;U(802,e+112|0,e+96|0,c|0);b=v[114578];v[114578]=0;c=1;if((b|0)==1){break j}mc(a,e+112|0);v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+112|0);c=0;break i}b=P()|0;O()|0;break g}b=P()|0;c=1;O()|0;break h}b=P()|0;O()|0}yb(e+96|0)}yb(e+80|0);if(!c){break d}}ca(a|0);break d}l:{switch(v[f+4>>2]){case 0:Hh(e+72|0,b);b=(_F(c)|0)!=0;c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;bI(a,e,b,d);break f;case 1:Hh(e- -64|0,b);b=jb-160|0;jb=b;c=Em(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;m:{if((h|0)==1){break b}v[114578]=0;U(123,b+8|0,f+(b+16|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}Ob(b+8|0);v[114578]=0;f=Q(178,c|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=v[v[f>>2]-12>>2];v[114578]=0;f=T(174,f+g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=v[b>>2];h=v[b+4>>2];If(c);jb=b+160|0;b=f?0:g;c=f?0:h;break m}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;aI(a,e+8|0,b,c,d);break f;case 2:Hh(e+56|0,b);b=jb-160|0;jb=b;c=Em(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;n:{if((h|0)==1){break b}v[114578]=0;U(123,b+8|0,f+(b+16|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}Ob(b+8|0);v[114578]=0;f=Q(179,c|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=v[v[f>>2]-12>>2];v[114578]=0;f=T(174,f+g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}i=A[b>>3];If(c);jb=b+160|0;i=f?0:i;break n}b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;$H(a,e+16|0,i,d);break f;case 3:break l;default:break f}}Hh(e+48|0,b);Hh(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;_H(a,e+32|0,e+24|0,d)}jb=e+128|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}a=P()|0;O()|0;If(c);S(a|0);L()}function rja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[pc(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[pc(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=pt(+(fR(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[pc(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[pc(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=pc(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[pc(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[pc(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[pc(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[pc(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[pc(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=41;h=a,i=Nk(hd(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=Aj(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){wj(a);break a}t[a+3|0]=0}jb=f+16|0}function U3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb-96|0;jb=d;a:{b:{c:{if(!(b<.8)){v[114578]=0;Z(2159,d+24|0);e=v[114578];v[114578]=0;d:{e:{f:{g:{h:{if((e|0)!=1){c=v[c>>2];v[114578]=0;R(2160,d+8|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}Pm(v[d+24>>2],v[d+8>>2]);e=v[d+24>>2];c=Ze(d+80|0,a);v[114578]=0;a=W(2146,e|0,c|0,15)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}Bb(c);if(a){a=v[d+24>>2];v[114578]=0;T(1405,a|0)|0;a=v[114578];v[114578]=0;f=1;if((a|0)==1){break f}}Yc(d+8|0);Gh(d+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;break d}a=V(0)|0;O()|0;Bb(c);break e}a=V(0)|0;O()|0}Yc(d+8|0)}Gh(d+24|0);break c}if(!(b<.6)){v[114578]=0;Z(2159,d+24|0);e=v[114578];v[114578]=0;i:{j:{k:{l:{m:{if((e|0)!=1){c=v[c>>2];v[114578]=0;R(2160,d+8|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break m}Pm(v[d+24>>2],v[d+8>>2]);e=v[d+24>>2];c=Ze(d- -64|0,a);v[114578]=0;a=W(2146,e|0,c|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}Bb(c);if(a){a=v[d+24>>2];v[114578]=0;T(1405,a|0)|0;a=v[114578];v[114578]=0;f=.8;if((a|0)==1){break k}}Yc(d+8|0);Gh(d+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;break i}a=V(0)|0;O()|0;Bb(c);break j}a=V(0)|0;O()|0}Yc(d+8|0)}Gh(d+24|0);break c}f=.2;if(!(b<.2)){v[114578]=0;Z(2159,d+24|0);e=v[114578];v[114578]=0;n:{o:{p:{q:{r:{if((e|0)!=1){c=v[c>>2];v[114578]=0;R(2160,d+8|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break r}Pm(v[d+24>>2],v[d+8>>2]);e=v[d+24>>2];c=Ze(d+48|0,a);v[114578]=0;a=W(2146,e|0,c|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}Bb(c);f=0;if(a){a=v[d+24>>2];v[114578]=0;T(1405,a|0)|0;a=v[114578];v[114578]=0;f=.6;if((a|0)==1){break p}}Yc(d+8|0);Gh(d+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;break n}a=V(0)|0;O()|0;Bb(c);break o}a=V(0)|0;O()|0}Yc(d+8|0)}Gh(d+24|0);break c}if(b<.1){break b}v[114578]=0;U(856,d+24|0,a|0,2048);c=v[114578];v[114578]=0;s:{t:{u:{if((c|0)!=1){v[114578]=0;c=T(414,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}e=v[d+24>>2];v[114578]=0;a=T(255,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break t}v[114578]=0;a=xD(2161,3,0,c,e,a,0);c=v[114578];v[114578]=0;if((c|0)==1){break t}a=a+1|0;if(a>>>0>=3){break u}f=A[(a<<3)+40512>>3];Ec(d+24|0);break b}a=V(0)|0;O()|0;break c}c=ba(8)|0;v[114578]=0;e=Q(85,d+8|0,38235)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(c,e);v[114578]=0;U(2010,c|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=V(0)|0;O()|0;yb(e);break s}a=V(0)|0;O()|0;ca(c|0);break s}a=V(0)|0;O()|0}Ec(d+24|0)}_(a|0)|0;$();f=0}jb=d+96|0;return+f}L()}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;e=jb-560|0;jb=e;a:{if(!Qc(b,1464)){break a}if(!An(b,e+556|0)){break a}Hd(a,1);d=a+1074312|0;wg(d,83);Nb(d,84,1);Nb(d,85,1);b:{if($d(e+556|0,16026)){d=Ub(e+32|0,16036);Gb(a+1304436|0,d);yb(d);d=Ub(e+32|0,16059);Gb(a+1304448|0,d);yb(d);d=Ub(e+32|0,16064);Gb(a+1304460|0,d);break b}if(!$d(e+556|0,16031)){break a}d=Ub(e+32|0,16081);Gb(a+1304436|0,d);yb(d);d=Ub(e+32|0,16093);Gb(a+1304448|0,d);yb(d);d=Ub(e+32|0,16097);Gb(a+1304460|0,d)}yb(d);v[a+1304496>>2]=2;d=0;Qc(b,0);Wz(b,a+1304400|0,20);u[a+480190>>1]=31;f=1;while(1){d=pz(b,e+32|0,(B(f,104)+a|0)+484380|0,((f<<5)+a|0)+946304|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}dq(e+552|0,b);m=cd(e+552|0);i=e+552|0;if(w[i|0]>128){break a}g=e+32|0;f=jb-16|0;jb=f;d=b;c:{if(Qb(d,512)){Xt(f+8|0,g);Bd(d,f+8|0);break c}hQ(g)}jb=f+16|0;d=e+544|0;f=e+32|0;g=w[m|0];d:{while(1){if(g>>>0>=w[f|0]){f=f+1|0;if((d|0)!=(f|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;mj(a,0);n=a+484360|0;eg(Vb(n),w[i|0]);u[e+30>>1]=0;j=a+484344|0;$f(j,w[i|0]);if(w[i|0]){g=0;while(1){s=rc(Vb(n),g),x=g,u[s>>1]=x;if(rg(j,g&65535,64)){p=g<<2;h=0;while(1){Qc(b,(w[e+32+(h+p)|0]<<8)+1468|0);f=Xe(_b(j,g),0,h&65535);d=0;while(1){lt(b,f);e:{f:{l=w[f+3|0];g:{if((l|0)!=14){if(!l){if(w[f+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[f+5|0]<=15){break f}}t[f+3|0]=0;break e}wj(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=e,x=bc(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){f=d;h:{if(w[v[e+24>>2]+3|0]!=17?w[v[e+24>>2]+3|0]!=16:0){break h}t[v[e+24>>2]+3|0]=16;k=0;if(w[v[e+24>>2]+5|0]<16){break h}if(!(!(w[v[e+24>>2]+5|0]&15)|(w[v[e+24>>2]+5|0]&15)==(w[v[e+24>>2]+5|0]>>>4|0))){q=w[v[e+24>>2]+5|0]>>>4|0;r=w[v[e+24>>2]+5|0]&15;k=1}d=v[e+24>>2];t[d+5|0]=w[d+5|0]>>>4}Dj(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}t[e+31|0]=r;t[e+30|0]=q;d=k&255;if(d){ql(_b(j,g),Ne(Qn(e+8|0,16,w[(e+d|0)+29|0]),h));d=k+1|0;k=(d&255)==3?1:d}else{k=0}h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Qc(b,(w[m|0]<<8)+1468|0);f=1;while(1){c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){tg(ad(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}jb=e+560|0;return o|0}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0;f=jb-32|0;jb=f;p=a+4|0;o=v[p>>2];n=a+20|0;s=v[Rc(n,b)+16>>2];a:{if(s+1>>>0<2){break a}h=(B(b,896)+o|0)+608|0;if(!Kh(h)){if(!w[Rc(n,b)+20|0]){break a}}i=B(b,896)+o|0;if(!v[i+712>>2]){break a}D=v[(v[i+696>>2]&2?i+692|0:i+684|0)>>2];g=v[i+688>>2];j=v[i+692>>2];Eb(f+24|0,v[a>>2]+1074312|0,31);u=Cb(f+24|0);y=i+1356|0;l=w[y|0];z=i+616|0;e=Fu(z,c);k=mb;m=k;v[f+24>>2]=e;v[f+28>>2]=k;if(w[i+696|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+m|0)}k=j-g|0;E=k<<1;e=B(b,896)+o|0;A=e;F=e+1308|0;m=e+1480|0;G=(l&17)!=1;b:{while(1){c:{if(d>>>0>q>>>0){g=(w[y|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=Xe(_b(v[a>>2]+484344|0,x[v[p>>2]+60>>1]),v[v[p>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){hy(f+16|0,v[a>>2],e,0);l=hc(f+16|0);bn(v[a>>2],h,v[f+16>>2]);g=1;if(w[l|0]){break c}}g=1;d:{switch(j-4|0){case 0:bn(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}bn(v[a>>2],h,0)}v[f+12>>2]=v[F>>2];if(u){ms(v[a>>2],h)}if(!G){eL(v[a>>2],h,f+12|0);g=1}if(!u){ms(v[a>>2],h)}v[f+8>>2]=0;gL(h,f+8|0);e:{f:{if(w[i+697|0]&2){break f}g:{if(!g){if(!w[Rc(n,b)+20|0]){break g}}if(w[m|0]&12){pO(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&8?-9:-5)&e}H=A,I=Jx(v[a>>2],h,v[f+12>>2],0),v[H+616>>2]=I;v[A+620>>2]=mb;H=Rc(n,b),I=0,t[H+20|0]=I;e=Fu(z,c);g=mb;j=g;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+696|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+j|0)}Sb(h,f+24|0);g=v[h+4>>2];j=g;l=v[h>>2];if(D>>>0>g>>>0){break f}e=v[i+696>>2];if(!(e&2)){break e}if(e&4){r=v[i+688>>2];l=r;e=l;if((e|0)>(j|0)?1:0){v[f+16>>2]=0;v[f+20>>2]=l<<1;H=h,I=ig(f+16|0,h),v[H>>2]=I;v[h+4>>2]=mb;v[i+696>>2]=v[i+696>>2]^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;r=v[i+688>>2];g=v[h+4>>2]}Eb(f+16|0,v[a>>2]+1074312|0,33);e=(g-r>>>0)%(E-Cb(f+16|0)>>>0)|0;j=e>>>0<k>>>0;h:{if(!j){v[h+4>>2]=v[i+692>>2]+(k-e|0);g=v[i+696>>2];if(!(j^(g&128)>>>7)){break h}break f}v[h+4>>2]=e+v[i+688>>2];g=v[i+696>>2];if(j^(g&128)>>>7){break f}}v[i+696>>2]=g^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;break f}j=v[i+692>>2];if(j+k>>>0<=g>>>0){g=j+((g-j>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=l;v[h+4>>2]=e}q=q+1|0;if((s|0)!=(q|0)){continue}break b}break}rO(h);v[(B(b,896)+o|0)+1316>>2]=0}H=Rc(n,b),I=0,v[H+16>>2]=I}jb=f+32|0}function CU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-384|0;jb=e;Jc(b);f=jb-16|0;jb=f;g=e+344|0;kB(f+8|0,g);i=Hb(f+8|0);d=b;j=nc(d,ac(f,f+8|0));if((i|0)==(j|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){lB(g)}a:{b:{if(!d){break b}if(!EB(e+344|0)){break b}if(!Qb(b,hd(DB(e+344|0),mb))){break b}c:{if(!c){break c}Hd(a,2097152);vi(a);h=1;mj(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[e+376|0];v[a+480204>>2]=B(w[e+377|0],1e4);u[a+480190>>1]=w[e+378|0];if(w[e+381|0]<w[e+380|0]){Oe(Vb(a+484360|0),w[e+381|0])}d=Ub(e+80|0,12002);Gb(a+1304436|0,d);yb(d);d=Ub(e+80|0,12022);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;iu(b,e+80|0);eq(Vb(a+484360|0),e+80|0,w[e+380|0],65535,65535);if(x[a+480190>>1]){i=1;while(1){CB(b,e+40|0);j=jb-16|0;jb=j;g=(B(h,104)+a|0)+484380|0;Ed(g,0);k=e+40|0;t[g+37|0]=w[k+22|0]<<4;t[j+15|0]=w[k+23|0];t[j+14|0]=64;m=g,n=w[pc(j+15|0,j+14|0)|0]<<2,u[m+30>>1]=n;t[g+36|0]=w[k+24|0];d=k+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=k+33|0;d:{if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}jb=j+16|0;Tl(e+8|0,2,e+40|0);Ic(e+24|0,e+8|0);v[114578]=0;Q(371,((h<<5)+a|0)+946304|0,e+24|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}yb(e+24|0);i=i+1|0;h=i&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}$b(b,B(64-w[e+378|0]|0,37));f=a+484344|0;$f(f,w[e+379|0]);if(w[e+379|0]){h=c&1;i=0;while(1){e:{f:{if(h){if(rg(f,i&65535,64)){break f}}$b(b,2048);break e}d=_b(f,i);m=e,n=bc(d),v[m+40>>2]=n;m=e,n=cc(d),v[m+24>>2]=n;if(!Jb(e+40|0,e+24|0)){break e}while(1){d=v[e+40>>2];Sl(e+8|0,b);g=cd(e+8|0);j=Bf(e+8|0);k=Rh(e+8|0);l=w[e+8|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[g|0];t[d+3|0]=w[j|0];t[d+5|0]=w[k|0];wj(d);Dj(e+40|0);if(Jb(e+40|0,e+24|0)){continue}break}}i=i+1|0;if(i>>>0<w[e+379|0]){continue}break}}if(!(c&2)){break c}h=1;c=ad(e+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){tg(c,(B(h&65535,104)+a|0)+484380|0,b);h=h+1|0;if(x[a+480190>>1]>=(h&65535)>>>0){continue}break}}h=1}jb=e+384|0;return h|0}a=P()|0;O()|0;yb(e+24|0);S(a|0);L()}function vG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;g=jb-48|0;jb=g;o(+a);d=j(1)|0;h=j(0)|0;a:{b:{e=d;d=e;f=e&2147483647;c:{if(f>>>0<=1074752122){if((d&1048575)==598523){break c}if(f>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(f>>>0<=1075594811){if(f>>>0<=1075183036){if((f|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((f|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(f>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;h=f>>>20|0;e=(h-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(e){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;e=h;o(+a);h=j(1)|0;j(0)|0;if((e-(h>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(f>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,h|0);l(1,e&1048575|1096810496);a=+n();d=g+16|0;h=g+16|8;m=1;while(1){if(D(a)<2147483648){p=~~a}else{p=-2147483648}c=+(p|0);A[d>>3]=c;a=(a-c)*16777216;if(m){m=0;d=h;continue}break}A[g+32>>3]=a;p=g+16|0;m=g;f=(f>>>20|0)-1046|0;e:{if(a==0){d=1;while(1){h=d;d=d-1|0;if(A[(g+16|0)+(h<<3)>>3]==0){continue}break}d=h+1|0;break e}d=3}d=wG(p,m,f,d,1);a=A[g>>3];if((e|0)<-1?1:(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}jb=g+48|0;return d}function uW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-336|0;jb=d;e=jb-16|0;jb=e;v[a>>2]=0;f=a+32|0;wv(f,32);t[e+15|0]=0;ko(f,e+15|0);jb=e+16|0;e=v[a+28>>2];a:{if(!Gf(v[v[e>>2]-12>>2]+e|0)){Jg(a,1073741825);break a}pf(d- -64|0,v[a+28>>2]);e=d- -64|0;f=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=f;f=Oc(d- -64|0,3);g=v[a+28>>2];h=d+24|0;e=0;if(v[f>>2]){while(1){yh(g,e+h|0);e=e+1|0;if(e>>>0<y[f>>2]){continue}break}}if(pd(d+24|0,6931,3)){Jg(a,1073741827);break a}t[d+335|0]=0;yh(v[a+28>>2],d+335|0);tD(d- -64|0);f=b;g=d+24|0;h=d- -64|0;e=w[d+335|0];if(e){ak(v[a+28>>2],d- -64|0,e);b=w[d+335|0]}else{b=0}b=nm(g,h,b);e=iv(f,b);Ib(b);if(!e){Jg(a,1073741830)}if(w[a+3|0]&64){break a}yh(v[a+28>>2],d+63|0);e=w[d+63|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(Zh(e,6)){Oj(a,9,1)}v[d+56>>2]=0;sD(v[a+28>>2],d+56|0);b=v[d+56>>2];t[d+55|0]=0;if(b>>>0>=2){yh(v[a+28>>2],d+63|0);f=w[d+63|0];if(!f){yh(v[a+28>>2],d+55|0);f=w[d+63|0]}gl(v[a+28>>2],b+(f?-1:-2)|0,-1)}v[d+40>>2]=0;v[d+44>>2]=0;b:{if(!Zh(e,4)){break b}Nj(v[a+28>>2],d+40|0);b=v[d+44>>2];f=v[d+40>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break b}Jg(a,536871424)}if(Zh(e,5)){yh(v[a+28>>2],d+63|0);gl(v[a+28>>2],w[d+63|0],-1)}c:{if(!Zh(w[d+55|0],0)){break c}yh(v[a+28>>2],d+63|0);b=w[d+63|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break c}Jg(a,536871168)}v[a+4>>2]=0;b=1;if(Zh(w[d+55|0],1)){sD(v[a+28>>2],a+4|0)}Oj(a,6,Zh(e,2));Oj(a,7,Zh(e,3));Oj(a,5,x[a+16>>1]!=0);Oj(a,8,Zh(e,7));d:{if(xd(a,5)){break d}if(xd(a,6)){break d}if(xd(a,7)){break d}b=xd(a,8)}Oj(a,11,b);xd(a,11);b=w[d+55|0];if(Zh(b,2)){u[d+24>>1]=0;hv(v[a+28>>2],d+24|0);gl(v[a+28>>2],B(x[d+24>>1],xd(a,9)?2:1),-1);b=w[d+55|0]}if(Zh(b&255,3)){gl(v[a+28>>2],5,-1)}Nj(v[a+28>>2],d+40|0);c=v[d+44>>2];b=v[d+40>>2];if(!c&b>>>0>=16001|c){Jg(a,1073741831);break a}v[a+92>>2]=b;if(!b){Jg(a,536871040)}e:{if(!xd(a,11)){break e}Nj(v[a+28>>2],d+40|0);b=v[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}Jg(a,1073741829);break a}pf(d+8|0,v[a+28>>2]);yD(d+24|0,d+8|0,v[a+8>>2],v[a+12>>2]);b=v[d+36>>2];e=v[d+32>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){Jg(a,1073741832);break a}v[a+88>>2]=e;b=a;f:{if(xd(a,11)){c=v[d+40>>2];break f}c=v[a+88>>2]}v[b+64>>2]=c;if(!xd(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}Oj(a,10,1)}jb=d+336|0}function y_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=Xv(g);o=Hv(g);ng(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114578]=0;g=Q(2483,m|0,g<<24>>24)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114578]=0;g=Q(2483,m|0,48)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[114578]=0;g=Q(2483,m|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;j=da(2453)|0;l=v[114578];v[114578]=0;e:{if((l|0)==1){break e}v[114578]=0;h=Qv(h,j);j=v[114578];v[114578]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;da(2453)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}v[114578]=0;h=bh(h);j=v[114578];v[114578]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Wc(k)){h=v[f>>2];v[114578]=0;aa(2471,m|0,i|0,g|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break f}l=0;v[114578]=0;Wj(i,g);h=v[114578];v[114578]=0;if((h|0)==1){break a}v[114578]=0;q=T(2468,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114578]=0;qo((i-a<<2)+d|0,h);i=v[114578];v[114578]=0;if((i|0)!=1){break f}break a}g:{if(t[kc(k,j)|0]<1){break g}if(t[kc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=q;j=(Fb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114578]=0;p=Q(2483,m|0,p|0)|0;n=v[114578];v[114578]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[114578]=0;i=T(2472,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}j=v[f>>2];h=j+4|0;v[f>>2]=h;v[j>>2]=i;g=g+1|0;break h}v[114578]=0;i=Q(2483,m|0,i<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[114578]=0;aa(2471,m|0,g|0,c|0,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;yb(k);jb=k+16|0;return}a=P()|0;O()|0;yb(k);S(a|0);L()}function SP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-80|0;jb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=Od(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=jb-16|0;jb=b;d=Ci(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[de(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}g=c;d=(d|0)/32|0;c=d<<2;aj(g,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}Od(a,f);jb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=Od(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=jb-16|0;jb=f;d=Ci(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;b=v[de(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;d=v[g+4>>2];h=v[v[e+24>>2]>>2];j=v[e+28>>2];v[f+8>>2]=b;k=32-d|0;v[f+4>>2]=k;l=Lb(f+8|0,f+4|0);i=v[g>>2];j=h&(-1<<j&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=de(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}Od(a,g);jb=f+16|0}jb=e+80|0}function J_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=nu(g);o=Kv(g);ng(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114578]=0;g=Q(22,m|0,g<<24>>24)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114578]=0;g=Q(22,m|0,48)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[114578]=0;g=Q(22,m|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;j=da(2453)|0;l=v[114578];v[114578]=0;e:{if((l|0)==1){break e}v[114578]=0;h=Qv(h,j);j=v[114578];v[114578]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;da(2453)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}v[114578]=0;h=bh(h);j=v[114578];v[114578]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Wc(k)){h=v[f>>2];v[114578]=0;aa(2448,m|0,i|0,g|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break f}l=0;v[114578]=0;Wj(i,g);h=v[114578];v[114578]=0;if((h|0)==1){break a}v[114578]=0;q=T(2439,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114578]=0;Wj((i-a|0)+d|0,h);i=v[114578];v[114578]=0;if((i|0)!=1){break f}break a}g:{if(t[kc(k,j)|0]<1){break g}if(t[kc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;j=(Fb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114578]=0;p=Q(22,m|0,p|0)|0;n=v[114578];v[114578]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break h}v[114578]=0;i=T(2449,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[114578]=0;aa(2448,m|0,g|0,c|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;yb(k);jb=k+16|0;return}v[114578]=0;i=Q(22,m|0,i<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;yb(k);S(a|0);L()}function A2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-160|0;jb=d;a:{if(nj(b)){break a}e=w[fk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}rk(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}Cd(d+128|0);e=v[d+128>>2];Cd(d+112|0);e=ek(e,v[d+116>>2],b);Cd(d+128|0);b:{c:{d:{e:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=qc(d+144|0,38235);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114578]=0;c=Q(85,d+128|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}e=0;f=0;if(!c){break e}a=ba(8)|0;v[114578]=0;e=Q(2143,d+112|0,b|0)|0;b=v[114578];v[114578]=0;f:{g:{h:{if((b|0)!=1){v[114578]=0;U(2120,d+128|0,39179,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}mc(a,d+128|0);c=0;v[114578]=0;U(2010,a|0,83440,2018);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(d+128|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}yb(e);if(!c){break c}}ca(a|0);break c}if(v[e+4>>2]!=1){a=ba(8)|0;v[114578]=0;c=Q(85,d+128|0,39193)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=qc(d+96|0,38235);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){a=ba(8)|0;v[114578]=0;c=Q(85,d+128|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=qc(d+80|0,39014);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break e}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=qc(d- -64|0,39162);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Hc(d+24|0,d+16|0)){break e}a=v[v[a+32>>2]+40>>2];e=a;f=a>>31}a=f;jb=d+160|0;mb=a;return e|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Wb(a);v[114578]=0;Y(81);c=v[114578];v[114578]=0;a:{b:{if((c|0)==1){c=$a(83440,71204,71180,0)|0;d=O()|0;c:{d:{e:{if((ga(83440)|0)==(d|0)){c=_(c|0)|0;v[114578]=0;Q(1996,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;Q(1996,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;Q(1996,a|0,37713)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114578]=0;Q(1996,a|0,(b?b:34181)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ga(71204)|0)==(d|0)){c=_(c|0)|0;v[114578]=0;Q(1996,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Q(1996,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Q(1996,a|0,37697)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114578]=0;Q(1996,a|0,(b?b:34181)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ga(71180)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[114578]=0;Q(1996,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;Q(1996,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;Q(1996,a|0,37680)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114578]=0;Q(1996,a|0,(b?b:34181)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[114578]=0;Q(1996,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;Q(1996,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;Q(1996,a|0,37657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Ab()}L()}return}yb(a);S(b|0);L()}function $M(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-96|0;jb=f;t[f+95|0]=d;d=0;m=hp(a);n=sj(m);u[b>>1]=0;a:{if(n){while(1){o=x[rc(m,d)>>1];b:{if(!dg(v[a+24>>2]+484344|0,o)){break b}d=x[b>>1];if(yc(a)>>>0<=d>>>0){v[c>>2]=0;a=1;break a}l=qd(a,x[b>>1]);vj(f+72|0,l);wk(f- -64|0,l);d=v[f+76>>2];v[f+32>>2]=v[f+72>>2];v[f+36>>2]=d;d=v[f+68>>2];v[f+24>>2]=v[f+64>>2];v[f+28>>2]=d;k=f+80|0;e=f+32|0;h=f+24|0;d=jb-32|0;jb=d;c:{if(w[f+95|0]){g=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=g;e=Ci(h,e);h=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=h;h=jb-16|0;jb=h;v[h+12>>2]=e;i=d+8|0;g=v[i+4>>2];d:{if(g){v[h+8>>2]=32-g;e=Lb(h+8|0,h+12|0);j=v[i>>2];e=v[e>>2];g=v[j>>2]&(-1<<g&-1>>>v[h+8>>2]-e);if(g){Uc(k,j,Gma(g));break d}g=v[h+12>>2];if((g|0)==(e|0)){UM(k,i,e);break d}e=g-e|0;v[h+12>>2]=e;v[i>>2]=j+4}if(e>>>0>=32){g=v[i>>2];while(1){j=v[g>>2];if(j){Uc(k,g,Gma(j));break d}g=g+4|0;v[i>>2]=g;e=e-32|0;v[h+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){g=v[i>>2];break e}g=v[i>>2];i=v[g>>2]&-1>>>32-e;if(!i){break e}Uc(k,g,Gma(i));break d}Uc(k,g,e)}jb=h+16|0;break c}g=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=g;e=Ci(h,e);h=v[d+20>>2];v[d>>2]=v[d+16>>2];v[d+4>>2]=h;g=jb-16|0;jb=g;v[g+12>>2]=e;h=d;i=v[d+4>>2];f:{if(i){v[g+8>>2]=32-i;e=v[Lb(g+8|0,g+12|0)>>2];j=-1<<i&-1>>>v[g+8>>2]-e;i=v[h>>2];j=j&(v[i>>2]^-1);if(j){Uc(k,i,Gma(j));break f}j=v[g+12>>2];if((j|0)==(e|0)){UM(k,h,e);break f}e=j-e|0;v[g+12>>2]=e;v[h>>2]=i+4}if(e>>>0>=32){i=v[h>>2];while(1){j=v[i>>2];if((j|0)!=-1){Uc(k,i,Gma(j^-1));break f}i=i+4|0;v[h>>2]=i;e=e-32|0;v[g+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){i=v[h>>2];break g}i=v[h>>2];h=(v[i>>2]^-1)&-1>>>32-e;if(!h){break g}Uc(k,i,Gma(h));break f}Uc(k,i,e)}jb=g+16|0}jb=d+32|0;d=c;h:{if(w[f+95|0]){wk(f+56|0,l);h=0;if(_M(f+80|0,f+56|0)){break h}if(w[f+95|0]){break b}}wk(f+56|0,l);if(_M(f+80|0,f+56|0)^1){vj(f+48|0,l);a=v[f+84>>2];b=v[f+80>>2];v[f+40>>2]=b;v[f+44>>2]=a;c=v[f+52>>2];v[f+16>>2]=v[f+48>>2];v[f+20>>2]=c;v[f+8>>2]=b;v[f+12>>2]=a;h=oP(f+16|0,f+8|0);break h}if(y[l+4>>2]>=y[_b(v[a+24>>2]+484344|0,o)+12>>2]){break b}h=v[l+4>>2]}v[d>>2]=h;a=1;break a}d=x[b>>1]+1|0;u[b>>1]=d;d=d&65535;if(n>>>0>d>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}jb=f+96|0;return a|0}function w2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;a:{if(nj(c)){break a}f=w[fk(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}Cd(e+128|0);f=v[e+128>>2];Cd(e+112|0);h=ek(f,v[e+116>>2],c);Cd(e+128|0);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=qc(e+144|0,38235);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Hc(e+8|0,e)){a=ba(8)|0;v[114578]=0;b=Q(85,e+128|0,39169)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(d){b=ba(8)|0;v[114578]=0;d=Q(2143,e+112|0,c|0)|0;a=v[114578];v[114578]=0;f:{g:{h:{if((a|0)!=1){v[114578]=0;U(2120,e+128|0,39179,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break h}mc(b,e+128|0);a=0;v[114578]=0;U(2010,b|0,83440,2018);c=v[114578];v[114578]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(e+128|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}yb(d);if(!a){break c}}ca(b|0);break c}Wb(a);break e}v[e+104>>2]=f;v[e+108>>2]=g;d=qc(e+96|0,38235);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Hc(e+56|0,e+48|0)){a=ba(8)|0;v[114578]=0;b=Q(85,e+128|0,39169)|0;c=v[114578];v[114578]=0;if((c|0)!=1){mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=qc(e+80|0,39058);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Hc(e+40|0,e+32|0)){i:{switch(v[b+52>>2]){case 0:Ub(a,39251);break e;case 1:Ub(a,39259);break e;case 2:Ub(a,39268);break e;default:break i}}Wb(a);break e}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=qc(e- -64|0,39101);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Hc(e+24|0,e+16|0)){j:{switch(v[b+56>>2]){case 0:Ub(a,39273);break e;case 1:Ub(a,39278);break e;case 2:Ub(a,39284);break e;case 3:Ub(a,39295);break e;default:break j}}Wb(a);break e}Wb(a)}jb=e+160|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-48|0;jb=l;f=v[a+4>>2];e=Od(l+40|0,b);j=Od(l+32|0,c);d=jb-16|0;jb=d;e=RP(Od(d+8|0,e),Od(d,j));jb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){e=v[a>>2];v[(d>>>0<33?e:e+(d-1>>>3&536870908)|0)>>2]=0}d=Od(l+24|0,b);c=Od(l+16|0,c);Tn(l+8|0,a,f);b=l;j=jb-48|0;jb=j;a=l+8|0;a:{if(v[d+4>>2]==v[a+4>>2]){d=Od(j+40|0,d);c=Od(j+32|0,c);f=Od(j+24|0,a);a=jb-16|0;jb=a;c=Ci(c,d);v[a+12>>2]=c;b:{if((c|0)<1){break b}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[de(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;aj(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break b}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];i=d;n=v[d>>2];d=-1>>>32-e|0;v[i>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}Od(b,f);jb=a+16|0;break a}e=Od(j+16|0,d);c=Od(j+8|0,c);d=Od(j,a);f=jb-16|0;jb=f;a=Ci(c,e);v[f+12>>2]=a;c:{if((a|0)<1){break c}c=v[e+4>>2];d:{if(!c){c=v[d+4>>2];break d}c=32-c|0;v[f+8>>2]=c;a=v[de(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;g=v[d+4>>2];k=v[v[e>>2]>>2];i=v[e+4>>2];v[f+8>>2]=a;m=32-g|0;v[f+4>>2]=m;n=Lb(f+8|0,f+4|0);h=v[d>>2];k=k&(-1<<i&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];i=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=i|v[h>>2]&(-1<<c&-1>>>m-g^-1);i=c+g|0;c=i&31;v[d+4>>2]=c;h=h+(i>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;i=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=i&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break c}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=de(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];i=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=i|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break c}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}Od(b,d);jb=f+16|0}jb=j+48|0;jb=l+48|0}function ZT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=jb-32|0;jb=f;j=Qh(f+24|0);if(v[a+12>>2]){q=b^1;r=j+3|0;s=j+5|0;x=j+4|0;z=j+2|0;A=j+1|0;C=f+16|5;D=f+16|3;while(1){E=Rn(a,n);while(1){a:{if(!Qb(c,1)){break a}k=Gd(c);if((k|0)==255){break a}h=k&31;d=lk(a)>>>0>h>>>0;h=B(h,6)+E|0;if(k&64){l=1}else{e=Gd(c);i=e<<24>>24;g=255;b:{c:{d:{e=e&127;switch(e|0){case 0:break b;case 1:break c;default:break d}}if(!(e>>>0>121|q)){g=e-1|0;break c}if((e-12&255)>>>0>96|b){break b}g=e+13|0}t[(d?h:f+24|0)|0]=g}F=d?h+1|0:A,G=Gd(c),t[F|0]=G;l=(i|0)<0}if(l){p=d?h:j;g=d?h+3|0:r;e=d?h+5|0:s;o=d?h+4|0:x;m=d?h+2|0:z;h=d?h:f+24|0;while(1){d=h;v[f+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[f+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Gd(c);l=d&128;i=d&63;e:{if(d&64){t[m|0]=1;t[o|0]=i;break e}d=Gd(c);t[e|0]=d;f:{g:{if(i>>>0<=15){t[g|0]=i;wj(p);h:{i:{j:{d=w[g|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[e|0]=B(w[e|0]&15,17);break f}t[g|0]=0;t[m|0]=1;v[f+12>>2]=w[e|0]+1>>>1;v[f+8>>2]=64;F=o,G=v[de(f+12|0,f+8|0)>>2],t[F|0]=G;break f}if((d|0)!=19){break f}if(w[e|0]==128){break g}vx(p);break f}if(i>>>0>44){break f}i=i-16|0;t[g|0]=w[i+12272|0];k:{switch(i|0){case 0:if(d>>>0>1){break g}t[e|0]=d|158;break f;case 1:case 2:t[f+12|0]=15;F=e,G=w[pc(f+12|0,e)|0]|224,t[F|0]=G;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=d+1;F=e,G=v[de(f+12|0,f+8|0)>>2]/2|240,t[F|0]=G;break f;case 14:l:{m:{n:{o:{p:{i=d>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[e|0]=d|240;break f}t[g|0]=3;t[e|0]=d|240;break f}t[g|0]=11;t[e|0]=(d<<3&120)+8|15;break f}t[g|0]=11;t[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=d+1>>>1;v[f+8>>2]=64;F=e,G=v[de(f+12|0,f+8|0)>>2],t[F|0]=G;break f}t[g|0]=0}tx(g,e,D,C);if(Ym(w[f+19|0])>>>0<=Ym(w[g|0])>>>0){break e}q:{if(w[m|0]){break q}if(!ux(g,e,1)){break q}t[m|0]=w[g|0];t[o|0]=w[e|0]}t[g|0]=w[f+19|0];t[e|0]=w[f+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}jb=f+32|0}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-1136|0;jb=e;Jc(b);f=jb-16|0;jb=f;i=e+1112|0;BK(f+8|0,i);g=Hb(f+8|0);d=b;j=nc(d,ac(f,f+8|0));if((g|0)==(j|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(g|0)==(j|0);if(!d){CK(i)}a:{if(!d){break a}if(!HK(e+1112|0)){break a}d=e+1120|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=(Lj(b)|0)){break a}g=e+1128|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))!=(nf(b)|0)){break a}if(!c){h=1;break a}Rb(e+1056|0,0,56);d=e+1056|0;i=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;f=v[d+32>>2];if(!f){v[d+32>>2]=2300;f=2300}if(!v[d+36>>2]){v[d+36>>2]=2301}f=nb[f|0](v[d+40>>2],1,43784)|0;i=-4;if(!f){break b}v[d+28>>2]=f;v[f+43780>>2]=1;v[f+10992>>2]=0;v[f+10996>>2]=0;v[f>>2]=0;v[f+11008>>2]=15;v[f+11e3>>2]=1;v[f+11004>>2]=0;i=0}if(i){break a}d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[e+1052>>2]=d;h=e+1132|0;h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);g=(h|0)!=0;f=qS(e+1040|0,h);c:{d:{e:{f:{if(!d|!h){break f}while(1){v[114578]=0;v[e+12>>2]=1024;d=Q(333,e+12|0,e+1052|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}d=v[d>>2];v[114578]=0;W(261,b|0,e+16|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;k=W(1558,k|0,e+16|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[e+1072>>2]=h;v[e+1060>>2]=d;v[e+1056>>2]=e+16;g=v[f>>2];v[114578]=0;v[e+1068>>2]=g+l;m=Q(1559,e+1056|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}i=v[e+1052>>2]-d|0;v[e+1052>>2]=i;d=v[e+1072>>2];g=(d|0)!=0;if(!i|!d){break f}l=(h+l|0)-d|0;h=d;if((m|0)!=1){continue}break}}v[114578]=0;T(1560,e+1056|0)|0;b=v[114578];v[114578]=0;g:{h:{if((b|0)!=1){h=0;b=e+1124|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(k|0)|g|(m|0)!=1)){v[114578]=0;R(834,e|0,f|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;b=W(835,e+16|0,e|0,0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}v[114578]=0;h=W(1498,a|0,b|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}Bb(b)}fe(f);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(b);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}fe(f);S(a|0);L()}jb=e+1136|0;return h|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=d;k=Mj(a,c);pf(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(xd(a,5)){break a}}f=v[h+24>>2];d=jb-160|0;jb=d;i=$k(d+56|0,v[a+28>>2]);v[114578]=0;g=Q(683,d+40|0,18621)|0;e=v[114578];v[114578]=0;b:{c:{d:{e:{if((e|0)!=1){v[114578]=0;v[d+24>>2]=19468288;v[d+28>>2]=0;U(684,i|0,g|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}Ib(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ib(g);break c}v[114578]=0;t[d+39|0]=0;g=Q(683,d+40|0,18628)|0;e=v[114578];v[114578]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[114578]=0;W(685,i|0,d+39|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}Ib(g);g=Wb(d+40|0);v[114578]=0;e=Q(683,d+24|0,18630)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}v[114578]=0;W(1183,i|0,g|0,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}Ib(e);v[114578]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;R(487,b|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}yb(d+24|0);v[114578]=0;u[d+22>>1]=0;e=Q(683,d+24|0,18632)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;W(1184,i|0,d+22|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}Ib(e);jg(d+22|0,x[v[19811]+12>>1]);v[114578]=0;e=Q(683,d+24|0,18634)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}f=v[Oc(d+16|0,x[d+22>>1])>>2];v[114578]=0;aa(1185,i|0,b|0,e|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}Ib(e);v[114578]=0;u[d+14>>1]=65535;e=Q(683,d+24|0,18636)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}v[114578]=0;f=W(1184,i|0,d+14|0,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Ib(e);if(!((f|0)==1|j>>>0<=l>>>0)){Oe(b,x[d+14>>1])}yb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ib(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(d+24|0);break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0}yb(g)}vg(i);S(a|0);L()}vg(i);jb=d+160|0}_i(a,k,c,h+16|0);jb=h+32|0}function W4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-80|0;jb=j;a:{b:{c:{k=jo(1,32);d:{e:{if(!k){a=ba(4)|0;Yk(a);v[114578]=0;U(2010,a|0,71204,2009);a=v[114578];v[114578]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1998;d=Is(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,j+48|0,c|0)|0;f=v[114578];v[114578]=0;i:{if((f|0)!=1){v[114578]=0;f=Q(2011,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break i}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}v[114578]=0;c=Q(85,j+48|0,c|0)|0;e=v[114578];v[114578]=0;j:{if((e|0)!=1){v[114578]=0;Q(2012,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114578]=0;a=T(1401,96)|0;i=v[114578];v[114578]=0;k:{l:{m:{if((i|0)!=1){v[114578]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;U(2013,j+48|0,k|0,k+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break m}b=Ho(j+24|0,j+48|0);v[114578]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;aa(2087,a|0,j+8|0,b|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break l}v[k+28>>2]=a;Yc(b);Yc(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;sk(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Yc(b);Yc(j+48|0)}Xb(a)}sk(d);_(i|0)|0;v[114578]=0;X(1990,37229,k|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){a=v[k+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[114578]=0;X(1990,37229,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=j+80|0;return k|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function _w(a){a=a|0;var b=0,c=0,d=C(0),e=0;Rb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[114578]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}fa(1917,e|0,67,5,c|0,b|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[114578]=0;fa(1917,a+4528|0,62,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[114578]=0;fa(1917,a+4552|0,53,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[114578]=0;fa(1917,a+4576|0,43,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[114578]=0;fa(1917,a+4600|0,32,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[114578]=0;fa(1917,a+4624|0,22,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[114578]=0;fa(1917,a+4648|0,75,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[114578]=0;fa(1917,a+4672|0,69,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[114578]=0;fa(1917,a+4696|0,60,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[114578]=0;fa(1917,a+4720|0,48,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[114578]=0;fa(1917,a+4744|0,36,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[114578]=0;fa(1917,a+4768|0,25,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1917,a+4792|0,0,0,0,0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[114578]=0;fa(1917,a+4816|0,3,0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[114578]=0;fa(1917,a+4840|0,3,0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1917,a+4864|0,407,1,c|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1917,a+4888|0,400,1,c|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1917,a+4912|0,10,0,c|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1917,a+4936|0,10,0,c|0,-1);c=v[114578];v[114578]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(71204)|0;if((O()|0)==(ga(71204)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=jb-80|0;jb=e;t=v[a+16>>2];h=Qf(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];x=h,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[h+16>>2];if(b){x=h,y=Pf(a+8|0,b),v[x>>2]=y;v[h+4>>2]=mb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){b=0;f=b;j=g;v[e+72>>2]=g;v[e+76>>2]=b;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Ad(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=Kf(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;p=v[i>>2];b=Yb(p,-16777216,16776704);s=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);q=v[a+68>>2];w=q;q=q>>31;v[i+4>>2]=p;p=v[a+72>>2];r=k>>31;k=f<<8;f=k;f=Hma(l,r,f,f>>31);l=mb;r=(e+8|0)+(j<<2)|0;j=Hma(s,s>>31,b,b>>31);f=j+f|0;b=mb+l|0;b=f>>>0<j>>>0?b+1|0:b;l=f;f=Hma(w,q,g,g>>31);g=l+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[r>>2]=(b|0)/256;v[i>>2]=b-(k&p);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;jb=e+80|0}function uH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=jb-48|0;jb=f;v[f+40>>2]=c;v[f+44>>2]=b;v[f+36>>2]=d;j=v[a+8>>2];v[f+28>>2]=f+36;v[f+24>>2]=f+40;b=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=b;v[f+16>>2]=a;v[f+20>>2]=f+44;b=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=b;c=f;a:{b:{switch(v[j+40>>2]){case 0:d=jb-80|0;jb=d;e=v[c>>2];i=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;k=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=k;Eh(b- -64|0,b+32|0,i);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);k=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;n=b+16|0;c=jb-16|0;jb=c;if(k){while(1){i=0;if(g){while(1){h=A[ch(b,i,l)>>3];fc(j,i);A[c+8>>3]=h;Rf(c+8|0,-1,1);h=A[c+8>>3]*32768;A[c+8>>3]=h;h=Sd(h);c:{if(D(h)<2147483648){m=~~h;break c}m=-2147483648}e=Vc(m);q=Nm(n,i,l),r=e,u[q>>1]=r;i=i+1|0;if((g|0)!=(i|0)){continue}break}}l=l+1|0;if((k|0)!=(l|0)){continue}break}}jb=c+16|0;jb=d+80|0;break a;case 2:Lw(c,zb(j));break a;case 3:j=Ug(j);d=jb-80|0;jb=d;e=v[c>>2];l=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;k=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=k;Eh(b- -64|0,b+32|0,l);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);l=v[v[c+12>>2]>>2];k=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;n=b+16|0;c=jb-16|0;jb=c;if(l){o=j+16|0;while(1){e=0;if(k){while(1){h=Sd(A[ch(b,e,i)>>3]*134217728);g=Ve(j,e);m=g;g=tj(h)+(v[g>>2]>>1)|0;p=g;g=Hr(o)+g&-4096;v[m>>2]=p-g;A[c+8>>3]=+(g|0)*7.450580596923828e-9;Rf(c+8|0,-1,1);h=A[c+8>>3]*32768;A[c+8>>3]=h;h=Sd(h);d:{if(D(h)<2147483648){g=~~h;break d}g=-2147483648}g=Vc(g);q=Nm(n,e,i),r=g,u[q>>1]=r;e=e+1|0;if((k|0)!=(e|0)){continue}break}}i=i+1|0;if((l|0)!=(i|0)){continue}break}}jb=c+16|0;jb=d+80|0;break a;case 1:Lw(c,zb(j));break a;default:break b}}Lw(c,zb(j))}v[a+4>>2]=v[a+4>>2]+v[f+36>>2];jb=f+48|0}function rI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-80|0;jb=j;a:{b:{c:{d:{e:{f:{k=jo(1,28);if(!k){a=ba(4)|0;Yk(a);v[114578]=0;U(2010,a|0,71204,2009);a=v[114578];v[114578]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1998;d=Is(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,j+48|0,c|0)|0;f=v[114578];v[114578]=0;j:{if((f|0)!=1){v[114578]=0;f=Q(2011,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}v[114578]=0;c=Q(85,j+48|0,c|0)|0;e=v[114578];v[114578]=0;k:{if((e|0)!=1){v[114578]=0;Q(2012,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114578]=0;a=T(1401,80)|0;i=v[114578];v[114578]=0;l:{m:{n:{if((i|0)!=1){v[114578]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;U(2013,j+48|0,k|0,k+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break n}b=Ho(j+24|0,j+48|0);v[114578]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;aa(2014,a|0,j+8|0,b|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[k+24>>2]=a;Yc(b);Yc(j+48|0);sk(d);c=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Yc(b);Yc(j+48|0)}Xb(a)}sk(d);_(i|0)|0;v[114578]=0;X(1990,34722,k|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Xb(Qr(a))}c=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);break d}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114578]=0;X(1990,34722,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=j+80|0;return c|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function bn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-16|0;jb=g;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Eb(g+8|0,a+1074312|0,15);if(Cb(g+8|0)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+831|0];t[b+832|0]=c;t[b+831|0]=c}if(c){v[b+776>>2]=c}c:{if(uj(b)){c=v[b+776>>2];if(!c){break c}e=v[a+1074392>>2];d=v[b+708>>2];if((c|0)<1|(d|0)>-1?(c|0)<0?(d|0)>=1:0:1){c=0-c|0;v[b+776>>2]=c}i=v[b+880>>2];h=b;j=(+(e>>>0)+1)*+(c|0)/+y[a+1074416>>2];d:{if(D(j)<2147483648){a=~~j;break d}a=-2147483648}v[h+880>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+880>>2]=a}a=a-(e?i:0)|0;c=a>>31;f=d>>31;if((f+d^f)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+876>>2]=d+v[b+876>>2];t[b+872|0]=w[b+872|0]|8;break c}v[b+708>>2]=d-a;v[b+876>>2]=a+v[b+876>>2];t[b+872|0]=w[b+872|0]|8;break c}e=1;e:{if(!(t[b+872|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){Eb(g+8|0,a+1074312|0,6);if(Cb(g+8|0)){break e}}e=0;if(v[a+480180>>2]!=8){break e}e=(w[a+480208|0]&2)>>>1|0}f=v[b+776>>2];i=v[a+480180>>2];k=w[b+872|0];l=v[a+480180>>2];c=v[b+700>>2];f:{if(!c){d=v[b+708>>2];c=0;break f}d=v[b+708>>2];if(!d){break f}h=e;e=(i|0)==268435456&(f|0)>239;if(!(e?k&1:h)){break f}f=e?f-240|0:f;e=(l|0)==64?B(f,10):f;h=b;g:{h:{i:{j:{k:{if((c|0)<(d|0)){if(w[a+480208|0]&16){if(v[a+480180>>2]!=4){break k}c=v[b+700>>2]}e=e<<2;break h}if((c|0)<=(d|0)){break f}if(w[a+480208|0]&16){if(v[a+480180>>2]!=4){break j}c=v[b+700>>2]}e=0-(e<<2)|0;break i}c=v[((e>>>0<255?e:255)<<2)+25312>>2];e=c;d=c>>31;c=v[b+700>>2];d=Hma(e,d,c,c>>31)+32768|0;c=mb;e=Ac(Ima(d,d>>>0<32768?c+1|0:c,65536,0),mb);c=v[b+700>>2];d=e-c|0;e=(d|0)>1?d:1;break h}c=v[((e>>>0<255?e:255)<<2)+26336>>2];e=c;d=c>>31;c=v[b+700>>2];d=Hma(e,d,c,c>>31)+32768|0;c=mb;e=Ac(Ima(d,d>>>0<32768?c+1|0:c,65536,0),mb);c=v[b+700>>2];d=e-c|0;e=(d|0)<-1?d:-1}d=v[b+708>>2];c=c+e|0;c=(c|0)<(d|0)?d:c;break g}d=v[b+708>>2];c=c+e|0;c=(c|0)>(d|0)?d:c}v[h+700>>2]=c}if((c|0)!=(d|0)){break c}Eb(g+8|0,a+1074312|0,25);if(!(m=Cb(g+8|0),n=1,o=v[a+480180>>2]!=1,o?m:n)){break c}v[b+708>>2]=0}jb=g+16|0}function zD(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=jb-128|0;jb=j;a:{b:{c:{if(!dl(f,g,h,i,0,0,0,0)){break c}m=f;n=g;l=h;o=i&65535;k=i>>>16&32767;d:{e:{if((k|0)!=32767){p=4;if(k){break e}m=l|m|(n|o)?3:2;break d}p=!(l|m|(n|o))}m=p}if(!m){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}rd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];pF(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=o<<16;p=d;q=l|e&65535;m=q;n=h;q=i>>>16&32767;k=i&65535|q<<16;if((dl(b,c,p,m,f,g,h,k)|0)<=0){if(dl(b,c,p,m,f,g,n,k)){h=b;i=c;break a}rd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{rd(j+96|0,b,c,p,m,0,0,0,1081540608);h=v[j+108>>2];m=h;p=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){rd(j+80|0,f,g,n,k,0,0,0,1081540608);f=v[j+92>>2];k=f;n=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((o|0)>(q|0)){while(1){k=p;l=n;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0?1:(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){rd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;p=k<<1|i>>>31;break f}l=m<<1|p>>>31;p=p<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}l=p;q=l-n|0;n=m-((l>>>0<n>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=n-(l>>>0>q>>>0)|0;n=q-l|0;g:{if((k|0)<0){n=p;k=m;break g}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|n|(i|k)){break g}rd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=n;k=k<<1|b>>>31;n=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){rd(j- -64|0,h,i,n,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=n;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;jb=j+128|0}function pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0;e=jb-80|0;jb=e;u=v[a+16>>2];h=Qf(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];x=h,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[h+16>>2];if(b){x=h,y=Pf(a+8|0,b),v[x>>2]=y;v[h+4>>2]=mb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){b=0;f=b;j=g;v[e+72>>2]=g;v[e+76>>2]=b;i=(((i&2147483647)<<1|g>>>31)&-2)+u|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Ad(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);zd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=Kf(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;p=v[i>>2];b=Yb(p,-16777216,16776704);s=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);q=v[a+68>>2];w=q;q=q>>31;v[i+4>>2]=p;p=v[a+72>>2];r=k>>31;k=f<<8;f=k;f=Hma(l,r,f,f>>31);l=mb;r=(e+8|0)+(j<<2)|0;j=Hma(s,s>>31,b,b>>31);f=j+f|0;b=mb+l|0;b=f>>>0<j>>>0?b+1|0:b;l=f;f=Hma(w,q,g,g>>31);g=l+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[r>>2]=(b|0)/256;v[i>>2]=b-(k&p);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;jb=e+80|0}
function Wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-48|0;jb=g;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}t=b;w=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=i;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+w|0;e=(j>>>16&65520)+t|0;j=u[e+14>>1];i=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];x=u[e+6>>1];n=u[e+4>>1];r=u[e+2>>1];s=u[e>>1];h=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],r)+B(u[b+(e|-12)>>1],s)|0)+B(u[b+(e|-4)>>1],n)|0)+B(u[b+e>>1],x)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(i,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(h<<2)|0;j=v[k>>2];i=v[a+60>>2];e=(g+32|0)+(h<<3)|0;h=v[e>>2];b=Yb(h,-16777216,16776704);q=v[a+64>>2];f=Yb(v[e+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[e+4>>2]=h;s=v[a+72>>2];j=j<<8;h=j;h=Hma(i,i>>31,h,h>>31);i=mb;l=k;k=Hma(q,q>>31,b,b>>31);h=k+h|0;b=mb+i|0;b=h>>>0<k>>>0?b+1|0:b;i=h;h=Hma(r,n,f,f>>31);f=i+h|0;b=mb+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[l>>2]=(b|0)/256;v[e>>2]=b-(j&s);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=b+o|0;b=o>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];h=v[g+32>>2];break e}b=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;jb=g+48|0}function ql(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;a:{b:{if(md(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=lk(a)>>>0;g=x[b+8>>1];if((g|0)!=65535?c:0){break b}f=g;if((f&65535)==65535){g=lk(a)-1|0;f=0}d=Xe(a,v[b+4>>2],f&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=g&65535;if(l>>>0<(f&65535)>>>0){break d}j=w[b+10|0];e=f;c=d;while(1){e:{if(!k){if((j|0)!=w[c+3|0]){break e}break c}if((j|0)==w[c+2|0]){break c}}c=c+6|0;e=e+1|0;if((e&65535)>>>0<=l>>>0){continue}break}}j=g&65535;if(j>>>0>=(f&65535)>>>0){e=f;c=d;while(1){f:{if(!k){if(w[c+3|0]){break f}t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break c}if(w[c+2|0]){break f}t[c+2|0]=w[b+10|0];t[c+4|0]=w[b+11|0];break c}c=c+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[Xm(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}g=g&65535;if(g>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[d+3|0]-9|0){case 4:if(!AK(v[Xm(a)+8>>2],1)){break i}c=1;t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}c=d;k:{if(i){e=w[d+5|0];if(e>>>0>128){break i}t[d+2|0]=2;t[d+3|0]=w[b+10|0];a=1;break k}t[d+2|0]=2;t[d+3|0]=w[b+10|0];e=w[d+5|0];a=2}t[c+4|0]=a+e>>>a;t[d+5|0]=w[b+11|0];break c}d=d+6|0;f=f+1|0;if(g>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){c=w[b+11|0];d=13;m:{switch(w[b+10|0]-1|0){case 1:c=Nk(B(i?2:4,c));e=w[b+12|0];d=9;break;case 0:break m;default:break l}}t[b+11|0]=c;t[b+10|0]=d;e=e&254;t[b+12|0]=e;break l}f=w[b+11|0];t[h+14|0]=f;d=b;c=w[b+10|0];n:{o:{if(!(!i|(c|0)!=9)){if(f>>>0>128){break n}c=2;f=(f&254)>>>1|0;break o}t[h+15|0]=c;if(!ux(h+15|0,h+14|0,1)){break n}c=w[h+15|0];if(!c){break n}e=w[b+12|0];f=w[h+14|0]}t[d+11|0]=f;t[b+10|0]=c;t[b+12|0]=e&254}e=w[b+12|0]}c=1;if(e&1){break g}t[b+12|0]=e^4;if(ql(a,b)){break a}}p:{q:{d=v[b>>2];if((d|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){break q}d=v[b>>2]}if((d|0)!=2){break b}c=0;d=v[b+4>>2];if(!d){break a}v[b+4>>2]=d-1;break p}v[b+4>>2]=v[b+4>>2]+1}t[b+12|0]=w[b+12|0]|1;c=ql(a,b);break a}c=1;break a}c=0}jb=h+16|0;return c|0}function QZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-1072|0;jb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;v[j+956>>2]=j+960;k=bw(j+960|0,100,64687,j+16|0);v[j+48>>2]=2428;n=Rd(j+536|0,0,j+48|0);v[j+48>>2]=2428;l=Rd(j+528|0,0,j+48|0);m=j+544|0;a:{b:{c:{if(k>>>0>=100){v[114578]=0;a=da(2453)|0;k=v[114578];v[114578]=0;if((k|0)==1){break b}v[j>>2]=f;v[j+4>>2]=g;v[114578]=0;v[j+8>>2]=h;v[j+12>>2]=i;k=aa(2475,j+956|0,a|0,64687,j|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}a=v[j+956>>2];if(!a){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}ye(n,a);ye(l,od(k<<2));if(rj(l)){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)==1){break b}break c}m=v[l>>2]}v[114578]=0;Bc(j+520|0,d);a=v[114578];v[114578]=0;d:{e:{f:{g:{h:{i:{j:{if((a|0)!=1){v[114578]=0;p=T(2457,j+520|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break j}v[114578]=0;a=v[j+956>>2];aa(2471,p|0,a|0,a+k|0,m|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break j}o=k?w[v[j+956>>2]]==45:o;h=Wb(j+488|0);f=tf(j+472|0);g=tf(j+456|0);v[114578]=0;na(2511,c|0,o|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);a=v[114578];v[114578]=0;if((a|0)==1){break i}v[j+36>>2]=2428;i=Rd(j+40|0,0,j+36|0);c=j+48|0;a=v[j+452>>2];k:{if((a|0)<(k|0)){a=((Fb(g)+(k-a<<1|1)|0)+Fb(f)|0)+v[j+452>>2]|0;break k}a=((Fb(g)+Fb(f)|0)+v[j+452>>2]|0)+2|0}if(a>>>0<101){break h}ye(i,od(a<<2));c=v[i>>2];if(c){break h}v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break g}k=P()|0;O()|0;break a}k=P()|0;O()|0;break e}k=P()|0;O()|0;break f}a=v[d+4>>2];v[114578]=0;sa(2512,c|0,j+36|0,j+32|0,a|0,m|0,(k<<2)+m|0,p|0,o|0,j+512|0,v[j+508>>2],v[j+504>>2],h|0,f|0,g|0,v[j+452>>2]);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;a=ka(2487,b|0,c|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break d}}}k=P()|0;O()|0;Gc(i)}Lc(g);Lc(f);yb(h)}Ob(j+520|0);break a}Gc(i);Lc(g);Lc(f);yb(h);Ob(j+520|0);Gc(l);Gc(n);jb=j+1072|0;return a|0}L()}k=P()|0;O()|0}Gc(l);Gc(n);S(k|0);L()}function Gy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;a:{if(!De(a)){break a}on(a);if(c){c=b;o=jb-16|0;jb=o;f=a;if(De(a)){e=x[f+34>>1];p=v[f+4>>2];h=v[f+8>>2];n=v[f>>2];s=!(e&2)|(p>>>0>=h>>>0|n>>>0<h>>>0);q=v[f+12>>2];g=v[f+16>>2];z=!(e&8)|(q>>>0>=g>>>0|g>>>0>n>>>0);A=c+1304360|0;d=c+1074984|0;l=e&4;j=e&16;while(1){b:{if((f|0)!=v[d+104>>2]){break b}c=v[d+76>>2];if(!c){break b}c:{d:{i=d;e:{f:{if(z){break f}k=v[d+88>>2];if(k&2048){break f}v[d+84>>2]=g;v[d+80>>2]=q;e=j;c=g;break e}if(s){break d}v[d+84>>2]=h;v[d+80>>2]=p;k=v[d+88>>2];e=l;c=h}v[i+76>>2]=c;i=k|2;r=d+88|0;k=(e|0)!=0;e=1;break c}r=d+88|0;i=v[d+88>>2]&-3;k=0;e=0}i=i&-5|(e?k?4:0:0);v[d+88>>2]=i;if(y[d+4>>2]>c>>>0){i=i&-129;v[d+88>>2]=i;m=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=m}if(!k){v[r>>2]=i&-129}if(e){break b}v[d+76>>2]=n}d=d+896|0;if((A|0)!=(d|0)){continue}break}}jb=o+16|0}if((sq(a)|0)==2){d=0;f=jb+-64|0;jb=f;e=ue(a);l=e<<6;h=v[a+20>>2];g=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){j=B(d,e);m=B(e,d^-1);c=0;while(1){u[g+(c+j<<1)>>1]=x[g+(c-e<<1)>>1];u[h+(c+m<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){j=v[a+8>>2];g=v[a+4>>2];Eb(f+32|0,b+1074312|0,33);dO(f+40|0,d,h+(B(e,g)<<1)|0,j-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Eb(f+32|0,b+1074312|0,33);dO(f+8|0,d+(l<<1)|0,h+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}jb=f- -64|0;return}if((sq(a)|0)!=1){break a}d=0;f=jb+-64|0;jb=f;e=ue(a);l=e<<6;h=v[a+20>>2];g=h+B(e,v[a>>2])|0;while(1){if(e){j=B(d,e);m=B(e,d^-1);c=0;while(1){t[g+(c+j|0)|0]=w[g+(c-e|0)|0];t[h+(c+m|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){j=v[a+8>>2];g=v[a+4>>2];Eb(f+32|0,b+1074312|0,33);cO(f+40|0,d,h+B(e,g)|0,j-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Eb(f+32|0,b+1074312|0,33);cO(f+8|0,d+l|0,h+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}jb=f- -64|0}}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;e=jb-48|0;jb=e;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}w=b;x=v[a+16>>2];g=v[a+44>>2];v[e+32>>2]=g;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;o=v[a+40>>2];p=v[a+36>>2];h=v[a+4>>2];j=v[a>>2];v[e+24>>2]=j;v[e+28>>2]=h;v[e+16>>2]=i;v[e+20>>2]=f;e:{if(d){while(1){h=(((h&2147483647)<<1|j>>>31)&-2)+x|0;b=(j>>>16&65520)+w|0;f=u[b+14>>1];j=u[b+12>>1];i=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];y=u[b+4>>1];n=u[b+2>>1];r=u[b>>1];g=0;m=1;k=1;b=0;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[h+(b|-4)|0],n)+B(t[h+(b|-6)|0],r)|0)+B(t[h+(b|-2)|0],y)|0)+B(t[b+h|0],q)|0)+B(t[h+(b|2)|0],l)|0)+B(t[h+(b|4)|0],i)|0)+B(j,t[h+(b|6)|0])|0)+B(f,t[h+(b|8)|0])<<8)/32768;s=k&1;k=0;b=1;if(s){continue}break}while(1){k=(e+8|0)+(g<<2)|0;j=v[k>>2];i=v[a+60>>2];h=(e+32|0)+(g<<3)|0;g=v[h>>2];b=Yb(g,-16777216,16776704);q=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[h+4>>2]=g;s=v[a+72>>2];j=j<<8;g=j;g=Hma(i,i>>31,g,g>>31);i=mb;l=k;k=Hma(q,q>>31,b,b>>31);g=k+g|0;b=mb+i|0;b=g>>>0<k>>>0?b+1|0:b;i=g;g=Hma(r,n,f,f>>31);f=i+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[l>>2]=(b|0)/256;v[h>>2]=b-(j&s);g=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[e+8>>2]);o=b+o|0;b=o>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;j=v[e+24>>2];h=v[e+28>>2];continue}break}j=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];g=v[e+32>>2];break e}b=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=g;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=h;jb=e+48|0}function UZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-464|0;jb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;v[j+348>>2]=j+352;k=bw(j+352|0,100,64687,j+16|0);v[j+48>>2]=2428;n=Rd(j+232|0,0,j+48|0);v[j+48>>2]=2428;l=Rd(j+224|0,0,j+48|0);m=j+240|0;a:{b:{c:{if(k>>>0>=100){v[114578]=0;a=da(2453)|0;k=v[114578];v[114578]=0;if((k|0)==1){break b}v[j>>2]=f;v[j+4>>2]=g;v[114578]=0;v[j+8>>2]=h;v[j+12>>2]=i;k=aa(2475,j+348|0,a|0,64687,j|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}a=v[j+348>>2];if(!a){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}ye(n,a);ye(l,od(k));if(rj(l)){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)==1){break b}break c}m=v[l>>2]}v[114578]=0;Bc(j+216|0,d);a=v[114578];v[114578]=0;d:{e:{f:{g:{h:{i:{j:{if((a|0)!=1){v[114578]=0;p=T(21,j+216|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break j}v[114578]=0;a=v[j+348>>2];aa(2448,p|0,a|0,a+k|0,m|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break j}o=k?w[v[j+348>>2]]==45:o;h=Wb(j+192|0);f=Wb(j+176|0);g=Wb(j+160|0);v[114578]=0;na(2509,c|0,o|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);a=v[114578];v[114578]=0;if((a|0)==1){break i}v[j+36>>2]=2428;i=Rd(j+40|0,0,j+36|0);c=j+48|0;a=v[j+156>>2];k:{if((a|0)<(k|0)){a=((Fb(g)+(k-a<<1|1)|0)+Fb(f)|0)+v[j+156>>2]|0;break k}a=((Fb(g)+Fb(f)|0)+v[j+156>>2]|0)+2|0}if(a>>>0<101){break h}ye(i,od(a));c=v[i>>2];if(c){break h}v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break g}k=P()|0;O()|0;break a}k=P()|0;O()|0;break e}k=P()|0;O()|0;break f}a=v[d+4>>2];v[114578]=0;sa(2510,c|0,j+36|0,j+32|0,a|0,m|0,k+m|0,p|0,o|0,j+208|0,t[j+207|0],t[j+206|0],h|0,f|0,g|0,v[j+156>>2]);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;a=ka(17,b|0,c|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break d}}}k=P()|0;O()|0;Gc(i)}yb(g);yb(f);yb(h)}Ob(j+216|0);break a}Gc(i);yb(g);yb(f);yb(h);Ob(j+216|0);Gc(l);Gc(n);jb=j+464|0;return a|0}L()}k=P()|0;O()|0}Gc(l);Gc(n);S(k|0);L()}function qH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;d=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;c=e;a:{b:{switch(v[d+40>>2]){case 0:b=jb-80|0;jb=b;f=v[c>>2];h=v[f+4>>2];v[b+40>>2]=v[f+20>>2];j=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=j;Mm(b- -64|0,b+32|0,h);f=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];l=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;m=b+16|0;c=b;h=jb-16|0;jb=h;if(j){while(1){f=0;if(l){while(1){i=A[ch(c,f,k)>>3];fc(d,f);A[h+8>>3]=i;Rf(h+8|0,-1,1);i=A[h+8>>3]*32768;A[h+8>>3]=i;i=Sd(i);c:{if(D(i)<2147483648){g=~~i;break c}g=-2147483648}g=Vc(g);q=Lm(m,f,k),r=g,u[q>>1]=r;f=f+1|0;if((l|0)!=(f|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}jb=h+16|0;jb=b+80|0;break a;case 2:Iw(c,zb(d));break a;case 3:k=Ug(d);b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];v[b+40>>2]=v[d+20>>2];j=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=j;Mm(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];l=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;m=b+16|0;c=b;d=jb-16|0;jb=d;if(j){n=k+16|0;while(1){h=0;if(l){while(1){i=Sd(A[ch(c,h,f)>>3]*134217728);g=Ve(k,h);o=g;g=tj(i)+(v[g>>2]>>1)|0;p=g;g=Hr(n)+g&-4096;v[o>>2]=p-g;A[d+8>>3]=+(g|0)*7.450580596923828e-9;Rf(d+8|0,-1,1);i=A[d+8>>3]*32768;A[d+8>>3]=i;i=Sd(i);d:{if(D(i)<2147483648){g=~~i;break d}g=-2147483648}g=Vc(g);q=Lm(m,h,f),r=g,u[q>>1]=r;h=h+1|0;if((l|0)!=(h|0)){continue}break}}f=f+1|0;if((j|0)!=(f|0)){continue}break}}jb=d+16|0;jb=b+80|0;break a;case 1:Iw(c,zb(d));break a;default:break b}}Iw(c,zb(d))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb+-64|0;jb=d;u[d+62>>1]=c;jg(d+62|0,32);f=Ql(a);v[114578]=0;R(796,f|0,x[d+62>>1]);a=v[114578];v[114578]=0;a:{if((a|0)!=1){b:{c:{if(!x[d+62>>1]){break c}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}u[d+24>>1]=1;f:{if(!x[b+480190>>1]){break f}while(1){g:{if(De(vp(b,x[d+24>>1]))){break g}i=d,j=lz(bc(f),cc(f),d+24|0),v[i+48>>2]=j;i=d,j=cc(f),v[i+40>>2]=j;if(!rl(d+48|0,d+40|0)){break g}u[d+60>>1]=x[d+24>>1];a=1;if(!x[b+480192>>1]){break f}while(1){c=v[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=$s(c);if((c|0)==(e|0)){break h}while(1){if(x[c>>1]==x[d+60>>1]){u[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(x[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break e}a=ht(d+48|0);v[114578]=0;c=Q(1051,b|0,a|0)|0;e=v[114578];v[114578]=0;i:{j:{if((e|0)==1){break j}k:{if(c){v[114578]=0;Q(1052,b|0,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break j}e=1;if(!x[b+480192>>1]){break k}while(1){c=v[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=$s(c);if((c|0)==(g|0)){break l}while(1){m:{if(y[a+4>>2]<=x[c>>1]){break m}ee(d+40|0,a,x[c>>1]);if(Cb(d+40|0)){break m}u[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}ke(a);break c}vj(d+24|0,a);v[114578]=0;U(1053,d+32|0,d+24|0,1);c=v[114578];v[114578]=0;if((c|0)!=1){wk(d+16|0,a);v[114578]=0;t[d+15|0]=0;X(1054,d+40|0,d+32|0,d+16|0,d+15|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}}}c=P()|0;O()|0;ke(a);break a}vj(d,a);i=d,j=Ci(d+40|0,d),u[i+60>>1]=j;ke(a);if(x[d+60>>1]>=4e3){break d}}v[114578]=0;R(463,f|0,d+60|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}if(x[b+480190>>1]>=x[d+60>>1]){break d}u[b+480190>>1]=x[d+60>>1]}h=h+1|0;if(x[d+62>>1]>(h&65535)>>>0){continue}break}}jb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}kf(f);S(c|0);L()}function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=jb-80|0;jb=e;q=v[a+16>>2];i=Qf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];x=i,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[i+16>>2];if(b){x=i,y=Pf(a+8|0,b),v[x>>2]=y;v[i+4>>2]=mb}b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;h=v[a+52>>2];v[e+40>>2]=h;l=v[a+56>>2];v[e+44>>2]=l;r=v[a+24>>2];s=v[a+20>>2];j=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=j;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){b=0;g=b;h=f;v[e+72>>2]=f;v[e+76>>2]=b;j=((((j&2147483647)<<1|f>>>31)&2147483646)<<1)+q|0;a:{b=v[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;Ad(v[i+8>>2],(u[(f<<1|2)+j>>1]+u[j+((f&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break a}b=b-1|0;h=v[e+72>>2];g=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];f=v[b+4>>2];if(f){k=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(k,(u[(b<<1|2)+j>>1]+u[j+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[i+8>>2],f);b=v[i+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;h=Kf(b,v[i+12>>2]);v[e+12>>2]=h;v[e+8>>2]=h;g=0;l=1;while(1){k=v[a+60>>2];o=k;j=(e+32|0)+(g<<3)|0;m=v[j>>2];b=Yb(m,-16777216,16776704);p=v[a+64>>2];f=Yb(v[j+4>>2],-16777216,16776704);n=v[a+68>>2];t=n;n=n>>31;v[j+4>>2]=m;m=v[a+72>>2];k=k>>31;h=h<<8;k=Hma(o,k,h,h>>31);o=mb;w=(e+8|0)+(g<<2)|0;g=k;k=Hma(p,p>>31,b,b>>31);g=g+k|0;b=mb+o|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=Hma(t,n,f,f>>31);f=k+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[w>>2]=(b|0)/256;v[j>>2]=b-(h&m);if(l){g=1;l=0;h=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],r);Sb(e+24|0,e+16|0);if(d){c=c+8|0;f=v[e+24>>2];j=v[e+28>>2];continue}break}f=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];h=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=h;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=f;v[a+4>>2]=j;jb=e+80|0}function dL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;e=B(b,896)+a|0;a:{if(w[e+1075074|0]&2){i=1;b:{if(!(w[a+480209|0]&16)){break b}i=0;if(!(v[a+480180>>2]&16777248)){break b}i=!(w[a+480208|0]&4)}if(v[a+480180>>2]==64){a=B(b,896)+a|0;b=a+1075823|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075828|0],167)}t[b|0]=d+1;break a}f=e+1074984|0;c:{if(!i){break c}Eb(h+8|0,a+1074312|0,21);if(!Cb(h+8|0)){break c}e=B(b,896)+a|0;g=e+1075823|0;t[g|0]=w[g|0]+(w[e+1075827|0]<<2)}g=B(b,896)+a|0;j=g+1075826|0;k=g+1075823|0;e=Ix(a,w[j|0],w[k|0]);d:{if(uj(f)){z[d>>2]=C(C(B(w[g+1075828|0],e)|0)*C(6510417279059766e-21))+z[d>>2];c=g+1075856|0;d=w[c|0];t[c|0]=d&243|8;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break d}t[c|0]=d|12;break d}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}e=v[a+480180>>2]&5?(w[j|0]&3)==1?0-e|0:e:e;f=a+1074312|0;Eb(h+8|0,f,21);d=Cb(h+8|0);g=v[a+480208>>2];e:{if(d){d=g&4;e=d?e:0-e|0;d=d?5:6;break e}d=5;f:{if(g&131072){break f}d=8;if(v[a+480180>>2]==1024){break f}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break f}d=6}Eb(h+8|0,f,80);if(!Cb(h+8|0)){break e}d=w[(B(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(B(w[(B(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;g=0-d|0;g:{if(!(w[a+480208|0]&16)|v[a+480180>>2]==4){break g}e=v[c>>2];h:{if((d|0)<=-1){d=$x(a,g>>>2|0);d=Ac(Ima(Hma(d,d>>31,e,e>>31),mb,65536,0),mb);e=v[c>>2];d=d-e|0;f=g&3;if(!f){break g}f=cM(a,f);break h}f=d&3;d=_x(a,d>>>2|0);d=Ac(Ima(Hma(d,d>>31,e,e>>31),mb,65536,0),mb);e=v[c>>2];d=d-e|0;if(!f){break g}f=bM(a,f)}d=(Ac(Ima(Hma(f,f>>31,e,e>>31),mb,65536,0),mb)+d|0)-v[c>>2]|0}v[c>>2]=v[c>>2]+d;c=ay(a,b);if(!c){break d}d=c;f=g<<16>>16;e=v[(B(b,896)+a|0)+1075640>>2];if(e){j=w[e+33|0]}else{j=2}nb[v[v[c>>2]+84>>2]](d,f,j<<24>>24,b)}if(!i){break a}Eb(h+8|0,a+1074312|0,21);if(Cb(h+8|0)){break a}t[k|0]=w[k|0]+w[(B(b,896)+a|0)+1075827|0];break a}if(!(w[e+1075654|0]&2)){break a}a=ay(a,b);if(!a){break a}nb[v[v[a>>2]+84>>2]](a,0,0,b)}jb=h+16|0}function Eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=jb+-64|0;jb=c;e=jb-16|0;jb=e;f=b+16|0;ER(e+8|0,f);d=a;g=Hb(e+8|0);h=nc(a,ac(e,e+8|0));if((g|0)==(h|0)){$b(d,Hb(e+8|0))}jb=e+16|0;if((g|0)!=(h|0)){d=jb-16|0;jb=d;Rb(f,0,128);jb=d+16|0}cS(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;ud(c+48|0,a,Cf(a));v[114578]=0;d=T(332,c+48|0)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)==1){break b}v[114578]=0;e=b+4|0;R(508,e|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(698,c+40|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;Q(699,c+48|0,c+40|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;d=T(392,a|0)|0;e=v[114578];v[114578]=0;c:{if((e|0)==1){break c}v[114578]=0;U(343,c+24|0,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}v[114578]=0;a=T(339,c+24|0)|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){e:{f:{g:{if(!a){break g}while(1){v[114578]=0;a=Q(258,c+24|0,5)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if(!a){break g}v[114578]=0;Q(700,c+24|0,c+20|0)|0;a=v[114578];v[114578]=0;h:{if((a|0)!=1){a=4;if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))==1414682436|(w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))==1196380752){break h}v[114578]=0;a=T(392,c+24|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[114578]=0;U(343,c|0,c+24|0,a|0);a=v[114578];v[114578]=0;i:{j:{if((a|0)!=1){if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))!=1414682436){break j}v[114578]=0;i=C(Aa(701,c|0));a=v[114578];v[114578]=0;if((a|0)==1){break e}z[b+144>>2]=i;break i}a=P()|0;O()|0;break d}if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))!=1196380752){break i}v[114578]=0;a=T(392,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}v[b+148>>2]=a}Bb(c);continue}}Bb(c+24|0);Bb(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0;Bb(c);break d}a=P()|0;O()|0}Bb(c+24|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Bb(c+48|0);S(a|0);L()}function Ov(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[21203]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return $e(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}h=e+1|0;f=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}h=e+2|0;f=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+60112>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+60112>>2];f=1;continue}h=w[e|0];f=h>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{i=e+1|0;f=h-128|g<<6;h=i;v:{if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=e+2|0;f=h|f<<6;h=i;if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[114552]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[114552]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function V4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-48|0;jb=k;a:{b:{c:{j=jo(1,32);d:{e:{if(!j){a=ba(4)|0;Yk(a);v[114578]=0;U(2010,a|0,71204,2009);a=v[114578];v[114578]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1998;d=Is(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,k+16|0,c|0)|0;f=v[114578];v[114578]=0;i:{if((f|0)!=1){v[114578]=0;f=Q(2011,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break i}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}v[114578]=0;c=Q(85,k+16|0,c|0)|0;e=v[114578];v[114578]=0;j:{if((e|0)!=1){v[114578]=0;Q(2012,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114578]=0;c=T(1401,96)|0;e=v[114578];v[114578]=0;k:{l:{m:{if((e|0)!=1){v[114578]=0;U(2013,k+16|0,j|0,j+4|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}e=Ho(k+8|0,k+16|0);v[114578]=0;ea(2088,c|0,a|0,b|0,e|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break l}v[j+28>>2]=c;Yc(e);Yc(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;sk(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Yc(e);Yc(k+16|0)}Xb(c)}sk(d);_(i|0)|0;v[114578]=0;X(1990,37255,j|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){a=v[j+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[114578]=0;X(1990,37255,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=k+48|0;return j|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=jb-208|0;jb=c;f=1;e=v[a+12>>2];k=1<<e;n=2;if(e>>>0>=2){j=k;while(1){j=j>>>2|0;if(j){p=B(f,3);q=f<<1;l=0;while(1){NK(c+192|0,tc(a,l<<1));NK(c+176|0,tc(a,l));Jh(c+160|0,c+176|0,c+192|0);e=l<<n;o=f+e|0;if(e>>>0<o>>>0){while(1){d=tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+f|0;d=tc(b,g);h=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=h;h=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=h;h=e+q|0;d=tc(b,h);m=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=m;m=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=m;m=e+p|0;d=tc(b,m);i=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=i;i=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=i;ok(c+80|0,c+144|0,c+128|0);ui(c- -64|0,c+144|0,c+128|0);ok(c+48|0,c+112|0,c+96|0);ui(c+16|0,c+112|0,c+96|0);Jh(c+32|0,30864,c+16|0);ok(c+16|0,c+80|0,c+48|0);d=tc(b,e);i=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=i;i=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=i;ok(c,c- -64|0,c+32|0);Jh(c+16|0,c+192|0,c);d=tc(b,g);i=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=i;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ui(c,c+80|0,c+48|0);Jh(c+16|0,c+176|0,c);d=tc(b,h);h=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=h;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ui(c,c- -64|0,c+32|0);Jh(c+16|0,c+160|0,c);d=tc(b,m);h=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=h;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((o|0)!=(e|0)){continue}break}}l=l+1|0;if((l|0)!=(j|0)){continue}break}e=v[a+12>>2]}f=f<<2;n=n+2|0;if(n>>>0<=e>>>0){continue}break}}a:{if(!(e&1)){break a}j=k>>>1|0;if(!j){break a}e=0;while(1){k=e+j|0;a=tc(b,k);f=v[a+12>>2];v[c+200>>2]=v[a+8>>2];v[c+204>>2]=f;f=v[a+4>>2];v[c+192>>2]=v[a>>2];v[c+196>>2]=f;ui(c+176|0,tc(b,e),c+192|0);a=tc(b,k);f=v[c+188>>2];v[a+8>>2]=v[c+184>>2];v[a+12>>2]=f;k=v[c+180>>2];v[a>>2]=v[c+176>>2];v[a+4>>2]=k;yx(tc(b,e),c+192|0);e=e+1|0;if((j|0)!=(e|0)){continue}break}}jb=c+208|0}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{switch(b|0){case 0:e=jb-16|0;jb=e;f=Wb(a);c:{d:{if(Fb(c)){while(1){d=v[ij(c,i)>>2];e:{if(d>>>0>=2097152){v[114578]=0;R(110,f|0,63);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break d}b=0;f:{g:{h:{while(1){h=d&63;t[(e+10|0)+b|0]=h;a=b+1|0;d=d>>>6|0;if(!d){break h}b=a;if((a|0)!=6){continue}break}a=7;b=1;break g}if(!b){v[114578]=0;R(110,f|0,t[e+10|0]);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break d}b=7-b|0;if((a|0)!=2){break g}if((h|0)==1){break f}a=2;b=6}h=a+e|0;b=(-1<<a^-1)<<b;d=a;while(1){i:{j:{if((a|0)==(d|0)){g=w[h+9|0];v[114578]=0;R(110,f|0,(b|g)<<24>>24);g=v[114578];v[114578]=0;if((g|0)==1){break i}d=d-1|0;break j}v[114578]=0;d=d-1|0;R(110,f|0,t[d+(e+10|0)|0]|-128);g=v[114578];v[114578]=0;if((g|0)==1){break i}}if(d){continue}break e}break}break d}v[114578]=0;R(110,f|0,t[e+10|0]|64);a=v[114578];v[114578]=0;if((a|0)==1){break d}}i=i+1|0;if(Fb(c)>>>0>i>>>0){continue}break}}jb=e+16|0;break c}a=P()|0;O()|0;yb(f);S(a|0);L()}return;case 1:b=0;d=Wb(a);a=Fb(c);v[114578]=0;R(111,d|0,a|0);a=v[114578];v[114578]=0;k:{if((a|0)!=1){l:{if(Fb(c)){while(1){a=v[ij(c,b)>>2];m:{if(a>>>0<=127){v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break m}break l}v[114578]=0;R(110,d|0,63);a=v[114578];v[114578]=0;if((a|0)==1){break l}}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break k}}break a}return;case 2:b=0;d=Wb(a);a=Fb(c);v[114578]=0;R(111,d|0,a|0);a=v[114578];v[114578]=0;n:{if((a|0)!=1){o:{if(Fb(c)){while(1){a=v[ij(c,b)>>2];p:{if(a>>>0<=255){v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break p}break o}v[114578]=0;R(110,d|0,63);a=v[114578];v[114578]=0;if((a|0)==1){break o}}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break n}}break a}return;case 3:Ko(a,c,1520);return;case 4:Ko(a,c,2544);return;case 5:Ko(a,c,3568);return;case 6:Ko(a,c,4592);return;case 7:Ko(a,c,5616);return;default:break b}}Wb(a);return}a=P()|0;O()|0;yb(d);S(a|0);L()}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=jb-48|0;jb=f;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}r=b;s=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){l=1;e=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;b=(j>>>16&65520)+r|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];o=u[b+8>>1];p=u[b+6>>1];m=u[b+4>>1];q=u[b+2>>1];x=u[b>>1];k=0;b=1;i=0;while(1){g=i<<1;v[(f+8|0)+(i<<2)>>2]=(((((((B(u[e+(g|-8)>>1],q)+B(u[e+(g|-12)>>1],x)|0)+B(u[e+(g|-4)>>1],m)|0)+B(u[e+g>>1],p)|0)+B(u[e+(g|4)>>1],o)|0)+B(u[e+(g|8)>>1],n)|0)+B(u[e+(g|12)>>1],h)|0)+B(j,u[e+(g|16)>>1])|0)/32768;g=b;b=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(k<<2)|0;j=v[i>>2];h=v[a+60>>2];n=h;g=(f+32|0)+(k<<3)|0;k=v[g>>2];b=Yb(k,-16777216,16776704);o=v[a+64>>2];e=Yb(v[g+4>>2],-16777216,16776704);m=v[a+68>>2];q=m;m=m>>31;v[g+4>>2]=k;k=v[a+72>>2];p=h>>31;j=j<<8;h=j;h=Hma(n,p,h,h>>31);n=mb;p=i;i=h;h=Hma(o,o>>31,b,b>>31);i=i+h|0;b=mb+n|0;b=h>>>0>i>>>0?b+1|0:b;h=i;i=Hma(q,m,e,e>>31);e=h+i|0;b=mb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|e>>>24;v[p>>2]=(b|0)/256;v[g>>2]=b-(j&k);k=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],t);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;jb=f+48|0}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=a;d=w[b+2|0];e=d-16|0;a:{b:{if((e&255)>>>0<=128){t[a+2|0]=1;d=(e&254)>>>1|0;break b}c:{switch((d+96&240)>>>4|0){case 0:t[a+2|0]=4;d=d&15;break b;case 1:t[a+2|0]=3;d=d&15;break b;case 2:t[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;d=d&15}t[c+4|0]=d}d=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=w[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}t[a+2|0]=15;c=w[b+6|0];t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;g=a,h=w[pc(b+5|0,f+15|0)|0]|208,t[g+5|0]=h;break d}c=w[b+6|0];e=w[b+5|0];if(!(c|e)){break d}t[a+5|0]=e;t[a+3|0]=c;wj(a);d=w[b+6|0]==15;break d}t[a+3|0]=2;g=a,h=Aj(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=3;g=a,h=Aj(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=4;g=a,h=Aj(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=5;t[a+5|0]=w[b+6|0]&240|w[b+5|0]>>>4;break d}c=w[b+5|0];if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((w[b+6|0]-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=w[b+6|0]>>>1;break d}c=w[b+6|0];if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=w[b+5|0]&15;break d}t[a+3|0]=w[b+6|0];t[a+5|0]=w[b+5|0];Wy(a,1);d=(w[a+3|0]&254)==16;break d}t[a+3|0]=18;t[a+5|0]=w[b+5|0];break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1;break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=w[b+6|0]>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}jb=f+16|0;return d|0}function J3(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;d=jb-16|0;jb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!((a|0)>-1?a>>>0>=8388608:0)){g=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}g=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));f=C(k*k);m=C(f*f);g=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());f=C(C(C(g-c)-i)+C(k*C(i+C(C(f*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}g=c}f=C(g*C(2e3));if(!(C(D(f))<C(2147483648))){break c}a=~~f;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=jb-16|0;jb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){d=ba(8)|0;v[114578]=0;b=Q(85,b|0,39833)|0;a=v[114578];v[114578]=0;if((a|0)==1){break k}mc(d,b);v[114578]=0;U(2010,d|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break i}a=P()|0;O()|0;yb(b);break j}jb=b+16|0;a=v[(a<<24>>24<<2)+40536>>2];break h}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}break b;case 3:v[d>>2]=0;e=jb-80|0;jb=e;a=v[a+24>>2]+24604|0;v[e+40>>2]=v[a+32>>2];v[e>>2]=v[a+36>>2];b=v[zf(e+40|0,e)>>2];o=d;l:{if(v[a+32>>2]==v[rp(e+40|0)+32>>2]){h=-1;if(v[a+36>>2]==v[rp(e)+36>>2]){break l}}h=0;if((b|0)<1){break l}h=(b+500>>>0)/1e3|0}v[o>>2]=h;jb=e+80|0;a=v[d>>2];break b;default:break d}}e=ba(8)|0;v[114578]=0;d=Q(85,d|0,38669)|0;a=v[114578];v[114578]=0;m:{if((a|0)!=1){mc(e,d);v[114578]=0;U(2010,e|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break m}b=P()|0;O()|0;ca(e|0)}S(b|0);L()}a=-2147483648}jb=d+16|0;return a|0}L()}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0;e=jb-80|0;jb=e;q=v[a+16>>2];i=Qf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];x=i,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[i+16>>2];if(b){x=i,y=Pf(a+8|0,b),v[x>>2]=y;v[i+4>>2]=mb}b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;h=v[a+52>>2];v[e+40>>2]=h;l=v[a+56>>2];v[e+44>>2]=l;r=v[a+24>>2];s=v[a+20>>2];j=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=j;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){b=0;g=b;h=f;v[e+72>>2]=f;v[e+76>>2]=b;j=(((j&2147483647)<<1|f>>>31)&-2)+q|0;a:{b=v[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;Ad(v[i+8>>2],t[(f|1)+j|0]+t[j+(f&-2)|0]<<5);zd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break a}b=b-1|0;h=v[e+72>>2];g=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];f=v[b+4>>2];if(f){k=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(k,t[(b|1)+j|0]+t[j+(b&-2)|0]<<5);zd(v[i+8>>2],f);b=v[i+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;h=Kf(b,v[i+12>>2]);v[e+12>>2]=h;v[e+8>>2]=h;g=0;l=1;while(1){k=v[a+60>>2];o=k;j=(e+32|0)+(g<<3)|0;m=v[j>>2];b=Yb(m,-16777216,16776704);p=v[a+64>>2];f=Yb(v[j+4>>2],-16777216,16776704);n=v[a+68>>2];u=n;n=n>>31;v[j+4>>2]=m;m=v[a+72>>2];k=k>>31;h=h<<8;k=Hma(o,k,h,h>>31);o=mb;w=(e+8|0)+(g<<2)|0;g=k;k=Hma(p,p>>31,b,b>>31);g=g+k|0;b=mb+o|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=Hma(u,n,f,f>>31);f=k+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[w>>2]=(b|0)/256;v[j>>2]=b-(h&m);if(l){g=1;l=0;h=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],r);Sb(e+24|0,e+16|0);if(d){c=c+8|0;f=v[e+24>>2];j=v[e+28>>2];continue}break}f=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];h=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=h;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=f;v[a+4>>2]=j;jb=e+80|0}function qI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-48|0;jb=k;a:{b:{c:{d:{e:{f:{j=jo(1,28);if(!j){a=ba(4)|0;Yk(a);v[114578]=0;U(2010,a|0,71204,2009);a=v[114578];v[114578]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1998;d=Is(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,k+16|0,c|0)|0;f=v[114578];v[114578]=0;j:{if((f|0)!=1){v[114578]=0;f=Q(2011,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}v[114578]=0;c=Q(85,k+16|0,c|0)|0;e=v[114578];v[114578]=0;k:{if((e|0)!=1){v[114578]=0;Q(2012,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114578]=0;c=T(1401,80)|0;e=v[114578];v[114578]=0;l:{m:{n:{if((e|0)!=1){v[114578]=0;U(2013,k+16|0,j|0,j+4|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}e=Ho(k+8|0,k+16|0);v[114578]=0;ea(2015,c|0,a|0,b|0,e|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}v[j+24>>2]=c;Yc(e);Yc(k+16|0);sk(d);c=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Yc(e);Yc(k+16|0)}Xb(c)}sk(d);_(i|0)|0;v[114578]=0;X(1990,34745,j|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Xb(Qr(a))}c=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);break d}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114578]=0;X(1990,34745,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=k+48|0;return c|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=jb-48|0;jb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}r=b;s=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;k=v[a+48>>2];v[f+36>>2]=k;j=v[a+52>>2];v[f+40>>2]=j;l=v[a+56>>2];v[f+44>>2]=l;w=v[a+24>>2];x=v[a+20>>2];h=v[a+4>>2];i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=h;v[f+16>>2]=g;v[f+20>>2]=e;if(d){while(1){e=(((h&2147483647)<<1|i>>>31)&-2)+s|0;b=(i>>>16&65520)+r|0;i=u[b+14>>1];g=u[b+12>>1];n=u[b+10>>1];o=u[b+8>>1];p=u[b+6>>1];m=u[b+4>>1];q=u[b+2>>1];y=u[b>>1];j=0;l=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],q)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],m)|0)+B(t[b+e|0],p)|0)+B(t[e+(b|2)|0],o)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],g)|0)+B(i,t[e+(b|8)|0])<<8)/32768;h=k;k=0;b=1;if(h){continue}break}while(1){e=(f+8|0)+(j<<2)|0;i=v[e>>2];g=v[a+60>>2];n=g;k=(f+32|0)+(j<<3)|0;j=v[k>>2];b=Yb(j,-16777216,16776704);o=v[a+64>>2];h=Yb(v[k+4>>2],-16777216,16776704);m=v[a+68>>2];q=m;m=m>>31;v[k+4>>2]=j;j=v[a+72>>2];p=g>>31;i=i<<8;g=i;g=Hma(n,p,g,g>>31);n=mb;p=e;e=g;g=Hma(o,o>>31,b,b>>31);e=e+g|0;b=mb+n|0;b=e>>>0<g>>>0?b+1|0:b;g=e;e=Hma(q,m,h,h>>31);h=g+e|0;b=mb+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;v[p>>2]=(b|0)/256;v[k>>2]=b-(i&j);j=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],w);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];l=v[f+44>>2];j=v[f+40>>2];k=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=l;v[a+52>>2]=j;v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=h;jb=f+48|0}function Pq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return od(b)}if(b>>>0>=4294967232){v[114552]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=v[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=v[116006]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}v[f+4>>2]=j&1|g|2;c=f+g|0;v[c+4>>2]=d|3;v[h+4>>2]=v[h+4>>2]|1;Oq(c,d);break b}if(v[115892]==(h|0)){e=e+v[115889]|0;if(e>>>0<=g>>>0){break a}v[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;v[d+4>>2]=c|1;v[115889]=c;v[115892]=d;break b}if(v[115891]==(h|0)){d=e+v[115888]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){v[f+4>>2]=j&1|g|2;e=f+g|0;v[e+4>>2]=c|1;d=d+f|0;v[d>>2]=c;v[d+4>>2]=v[d+4>>2]&-2;break c}v[f+4>>2]=d|j&1|2;c=d+f|0;v[c+4>>2]=v[c+4>>2]|1;c=0;e=0}v[115891]=e;v[115888]=c;break b}d=v[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=v[h+8>>2];c=d>>>3|0;d=v[h+12>>2];if((d|0)==(e|0)){n=463544,o=v[115886]&Lma(-2,c),v[n>>2]=o;break d}v[e+12>>2]=d;v[d+8>>2]=e;break d}l=v[h+24>>2];i=v[h+12>>2];e:{if((i|0)!=(h|0)){c=v[h+8>>2];v[c+12>>2]=i;v[i+8>>2]=c;break e}f:{e=h+20|0;c=v[e>>2];if(c){break f}e=h+16|0;c=v[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=v[e>>2];if(c){continue}e=i+16|0;c=v[i+16>>2];if(c){continue}break}v[d>>2]=0}if(!l){break d}d=v[h+28>>2];c=(d<<2)+463848|0;g:{if(v[c>>2]==(h|0)){v[c>>2]=i;if(i){break g}n=463548,o=v[115887]&Lma(-2,d),v[n>>2]=o;break d}v[(v[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}v[i+24>>2]=l;c=v[h+16>>2];if(c){v[i+16>>2]=c;v[c+24>>2]=i}c=v[h+20>>2];if(!c){break d}v[i+20>>2]=c;v[c+24>>2]=i}if(m>>>0<=15){v[f+4>>2]=j&1|k|2;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;break b}v[f+4>>2]=j&1|g|2;d=f+g|0;v[d+4>>2]=m|3;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;Oq(d,m)}c=f}if(c){return c+8|0}f=od(b);if(!f){return 0}c=v[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;lc(f,a,b>>>0>c>>>0?c:b);Xb(a);return f}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-48|0;jb=f;v[f+40>>2]=c;v[f+44>>2]=b;v[f+36>>2]=d;e=v[a+8>>2];v[f+28>>2]=f+36;v[f+24>>2]=f+40;b=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=b;v[f+16>>2]=a;v[f+20>>2]=f+44;b=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=b;c=f;a:{b:{switch(v[e+40>>2]){case 0:b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];g=v[d+24>>2];v[b+40>>2]=v[d+20>>2];v[b+44>>2]=g;g=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=g;Eh(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;k=b+16|0;c=b;if(h){while(1){d=0;if(g){while(1){i=v[Of(c,d,j)>>2];fc(e,d);i=i-2147481600>>>12|0;i=i>>>0>491520?i:491520;o=Nm(k,d,j),p=(i|0)<557055?i:557055,u[o>>1]=p;d=d+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((h|0)!=(j|0)){continue}break}}jb=b+80|0;break a;case 2:Mw(c,zb(e));break a;case 3:j=Ug(e);d=jb-80|0;jb=d;e=v[c>>2];g=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;k=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=k;Eh(b- -64|0,b+32|0,g);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];k=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;i=b+16|0;if(g){m=j+16|0;while(1){c=0;if(k){while(1){e=v[Of(b,c,h)>>2];l=Ve(j,c);e=e+(v[l>>2]>>1)|0;n=e;e=Hr(m)+e&-4096;v[l>>2]=n-e;e=e-2147481600>>>12|0;e=e>>>0>491520?e:491520;o=Nm(i,c,h),p=(e|0)<557055?e:557055,u[o>>1]=p;c=c+1|0;if((k|0)!=(c|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=d+80|0;break a;case 1:Mw(c,zb(e));break a;default:break b}}Mw(c,zb(e))}v[a+4>>2]=v[a+4>>2]+v[f+36>>2];jb=f+48|0}function oi(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0;if(!(nb[v[v[a>>2]+132>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(nb[v[v[a>>2]+132>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((nb[v[v[a>>2]+148>>2]](a)|0)<1){break a}if(!mJ(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(n*k);j=C(n*j);l=a+44|0;m=Pd(l,0);l=Pd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;p=h;k=C(z[g+m>>2]+z[h>>2]);h=c+g|0;z[p>>2]=C(k-C(z[g+l>>2]+C(k+z[h>>2])))+C(z[d+g>>2]*j);z[h>>2]=C(z[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+m>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+m>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=mJ(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(n*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(n*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(nb[v[v[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+m>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function Q6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(rh(m)){A=Pd(m,0);B=Pd(m,1);D=id(m,0);E=id(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];r=r&1023;I=(r<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;oi(a,b,c,id(m,0),id(m,1),d)}}function TJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;i=Oc(h+8|0,b);st(i);if(v[a>>2]==(b|0)){v[a>>2]=v[i>>2]}d=zb(a);v[d>>2]=v[d>>2]-1;d=v[hc(a)>>2];a:{b:{e=v[b>>2];c:{if(!e){a=b;break c}if(!v[b+4>>2]){a=b;break b}a=b;g=v[a+4>>2];d:{if(!g){if(!ug(a)){while(1){a=v[a+8>>2];if(!ug(a)){continue}break}}a=v[a+8>>2];break d}a=UQ(g)}e=v[a>>2];if(e){break b}}e=v[a+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[a+8>>2];g=0}e:{f:{if(ug(a)){v[v[a+8>>2]>>2]=e;if((a|0)==(d|0)){d=e;c=0;break e}c=v[a+8>>2]+4|0;break f}v[v[a+8>>2]+4>>2]=e;c=v[a+8>>2]}c=v[c>>2]}j=!w[a+12|0];if((a|0)!=(b|0)){v[a+8>>2]=v[b+8>>2];g:{if(ug(b)){f=v[a+8>>2];break g}f=v[a+8>>2]+4|0}v[f>>2]=a;f=v[b>>2];v[a>>2]=f;xn(f,a);f=v[b+4>>2];v[a+4>>2]=f;if(f){xn(f,a)}t[a+12|0]=w[b+12|0];d=(b|0)==(d|0)?a:d}if(!(j|!d)){h:{if(g){while(1){a=ug(c);b=w[c+12|0];i:{j:{if(!a){if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Ep(v[c+8>>2]);a=v[c>>2];d=(a|0)==(d|0)?c:d;c=v[a+4>>2]}b=v[c>>2];k:{l:{m:{if(!(w[b+12|0]?0:b)){a=v[c+4>>2];if(w[a+12|0]?0:a){break m}t[c+12|0]=0;n:{a=v[c+8>>2];if((a|0)!=(d|0)){if(w[a+12|0]){break n}}else{a=d}t[a+12|0]=1;break h}if(!ug(a)){break j}a=v[a+8>>2]+4|0;break i}a=v[c+4>>2];if(!a){break l}}if(!w[a+12|0]){break k}}t[b+12|0]=1;t[c+12|0]=0;Dp(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;Ep(v[c+8>>2]);break h}if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Dp(v[c+8>>2]);a=v[c+4>>2];d=(a|0)==(d|0)?c:d;c=v[a>>2]}b=v[c>>2];o:{if(w[b+12|0]?0:b){break o}a=v[c+4>>2];if(!(w[a+12|0]?0:a)){t[c+12|0]=0;a=v[c+8>>2];if(!((a|0)!=(d|0)?w[a+12|0]:0)){t[a+12|0]=1;break h}if(ug(a)){a=v[a+8>>2]+4|0;break i}a=v[a+8>>2];break i}if(b){if(!w[b+12|0]){break o}a=v[c+4>>2]}t[a+12|0]=1;t[c+12|0]=0;Ep(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;Dp(v[c+8>>2]);break h}a=v[a+8>>2]}c=v[a>>2];continue}}t[e+12|0]=1}}jb=h+16|0;return v[i>>2]}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb-208|0;jb=c;f=1;e=v[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;if(i){e=0;while(1){j=e+i|0;f=tc(b,j);d=v[f+12>>2];v[c+200>>2]=v[f+8>>2];v[c+204>>2]=d;d=v[f+4>>2];v[c+192>>2]=v[f>>2];v[c+196>>2]=d;ui(c+176|0,tc(b,e),c+192|0);f=tc(b,j);d=v[c+188>>2];v[f+8>>2]=v[c+184>>2];v[f+12>>2]=d;j=v[c+180>>2];v[f>>2]=v[c+176>>2];v[f+4>>2]=j;yx(tc(b,e),c+192|0);e=e+1|0;if((i|0)!=(e|0)){continue}break}e=v[a+12>>2]}f=2;h=h>>>3|0}else{h=h>>>2|0}j=e&-2;if(j){while(1){if(f){o=B(h,3);p=h<<1;i=0;while(1){e=tc(a,i<<1);d=v[e+12>>2];v[c+200>>2]=v[e+8>>2];v[c+204>>2]=d;d=v[e+4>>2];v[c+192>>2]=v[e>>2];v[c+196>>2]=d;e=tc(a,i);d=v[e+12>>2];v[c+184>>2]=v[e+8>>2];v[c+188>>2]=d;d=v[e+4>>2];v[c+176>>2]=v[e>>2];v[c+180>>2]=d;Jh(c+160|0,c+176|0,c+192|0);e=i<<j;m=h+e|0;if(e>>>0<m>>>0){while(1){d=tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+h|0;Jh(c+128|0,c+192|0,tc(b,g));k=e+p|0;Jh(c+112|0,c+176|0,tc(b,k));n=e+o|0;Jh(c+96|0,c+160|0,tc(b,n));ok(c+80|0,c+144|0,c+112|0);ui(c- -64|0,c+144|0,c+112|0);ok(c+48|0,c+128|0,c+96|0);Bl(c+16|0,-A[3858],-A[3859]);ui(c,c+128|0,c+96|0);Jh(c+32|0,c+16|0,c);ok(c+16|0,c+80|0,c+48|0);d=tc(b,e);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;l=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=l;ui(c+16|0,c+80|0,c+48|0);d=tc(b,g);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ok(c+16|0,c- -64|0,c+32|0);d=tc(b,k);k=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=k;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ui(c+16|0,c- -64|0,c+32|0);d=tc(b,n);k=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=k;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((m|0)!=(e|0)){continue}break}}i=i+1|0;if((f|0)!=(i|0)){continue}break}}h=h>>>2|0;f=f<<2;j=j-2|0;if(j){continue}break}}jb=c+208|0}function D2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-96|0;jb=e;a:{if(Wc(c)){break a}f=w[dI(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}br(e+80|0,c,0,Fb(c)-1|0);Gb(c,e+80|0);yb(e+80|0)}Cd(e+80|0);f=v[e+80>>2];Cd(e+72|0);g=cI(f,v[e+76>>2],c);Cd(e+80|0);b:{c:{d:{e:{f:{if(v[e+84>>2]==(g|0)){if(Vd(c,38235)){a=ba(8)|0;v[114578]=0;b=Q(85,e+80|0,39169)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(!d){break f}a=ba(8)|0;v[114578]=0;U(2137,e+80|0,39179,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,e+80|0);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(e+80|0);break c}c=P()|0;O()|0;ca(a|0);break c}f=Wb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Hh(e- -64|0,c);v[114578]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(2078,b|0,e+8|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;t[e+72|0]=b;R(2142,a|0,e+72|0);a=v[114578];v[114578]=0;if((a|0)!=1){break g}}break i;case 1:Hh(e+56|0,c);v[114578]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=wD(b,e+16|0,d);c=mb;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2144,a|0,e+72|0);a=v[114578];v[114578]=0;if((a|0)!=1){break g}}break i;case 2:Hh(e+48|0,c);v[114578]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(2080,b|0,e+24|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[114578]=0;A[e+72>>3]=h;R(2145,a|0,e+72|0);a=v[114578];v[114578]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Hh(e+40|0,c);v[114578]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;X(2081,a|0,b|0,e+32|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;yb(f);break c}td(a,f)}yb(f);break e}Wb(a)}jb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-48|0;jb=g;x=v[a+16>>2];j=v[a+44>>2];v[g+32>>2]=j;m=v[a+48>>2];v[g+36>>2]=m;i=v[a+52>>2];v[g+40>>2]=i;h=v[a+56>>2];v[g+44>>2]=h;p=v[a+40>>2];q=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+x|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];h=u[f+36>>1];l=u[f+34>>1];n=u[f+32>>1];r=u[f+30>>1];s=u[f+28>>1];o=u[f+26>>1];t=u[f+24>>1];j=0;i=1;f=0;while(1){w=(g+8|0)+(f<<2)|0;f=f<<1;v[w>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],n)|0)+B(h,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],o)+B(u[e+(f|-12)>>1],t)|0)+B(u[e+(f|-4)>>1],s)|0)+B(u[e+f>>1],r)|0)/2|0)|0)/16384;w=i&1;i=0;f=1;if(w){continue}break}while(1){i=(g+8|0)+(j<<2)|0;k=v[i>>2];h=v[a+60>>2];l=h;f=(g+32|0)+(j<<3)|0;n=v[f>>2];e=Yb(n,-16777216,16776704);r=v[a+64>>2];j=Yb(v[f+4>>2],-16777216,16776704);o=v[a+68>>2];t=o;o=o>>31;v[f+4>>2]=n;n=v[a+72>>2];s=h>>31;k=k<<8;h=k;h=Hma(l,s,h,h>>31);l=mb;s=i;i=h;h=Hma(r,r>>31,e,e>>31);i=i+h|0;e=mb+l|0;e=i>>>0<h>>>0?e+1|0:e;h=i;i=Hma(t,o,j,j>>31);j=h+i|0;e=mb+e|0;e=j>>>0<i>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;v[s>>2]=(e|0)/256;v[f>>2]=e-(k&n);j=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];q=v[a+28>>2]+q|0;f=q>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);p=e+p|0;l=p>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];h=v[g+44>>2];i=v[g+40>>2];m=v[g+36>>2];j=v[g+32>>2];break a}l=p>>12;f=q>>12}v[a+40>>2]=p;v[a+20>>2]=f;v[a+36>>2]=q;v[a+56>>2]=h;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=j;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;jb=g+48|0}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-48|0;jb=g;x=v[a+16>>2];j=v[a+44>>2];v[g+32>>2]=j;m=v[a+48>>2];v[g+36>>2]=m;i=v[a+52>>2];v[g+40>>2]=i;h=v[a+56>>2];v[g+44>>2]=h;p=v[a+40>>2];q=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+x|0;m=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];h=u[f+36>>1];l=u[f+34>>1];n=u[f+32>>1];r=u[f+30>>1];s=u[f+28>>1];o=u[f+26>>1];w=u[f+24>>1];j=0;i=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],n)|0)+B(h,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],o)+B(t[e+(f|-6)|0],w)|0)+B(t[e+(f|-2)|0],s)|0)+B(t[e+f|0],r)<<8)/2|0)|0)/16384;y=i&1;i=0;f=1;if(y){continue}break}while(1){i=(g+8|0)+(j<<2)|0;k=v[i>>2];h=v[a+60>>2];l=h;f=(g+32|0)+(j<<3)|0;n=v[f>>2];e=Yb(n,-16777216,16776704);r=v[a+64>>2];j=Yb(v[f+4>>2],-16777216,16776704);o=v[a+68>>2];w=o;o=o>>31;v[f+4>>2]=n;n=v[a+72>>2];s=h>>31;k=k<<8;h=k;h=Hma(l,s,h,h>>31);l=mb;s=i;i=h;h=Hma(r,r>>31,e,e>>31);i=i+h|0;e=mb+l|0;e=i>>>0<h>>>0?e+1|0:e;h=i;i=Hma(w,o,j,j>>31);j=h+i|0;e=mb+e|0;e=j>>>0<i>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;v[s>>2]=(e|0)/256;v[f>>2]=e-(k&n);j=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];q=v[a+28>>2]+q|0;l=q>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);p=e+p|0;f=p>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];h=v[g+44>>2];i=v[g+40>>2];m=v[g+36>>2];j=v[g+32>>2];break a}f=p>>12;l=q>>12}v[a+40>>2]=p;v[a+20>>2]=l;v[a+36>>2]=q;v[a+56>>2]=h;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;jb=g+48|0}function rH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;d=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;c=e;a:{b:{switch(v[d+40>>2]){case 0:b=jb-80|0;jb=b;f=v[c>>2];h=v[f+4>>2];v[b+40>>2]=v[f+20>>2];i=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=i;Mm(b- -64|0,b+32|0,h);f=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;g=b+16|0;c=b;if(h){while(1){f=0;if(i){while(1){j=v[Of(c,f,k)>>2];fc(d,f);j=j-2147481600>>>12|0;j=j>>>0>491520?j:491520;o=Lm(g,f,k),p=(j|0)<557055?j:557055,u[o>>1]=p;f=f+1|0;if((i|0)!=(f|0)){continue}break}}k=k+1|0;if((h|0)!=(k|0)){continue}break}}jb=b+80|0;break a;case 2:Jw(c,zb(d));break a;case 3:k=Ug(d);b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];v[b+40>>2]=v[d+20>>2];i=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=i;Mm(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(h){m=k+16|0;while(1){d=0;if(i){while(1){g=v[Of(c,d,f)>>2];l=Ve(k,d);g=g+(v[l>>2]>>1)|0;n=g;g=Hr(m)+g&-4096;v[l>>2]=n-g;g=g-2147481600>>>12|0;g=g>>>0>491520?g:491520;o=Lm(j,d,f),p=(g|0)<557055?g:557055,u[o>>1]=p;d=d+1|0;if((i|0)!=(d|0)){continue}break}}f=f+1|0;if((h|0)!=(f|0)){continue}break}}jb=b+80|0;break a;case 1:Jw(c,zb(d));break a;default:break b}}Jw(c,zb(d))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function c8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=C(0),x=0,y=0,A=C(0),B=0,E=0,F=0,G=C(0);a:{if(!v[a+4276>>2]){break a}j=a+44|0;if(!rh(j)){break a}o=Pd(j,0);p=Pd(j,1);q=id(j,0);r=id(j,1);y=nb[v[v[a>>2]+188>>2]](a)|0;e=C(nb[v[v[a>>2]+196>>2]](a));w=C(nb[v[v[a>>2]+184>>2]](a));s=nb[v[v[a>>2]+208>>2]](a)|0;if(d){k=a+4260|0;A=C(e*C(.009999999776482582));B=s&1;n=v[a+4256>>2];f=v[a+4272>>2];E=s>>>0>1;t=d;while(1){i=z[o>>2];l=z[p>>2];h=Um(a,f+n|0);f=Um(a,f);e=z[Pb(k,h)>>2];F=Pb(k,f),G=C(C(A*e)+C(C(l+i)*C(.5))),z[F>>2]=G;b:{if(y){g=z[a+4244>>2];e=C(z[a+4236>>2]+g);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(g<=C(1))){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break b}g=z[a+4244>>2];m=z[a+4240>>2];e=C(C(g*m)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(m-C(e*g));z[a+4240>>2]=g}m=z[Pb(k,Um(a,v[a+4280>>2]+v[a+4272>>2]|0))>>2];F=q,G=C(C(C(C(m-i)+C(C(C(z[Pb(k,Um(a,v[a+4284>>2]+v[a+4272>>2]|0))>>2]-m)*C(.000244140625))*C(v[a+4280>>2]&4095)))*w)+i),z[F>>2]=G;i=z[Pb(k,Um(a,v[a+4288>>2]+v[a+4272>>2]|0))>>2];F=r,G=C(C(C(C(i-l)+C(C(C(z[Pb(k,Um(a,v[a+4292>>2]+v[a+4272>>2]|0))>>2]-i)*C(.000244140625))*C(v[a+4288>>2]&4095)))*w)+l),z[F>>2]=G;u=a;n=v[a+4256>>2];f=n;i=z[a+4248>>2];l=C(i*(B?g:e));c:{if(C(D(l))<C(2147483648)){h=~~l;break c}h=-2147483648}x=f+(E?h:0-h|0)|0;v[u+4288>>2]=x;f=s>>>0<4;u=a;e=C(i*e);d:{if(C(D(e))<C(2147483648)){h=~~e;break d}h=-2147483648}f=(f?h:0-h|0)+n|0;v[u+4280>>2]=f;v[a+4292>>2]=x+4096;v[a+4284>>2]=f+4096;p=p+4|0;o=o+4|0;r=r+4|0;q=q+4|0;h=a;f=v[a+4272>>2];if((f|0)<=0){f=f+(v[a+4276>>2]<<12)|0}f=f-4096|0;v[h+4272>>2]=f;t=t-1|0;if(t){continue}break}}oi(a,b,c,id(j,0),id(j,1),d)}}function x_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=jb-432|0;jb=i;v[i+424>>2]=37;v[i+428>>2]=0;j=ar(i+424|1,64442,v[c+4>>2]);v[i+380>>2]=i+384;a=le();a:{if(j){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;l=i- -64|0;v[l>>2]=e;v[l+4>>2]=f;v[i+48>>2]=k;a=af(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=af(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2428;k=Rd(i+368|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){v[114578]=0;a=da(2453)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[114578]=0;a=aa(2475,i+380|0,a|0,i+424|0,i|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break e}break c}v[114578]=0;a=da(2453)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114578]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=aa(2475,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}}e=v[i+380>>2];if(!e){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(k,e)}e=v[i+380>>2];g=e+a|0;h=mg(e,g,c);v[i+116>>2]=2428;f=Rd(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;e=i+384|0;break g}a=od(a<<3);if(!a){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(f,a);e=v[i+380>>2]}v[114578]=0;Bc(i+104|0,c);j=v[114578];v[114578]=0;h:{i:{if((j|0)!=1){v[114578]=0;ja(2486,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Ob(i+104|0);v[114578]=0;a=ka(2487,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(f);Gc(k);jb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(i+104|0);break f}c=P()|0;O()|0}Gc(f);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function I_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=jb-256|0;jb=i;v[i+248>>2]=37;v[i+252>>2]=0;j=ar(i+248|1,64442,v[c+4>>2]);v[i+204>>2]=i+208;a=le();a:{if(j){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;l=i- -64|0;v[l>>2]=e;v[l+4>>2]=f;v[i+48>>2]=k;a=af(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=af(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2428;k=Rd(i+192|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){v[114578]=0;a=da(2453)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[114578]=0;a=aa(2475,i+204|0,a|0,i+248|0,i|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break e}break c}v[114578]=0;a=da(2453)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114578]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=aa(2475,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}}e=v[i+204>>2];if(!e){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(k,e)}e=v[i+204>>2];g=e+a|0;h=mg(e,g,c);v[i+116>>2]=2428;f=Rd(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;e=i+208|0;break g}a=od(a<<1);if(!a){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(f,a);e=v[i+204>>2]}v[114578]=0;Bc(i+104|0,c);j=v[114578];v[114578]=0;h:{i:{if((j|0)!=1){v[114578]=0;ja(2476,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Ob(i+104|0);v[114578]=0;a=ka(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(f);Gc(k);jb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(i+104|0);break f}c=P()|0;O()|0}Gc(f);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function sH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);f=jb-48|0;jb=f;v[f+40>>2]=c;v[f+44>>2]=b;v[f+36>>2]=d;h=v[a+8>>2];v[f+28>>2]=f+36;v[f+24>>2]=f+40;b=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=b;v[f+16>>2]=a;v[f+20>>2]=f+44;b=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=b;c=f;a:{b:{switch(v[h+40>>2]){case 0:d=jb-80|0;jb=d;e=v[c>>2];g=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;j=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=j;Eh(b- -64|0,b+32|0,g);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];c=v[v[c+8>>2]>>2];g=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=g;g=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=g;v[b+8>>2]=v[e+8>>2];g=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=g;e=b+16|0;if(j){while(1){g=0;if(c){while(1){k=A[ch(b,g,i)>>3];fc(h,g);m=rn(e,g,i),n=C(k),z[m>>2]=n;g=g+1|0;if((c|0)!=(g|0)){continue}break}}i=i+1|0;if((j|0)!=(i|0)){continue}break}}jb=d+80|0;break a;case 2:Kw(c,zb(h));break a;case 3:j=Ug(h);d=jb-80|0;jb=d;e=v[c>>2];h=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;i=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=i;Eh(b- -64|0,b+32|0,h);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;e=b+16|0;if(h){while(1){c=0;if(i){while(1){k=A[ch(b,c,g)>>3];Ve(j,c);l=tj(Sd(k*134217728));m=rn(e,c,g),n=C(+(l|0)*7.450580596923828e-9),z[m>>2]=n;c=c+1|0;if((i|0)!=(c|0)){continue}break}}g=g+1|0;if((h|0)!=(g|0)){continue}break}}jb=d+80|0;break a;case 1:Kw(c,zb(h));break a;default:break b}}Kw(c,zb(h))}v[a+4>>2]=v[a+4>>2]+v[f+36>>2];jb=f+48|0}function ns(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-160|0;jb=h;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}f=v[c+4>>2];if(!f&y[c>>2]>=oh(b)>>>0|f){break h}b=ba(8)|0;v[114578]=0;Q(214,b|0,20525)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[114578]=0;Q(1406,b|0,20525)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break f}a=P()|0;O()|0;ca(b|0);break a}f=wh(h+128|0,b);d=jb-16|0;jb=d;ho(d+8|0,wh(d,f));e=jb-16|0;jb=e;i=wh(e+8|0,d+8|0);g=jb-16|0;jb=g;f=h+136|0;PC(f,wh(g+8|0,i));jb=g+16|0;jb=e+16|0;v[f+16>>2]=0;v[f+12>>2]=0;jb=d+16|0;i:{j:{if(a&2){d=Uo(h+104|0,f);v[114578]=0;j=Q(1407,d|0,c|0)|0;e=v[114578];v[114578]=0;d=1;if((e|0)==1){break i}if((j|0)==1){break j}e=Uo(h+80|0,f);v[114578]=0;e=Q(1408,e|0,c|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}k=(e|0)==1;if(k){break j}g=Uo(h+56|0,f);v[114578]=0;g=Q(1409,g|0,c|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}l=(g|0)==1;if(l){break j}i=Uo(h+32|0,f);v[114578]=0;i=Q(1410,i|0,c|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(j|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(i|0)==-1?-1:l?d:(g|0)==-1?-1:d}if(a&1){a=77744;while(1){d=v[a>>2];if(d){e=Uo(h+8|0,f);v[114578]=0;e=Q(d|0,e|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}j=(e|0)==-1?-1:j}a=a+12|0;if((a|0)!=78200){continue}break}}if(c){d=0;if((j|0)!=-1){break j}a=v[c+4>>2];c=v[c>>2];v[114578]=0;a=Gg(448,c,a);c=v[114578];v[114578]=0;if((c|0)!=1){d=oh(b)>>>0<a>>>0?-1:0;break j}a=P()|0;O()|0;break a}d=0;if((j|0)!=-1){break j}d=oh(b)>>>0>2047?1:-1}jb=h+160|0;return d}a=P()|0;O()|0;break a}ha(b|0,71464,24);L()}ha(b|0,71360,24);L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}S(a|0);L()}function Nf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;f=x[a+20>>1];b=x[a+70>>1]+(f+x[a+22>>1]|0)|0;b=w[a+79|0]?x[v[a>>2]+3836>>1]+b|0:b;a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];g=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;h=c;c=x[a+46>>1];f=f+(c?h&c?0:g:g)|0;u[a+20>>1]=f;c=2;g=x[a+28>>1];if((g|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;g=x[v[a>>2]+3832>>1];i=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((g>>>x[a+56>>1]&7)<<1)>>1]|0:0;h=g;g=x[a+58>>1];f=f+(g?h&g?0:i:i)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;i=x[v[a>>2]+3832>>1];h=x[a+24>>1]?B((f^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((i>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;k=x[a+34>>1];f=f+(k?i&k?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16>=1){break b}}v[a+16>>2]=c;u[a+20>>1]=g}d=e?(u[a+74>>1]+u[a+72>>1]>>e)+d|0:d;e=b<<3;c=(j>>>10|0)+d|0;d=c&255;b=c&65535;e:{f:{switch(x[a+12>>1]){case 0:c=(b&512)>>>9|0;b=x[((b&256?d^255:d)<<1)+19296>>1];break e;case 1:c=0;b=x[((b&512?0:b&256?d^255:d)<<1)+19296>>1];break e;case 2:c=0;b=x[((b&256?d^255:d)<<1)+19296>>1];break e;case 3:c=0;b=x[((b&256?0:d)<<1)+19296>>1];break e;case 4:g:{if(b&512){d=19296;c=0;break g}d=(((d<<1^b<<24>>31)&254)<<1)+19296|0;c=(b&256)>>>8|0}b=x[d>>1];break e;case 5:c=0;if(b&512){b=19296}else{d=d<<1&254;b=((b&128?d^255:d)<<1)+19296|0}b=x[b>>1];break e;case 6:c=(c&512)>>>9|0;b=0;break e;default:break f}}c=c<<3&4088;g=c^4088;d=c;c=(b&512)>>>9|0;b=c?g:d}u[a+74>>1]=x[a+72>>1];d=a;a=b+e|0;a=(a&65535)>>>0<8191?a:8191;c=0-c^x[((a&255)<<1)+18784>>1]+1024>>>((a&65280)>>>8)<<1;u[d+72>>1]=c}return c<<16>>16}function R2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;g=gh(a);a=b+24|0;f=Vb(v[a>>2]+484360|0);v[114578]=0;i=T(2194,f|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)==1){break c}v[114578]=0;R(1534,g|0,i|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=x[rc(Vb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[114578]=0;d=Q(918,d+484344|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[rc(Vb(v[a>>2]+484360|0),f)>>1]);v[114578]=0;R(2192,e|0,c|0);c=v[114578];v[114578]=0;g:{h:{i:{if((c|0)!=1){v[114578]=0;U(2186,e+16|0,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;R(1536,g|0,e+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}yb(e+16|0);yb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(e+16|0)}yb(e);break a}v[114578]=0;d=da(964)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114578]=0;c=Q(85,e+16|0,38847)|0;d=v[114578];v[114578]=0;j:{if((d|0)!=1){v[114578]=0;R(1536,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break j}yb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}v[114578]=0;d=da(963)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114578]=0;c=Q(85,e+16|0,38856)|0;d=v[114578];v[114578]=0;k:{if((d|0)!=1){v[114578]=0;R(1536,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}yb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}v[114578]=0;c=Q(85,e+16|0,38865)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;R(1536,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}yb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}kd(g);S(a|0);L()}function s1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=WG(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=WG(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;lc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;lc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}jb=e+16|0;return g|0}function AO(a){a=a|0;var b=0,c=0,d=0;Rb(a,0,288);Oy(a+288|0);sp(a+800|0);t[a+2|0]=w[18178];b=w[18176]|w[18177]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[18181];b=w[18179]|w[18180]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[18185]|w[18186]<<8|(w[18187]<<16|w[18188]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[18182]|w[18183]<<8|(w[18184]<<16|w[18185]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[18189]|w[18190]<<8|(w[18191]<<16|w[18192]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[18192]|w[18193]<<8|(w[18194]<<16|w[18195]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[18200];b=w[18196]|w[18197]<<8|(w[18198]<<16|w[18199]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;b=jb-80|0;jb=b;v[b+76>>2]=0;d=Ub(b- -64|0,18062);v[114578]=0;R(512,b+48|0,a+288|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114578]=0;Q(471,b+48|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}yb(d);break c}a=P()|0;O()|0;yb(d);break b}jb=b+80|0;break a}S(a|0);L()}d=a+800|0;b=0;a=jb+-64|0;jb=a;e:{f:{g:{h:{i:{j:{while(1){v[a+60>>2]=b;v[a+60>>2]=b<<3;sA(a+32|0,b>>>0<16?18126:18061);v[114578]=0;R(510,a+16|0,a+60|0);c=v[114578];v[114578]=0;if((c|0)==1){break j}v[114578]=0;U(511,a+48|0,a+32|0,a+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;R(512,a+8|0,d+(b<<5)|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}v[114578]=0;Q(471,a+8|0,a+48|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}yb(a+48|0);yb(a+16|0);Ib(a+32|0);b=b+1|0;if((b|0)!=128){continue}break}jb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(a+48|0)}yb(a+16|0)}Ib(a+32|0);S(b|0);L()}}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-144|0;jb=c;e=$k(c+40|0,a);v[114578]=0;d=Q(683,c+24|0,32299)|0;a=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[114578]=0;v[c>>2]=19468288;v[c+4>>2]=0;U(684,e|0,d|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}Ib(d);if(v[e>>2]&1073741824){break e}v[114578]=0;d=Q(683,c+24|0,32304)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;aa(1571,e|0,b|0,d|0,1572)|0;a=v[114578];v[114578]=0;if((a|0)==1){break l}Ib(d);v[114578]=0;v[c+20>>2]=0;v[c+16>>2]=0;d=Q(683,c+24|0,32309)|0;a=v[114578];v[114578]=0;if((a|0)==1){break k}v[114578]=0;W(1573,e|0,c+20|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break j}Ib(d);v[114578]=0;d=Q(683,c+24|0,32314)|0;a=v[114578];v[114578]=0;if((a|0)==1){break i}v[114578]=0;W(1573,e|0,c+16|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break h}Ib(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[Xm(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[Xm(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Yx(c+24|0);v[114578]=0;f=Q(683,c|0,32319)|0;a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;aa(1574,e|0,d|0,f|0,674)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}Ib(f);if(md(d)){break f}v[114578]=0;U(1575,d|0,v[c+20>>2],16777216);a=v[114578];v[114578]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;Ib(f);break b}v[114578]=0;R(1576,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}oe(d)}vg(e);jb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}oe(d)}vg(e);S(a|0);L()}function uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-32|0;jb=g;v[g+24>>2]=d;i=Mj(a,c);pf(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!i){if(xd(a,5)){break a}}j=v[g+24>>2];d=jb-160|0;jb=d;h=$k(d+56|0,v[a+28>>2]);v[114578]=0;f=Q(683,d+8|0,18638)|0;e=v[114578];v[114578]=0;b:{c:{d:{e:{if((e|0)!=1){v[114578]=0;v[d+48>>2]=19468288;v[d+52>>2]=0;U(684,h|0,f|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}Ib(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f);break c}v[114578]=0;t[d+48|0]=0;t[d+47|0]=0;f=Q(683,d+8|0,18630)|0;e=v[114578];v[114578]=0;f:{if((e|0)!=1){v[114578]=0;W(1188,h|0,d+48|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}Ib(f);if(!w[d+48|0]){break b}Ue(d+48|0,50);v[114578]=0;f=Q(683,d+8|0,18646)|0;e=v[114578];v[114578]=0;g:{h:{i:{j:{if((e|0)!=1){v[114578]=0;W(1188,h|0,d+47|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}Ib(f);f=Mh(b);e=w[d+48|0];if(f>>>0<e>>>0){f=Ey(d+8|0,v[b+12>>2]);v[114578]=0;U(1189,b|0,e|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Dl(f)}e=0;f=x[Di(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){Oe(Di(b,e&255),f);e=Di(b,w[d+7|0]);v[114578]=0;R(1190,d+8|0,d+7|0);k=v[114578];v[114578]=0;if((k|0)==1){break h}v[114578]=0;X(1191,h|0,e|0,d+8|0,j|0);e=v[114578];v[114578]=0;if((e|0)==1){break g}Ib(d+8|0);e=w[d+7|0]+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];f=Mh(b);t[b+16|0]=e>>>0<f>>>0?w[d+47|0]:0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f);break c}e=P()|0;O()|0;Dl(f);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(d+8|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f)}vg(h);S(e|0);L()}vg(h);jb=d+160|0}_i(a,i,c,g+16|0);jb=g+32|0}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;j=c+484344|0;$f(j,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){f=v[a+8>>2];g=Cf(a);$b(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Gd(a)+1|0;break b}c=hg(a)}d=hg(a);Qc(a,f+g|0);ud(e+16|0,a,d);v[114578]=0;c=W(404,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}c:{if(!c|!d){break c}c=_b(j,i);k=e,l=bc(c),v[k+8>>2]=l;k=e,l=cc(c),v[k>>2]=l;if(!Jb(e+8|0,e)){break c}while(1){d=v[e+8>>2];v[114578]=0;c=T(389,e+16|0)|0;f=v[114578];v[114578]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){v[114578]=0;f=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d|0]=f}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[114578]=0;f=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d+1|0]=f}f=0;if(c&4){v[114578]=0;f=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}}if(c&8){v[114578]=0;g=T(389,e+16|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}t[d+3|0]=g}if(c&16){v[114578]=0;c=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d+5|0]=c}c=d;g:{h:{g=w[d|0];if(!g){break h}h=255;if((g|0)==97){break g}if(g>>>0>96){break h}h=g+12|0;break g}h=0}t[c|0]=h;i:{if(w[d+5|0]|w[d+3|0]){v[114578]=0;Z(574,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;t[d+4|0]=c;f=f-96>>4;t[d+2|0]=w[f+17983|0];if((f|0)!=6){break j}t[d+4|0]=c<<2}Dj(e+8|0);if(Jb(e+8|0,e)){continue}break}}Bb(e+16|0);i=i+1|0;if(i>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}jb=e+32|0;return}a=P()|0;O()|0;Bb(e+16|0);S(a|0);L()}function gr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=Ns(c,d);v[i+4>>2]=2428;m=Rd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=od(k);if(!j){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}ye(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114578]=0;h=Q(2430,a|0,i+120|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114578]=0;b=Q(2431,a|0,i+120|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114578]=0;n=T(2432,a|0)|0;b=v[114578];v[114578]=0;g:{if((b|0)!=1){if(g){break g}v[114578]=0;n=Q(2433,e|0,n|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114578]=0;T(2434,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[kc(b,q)|0];j:{if(g){break j}v[114578]=0;p=Q(2433,e|0,p<<24>>24)|0;s=v[114578];v[114578]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Fb(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Gc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Wc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Gc(m);S(b|0)}L()}function _Z(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-624|0;jb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2490;b=Rd(a+200|0,a+208|0,a+16|0);v[114578]=0;Bc(a+192|0,e);h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114578]=0;h=T(2457,a+192|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[a+191|0]=0;e=v[e+4>>2];v[114578]=0;c=ta(2501,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(!c){break f}c=w[64683]|w[64684]<<8|(w[64685]<<16|w[64686]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[64680]|w[64681]<<8|(w[64682]<<16|w[64683]<<24);v[a+176>>2]=w[64676]|w[64677]<<8|(w[64678]<<16|w[64679]<<24);v[a+180>>2]=c;v[114578]=0;aa(2471,h|0,a+176|0,a+186|0,a+128|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[a+4>>2]=2428;d=Rd(a+8|0,0,a+4|0);c=a+16|0;if((v[a+196>>2]-v[b>>2]|0)<393){break g}ye(d,od((v[a+196>>2]-v[b>>2]>>2)+2|0));if(v[d>>2]){break h}v[114578]=0;Y(2429);c=v[114578];v[114578]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+196>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((hF(a+16|0,a)|0)!=1){v[114578]=0;Z(2492,64660);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break d}Gc(d)}else{j=c,k=w[(a+176|0)+(Ev(a+128|0,a+168|0,e)-(a+128|0)>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;continue}break}}v[114578]=0;c=Q(2463,a+616|0,a+608|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Ob(a+192|0);Gc(b);jb=a+624|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Gc(d)}Ob(a+192|0)}Gc(b);S(e|0);L()}L()}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Wb(a+208|0);v[114578]=0;Bc(a+16|0,d);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){v[114578]=0;b=T(2457,a+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}v[114578]=0;aa(2471,b|0,64400,64426,a+224|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}Ob(a+16|0);c=Wb(a+192|0);b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114578]=0;d=Q(2462,a+344|0,a+336|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Fb(c)+b|0)){d=Fb(c);b=Fb(c);v[114578]=0;R(149,c|0,b<<1);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=d+b}v[114578]=0;d=T(2464,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}v[114578]=0;d=Yj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}if(d){break c}v[114578]=0;T(2466,a+344|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ob(a+16|0);break a}v[114578]=0;R(149,c|0,v[a+188>>2]-b|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=Tb(c);v[114578]=0;d=da(2453)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[a>>2]=f;v[114578]=0;b=aa(2454,b|0,d|0,64433,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(c);yb(h);jb=a+352|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Wb(a+208|0);v[114578]=0;Bc(a+16|0,d);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){v[114578]=0;b=T(21,a+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}v[114578]=0;aa(2448,b|0,64400,64426,a+224|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}Ob(a+16|0);c=Wb(a+192|0);b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114578]=0;d=Q(2430,a+264|0,a+256|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Fb(c)+b|0)){d=Fb(c);b=Fb(c);v[114578]=0;R(149,c|0,b<<1);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=d+b}v[114578]=0;d=T(2432,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}v[114578]=0;d=Zj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}if(d){break c}v[114578]=0;T(2434,a+264|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ob(a+16|0);break a}v[114578]=0;R(149,c|0,v[a+188>>2]-b|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=Tb(c);v[114578]=0;d=da(2453)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[a>>2]=f;v[114578]=0;b=aa(2454,b|0,d|0,64433,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(c);yb(h);jb=a+272|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function er(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=Ns(c,d);v[i+4>>2]=2428;m=Rd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=od(k);if(!j){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}ye(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114578]=0;h=Q(2462,a|0,i+120|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114578]=0;b=Q(2463,a|0,i+120|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114578]=0;n=T(2464,a|0)|0;b=v[114578];v[114578]=0;g:{if((b|0)!=1){if(g){break g}v[114578]=0;n=Q(2465,e|0,n|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114578]=0;T(2466,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[ij(b,q)>>2];j:{if(g){break j}v[114578]=0;p=Q(2465,e|0,p|0)|0;s=v[114578];v[114578]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Fb(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Gc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Wc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Gc(m);S(b|0)}L()}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-48|0;jb=k;a:{if(!Qb(a,1)){break a}d=b;c=zk(d);b:{if(c>>>0<64){m=jb-32|0;jb=m;c:{l=64-c|0;d:{if(l>>>0<=(v[zb(d)>>2]-v[d+4>>2]|0)/33>>>0){c=jb-16|0;jb=c;e=c;v[c>>2]=d;f=v[d+4>>2];v[c+4>>2]=f;v[c+8>>2]=f+B(l,33);e:{if(v[c+4>>2]!=v[c+8>>2]){while(1){h=zb(d);f=v[e+4>>2];v[114578]=0;R(767,h|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}f=v[e+4>>2]+33|0;v[e+4>>2]=f;if((f|0)!=v[e+8>>2]){continue}break}}Mb(e);jb=c+16|0;break d}a=P()|0;O()|0;Mb(e);S(a|0);L()}n=zb(d);i=m+8|0;f=zk(d)+l|0;j=jb-16|0;jb=j;v[j+12>>2]=f;g=jb-16|0;jb=g;e=d;zb(d);v[g+12>>2]=130150524;v[114578]=0;v[g+8>>2]=2147483647;h=Q(33,g+12|0,g+8|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)!=1){jb=g+16|0;c=v[h>>2];break f}V(0)|0;O()|0;Ab();L()}g:{if(c>>>0>=f>>>0){e=Jl(e);if(e>>>0<c>>>1>>>0){v[j+8>>2]=e<<1;c=v[bd(j+8|0,j+12|0)>>2]}jb=j+16|0;break g}ed();L()}f=zk(d);g=0;h=jb-16|0;jb=h;v[h+12>>2]=0;Tc(i+12|0,n);if(c){e=c;if(c>>>0>130150524){Fc(14703);L()}g=sc(B(e,33),1)}v[i>>2]=g;e=B(f,33)+g|0;v[i+8>>2]=e;v[i+4>>2]=e;o=ec(i),p=B(c,33)+g|0,v[o>>2]=p;jb=h+16|0;v[114578]=0;R(765,i|0,l|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}v[114578]=0;R(766,d|0,i|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}yR(i)}jb=m+32|0;break b}a=P()|0;O()|0;yR(i);S(a|0);L()}if(c>>>0>64){c=v[d>>2]+2112|0;zk(d);xR(d,c);Jl(d);zk(d)}}g=Gd(a);if(!g){break a}while(1){g=g-1|0;h=jb-16|0;jb=h;f=k+8|0;Ez(h+8|0,f);e=Hb(h+8|0);c=a;d=nc(c,ac(h,h+8|0));if((e|0)==(d|0)){$b(c,Hb(h+8|0))}jb=h+16|0;d=(d|0)==(e|0);if(!d){c=jb-16|0;jb=c;vR(f);jb=c+16|0}h:{if(!d){break h}c=w[k+8|0];if(c>>>0>63){break h}lc(BR(b,c),k+8|0,33)}if(g&255){continue}break}}jb=k+48|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=jb-48|0;jb=f;s=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;i=v[a+48>>2];v[f+36>>2]=i;l=v[a+52>>2];v[f+40>>2]=l;m=v[a+56>>2];v[f+44>>2]=m;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;if(d){while(1){m=1;h=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];k=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];n=u[e+28>>1];r=u[e+26>>1];x=u[e+24>>1];l=0;e=1;i=0;while(1){g=i<<1;v[(f+8|0)+(i<<2)>>2]=(((((B(u[h+(g|8)>>1],o)+B(u[h+(g|4)>>1],p)|0)+B(u[h+(g|12)>>1],k)|0)+B(j,u[h+(g|16)>>1])|0)/2|0)+((((B(u[h+(g|-8)>>1],r)+B(u[h+(g|-12)>>1],x)|0)+B(u[h+(g|-4)>>1],n)|0)+B(u[h+g>>1],q)|0)/2|0)|0)/16384;g=e;e=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(l<<2)|0;j=v[i>>2];k=v[a+60>>2];o=k;g=(f+32|0)+(l<<3)|0;l=v[g>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];h=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[g+4>>2]=l;l=v[a+72>>2];k=k>>31;j=j<<8;k=Hma(o,k,j,j>>31);o=mb;q=i;i=k;k=Hma(p,p>>31,e,e>>31);i=i+k|0;e=mb+o|0;e=i>>>0<k>>>0?e+1|0:e;k=i;i=Hma(r,n,h,h>>31);h=k+i|0;e=mb+e|0;e=h>>>0<i>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|h>>>24;v[q>>2]=(e|0)/256;v[g>>2]=e-(j&l);l=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],t);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];l=v[f+40>>2];i=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=l;v[a+48>>2]=i;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;jb=f+48|0}function f_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2490;b=Rd(a+152|0,a+160|0,a+16|0);v[114578]=0;Bc(a+144|0,e);h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114578]=0;h=T(21,a+144|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[a+143|0]=0;e=v[e+4>>2];v[114578]=0;c=ta(2491,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(!c){break f}c=w[64683]|w[64684]<<8|(w[64685]<<16|w[64686]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[64680]|w[64681]<<8|(w[64682]<<16|w[64683]<<24);v[a+128>>2]=w[64676]|w[64677]<<8|(w[64678]<<16|w[64679]<<24);v[a+132>>2]=c;v[114578]=0;aa(2448,h|0,a+128|0,a+138|0,a+118|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[a+4>>2]=2428;d=Rd(a+8|0,0,a+4|0);c=a+16|0;if((v[a+148>>2]-v[b>>2]|0)<99){break g}ye(d,od((v[a+148>>2]-v[b>>2]|0)+2|0));if(v[d>>2]){break h}v[114578]=0;Y(2429);c=v[114578];v[114578]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+148>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((hF(a+16|0,a)|0)!=1){v[114578]=0;Z(2492,64660);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break d}Gc(d)}else{j=c,k=w[((Tm(a+118|0,a+128|0,e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;continue}break}}v[114578]=0;c=Q(2431,a+280|0,a+272|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Ob(a+144|0);Gc(b);jb=a+288|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Gc(d)}Ob(a+144|0)}Gc(b);S(e|0);L()}L()}function fp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0;e=jb-16|0;jb=e;v[e+12>>2]=u[b+792>>1]+w[b+857|0];v[e+8>>2]=u[b+794>>1]+(w[b+858|0]&127);ce(e+12|0,0,127);ce(e+8|0,0,127);m=a+1074312|0;Eb(e,m,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+792>>1]=0;t[b+857|0]=i;j=v[e+8>>2];u[b+794>>1]=0;t[b+858|0]=j}Eb(e,m,36);i=B(i,d+256|0);n=(i|0)/256|0;j=Cb(e);l=v[e+8>>2];a:{if(!(l|!j|(i|0)<65024)){n=-1;a=b+810|0;if(!Tf(a)){break a}if(Ds(a)|x[b+808>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=ne(C(10),C(C(0-l|0)*C(.00937500037252903)));i=jb-16|0;jb=i;h=C(B(v[e+12>>2],d+256|0)>>>0);l=i;d=a;b:{if(v[a+480180>>2]!=33554432){g=C(110);k=C(C(h/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}g=C(125);k=C(h*C(9227362170349807e-20))}o=l,p=Lh(C(ne(C(2),k)*g)),v[o+12>>2]=p;ce(i+12|0,120,2e4);j=v[i+12>>2];d=v[d+24620>>2];jb=i+16|0;Eb(e,m,36);h=C(C(((d|0)<j<<1?d>>>1|0:j)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){g=C(C(y[a+24620>>2])/h);h=C(C(f+C(-1))+C(g*f));z[e>>2]=h;f=C(g*g);break c}g=C(h/C(y[a+24620>>2]));f=C(f+f);z[e>>2]=g*C(C(1)-f);LM(e,C(2));h=C(C(f-z[e>>2])/g);z[e>>2]=h;f=C(C(1)/C(g*g))}g=C(C(h+f)+C(1));h=C(C(C(f+f)+h)/g);k=C(C(16777216)/g);f=C(C(-f)/g);d:{if(w[b+865|0]==1){o=b,p=Lh(C(C(16777216)-k)),v[o+60>>2]=p;o=b,p=Lh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Lh(C(f*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Lh(k),v[o+60>>2]=p;o=b,p=Lh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Lh(C(f*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}jb=e+16|0;return n}function Zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=jb-16|0;jb=g;a:{b:{c:{h=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?h>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?h>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?h>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?h>>>0>2147483648:0){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}r=v[a+16>>2];j=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=e;v[g>>2]=h;v[g+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(i>>>16&65520)+o|0;i=u[e+14>>1];h=t[b+3|0];s=u[e+12>>1];w=t[b+2|0];x=u[e+10>>1];y=t[b+1|0];z=u[e+8>>1];A=t[b|0];C=u[e+6>>1];D=t[b-1|0];E=u[e+4>>1];F=t[b-2|0];G=u[e+2>>1];H=t[b-3|0];I=u[e>>1];b=v[a+60>>2];J=b;K=b>>31;b=Yb(m,-16777216,16776704);n=v[a+64>>2];e=Yb(j,-16777216,16776704);L=v[a+72>>2];M=v[a+32>>2];j=c;N=v[c>>2];b=Hma(n,n>>31,b,b>>31);n=mb;p=b;b=v[a+68>>2];q=Hma(b,b>>31,e,e>>31);e=p+q|0;b=mb+n|0;b=e>>>0<q>>>0?b+1|0:b;p=e;i=(((((((B(F,G)+B(H,I)|0)+B(D,E)|0)+B(A,C)|0)+B(y,z)|0)+B(w,x)|0)+B(h,s)|0)+B(f,i)<<8)/32768<<8;e=i;f=Hma(J,K,e,e>>31);e=p+f|0;b=mb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}e=(b&16777215)<<8|e>>>24;b=(e|0)/256|0;l=v[a+28>>2]+l|0;f=l>>12;v[j>>2]=B(b,f)+N;k=k+M|0;h=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,h);b=e-(i&L)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];e=v[g+12>>2];j=m;m=b;continue}break}i=v[g+8>>2];e=v[g+12>>2];j=m;break e}h=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=j;v[a+44>>2]=b;v[a+24>>2]=h;v[a>>2]=i;v[a+4>>2]=e;jb=g+16|0}function vv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){h=b-4|0;b:while(1){d=a;while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 5:break i;case 4:break j;case 2:break k;case 0:case 1:break c;case 3:break g;default:break h}}a=b-4|0;if(!Jd(a,d)){break c}Zb(d,a);return}uv(d,d+4|0,d+8|0,b-4|0);return}tv(d,d+4|0,d+8|0,d+12|0,b-4|0);return}if((a|0)<=123){h=b;g=jb-16|0;jb=g;e=d;c=d+8|0;rm(d,d+4|0,c);b=d+12|0;while(1){if((b|0)!=(h|0)){if(Jd(b,c)){v[g+12>>2]=v[b>>2];d=b;while(1){l:{a=c;v[d>>2]=v[a>>2];if((a|0)==(e|0)){a=e;break l}d=a;c=d-4|0;if(Jd(g+12|0,c)){continue}}break}v[a>>2]=v[g+12>>2]}c=b;b=b+4|0;continue}break}jb=g+16|0;return}f=((e|0)/2<<2)+d|0;m:{if((a|0)>=3997){a=(e|0)/4<<2;a=tv(d,a+d|0,f,a+f|0,h);break m}a=rm(d,f,h)}i=a;a=h;if(!Jd(d,f)){while(1){a=a-4|0;if((d|0)==(a|0)){e=d+4|0;if(Jd(d,h)){break e}while(1){if((e|0)==(h|0)){break c}if(Jd(d,e)){Zb(e,h);e=e+4|0;break e}else{e=e+4|0;continue}}}if(!Jd(a,f)){continue}break}Zb(d,a);i=i+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){g=e;e=e+4|0;if(Jd(g,f)){continue}while(1){a=a-4|0;if(!Jd(a,f)){continue}break}if(a>>>0<g>>>0){e=g;break f}else{Zb(g,a);f=(f|0)==(g|0)?a:f;i=i+1|0;continue}}}rm(d,d+4|0,b-4|0);break c}n:{if((e|0)==(f|0)){break n}if(!Jd(f,e)){break n}Zb(e,f);i=i+1|0}if(!i){g=OD(d,e);a=e+4|0;if(OD(a,b)){b=e;a=d;if(!g){continue a}break c}f=2;if(g){break d}}if((e-d|0)<(b-e|0)){vv(d,e,c);a=e+4|0;continue b}vv(e+4|0,b,c);b=e;a=d;continue a}f=h;if((f|0)==(e|0)){break c}while(1){a=e;e=e+4|0;if(!Jd(d,a)){continue}while(1){f=f-4|0;if(Jd(d,f)){continue}break}if(a>>>0<f>>>0){Zb(a,f);continue}break}f=4}d=a;switch(f-2|0){case 0:continue b;case 2:continue;default:break c}}break}break}break}}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];j=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];g=v[a>>2];v[h+8>>2]=g;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(g>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;g=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];H=u[e+8>>1];r=v[a+60>>2];b=Yb(m,-16777216,16776704);o=v[a+64>>2];e=Yb(j,-16777216,16776704);I=v[a+72>>2];J=v[a+32>>2];j=c;K=v[c>>2];b=Hma(o,o>>31,b,b>>31);o=mb;q=b;n=(((((((B(i,n)+B(f,g)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(G,H)|0)/32768<<8;b=n;f=Hma(r,r>>31,b,b>>31);g=q+f|0;b=mb+o|0;b=f>>>0>g>>>0?b+1|0:b;q=g;g=v[a+68>>2];g=Hma(g,g>>31,e,e>>31);e=q+g|0;b=mb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}e=(b&16777215)<<8|e>>>24;b=(e|0)/256|0;l=v[a+28>>2]+l|0;f=l>>12;v[j>>2]=B(b,f)+K;k=k+J|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);b=e-(n&I)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+8>>2];e=v[h+12>>2];j=m;m=b;continue}break}g=v[h+8>>2];e=v[h+12>>2];j=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=j;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=g;v[a+4>>2]=e;jb=h+16|0}function Lba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=jb-32|0;jb=k;b=a+8|0;ss(b,Ke(b));m=zb(b),n=0,v[m>>2]=n;m=b,n=hc(b),v[m>>2]=n;m=hc(b),n=0,v[m>>2]=n;v[a+32>>2]=0;v[a+36>>2]=0;f=a+4|0;v[v[f>>2]>>2]=0;v[v[f>>2]+40>>2]=v[v[a>>2]+480196>>2];v[v[f>>2]+44>>2]=v[v[a>>2]+480204>>2];v[v[f>>2]+68>>2]=v[v[a>>2]+480200>>2];e=x[v[a>>2]+480188>>1];b=k;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;i=b+8|0;b=i;v[b>>2]=0;v[b+4>>2]=0;t[b+21|0]=255;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;v[b+8>>2]=0;v[b+12>>2]=0;h=jb-16|0;jb=h;v[h+12>>2]=e;d=a+20|0;a:{if(We(d)>>>0>=e>>>0){m=h,n=Id(d),v[m+8>>2]=n;c=v[d>>2];b=i;g=v[Lb(h+12|0,h+8|0)>>2];if(g){while(1){e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;e=x[b+18>>1]|x[b+20>>1]<<16;l=x[b+14>>1]|x[b+16>>1]<<16;u[c+14>>1]=l;u[c+16>>1]=l>>>16;u[c+18>>1]=e;u[c+20>>1]=e>>>16;e=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=e;c=c+24|0;g=g-1|0;if(g){continue}break}}b=v[h+12>>2];c=v[h+8>>2];if(b>>>0>c>>>0){WL(d,b-c|0,i);break a}b=v[d>>2]+B(b,24)|0;Id(d);XL(d,b);up(d);break a}b=d;if(v[b>>2]){Id(b);YL(b);up(b);Xo(zb(b),v[b>>2],We(b));m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0}c=Hk(d,e);if(tT(d)>>>0<c>>>0){ed();L()}zb(b);g=c;if(c>>>0>178956970){Fc(20384);L()}g=sc(B(g,24),8);v[b>>2]=g;v[b+4>>2]=g;m=zb(b),n=g+B(c,24)|0,v[m>>2]=n;Tt(b,0);WL(d,e,i)}jb=h+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(j,896);qn((b+v[f>>2]|0)+608|0,v[a>>2],j&65535);t[(b+v[f>>2]|0)+1445|0]=0;t[(b+v[f>>2]|0)+1444|0]=0;t[(b+v[f>>2]|0)+1429|0]=0;t[(b+v[f>>2]|0)+1432|0]=0;t[(b+v[f>>2]|0)+1427|0]=0;j=j+1|0;if(j>>>0<x[v[a>>2]+480188>>1]){continue}break}}jb=k+32|0}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=jb-48|0;jb=f;s=v[a+16>>2];g=v[a+44>>2];v[f+32>>2]=g;e=v[a+48>>2];v[f+36>>2]=e;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;w=v[a+24>>2];x=v[a+20>>2];l=v[a+4>>2];i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=l;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;if(d){while(1){h=(((l&2147483647)<<1|i>>>31)&-2)+s|0;m=1;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];j=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];n=u[e+28>>1];r=u[e+26>>1];y=u[e+24>>1];k=0;e=1;g=0;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[h+(g|4)|0],o)+B(t[h+(g|2)|0],p)|0)+B(t[h+(g|6)|0],j)|0)+B(i,t[h+(g|8)|0])<<8)/2|0)+((((B(t[h+(g|-4)|0],r)+B(t[h+(g|-6)|0],y)|0)+B(t[h+(g|-2)|0],n)|0)+B(t[g+h|0],q)<<8)/2|0)|0)/16384;l=e;e=0;g=1;if(l){continue}break}while(1){h=(f+8|0)+(k<<2)|0;i=v[h>>2];j=v[a+60>>2];o=j;l=(f+32|0)+(k<<3)|0;k=v[l>>2];e=Yb(k,-16777216,16776704);p=v[a+64>>2];g=Yb(v[l+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[l+4>>2]=k;k=v[a+72>>2];j=j>>31;i=i<<8;j=Hma(o,j,i,i>>31);o=mb;q=h;h=j;j=Hma(p,p>>31,e,e>>31);h=h+j|0;e=mb+o|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=Hma(r,n,g,g>>31);g=j+h|0;e=mb+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;v[q>>2]=(e|0)/256;v[l>>2]=e-(i&k);k=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],w);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];l=v[f+28>>2];continue}break}i=v[f+24>>2];l=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+32>>2];e=v[f+36>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=l;jb=f+48|0}function oH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;d=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;c=e;a:{b:{switch(v[d+40>>2]){case 0:b=jb-80|0;jb=b;f=v[c>>2];g=v[f+4>>2];v[b+40>>2]=v[f+20>>2];i=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=i;Do(b- -64|0,b+32|0,g);f=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(g){while(1){f=0;if(i){while(1){k=A[ch(c,f,h)>>3];fc(d,f);m=Of(j,f,h),n=C(k),z[m>>2]=n;f=f+1|0;if((i|0)!=(f|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 2:Hw(c,zb(d));break a;case 3:i=Ug(d);b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];v[b+40>>2]=v[d+20>>2];g=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=g;Do(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(h){while(1){d=0;if(g){while(1){k=A[ch(c,d,f)>>3];Ve(i,d);l=tj(Sd(k*134217728));m=Of(j,d,f),n=C(+(l|0)*7.450580596923828e-9),z[m>>2]=n;d=d+1|0;if((g|0)!=(d|0)){continue}break}}f=f+1|0;if((h|0)!=(f|0)){continue}break}}jb=b+80|0;break a;case 1:Hw(c,zb(d));break a;default:break b}}Hw(c,zb(d))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;s=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;g=v[a+56>>2];v[b+44>>2]=g;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){l=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;h=(j>>>21&2040)+27888|0;j=u[h+6>>1];g=u[h+4>>1];k=u[h+2>>1];m=u[h>>1];h=0;i=1;f=0;while(1){n=(b+8|0)+(f<<2)|0;f=f<<1;v[n>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],m)|0)+B(g,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;q=i&1;i=0;f=1;if(q){continue}break}while(1){i=(b+8|0)+(h<<2)|0;j=v[i>>2];g=v[a+60>>2];k=g;h=(b+32|0)+(h<<3)|0;m=v[h>>2];e=Yb(m,-16777216,16776704);q=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];t=n;n=n>>31;v[h+4>>2]=m;m=v[a+72>>2];r=g>>31;j=j<<8;g=j;g=Hma(k,r,g,g>>31);k=mb;r=i;i=g;g=Hma(q,q>>31,e,e>>31);i=i+g|0;e=mb+k|0;e=i>>>0<g>>>0?e+1|0:e;g=i;i=Hma(t,n,f,f>>31);f=g+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[r>>2]=(e|0)/256;v[h>>2]=e-(j&m);h=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);o=e+o|0;k=o>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];g=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=g;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;jb=b+48|0}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=Xs(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=Hma(v[a+24>>2],0,8272,0)+4181|0;d=mb;i=a,j=hd(Kma(e,e>>>0<4181?d+1|0:d,8363,0),mb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=Hma(v[a+24>>2],0,8363,0)+4136|0;d=mb;i=a,j=hd(Kma(e,e>>>0<4136?d+1|0:d,8272,0),mb),v[i+24>>2]=j}e=jb-16|0;jb=e;g=e+8|0;d=jb-16|0;jb=d;h=v[a+24>>2];b:{if(!h){t[g|0]=0;t[g+1|0]=0;break b}jG(d+8|0,Yb(nn(vo(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];Fy(g,d+7|0,d+6|0)}jb=d+16|0;Oc(e,a+36|0);Oc(e+4|0,a+37|0);d=e+8|0;_N(e,d);_N(e+4|0,d+1|0);jb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}d=c&4;if(d){e=x[a+34>>1];if(!(e&32)){u[a+28>>1]=128;u[a+34>>1]=e|32}Ue(a+40|0,15);Ue(a+41|0,63)}c:{if(!(!d|!(b&16777248)?c&16777248?b&4:0:1)|!w[a+41|0]){break c}e=w[a+40|0];if(!e){break c}b=a;d=w[a+39|0];if(d){d=Nk(hd(((e<<8|d>>>1)>>>0)/(d>>>0)|0,0))}else{d=255}t[b+39|0]=d}d:{e:{if((c|0)!=4){if((c|0)==16777216){break d}if((c|0)!=32|w[a+38|0]!=2){break e}t[a+38|0]=3;break e}if(w[a+38|0]!=4){break e}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}f:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;op(a,0,f);break f}if(!(w[a+35|0]&2)|(c|0)!=2){break f}a=a+68|0;b=fc(a,8);t[b|0]=w[b|0]&3;a=fc(a,9);t[a|0]=w[a|0]&3}jb=f+32|0}function ux(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;i=b,j=w[pc(b,f+15|0)|0],t[i|0]=j;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){h=w[d+20832|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}t[a|0]=11;t[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[pc(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}jb=f+16|0;return e}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;f=gh(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(mi(b)){Fo(c+56|0);break n}v[114578]=0;R(2190,c+40|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;R(2176,c+56|0,c+40|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}rf(c+40|0)}if(mi(b)){a=b+36|0}else{a=v[c+56>>2]}e=Id(a);v[114578]=0;R(1534,f|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break k}h=c,i=bc(a),v[h+32>>2]=i;h=c,i=cc(a),v[h+24>>2]=i;if(Jb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Di(v[a>>2]+484360|0,w[e+16|0]);v[114578]=0;R(2191,c+8|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break j}v[114578]=0;U(9,c+40|0,0,c+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break i}v[114578]=0;R(1536,f|0,c+40|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}yb(c+40|0);yb(c+8|0);o:{if(!Wc(KH(f))){break o}d=w[e+12|0];v[114578]=0;d=Q(546,b|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[114578]=0;d=T(686,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[rc(b,v[e+12>>2])>>1]);v[114578]=0;R(2192,c+8|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;X(440,c+40|0,0,d|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}Gb(KH(f),c+40|0);yb(c+40|0);yb(c+8|0)}Gk(c+32|0);if(Jb(c+32|0,c+24|0)){continue}break}}gk(c+56|0);jb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;rf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(c+40|0)}yb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(c+8|0);break b}b=P()|0;O()|0}gk(c+56|0)}kd(f);S(b|0);L()}function nO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=jb-32|0;jb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;d=!(b&2);b=w[a+14|0];if(d|b>>>0<=w[a+13|0]){break a}if(Kb(a)>>>0<=b>>>0){break a}while(1){d=Dc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Kb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Kb(a)>>>0<=b>>>0){break a}d=x[Dc(a,w[a+14|0])>>1];e=Dc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Dc(a,b)>>1]-1&65535;d=qp(a,b,64,64);q=f,r=bc(a),v[q+8>>2]=r;q=f,r=pp(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Md(f+24|0,f+16|0);i=Cp(f,b,d&255);g=jb-32|0;jb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=bc(a),v[q>>2]=r;d=d+(qt(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[zb(a)>>2]){j=v[b+4>>2];if((j|0)!=(d|0)){break d}sR(b,i);break c}e=zb(b);e=Un(g,Be(b,Kb(b)+1|0),d-v[b>>2]>>2,e);v[114578]=0;R(1160,e|0,i|0);k=v[114578];v[114578]=0;e:{if((k|0)==1){break e}v[114578]=0;d=W(1161,b|0,e|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Vh(e);break c}a=P()|0;O()|0;Vh(e);S(a|0);L()}l=jb-16|0;jb=l;k=d;n=b;o=v[b+4>>2];b=(o-(d+4|0)|0)+d|0;h=qe(l,n,j-b>>2);f:{g:{if(b>>>0<j>>>0){e=b;while(1){m=zb(n);p=v[h+4>>2];v[114578]=0;U(769,m|0,p|0,e|0);m=v[114578];v[114578]=0;if((m|0)==1){break g}v[h+4>>2]=v[h+4>>2]+4;e=e+4|0;if(j>>>0>e>>>0){continue}break}}Mb(h);Fp(k,b,o);jb=l+16|0;break f}a=P()|0;O()|0;Mb(h);S(a|0);L()}u[d>>1]=x[i>>1];t[d+2|0]=w[i+2|0]}Ng(d);jb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}jb=f+32|0}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;Jc(c);a:{if(!Qb(c,3)){break a}while(1){hq(f+8|0,c);i=cd(f+8|0);d=Bf(f+8|0);g=f+8|0;if(y[a+12>>2]<=w[g|0]){break a}e=Xe(a,w[g|0],b);h=w[i|0];b:{if(h>>>0<=126){if(!(h|w[d|0])){t[e|0]=254;break b}t[e|0]=h+1;if(w[d|0]==255){break b}if(!w[e+1|0]){t[e+1|0]=j}t[e+2|0]=1;t[e+4|0]=w[d|0];break b}c:{switch(h-127|0){case 0:d=w[g|0]+t[d|0]|0;if((d|0)<0|(d|0)>=v[a+12>>2]<<16>>16){break b}d=Xe(a,d,b);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e|0]=g;t[e+1|0]=g>>>8;t[e+2|0]=g>>>16;t[e+3|0]=g>>>24;d=w[d+4|0]|w[d+5|0]<<8;t[e+4|0]=d;t[e+5|0]=d>>>8;break b;case 1:j=w[d|0]+1|0;t[e+1|0]=j;break b;default:break c}}d=t[d|0];t[f+7|0]=d;g=0;h=h&127;if(h>>>0<=23){g=w[h+12144|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{h=w[i|0];switch((h&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break e}}if((d|0)>-1){break f}d=0-d&15;break e}t[f+6|0]=64;d=w[pc(f+7|0,f+6|0)|0];if(w[e+2|0]>1){break e}t[e+4|0]=d;t[e+2|0]=1;break b}if((d|0)>-1){g=3;break d}d=0-d&127;t[f+7|0]=d;break e}if(!d){break b}if((d|0)<=-1){d=0-d|-16;t[f+7|0]=d;break e}d=d<<4|15;t[f+7|0]=d;break e}if(!d){break b}g=(d|0)>-1;if(!g){d=0-d&15;t[f+7|0]=d;h=w[i|0]}g=g?3:2;d=((h|0)==22?-32:-16)|d;t[f+7|0]=d;break d}d=d&15|-48;t[f+7|0]=d;break e}d=d&15|-64;t[f+7|0]=d;break e}d=d- -64&127;if(!w[e+3|0]){break e}o:{switch(w[e+2|0]){case 0:case 2:break o;default:break b}}t[e+2|0]=2;t[e+4|0]=d>>>1;break b}d=d<<4}if(!(g&255)){break b}}t[e+5|0]=d;t[e+3|0]=g}if(Qb(c,3)){continue}break}}jb=f+16|0}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;b=jb-48|0;jb=b;s=v[a+16>>2];i=v[a+44>>2];v[b+32>>2]=i;l=v[a+48>>2];v[b+36>>2]=l;h=v[a+52>>2];v[b+40>>2]=h;g=v[a+56>>2];v[b+44>>2]=g;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+s|0;f=(j>>>21&2040)+27888|0;j=u[f+6>>1];g=u[f+4>>1];k=u[f+2>>1];m=u[f>>1];i=0;l=1;h=1;f=0;while(1){v[(b+8|0)+(f<<2)>>2]=(((B(t[e+f|0],k)+B(t[e+(f|-2)|0],m)|0)+B(g,t[e+(f|2)|0])|0)+B(j,t[e+(f|4)|0])<<8)/16384;p=h&1;h=0;f=1;if(p){continue}break}while(1){h=(b+8|0)+(i<<2)|0;j=v[h>>2];g=v[a+60>>2];k=g;f=(b+32|0)+(i<<3)|0;m=v[f>>2];e=Yb(m,-16777216,16776704);p=v[a+64>>2];i=Yb(v[f+4>>2],-16777216,16776704);q=v[a+68>>2];w=q;q=q>>31;v[f+4>>2]=m;m=v[a+72>>2];r=g>>31;j=j<<8;g=j;g=Hma(k,r,g,g>>31);k=mb;r=h;h=g;g=Hma(p,p>>31,e,e>>31);h=h+g|0;e=mb+k|0;e=h>>>0<g>>>0?e+1|0:e;g=h;h=Hma(w,q,i,i>>31);i=g+h|0;e=mb+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|i>>>24;v[r>>2]=(e|0)/256;v[f>>2]=e-(j&m);i=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;f=n>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];g=v[b+44>>2];h=v[b+40>>2];l=v[b+36>>2];i=v[b+32>>2];break a}f=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=g;v[a+52>>2]=h;v[a+48>>2]=l;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=j;v[a+4>>2]=e;jb=b+48|0}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-384|0;jb=a;v[a+368>>2]=c;v[a+376>>2]=b;Fv(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Wb(a+200|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114578]=0;b=Q(2462,a+376|0,a+368|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+196>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+196>>2]=b+c}v[114578]=0;b=T(2464,a+376|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=dr(b,a+23|0,a+22|0,c,a+196|0,v[a+236>>2],v[a+232>>2],a+216|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2466,a+376|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114578]=0;X(2451,a|0,c|0,v[a+196>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114578]=0;Ee(a+216|0,a+32|0,v[a+28>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+376|0,a+368|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];yb(d);yb(a+216|0);jb=a+384|0;break a}}b=P()|0;O()|0;yb(d);yb(a+216|0);S(b|0);L()}return b|0}function e$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;Iv(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Wb(a+208|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114578]=0;b=Q(2430,a+280|0,a+272|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+204>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+204>>2]=b+c}v[114578]=0;b=T(2432,a+280|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=fr(b,a+23|0,a+22|0,c,a+204|0,t[a+239|0],t[a+238|0],a+224|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2434,a+280|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114578]=0;X(2451,a|0,c|0,v[a+204>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114578]=0;Ee(a+224|0,a+32|0,v[a+28>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+280|0,a+272|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];yb(d);yb(a+224|0);jb=a+288|0;break a}}b=P()|0;O()|0;yb(d);yb(a+224|0);S(b|0);L()}return b|0}function qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;g=jb-48|0;jb=g;p=v[a+16>>2];h=Qf(g+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=Pf(a+8|0,b),v[t>>2]=w;v[h+4>>2]=mb}k=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];f=v[a+4>>2];e=v[a>>2];v[g+8>>2]=e;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(d){while(1){b=0;i=b;v[g+40>>2]=e;v[g+44>>2]=b;f=(f<<1)+p|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],u[(i<<1)+f>>1]/4<<16>>16);zd(v[h+8>>2],4);Sb(g+40|0,h);if((b|0)<2){break b}b=b-1|0;i=v[g+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Ad(b,u[f+(v[g+44>>2]<<1)>>1]/4<<16>>16);zd(v[h+8>>2],e);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);i=v[a+60>>2];b=Yb(n,-16777216,16776704);j=v[a+64>>2];f=Yb(k,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];k=c;s=v[c>>2];o=e<<8;e=o;e=Hma(i,i>>31,e,e>>31);i=mb;j=Hma(j,j>>31,b,b>>31);e=j+e|0;b=mb+i|0;b=e>>>0<j>>>0?b+1|0:b;i=e;e=v[a+68>>2];e=Hma(e,e>>31,f,f>>31);f=i+e|0;b=mb+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;m=v[a+28>>2]+m|0;i=m>>12;v[k>>2]=B(b,i)+s;l=l+r|0;j=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);b=f-(q&o)|0;Sb(g+8|0,g);if(d){c=c+8|0;e=v[g+8>>2];f=v[g+12>>2];k=n;n=b;continue}break}e=v[g+8>>2];f=v[g+12>>2];k=n;break a}j=l>>12;i=m>>12;b=n}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=k;v[a+44>>2]=b;v[a+24>>2]=j;v[a>>2]=e;v[a+4>>2]=f;jb=g+48|0}function bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-16|0;jb=d;a:{if(!Qb(a,2)){rg(c+484344|0,b,64);break a}j=c+484344|0;h=Fd(Wp(a),1,1024);if(!rg(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){n=Rn(_b(j,b),i);g=0;if(k){while(1){Sl(d+8|0,a);e=cd(d+8|0);o=Bf(d+8|0);c=B(g,6)+n|0;f=w[Rh(d+8|0)|0];t[c+5|0]=f;l=0;m=w[d+8|0];if((m-1&255)>>>0<=35){t[c|0]=m+48;l=w[e|0]+1|0}e=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[e|0]=f&15;break b;case 2:t[c+3|0]=3;t[e|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=36;t[d+7|0]=15;p=e,q=w[pc(d+7|0,e)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=35;t[d+6|0]=15;p=e,q=w[pc(d+6|0,e)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=36;t[d+5|0]=15;p=e,q=w[pc(d+5|0,e)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=35;t[d+4|0]=15;p=e,q=w[pc(d+4|0,e)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[e|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:gt(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[e|0]=f&15;break b;case 5:t[e|0]=f<<4;break b;case 6:t[d+3|0]=f&15;t[d+2|0]=14;p=e,q=w[pc(d+3|0,d+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[d+1|0]=f&15;t[d|0]=14;p=e,q=w[pc(d+1|0,d)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[e|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}jb=d+16|0}function hh(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;a:{if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;h=c&d;b:{if(h){ln(e,f);break b}ln(e,0)}t[f+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){By((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(B(b&256?d+9|0:d,44)+a|0)+16|0;v[g+8>>2]=d;f=v[d+36>>2];v[g+12>>2]=f;a=1;e=f?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;DN(d,a>>>5|0);h=c>>>2&7;CN(d,h);c=c&3;BN(d,c);if(!f){break a}b=1;d=(a|0)!=0;while(1){a=v[(g+8|0)+(b<<2)>>2];DN(a,d);CN(a,h);BN(a,c);b=b+1|0;if((e|0)!=(b|0)){continue}break}break a}AN(d,c);if(!f){break a}while(1){AN(v[(g+8|0)+(a<<2)>>2],c);a=a+1|0;if((e|0)!=(a|0)){continue}break}break a}t[d+42|0]=(c&32)>>>5;t[d+41|0]=(c&16)>>>4;a=c>>>1&7;u[d+30>>1]=a?9-a|0:0;u[d+32>>1]=c&1;break a}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=t[f+19888|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;mn(a);u[a+14>>1]=x[((c&15)<<1)+19920>>1];break a;case 1:u[a+68>>1]=w[(c>>>6|0)+19952|0];zN(a);u[a+22>>1]=(c&63)<<2;break a;case 2:u[a+24>>1]=c>>>4;mn(a);u[a+26>>1]=c&15;mn(a);break a;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;mn(a);break a;case 6:break d;default:break a}}u[a+12>>1]=c&7}jb=g+16|0}function fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-96|0;jb=d;b=b&4095;u[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=Hma(e,e>>31,1e4,0)+14780|0;b=mb;b=Ima(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Ub(d- -64|0,13390);v[114578]=0;R(219,d+80|0,e|0);f=v[114578];v[114578]=0;h=(B(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){v[114578]=0;g=b;b=h+2|0;f=(b|0)/12|0;v[d+44>>2]=g+f;R(191,d+48|0,d+44|0);g=v[114578];v[114578]=0;if((g|0)==1){break o}v[114578]=0;v[d+28>>2]=(b-B(f,12)|0)+1;R(193,d+32|0,d+28|0);b=v[114578];v[114578]=0;if((b|0)==1){break n}v[114578]=0;v[d+12>>2]=(((B(h,306)+5|0)/-10|0)+c|0)+1;R(193,d+16|0,d+12|0);b=v[114578];v[114578]=0;if((b|0)==1){break m}v[114578]=0;fa(619,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}yb(d+16|0);yb(d+32|0);yb(d+48|0);Ib(d+80|0);yb(e);break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;yb(d+16|0)}yb(d+32|0)}yb(d+48|0)}Ib(d+80|0)}yb(e);break a}c=Ub(d,13414);v[114578]=0;R(219,d+80|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;R(620,d+48|0,d+94|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(247,a|0,d+80|0,d+48|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}yb(d+48|0);Ib(d+80|0);yb(c)}jb=d+96|0;return}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+48|0)}Ib(d+80|0)}yb(c)}S(b|0);L()}function iD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-128|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=v[b>>2];l:{if(!b){Ub(a,7037);break l}if(!(b&65535)){e=Ub(c+96|0,7045);v[114578]=0;R(219,c+112|0,e|0);d=v[114578];v[114578]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){v[114578]=0;v[c+24>>2]=b>>>24;R(220,c+80|0,c+24|0);d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;v[c+8>>2]=b>>>16&255;R(221,c- -64|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break q}v[114578]=0;X(222,a|0,c+112|0,c+80|0,c- -64|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}yb(c- -64|0);yb(c+80|0);Ib(c+112|0);yb(e);break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;yb(c- -64|0)}yb(c+80|0)}Ib(c+112|0)}break a}e=Ub(c+48|0,7051);v[114578]=0;R(219,c+112|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}v[114578]=0;v[c+44>>2]=b>>>24;R(220,c+80|0,c+44|0);d=v[114578];v[114578]=0;if((d|0)==1){break j}v[114578]=0;v[c+40>>2]=b>>>16&255;R(221,c- -64|0,c+40|0);d=v[114578];v[114578]=0;if((d|0)==1){break i}v[114578]=0;v[c+20>>2]=b>>>8&255;R(221,c+24|0,c+20|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}v[114578]=0;v[c+4>>2]=b&255;R(221,c+8|0,c+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;ma(223,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break f}yb(c+8|0);yb(c+24|0);yb(c- -64|0);yb(c+80|0);Ib(c+112|0);yb(e)}jb=c+128|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;yb(c+8|0)}yb(c+24|0)}yb(c- -64|0)}yb(c+80|0)}Ib(c+112|0)}yb(e);S(b|0);L()}function XI(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=jb-16|0;jb=d;k=d,l=C($w(z[a+4216>>2])/C(Se(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(yo(C(z[nl(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=ne(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C($w(z[a+4220>>2])/C(Se(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[nl(d+12|0,d+8|0)>>2];k=d,l=C($w(z[a+4224>>2])/C(Se(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[nl(d+12|0,d+8|0)>>2]*C(3.1415927410125732));e=jb-16|0;jb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Im(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=Im(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=Im(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=Im(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=Im(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=qw(b,e+8|0);b=Im(A[e+8>>3],c&1)}jb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=yo(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+33376>>2];jb=d+16|0}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-384|0;jb=f;v[f+376>>2]=37;v[f+380>>2]=0;g=ar(f+376|1,64441,v[c+4>>2]);v[f+332>>2]=f+336;a=le();a:{if(g){h=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=h;a=af(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=af(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2428;h=Rd(f+320|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){v[114578]=0;a=da(2453)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114578]=0;A[f+8>>3]=e;a=aa(2475,f+332|0,a|0,f+376|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break e}break c}v[114578]=0;a=da(2453)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114578]=0;a=aa(2475,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}}g=v[f+332>>2];if(!g){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(h,g)}g=v[f+332>>2];j=g+a|0;k=mg(g,j,c);v[f+68>>2]=2428;i=Rd(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;g=f+336|0;break g}a=od(a<<3);if(!a){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(i,a);g=v[f+332>>2]}v[114578]=0;Bc(f+56|0,c);l=v[114578];v[114578]=0;h:{i:{if((l|0)!=1){v[114578]=0;ja(2486,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}Ob(f+56|0);v[114578]=0;a=ka(2487,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(i);Gc(h);jb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(f+56|0);break f}c=P()|0;O()|0}Gc(i);break b}L()}c=P()|0;O()|0}Gc(h);S(c|0);L()}function L_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-208|0;jb=f;v[f+200>>2]=37;v[f+204>>2]=0;g=ar(f+200|1,64441,v[c+4>>2]);v[f+156>>2]=f+160;a=le();a:{if(g){h=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=h;a=af(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=af(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2428;h=Rd(f+144|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){v[114578]=0;a=da(2453)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114578]=0;A[f+8>>3]=e;a=aa(2475,f+156|0,a|0,f+200|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break e}break c}v[114578]=0;a=da(2453)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114578]=0;a=aa(2475,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}}g=v[f+156>>2];if(!g){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(h,g)}g=v[f+156>>2];j=g+a|0;k=mg(g,j,c);v[f+68>>2]=2428;i=Rd(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;g=f+160|0;break g}a=od(a<<1);if(!a){v[114578]=0;Y(2429);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(i,a);g=v[f+156>>2]}v[114578]=0;Bc(f+56|0,c);l=v[114578];v[114578]=0;h:{i:{if((l|0)!=1){v[114578]=0;ja(2476,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}Ob(f+56|0);v[114578]=0;a=ka(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(i);Gc(h);jb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(f+56|0);break f}c=P()|0;O()|0}Gc(i);break b}L()}c=P()|0;O()|0}Gc(h);S(c|0);L()}function rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;g=jb-48|0;jb=g;p=v[a+16>>2];h=Qf(g+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=Pf(a+8|0,b),v[u>>2]=w;v[h+4>>2]=mb}k=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];f=v[a+4>>2];e=v[a>>2];v[g+8>>2]=e;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(d){while(1){b=0;i=b;v[g+40>>2]=e;v[g+44>>2]=b;f=f+p|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],t[f+i|0]<<6);zd(v[h+8>>2],4);Sb(g+40|0,h);if((b|0)<2){break b}b=b-1|0;i=v[g+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Ad(b,t[f+v[g+44>>2]|0]<<6);zd(v[h+8>>2],e);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);i=v[a+60>>2];b=Yb(n,-16777216,16776704);j=v[a+64>>2];f=Yb(k,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];k=c;s=v[c>>2];o=e<<8;e=o;e=Hma(i,i>>31,e,e>>31);i=mb;j=Hma(j,j>>31,b,b>>31);e=j+e|0;b=mb+i|0;b=e>>>0<j>>>0?b+1|0:b;i=e;e=v[a+68>>2];e=Hma(e,e>>31,f,f>>31);f=i+e|0;b=mb+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;m=v[a+28>>2]+m|0;i=m>>12;v[k>>2]=B(b,i)+s;l=l+r|0;j=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);b=f-(q&o)|0;Sb(g+8|0,g);if(d){c=c+8|0;e=v[g+8>>2];f=v[g+12>>2];k=n;n=b;continue}break}e=v[g+8>>2];f=v[g+12>>2];k=n;break a}j=l>>12;i=m>>12;b=n}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=k;v[a+44>>2]=b;v[a+24>>2]=j;v[a>>2]=e;v[a+4>>2]=f;jb=g+48|0}function jI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=jb-48|0;jb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}lc(d+8|0,v[a>>2]+24604|0,40);v[d+8>>2]=b;Lx(v[a>>2],d+8|0);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=jb-16|0;jb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}a=ba(8)|0;v[114578]=0;b=Q(85,g|0,39884)|0;c=v[114578];v[114578]=0;i:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break g}c=P()|0;O()|0;yb(b);break i}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=g+16|0;break f}L()}t[e+8|0]=b;if(!Uw(d+8|0,v[f>>2]+24648|0)){break d}Kx(v[f>>2],d+8|0);break d;case 3:b=a+24|0;lc(d+8|0,v[b>>2]+24604|0,40);a=d+8|0;e=jb-48|0;jb=e;j:{if((c|0)==-1){tl(a,v[rp(e+8|0)+32>>2]);ln(a,v[rp(e+8|0)+36>>2]);break j}if((c|0)<=0){tl(a,0);ln(a,0);break j}c=B(c,1e3);tl(a,c);ln(a,c)}jb=e+48|0;if(v[v[b>>2]+24640>>2]==v[d+44>>2]?v[v[b>>2]+24636>>2]==v[d+40>>2]:0){break d}Lx(v[b>>2],d+8|0);break d;default:a=ba(8)|0;v[114578]=0;c=Q(85,d+8|0,38669)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b;case 0:break e}}h=a,i=ne(C(10),C(C(c|0)*C(.0005000000237487257))),z[h+48>>2]=i}jb=d+48|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;s=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;f=v[a+48>>2];v[b+36>>2]=f;j=v[a+52>>2];v[b+40>>2]=j;k=v[a+56>>2];v[b+44>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){f=i>>>18|0;l=1;e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+s|0;g=0;j=1;h=0;while(1){k=h<<1;i=u[k+e>>1];v[(b+8|0)+(h<<2)>>2]=i+((B(f,u[e+(k|4)>>1]-i|0)|0)/16384|0);i=j&1;j=0;h=1;if(i){continue}break}while(1){h=(b+8|0)+(g<<2)|0;j=v[h>>2];f=v[a+60>>2];k=f;i=(b+32|0)+(g<<3)|0;o=v[i>>2];e=Yb(o,-16777216,16776704);r=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];t=p;p=p>>31;v[i+4>>2]=o;o=v[a+72>>2];q=f>>31;j=j<<8;f=j;f=Hma(k,q,f,f>>31);k=mb;q=h;h=f;f=Hma(r,r>>31,e,e>>31);h=h+f|0;e=mb+k|0;e=h>>>0<f>>>0?e+1|0:e;f=h;h=Hma(t,p,g,g>>31);g=f+h|0;e=mb+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;v[q>>2]=(e|0)/256;v[i>>2]=e-(j&o);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;h=n>>12;v[c>>2]=v[c>>2]+B(h,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];k=v[b+44>>2];j=v[b+40>>2];f=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;h=n>>12}v[a+40>>2]=m;v[a+20>>2]=h;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=j;v[a+48>>2]=f;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=jb-16|0;jb=h;a:{b:{c:{j=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?j>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?j>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?j>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];f=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=(i>>>16&65520)+m|0;g=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);H=v[a+72>>2];I=v[c>>2];b=Hma(l,l>>31,b,b>>31);l=mb;n=b;i=(((((((B(j,s)+B(g,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;g=Hma(o,o>>31,b,b>>31);e=n+g|0;b=mb+l|0;b=e>>>0<g>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=Hma(e,e>>31,f,f>>31);f=n+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=B(f,r)+I;v[c+4>>2]=v[c+4>>2]+B(f,q);b=b-(i&H)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?i>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?i>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?i>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=e+o|0;g=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[c>>2];b=Hma(l,l>>31,b,b>>31);l=mb;L=b;b=v[a+68>>2];n=Hma(b,b>>31,f,f>>31);f=L+n|0;b=mb+l|0;b=f>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(g,j)<<8)/32768<<8;g=Hma(H,I,e,e>>31);f=f+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=B(f,q)+K;v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(e&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;jb=h+16|0}function fF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-272|0;jb=h;g=v[b>>2];v[h+12>>2]=g;l=a?d:256;d=a?a:h+16|0;e=0;a:{b:{c:{if(!g|!l){break c}f=c>>>0>=l>>>0;if(!(f|c>>>0>32)){break b}while(1){k=f?l:c;c=c-k|0;m=0;n=jb-16|0;jb=n;d:{e:{f:{g:{f=d;if(f){if(k>>>0>=4){break g}g=k;break f}f=0;j=v[h+12>>2];g=v[j>>2];if(!g){break d}while(1){if(g>>>0<=127){f=f+1|0}else{m=-1;k=ck(n+12|0,g,0);if((k|0)==-1){break d}f=f+k|0}g=v[j+4>>2];j=j+4|0;m=f;if(g){continue}break}break d}j=v[h+12>>2];g=k;while(1){i=v[j>>2];h:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}m=-1;i=ck(f,i,0);if((i|0)==-1){break d}g=g-i|0;f=f+i|0;break h}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g>>>0>3){continue}break}}if(g){j=v[h+12>>2];while(1){i=v[j>>2];i:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}m=-1;i=ck(n+12|0,i,0);if((i|0)==-1){break d}if(g>>>0<i>>>0){break e}ck(f,v[j>>2],0);g=g-i|0;f=f+i|0;break i}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g){continue}break}}m=k;break d}m=k-g|0}jb=n+16|0;if((m|0)==-1){l=0;g=v[h+12>>2];e=-1;break c}f=(h+16|0)==(d|0);l=l-(f?0:m)|0;d=f?d:d+m|0;e=e+m|0;g=v[h+12>>2];if(!g|!l){break c}f=c>>>0>=l>>>0;if(f|c>>>0>=33){continue}break}break b}if(!g){break a}}if(!l|!c){break a}f=e;while(1){j:{k=ck(d,v[g>>2],0);k:{if(k+1>>>0<=1){e=-1;if(k){break a}v[h+12>>2]=0;break k}g=v[h+12>>2]+4|0;v[h+12>>2]=g;f=f+k|0;l=l-k|0;if(l){break j}}e=f;break a}d=d+k|0;e=f;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}jb=h+272|0;return e|0}function V_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;Fv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2462,a+360|0,a+352|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+180>>2]=b+c}v[114578]=0;b=T(2464,a+360|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=dr(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2466,a+360|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=C(va(2447,c|0,v[a+180>>2],e|0));b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114578]=0;Ee(a+200|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+360|0,a+352|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;Iv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=b+c}v[114578]=0;b=T(2432,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=fr(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2434,a+264|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=C(va(2447,c|0,v[a+188>>2],e|0));b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;k=v[a+56>>2];v[b+44>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>10&4194048;e=(((e&2147483647)<<1|h>>>31)&-2)+q|0;f=0;l=1;i=1;g=0;while(1){h=t[e+g|0];v[(b+8|0)+(g<<2)>>2]=((B(j,t[e+(g|2)|0]-h|0)|0)/16384|0)+(h<<8);h=i&1;i=0;g=1;if(h){continue}break}while(1){i=(b+8|0)+(f<<2)|0;j=v[i>>2];k=v[a+60>>2];h=(b+32|0)+(f<<3)|0;f=v[h>>2];e=Yb(f,-16777216,16776704);p=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);o=v[a+68>>2];r=o;o=o>>31;v[h+4>>2]=f;s=v[a+72>>2];j=j<<8;f=j;f=Hma(k,k>>31,f,f>>31);k=mb;u=i;i=Hma(p,p>>31,e,e>>31);f=i+f|0;e=mb+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Hma(r,o,g,g>>31);g=i+f|0;e=mb+e|0;e=g>>>0<f>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;v[u>>2]=(e|0)/256;v[h>>2]=e-(j&s);f=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];k=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;jb=b+48|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;Fv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2462,a+360|0,a+352|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+180>>2]=b+c}v[114578]=0;b=T(2464,a+360|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=dr(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2466,a+360|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=+oa(2450,c|0,v[a+180>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114578]=0;Ee(a+200|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+360|0,a+352|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function g$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;Iv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=b+c}v[114578]=0;b=T(2432,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=fr(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2434,a+264|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=+oa(2450,c|0,v[a+188>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function OZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=jb-16|0;jb=x;v[c>>2]=a;z=d&512;while(1){if((y|0)==4){if(Fb(n)>>>0>1){C=x,D=Dd(n),v[C+8>>2]=D;C=c,D=xj(pp(x+8|0,1),Vj(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}jb=x+16|0}else{a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=ir(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 3:if(Wc(n)){break a}q=v[ij(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 2:if(Wc(m)|!z){break a}C=c,D=xj(Dd(m),Vj(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}A=v[c>>2];e=h?e+4|0:e;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!$j(g,2048,v[r>>2])){break c}r=r+4|0;continue}break}s=o;if((s|0)>=1){while(1){if(!((s|0)<1|e>>>0>=r>>>0)){r=r-4|0;q=v[r>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;s=s-1|0;continue}break}if((s|0)<1){u=0}else{u=ir(g,48)}p=v[c>>2];while(1){q=p+4|0;if((s|0)>=1){v[p>>2]=u;s=s-1|0;p=q;continue}break}v[c>>2]=q;v[p>>2]=j}d:{if((e|0)==(r|0)){q=ir(g,48);p=v[c>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=q;break d}if(Wc(l)){q=-1}else{q=t[kc(l,0)|0]}p=0;s=0;while(1){if((e|0)!=(r|0)){u=p+1|0;e:{if((q|0)!=(p|0)){break e}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;s=s+1|0;if(Fb(l)>>>0<=s>>>0){q=p;u=1;break e}if(w[kc(l,s)|0]==127){q=-1;u=1;break e}q=t[kc(l,s)|0];u=1}p=u;r=r-4|0;B=v[r>>2];u=v[c>>2];v[c>>2]=u+4;v[u>>2]=B;continue}break}r=v[c>>2]}qo(A,r)}y=y+1|0;continue}break}}function ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;Ed(b,2);Fk(e+16|0,2,a+1|0);Ic(e+32|0,e+16|0);v[114578]=0;Q(372,b+43|0,e+32|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){yb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;g=b,h=v[Lb(e+32|0,e+16|0)>>2],v[g+4>>2]=h;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);g=b,h=v[Lb(e+32|0,b)>>2],v[g+8>>2]=h;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>y[b+4>>2]?d>>>0>=2:0){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}vh(e+16|0,a+16|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;vh(e+16|0,a+20|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+4|0]=f;t[d+5|0]=f>>>8;t[d+6|0]=f>>>16;t[d+7|0]=f>>>24;vh(e+16|0,a+24|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;op(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[pc(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=c?a&65535:a;v[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}v[b+24>>2]=c}jb=e+48|0;return}a=P()|0;O()|0;yb(e+32|0);S(a|0);L()}function qK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=jb-16|0;jb=h;a:{if((b|0)==(c|0)){break a}v[h+12>>2]=-1953789045;lK(b,c,h+12|0);d=c-b>>2;v[h+8>>2]=d;n=Kb(a);g=n+1|0;v[h+4>>2]=g;k=v[bd(h+4|0,h+8|0)>>2];j=v[((v[h+8>>2]<<2)+b|0)-4>>2];c=d;e=c;f=11;b:{if(c>>>0>622){break b}f=7;if(d>>>0>67){break b}f=5;if(d>>>0>38){break b}f=3;if(d>>>0>6){break b}f=d-1>>>1|0}l=e-f>>>1|0;c=(l<<2)+b|0;e=B(gs(j^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=e+v[c>>2];o=l+f|0;c=(o<<2)+b|0;d=c;f=v[c>>2];c=e+n|0;v[d>>2]=f+c;v[b>>2]=c;if(n){m=v[h+8>>2];c=1;while(1){e=c-1|0;d=((c+l>>>0)%(m>>>0)<<2)+b|0;f=(c>>>0)%(m>>>0)|0;i=(f<<2)+b|0;p=B(gs(v[((e>>>0)%(m>>>0)<<2)+b>>2]^(v[d>>2]^v[i>>2])),1664525);v[d>>2]=p+v[d>>2];d=Pb(a,e);m=v[h+8>>2];e=((c+o>>>0)%(m>>>0)<<2)+b|0;j=e;q=v[e>>2];e=v[d>>2]+(f+p|0)|0;v[j>>2]=q+e;v[i>>2]=e;c=c+1|0;if(n>>>0>=c>>>0){continue}break}}c=v[h+8>>2];if(g>>>0<k>>>0){while(1){a=((g+l>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=B(gs(v[((g-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[e>>2])),1664525);v[a>>2]=i+v[a>>2];c=v[h+8>>2];a=((g+o>>>0)%(c>>>0)<<2)+b|0;f=a;j=v[a>>2];a=d+i|0;v[f>>2]=j+a;v[e>>2]=a;g=g+1|0;if((k|0)!=(g|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}g=k;while(1){a=((g+l>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=B(gs(v[((g-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[e>>2]|0)|0),1566083941);v[a>>2]=i^v[a>>2];c=v[h+8>>2];a=((g+o>>>0)%(c>>>0)<<2)+b|0;f=a;j=v[a>>2];a=i-d|0;v[f>>2]=j^a;v[e>>2]=a;g=g+1|0;if(g>>>0<c+k>>>0){continue}break}}jb=h+16|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=jb-48|0;jb=e;p=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;h=v[a+48>>2];v[e+36>>2]=h;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;q=v[a+24>>2];r=v[a+20>>2];g=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=g;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){l=1;j=((((g&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;b=(i>>>21&2040)+27888|0;i=u[b+6>>1];k=u[b+4>>1];o=u[b+2>>1];m=u[b>>1];f=0;b=1;h=0;while(1){g=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[g+j>>1],o)+B(u[j+(g|-4)>>1],m)|0)+B(u[j+(g|4)>>1],k)|0)+B(i,u[j+(g|8)>>1])|0)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){i=(e+8|0)+(f<<2)|0;j=v[i>>2];k=v[a+60>>2];g=(e+32|0)+(f<<3)|0;f=v[g>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];h=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];s=n;n=n>>31;v[g+4>>2]=f;t=v[a+72>>2];j=j<<8;f=j;f=Hma(k,k>>31,f,f>>31);k=mb;w=i;i=Hma(m,m>>31,b,b>>31);f=i+f|0;b=mb+k|0;b=f>>>0<i>>>0?b+1|0:b;o=f;f=Hma(s,n,h,h>>31);h=o+f|0;b=mb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;v[w>>2]=(b|0)/256;v[g>>2]=b-(j&t);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];g=v[e+28>>2];continue}break}i=v[e+24>>2];g=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];h=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=h;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=g;jb=e+48|0}function Xw(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;a:{b:{c:{if(w[c|0]&2){if(v[b>>2]==-2147483648){e=Hj(d+48|0,1,45);b=v[b>>2];v[114578]=0;v[d+188>>2]=b;U(137,d+192|0,d+188|0,c|0);b=v[114578];v[114578]=0;d:{e:{if((b|0)!=1){v[114578]=0;U(138,a|0,e|0,d+192|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}yb(d+192|0);yb(e);break b}c=P()|0;O()|0;break d}c=P()|0;O()|0;yb(d+192|0)}yb(e);break a}e=v[b>>2];if((e|0)>-1){break c}e=Hj(d+48|0,1,45);b=v[b>>2];v[114578]=0;v[d+188>>2]=0-b;U(137,d+192|0,d+188|0,c|0);b=v[114578];v[114578]=0;f:{g:{if((b|0)!=1){v[114578]=0;U(138,a|0,e|0,d+192|0);a=v[114578];v[114578]=0;if((a|0)==1){break g}yb(d+192|0);yb(e);break b}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(d+192|0)}yb(e);break a}e=dh(d+48|0);f=v[v[e>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}v[114578]=0;U(123,d+40|0,f+(d+48|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break l}Ob(d+40|0);v[114578]=0;R(139,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break l}v[114578]=0;R(124,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;R(125,d+8|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;U(140,d+24|0,d+8|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break k}v[114578]=0;U(141,a|0,d+24|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break j}yb(d+24|0);yb(d+8|0);Yd(e);break b}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;yb(d+24|0)}yb(d+8|0)}Yd(e);break a}v[d+48>>2]=e;Vr(a,d+48|0,c)}jb=d+208|0;return}S(c|0);L()}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-48|0;jb=c;d=x[a+480190>>1];t[c+32|0]=0;cN(b,d+1|0,c+32|0);if(x[a+480192>>1]){g=rq(c+32|0);d=a+484344|0;k=c,l=bc(d),v[k+24>>2]=l;k=c,l=cc(d),v[k+16>>2]=l;if(Jb(c+24|0,c+16|0)){while(1){a:{i=v[c+24>>2];if(!mh(i)){break a}d=x[a+480188>>1];v[114578]=0;t[c|0]=0;U(1426,g|0,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){b:{k=c,l=bc(i),v[k+8>>2]=l;j=0;if(!v[i+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{d=v[c+8>>2];v[114578]=0;d=T(553,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}e:{if(!d){break e}d=w[v[c+8>>2]+1|0];if(!w[v[c+8>>2]+1|0]){d=w[wc(g,f)|0]}e=d&255;if(e){f:{if(e>>>0>256){break f}e=v[((w[v[c+8>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[dd(e+236|0,w[v[c+8>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}ee(c,b,e);ge(c,1)}k=wc(g,f),l=d,t[k|0]=l;break e}d=x[a+480192>>1];if(!d){break e}e=d;while(1){h=v[((d<<2)+a|0)+900380>>2];g:{if(!h){break g}h=x[dd(h+236|0,w[v[c+8>>2]]-1|0)>>1];if(h>>>0>x[a+480190>>1]){break g}ee(c,b,h);ge(c,1)}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}Dj(c+8|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;fe(g);S(a|0);L()}ty(c+24|0);if(Jb(c+24|0,c+16|0)){continue}break}}d=x[a+480190>>1];h:{if(!d){f=0;break h}f=0;e=d;while(1){ee(c,b,d);if(!Cb(c)){f=De((B(d,104)+a|0)+484380|0)+f|0}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}fe(g)}jb=c+48|0;return f&65535}function k8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=jb-16|0;jb=i;e=b+1304396|0;if(!sd(e)){c=i+8|0;d=Pe(12);v[114578]=0;g=T(1753,d|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){d=jb-16|0;jb=d;v[114578]=0;v[d+12>>2]=g;W(1759,c|0,d+12|0,d+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;Xb(d);S(a|0);L()}GL(e,Nd(i+8|0));qs(i+8|0)}d=v[e>>2];g=0;c=jb-80|0;jb=c;e=Ub(c+48|0,BL(a));v[114578]=0;R(1605,c- -64|0,e|0);f=v[114578];v[114578]=0;b:{c:{d:{e:{if((f|0)!=1){yb(e);j=c,k=bc(d),v[j+40>>2]=k;j=c,k=cc(d),v[j+32>>2]=k;if(Jb(c+40|0,c+32|0)){e=0;while(1){d=0;f=v[c+40>>2];if(v[v[f>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){d=v[v[f>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}h=v[f>>2];v[114578]=0;R(1754,c|0,h+8|0);h=v[114578];v[114578]=0;f:{g:{h:{i:{if((h|0)!=1){v[114578]=0;R(1605,c+16|0,c|0);h=v[114578];v[114578]=0;if((h|0)==1){break i}h=uf(c+16|0,c- -64|0);yb(c+16|0);yb(c);if(!d|!h){break g}g=v[f>>2];e=3;break f}d=P()|0;O()|0;break h}d=P()|0;O()|0;yb(c)}e=c- -64|0;break c}if((e|0)<2&d){g=v[f>>2];e=2;break f}d=h&(e|0)<1;g=d?v[f>>2]:g;e=d?1:e}_d(c+40|0);if(Jb(c+40|0,c+32|0)){continue}break}break e}d=0;break d}d=P()|0;O()|0;break c}d=0;if(!g){break d}e=v[g+4>>2];if(!e){break d}v[114578]=0;a=W(e|0,g|0,b|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){d=(a|0)!=0;break d}d=P()|0;e=c- -64|0;O()|0;break c}yb(c- -64|0);jb=c+80|0;break b}yb(e);S(d|0);L()}jb=i+16|0;return d|0}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;u[c+62>>1]=b;f=sj(a);b=f;e=c+48|0;g=gu(e);a:{if(!b){break a}v[114578]=0;R(921,e|0,b|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;R(1174,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bq(g);S(a|0);L()}b:{c:{if(!f){break c}b=0;while(1){i=rc(e,b),j=b-d|0,u[i>>1]=j;v[114578]=0;g=Q(1171,a|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break c}b=bc(a);d=cc(a);v[114578]=0;b=W(1172,b|0,d|0,c+62|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[c+32>>2]=b;b=Md(c+40|0,c+32|0);i=c,j=cc(a),v[i+16>>2]=j;d=v[Md(c+24|0,c+16|0)>>2];b=v[b>>2];v[114578]=0;W(1173,a|0,b|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}i=c,j=bc(a),v[i+32>>2]=j;i=c,j=cc(a),v[i+16>>2]=j;if(Jb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[114578]=0;d=Q(444,d+484344|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}d:{if(!d){break d}b=_b(v[a+24>>2]+484344|0,b);i=c,j=bc(b),v[i+8>>2]=j;i=c,j=cc(b),v[i>>2]=j;if(!Jb(c+8|0,c)){break d}while(1){b=v[c+8>>2];e:{if(w[b+3|0]!=12){break e}d=w[b+5|0];if(oc(e)>>>0<=d>>>0){break e}i=b,j=w[rc(e,w[b+5|0])|0],t[i+5|0]=j}Dj(c+8|0);if(Jb(c+8|0,c)){continue}break}}te(c+32|0);if(Jb(c+32|0,c+16|0)){continue}break}}b=x[a+28>>1];if(oc(e)>>>0<=b>>>0){break c}i=a,j=x[rc(e,x[a+28>>1])>>1],u[i+28>>1]=j}kf(e);jb=c- -64|0;return}a=P()|0;O()|0;kf(e);S(a|0);L()}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2462,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2464,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2466,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=io(2441,c,v[a+188>>2],e,b);c=mb;h=v[114578];v[114578]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2462,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2464,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2466,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=io(2445,c,v[a+188>>2],e,b);c=mb;h=v[114578];v[114578]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function SZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=jb-16|0;jb=x;v[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(Fb(n)>>>0>1){C=x,D=Dd(n),v[C+8>>2]=D;C=c,D=xj(cf(x+8|0,1),sf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}jb=x+16|0;return}a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Lk(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(Wc(n)){break a}q=w[kc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(Wc(m)|!A){break a}C=c,D=xj(Dd(m),sf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=h?e+1|0:e;s=e;while(1){c:{if(f>>>0<=s>>>0){break c}if(!Kg(g,2048,t[s|0])){break c}s=s+1|0;continue}break}q=o;if((q|0)>=1){while(1){if(!((q|0)<1|e>>>0>=s>>>0)){s=s-1|0;p=w[s|0];r=v[c>>2];v[c>>2]=r+1;t[r|0]=p;q=q-1|0;continue}break}if((q|0)<1){p=0}else{p=Lk(g,48)}while(1){r=v[c>>2];v[c>>2]=r+1;if((q|0)>=1){t[r|0]=p;q=q-1|0;continue}break}t[r|0]=j}d:{if((e|0)==(s|0)){q=Lk(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break d}if(Wc(l)){p=-1}else{p=t[kc(l,0)|0]}q=0;u=0;while(1){if((e|0)==(s|0)){break d}r=q+1|0;e:{if((q|0)!=(p|0)){break e}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;u=u+1|0;if(Fb(l)>>>0<=u>>>0){p=q;r=1;break e}if(w[kc(l,u)|0]==127){p=-1;r=1;break e}p=t[kc(l,u)|0];r=1}q=r;s=s-1|0;r=w[s|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=r;continue}}Wj(B,v[c>>2])}y=y+1|0;continue}}function qj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-32|0;jb=f;m=hp(a);j=sj(m);c=j;d=a;e=yc(d);a:{if(c>>>0>e>>>0){k=jb-32|0;jb=k;b:{h=c-e|0;c:{if(h>>>0<=(v[zb(d)>>2]-v[d+4>>2]|0)/12>>>0){g=jb-16|0;jb=g;d:{c=al(g,d,h);if(v[c+4>>2]!=v[c+8>>2]){while(1){e=zb(d);h=v[c+4>>2];v[114578]=0;R(1238,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}e=v[c+4>>2]+12|0;v[c+4>>2]=e;if((e|0)!=v[c+8>>2]){continue}break}}Mb(c);jb=g+16|0;break c}a=P()|0;O()|0;Mb(c);S(a|0);L()}i=zb(d);c=um(d,yc(d)+h|0);n=yc(d);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,i);if(c){g=c;if(c>>>0>357913941){Fc(20181);L()}g=sc(B(g,12),4)}v[e>>2]=g;i=B(n,12)+g|0;v[e+8>>2]=i;v[e+4>>2]=i;o=ec(e),p=B(c,12)+g|0,v[o>>2]=p;jb=l+16|0;v[114578]=0;R(1235,e|0,h|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1236,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}VM(e)}jb=k+32|0;break a}a=P()|0;O()|0;VM(e);S(a|0);L()}if(c>>>0<e>>>0){c=v[d>>2]+B(c,12)|0;yc(d);WM(d,c);ct(d)}}e:{if(!b){break e}d=a+12|0;Ks(d);if(yd(d)>>>0>1023){break e}v[f+28>>2]=0;c=v[a+24>>2]+484344|0;o=f,p=bc(c),v[o+24>>2]=p;o=f,p=cc(c),v[o+16>>2]=p;if(Jb(f+24|0,f+16|0)){while(1){v[f+12>>2]=v[v[f+24>>2]+12>>2];o=f,p=v[bd(f+28|0,f+12|0)>>2],v[o+28>>2]=p;ty(f+24|0);if(Jb(f+24|0,f+16|0)){continue}break}c=v[f+28>>2]}else{c=0}dN(d,c)}if(j){d=0;while(1){c=qd(a,d);g=sy(a,x[rc(m,d)>>1]);f:{if(b){t[f+28|0]=0;cN(c,g,f+28|0);break f}fz(c,g,0)}d=d+1|0;if((j|0)!=(d|0)){continue}break}}jb=f+32|0}function uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-48|0;jb=f;m=v[a+16>>2];h=Qf(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];s=h,t=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+12>>2]=t;b=v[h+16>>2];if(b){s=h,t=Pf(a+8|0,b),v[s>>2]=t;v[h+4>>2]=mb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];g=v[a>>2];v[f+8>>2]=g;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(!d){b=k;k=i;break a}while(1){b=0;j=b;v[f+40>>2]=g;v[f+44>>2]=b;e=(e<<1)+m|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],u[(j<<1)+e>>1]/4<<16>>16);zd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){Ad(b,u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Yb(k,-16777216,16776704);l=v[a+64>>2];i=Yb(i,-16777216,16776704);p=v[a+72>>2];q=v[c>>2];r=g>>31;g=e<<8;e=g;e=Hma(j,r,e,e>>31);j=mb;l=Hma(l,l>>31,b,b>>31);e=l+e|0;b=mb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Hma(e,e>>31,i,i>>31);i=j+e|0;b=mb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;i=(b|0)/256|0;v[c>>2]=B(i,o)+q;v[c+4>>2]=v[c+4>>2]+B(i,n);b=b-(g&p)|0;Sb(f+8|0,f);if(d){c=c+8|0;g=v[f+8>>2];e=v[f+12>>2];i=k;k=b;continue}break}g=v[f+8>>2];e=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=g;v[a+4>>2]=e;jb=f+48|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=jb-48|0;jb=e;p=v[a+16>>2];g=v[a+44>>2];v[e+32>>2]=g;b=v[a+48>>2];v[e+36>>2]=b;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){j=(((i&2147483647)<<1|h>>>31)&-2)+p|0;b=(h>>>21&2040)+27888|0;h=u[b+6>>1];k=u[b+4>>1];o=u[b+2>>1];m=u[b>>1];f=0;l=1;b=1;g=0;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+j|0],o)+B(t[j+(g|-2)|0],m)|0)+B(t[j+(g|2)|0],k)|0)+B(h,t[j+(g|4)|0])<<8)/16384;i=b;b=0;g=1;if(i){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=v[h>>2];k=v[a+60>>2];i=(e+32|0)+(f<<3)|0;f=v[i>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);n=v[a+68>>2];s=n;n=n>>31;v[i+4>>2]=f;w=v[a+72>>2];j=j<<8;f=j;f=Hma(k,k>>31,f,f>>31);k=mb;x=h;h=Hma(m,m>>31,b,b>>31);f=h+f|0;b=mb+k|0;b=f>>>0<h>>>0?b+1|0:b;o=f;f=Hma(s,n,g,g>>31);g=o+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[x>>2]=(b|0)/256;v[i>>2]=b-(j&w);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];i=v[e+28>>2];continue}break}h=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=h;v[a+4>>2]=i;jb=e+48|0}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2462,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2464,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2466,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2442,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2462,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2464,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2466,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2443,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2462,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2464,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2466,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2444,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2462,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2464,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2466,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2437,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2463,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);Am(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2432,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2434,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=io(2441,c,v[a+188>>2],e,b);c=mb;g=v[114578];v[114578]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function l$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);Am(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2432,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2434,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=io(2445,c,v[a+188>>2],e,b);c=mb;g=v[114578];v[114578]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Tx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=89;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;x=7;a=Xx(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!((b|0)!=32?c:1)){break c}Nb(a,0,1);Nb(a,7,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,11,1);Nb(a,12,1);Nb(a,13,1);Nb(a,14,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,19,1);Nb(a,20,1);Nb(a,21,1);Nb(a,22,1);Nb(a,23,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,27,1);Nb(a,28,1);Nb(a,29,1);Nb(a,30,1);Nb(a,31,1);Nb(a,32,1);Nb(a,33,1);Nb(a,34,1);Nb(a,35,1);Nb(a,36,1);Nb(a,37,1);Nb(a,38,1);Nb(a,39,1);Nb(a,40,1);Nb(a,41,1);Nb(a,42,1);Nb(a,43,1);Nb(a,44,1);Nb(a,45,1);Nb(a,46,1);Nb(a,47,1);Nb(a,48,1);Nb(a,103,1);Nb(a,50,1);Nb(a,87,1);Nb(a,88,1);Nb(a,100,1);Nb(a,102,1);Nb(a,104,1);if(!c){break a}d=105;e=99;break b;case 3:Nb(a,0,1);Nb(a,4,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,17,1);Nb(a,40,1);Nb(a,51,1);Nb(a,52,1);Nb(a,53,1);Nb(a,54,1);Nb(a,55,1);Nb(a,56,1);Nb(a,57,1);Nb(a,58,1);Nb(a,59,1);Nb(a,60,1);Nb(a,61,1);Nb(a,62,1);Nb(a,63,1);Nb(a,64,1);Nb(a,65,1);Nb(a,66,1);Nb(a,67,1);Nb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;f=69;case 1:Nb(a,f,1);Nb(a,e,1);Nb(a,d,1);Nb(a,w,1);Nb(a,v,1);Nb(a,u,1);m=t;l=s;k=r;j=q;i=c;h=p;c=o;g=n;break;case 2:break c;case 0:break d}}Nb(a,m,1);Nb(a,l,1);Nb(a,k,1);Nb(a,j,1);f=i;x=h;e=c;d=g}Nb(a,f,1);Nb(a,x,1)}Nb(a,e,1);Nb(a,d,1)}}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);Am(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2432,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2434,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2437,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);Am(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2432,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2434,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2442,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);Am(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2432,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2434,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2443,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function m$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);Am(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2432,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2434,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2444,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function _K(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb-16|0;jb=c;d=B(b,896)+a|0;a:{if(v[d+1075072>>2]&134218752){break a}if(!oj(d+1074984|0)){break a}h=v[(B(b,896)+a|0)+1075640>>2];if(w[h+15|0]&2){break a}d=wl(a,b,2,1);if(d-251>>>0<5|!d){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,896)+a|0;d=w[e+1075794|0];b:{if(w[e+1075796|0]==1){t[c+8|0]=64;f=w[pc(e+1075798|0,c+8|0)|0];break b}f=255;if(w[e+1075797|0]!=13){break b}t[c+8|0]=64;f=w[pc((B(b,896)+a|0)+1075799|0,c+8|0)|0]}j=a+1074312|0;Eb(c+8|0,j,2);if(Cb(c+8|0)){if(d){e=a;f=b;if(be(d)){d=w[fc(h+108|0,d-1|0)|0]}xl(e,f,d,x[(B(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}nb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=k<<2;v[c+4>>2]=e;if(!w[h+35|0]){e=v[(B(b,896)+a|0)+1075672>>2];v[c+4>>2]=e}i=u[(B(b,896)+a|0)+1075772>>1];Eb(c+8|0,j,28);l=c,m=(Cb(c+8|0)?i<<2:i)+e|0,v[l+4>>2]=m;ce(c+4|0,0,256);e=d;i=b;if(be(d)){e=w[fc(h+108|0,d-1|0)|0]}xl(a,i,e&255,x[c+4>>1])}e=w[h+35|0];Eb(c+8|0,j,101);i=(f|0)!=255;if(Cb(c+8|0)){a=(d|0)!=0}else{a=be(d)}if(!(!a|(e|0)!=1?a?0:i:1)){break a}c:{switch(w[h+36|0]){case 1:if((f|0)!=255){nJ(g,f<<1);break a}nJ(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;m=g,n=7,o=w[pc(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],nb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;p=g,o=7,n=w[Lb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],nb[l](p|0,o|0,n|0,m|0)}jb=c+16|0}function vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=jb-48|0;jb=f;m=v[a+16>>2];h=Qf(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];s=h,u=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+12>>2]=u;b=v[h+16>>2];if(b){s=h,u=Pf(a+8|0,b),v[s>>2]=u;v[h+4>>2]=mb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];g=v[a>>2];v[f+8>>2]=g;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(!d){b=k;k=i;break a}while(1){b=0;j=b;v[f+40>>2]=g;v[f+44>>2]=b;e=e+m|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],t[e+j|0]<<6);zd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){Ad(b,t[e+v[f+44>>2]|0]<<6);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Yb(k,-16777216,16776704);l=v[a+64>>2];i=Yb(i,-16777216,16776704);p=v[a+72>>2];q=v[c>>2];r=g>>31;g=e<<8;e=g;e=Hma(j,r,e,e>>31);j=mb;l=Hma(l,l>>31,b,b>>31);e=l+e|0;b=mb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Hma(e,e>>31,i,i>>31);i=j+e|0;b=mb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;i=(b|0)/256|0;v[c>>2]=B(i,o)+q;v[c+4>>2]=v[c+4>>2]+B(i,n);b=b-(g&p)|0;Sb(f+8|0,f);if(d){c=c+8|0;g=v[f+8>>2];e=v[f+12>>2];i=k;k=b;continue}break}g=v[f+8>>2];e=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=g;v[a+4>>2]=e;jb=f+48|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=(e<<1)+q|0;j=u[g-6>>1];e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+24>>1];o=u[g-4>>1];r=u[e+26>>1];s=u[g-2>>1];t=u[e+28>>1];w=u[g>>1];x=u[e+30>>1];y=u[g+2>>1];z=u[e+32>>1];A=u[g+4>>1];C=u[e+34>>1];D=u[g+6>>1];E=u[e+36>>1];F=u[g+8>>1];G=u[e+38>>1];g=v[a+60>>2];H=g;I=g>>31;e=Yb(n,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[a+32>>2];g=c;L=v[g>>2];e=Hma(k,k>>31,e,e>>31);k=mb;M=e;e=v[a+68>>2];p=Hma(e,e>>31,f,f>>31);e=M+p|0;f=mb+k|0;f=e>>>0<p>>>0?f+1|0:f;k=e;i=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(F,G)|0)/2|0)+((((B(o,r)+B(i,j)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=i;j=Hma(H,I,e,e>>31);e=k+j|0;f=mb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(f,j)+L;l=l+K|0;o=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,o);g=e-(i&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=n;n=g;continue}break}i=v[h+8>>2];e=v[h+12>>2];f=n;break a}o=l>>12;j=m>>12;g=n}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=g;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function aJ(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=jb-16|0;jb=e;c=Se(v[a+16>>2]);o=a,r=ne(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[o+4232>>2]=r;f=C(C(c>>>0)*C(.0010000000474974513));o=a,r=ne(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*f))),z[o+4236>>2]=r;o=a,r=ne(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*f))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(ne(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!((c|0)>-1?c>>>0>=8388608:0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(d*C(96817624))+C(67108864);o=a,r=C(z[nl(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(C(z[a+4228>>2]*C(4))*f)+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;jb=e+16|0}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=e+q|0;j=t[g-3|0];e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+24>>1];o=t[g-2|0];r=u[e+26>>1];s=t[g-1|0];w=u[e+28>>1];x=t[g|0];y=u[e+30>>1];z=t[g+1|0];A=u[e+32>>1];C=t[g+2|0];D=u[e+34>>1];E=t[g+3|0];F=u[e+36>>1];G=t[g+4|0];H=u[e+38>>1];g=v[a+60>>2];I=g;J=g>>31;e=Yb(n,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);K=v[a+72>>2];L=v[a+32>>2];g=c;M=v[g>>2];e=Hma(k,k>>31,e,e>>31);k=mb;N=e;e=v[a+68>>2];p=Hma(e,e>>31,f,f>>31);e=N+p|0;f=mb+k|0;f=e>>>0<p>>>0?f+1|0:f;k=e;i=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(G,H)<<8)/2|0)+((((B(o,r)+B(i,j)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=i;j=Hma(I,J,e,e>>31);e=k+j|0;f=mb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(f,j)+M;l=l+L|0;o=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,o);g=e-(i&K)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=n;n=g;continue}break}i=v[h+8>>2];e=v[h+12>>2];f=n;break a}o=l>>12;j=m>>12;g=n}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=g;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function Sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;s=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+s|0;h=u[e>>1];v[b+8>>2]=h;v[b+12>>2]=u[e+2>>1];f=0;l=1;while(1){g=v[a+60>>2];k=g;i=(b+32|0)+(f<<3)|0;o=v[i>>2];e=Yb(o,-16777216,16776704);r=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];t=p;p=p>>31;v[i+4>>2]=o;o=v[a+72>>2];q=g>>31;h=h<<8;g=h;g=Hma(k,q,g,g>>31);k=mb;q=(b+8|0)+(f<<2)|0;f=g;g=Hma(r,r>>31,e,e>>31);f=f+g|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;j=Hma(t,p,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[q>>2]=(e|0)/256;v[i>>2]=e-(h&o);if(l){f=1;l=0;h=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=k;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function kV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-48|0;jb=f;Jc(b);Fq(a);a:{if(!Ef(b,f+40|0)){break a}if(!vC(f+40|0)){break a}if(!c){i=1;break a}if(!Qb(b,4)){break a}bv(a);av(f+24|0);$u(Tg(a)+28|0,f+24|0);Eq(f+24|0);j=v[Tg(a)+28>>2];c=Lj(b);if(c&1){break a}d=c-4|0;Qc(b,d);c=Gd(b);c=Gd(b)<<8|c<<16|Gd(b);if(!c){break a}v[114578]=0;R(331,j|0,c|0);g=v[114578];v[114578]=0;i=1;if((g|0)==1){a=V(71204)|0;if((O()|0)==(ga(71204)|0)){_(a|0)|0;$();i=0;break a}S(a|0);L()}Qc(b,4);g=uC(b);k=Db(v[j>>2]);e=jb-32|0;jb=e;t[e+24|0]=w[g|0];t[e+25|0]=w[g+1|0];t[e+26|0]=w[g+2|0];t[e+27|0]=w[g+3|0];b=tC(e+8|0);d=d+g|0;v[b+12>>2]=d-4;v[b+8>>2]=g;Ui(b,w[d-1|0]);g=c;b:{if(!c){break b}while(1){if(!Ui(b,1)){v[e+4>>2]=1;while(1){d=Ui(b,2);v[e+4>>2]=d+v[e+4>>2];if((d|0)==3){continue}break}Cc(e+4|0,c);c:{if(!v[e+4>>2]){break c}d=1;while(1){c=c-1|0;o=k+c|0,p=Ui(b,8),t[o|0]=p;if(y[e+4>>2]<=d>>>0){break c}d=d+1|0;continue}}if(!c){break b}}d=Ui(b,2);v[e+4>>2]=d+2;d:{if((d|0)==3){d=b;if(Ui(b,1)){h=w[fc(e+24|0,3)|0]}else{h=7}l=Ui(d,h);while(1){d=Ui(b,3);v[e+4>>2]=d+v[e+4>>2];if((d|0)==7){continue}break}break d}l=Ui(b,w[fc(e+24|0,d)|0])}Cc(e+4|0,c);h=0;m=v[e+4>>2];if(m){while(1){d=0;n=c+l|0;if(g>>>0>n>>>0){d=w[k+n|0]}c=c-1|0;t[k+c|0]=d;h=h+1|0;if((m|0)!=(h|0)){continue}break}}if(c){continue}break}}jb=e+32|0;Wi(f+8|0,j);Xu(f+16|0,f+8|0);b=fo(f+24|0,f+16|0,0);Wd(Tg(a)+12|0,b);Bb(b)}jb=f+48|0;return i|0}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=fc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=dd(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=dd(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}sz(a+484|0,b+48|0,0);sz(a+590|0,b+68|0,0);sz(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[pc(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[lf(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[lf(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;uu(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;tu(b,w[a|0]&127,w[a|0]>>>7|0);jb=e+16|0}function YG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;a:{b:{c:{i=(b|0)>=0;f=a+8|0;d:{if(ml(f)){f=ml(f);break d}f=Or(f)}if(!((f|0)>(b|0)?i:0)){b=ba(8)|0;v[114578]=0;c=Q(85,g|0,40673)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}if(c>>>0>=120){b=ba(8)|0;v[114578]=0;c=Q(85,g|0,40692)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0);break b}h=a+32|0;a=fy(v[h>>2],65535);a=(a|0)==65535?255:a;u[g>>1]=a;a=v[h>>2]+B(a,896)|0;f=a+1074984|0;qn(f,v[h>>2],65535);c=c+1|0;t[a+1075808|0]=c;t[a+1075805|0]=c;u[a+1075792>>1]=0;yl(f);dp(v[h>>2],f,b+1|0,0,1,1);v[a+1075680>>2]=65536;As(v[h>>2],f,c,0,1,1,65535);l=a+1075676|0,m=nn(ky(e*128,-128,128)+128),v[l>>2]=m;l=a+1075672|0,m=nn(ky(d*256,0,256)),v[l>>2]=m;a=v[h>>2]+1074466|0;i=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;j=f;k=g;c=g;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((j|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[k>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=py(i,b);u[v[h>>2]+480212>>1]=a;jb=g+16|0;return x[g>>1]}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;e=lN(d+32|0,1<<v[b+12>>2]);if(Dg(a)){while(1){g=A[Tk(a,c)>>3];kN(tc(e,c),g);c=c+1|0;if(Dg(a)>>>0>c>>>0){continue}break}}v[114578]=0;R(1216,b|0,e|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}h=d,i=bc(e),v[h>>2]=i;h=d,i=cc(e),v[h+24>>2]=i;b:{if(Jb(d,d+24|0)){while(1){c=v[d>>2];v[114578]=0;g=+la(1217,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}kN(c,vo(g));Uf(d);if(Jb(d,d+24|0)){continue}break}}v[114578]=0;R(1218,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;Z(1219,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}if(nd(e)>>>0>3){c=1;while(1){wy(tc(e,c),2);wy(tc(e,(nd(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<nd(e)>>>1>>>0){continue}break}}v[114578]=0;R(1216,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}h=d,i=bc(e),v[h+24>>2]=i;h=d,i=cc(e),v[h+16>>2]=i;if(Jb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[114578]=0;R(1220,d|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}f=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=f;f=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=f;Uf(d+24|0);if(Jb(d+24|0,d+16|0)){continue}break}}v[114578]=0;R(1218,b|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;Z(1219,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}if(Dg(a)){c=0;while(1){g=A[tc(e,c)>>3];h=Tk(a,c),j=g,A[h>>3]=j;c=c+1|0;if(Dg(a)>>>0>c>>>0){continue}break}}ip(e);jb=d+48|0;return}}a=P()|0;O()|0;ip(e);S(a|0);L()}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;b=jb-48|0;jb=b;s=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+s|0;h=t[e|0]<<8;v[b+8>>2]=h;v[b+12>>2]=t[e+1|0]<<8;f=0;l=1;while(1){g=v[a+60>>2];k=g;i=(b+32|0)+(f<<3)|0;o=v[i>>2];e=Yb(o,-16777216,16776704);r=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];u=p;p=p>>31;v[i+4>>2]=o;o=v[a+72>>2];q=g>>31;h=h<<8;g=h;g=Hma(k,q,g,g>>31);k=mb;q=(b+8|0)+(f<<2)|0;f=g;g=Hma(r,r>>31,e,e>>31);f=f+g|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;j=Hma(u,p,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[q>>2]=(e|0)/256;v[i>>2]=e-(h&o);if(l){f=1;l=0;h=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=k;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function nY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){b=2;i=w[c|0];if(i>>>0>1114111){break b}m=a;d:{if(i<<24>>24>=0){u[f>>1]=i;b=c+1|0;break d}if(i>>>0<194){break b}if(i>>>0<=223){if((d-c|0)<2){break c}j=w[c+1|0];if((j&192)!=128){break a}i=j&63|i<<6&1984;if(i>>>0>1114111){break a}u[f>>1]=i;b=c+2|0;break d}if(i>>>0<=239){if((d-c|0)<3){break c}k=w[c+2|0];j=w[c+1|0];e:{f:{if((i|0)!=237){if((i|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}i=k&63|((j&63)<<6|i<<12);if((i&65535)>>>0>1114111){break a}u[f>>1]=i;b=c+3|0;break d}if(i>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];j=w[c+2|0];c=w[c+1|0];g:{h:{switch(i-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((j&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;k=k&63;l=j<<6;i=i&7;if((k|(l&4032|(c<<12&258048|i<<18)))>>>0>1114111){break a}b=c<<2;u[f>>1]=(j>>>4&3|(b&192|i<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=k|l&960|56320;b=v[a+12>>2]+4|0}v[m+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function Y0(a){a=a|0;var b=0,c=0,d=0,e=0;c=v[13925];b=jb-16|0;jb=b;d=or(461076);v[115279]=461132;v[115277]=c;v[115269]=55716;t[461128]=0;v[115281]=-1;rr(b+8|0,d);e=v[v[115269]+8>>2];v[114578]=0;R(e|0,461076,b+8|0);e=v[114578];v[114578]=0;a:{if((e|0)!=1){Ob(b+8|0);jb=b+16|0;break a}a=P()|0;O()|0;Ob(b+8|0);il(d);S(a|0);L()}b=Sr(460400);v[115098]=58756;v[b>>2]=58776;v[115099]=0;v[114578]=0;R(2314,v[14686]+460392|0,461076);d=v[114578];v[114578]=0;b:{if((d|0)==1){break b}b=jb-16|0;jb=b;d=NF(461140);v[115295]=461196;v[115293]=c;v[115285]=55856;t[461192]=0;v[115297]=-1;rr(b+8|0,d);c=v[v[115285]+8>>2];v[114578]=0;R(c|0,461140,b+8|0);c=v[114578];v[114578]=0;c:{if((c|0)!=1){Ob(b+8|0);jb=b+16|0;break c}a=P()|0;O()|0;Ob(b+8|0);uo(d);S(a|0);L()}b=bG(460488);v[115120]=58804;v[b>>2]=58824;v[115121]=0;v[114578]=0;R(2315,v[14698]+460480|0,461140);c=v[114578];v[114578]=0;if((c|0)==1){break b}b=v[13926];fG(461204,b,461252);fw(460568,461204);eG(461260,b,461308);ew(460652,461260);b=v[13922];fG(461316,b,461364);fw(460736,461316);fw(460904,v[(v[v[115184]-12>>2]+460736|0)+24>>2]);eG(461372,b,461420);ew(460820,461372);ew(460988,v[(v[v[115205]-12>>2]+460820|0)+24>>2]);sr(v[v[115098]-12>>2]+460392|0,460568);sr(v[v[115120]-12>>2]+460480|0,460652);dG(v[v[115184]-12>>2]+460736|0);dG(v[v[115205]-12>>2]+460820|0);sr(v[v[115184]-12>>2]+460736|0,460568);sr(v[v[115205]-12>>2]+460820|0,460652);return a|0}a=P()|0;O()|0;ah(b);S(a|0);L()}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-16|0;jb=f;a:{if(vt(a)){break a}k=d+484344|0;i=Fd(Gd(a)+1|0,1,1024);if(!rg(k,b,i)){break a}d=x[d+480188>>1];if(!d|!i){break a}l=d-1|0;while(1){if(!Qb(a,1)){break a}h=Gd(a);b:{if(!h){j=j+1|0;break b}d=_b(k,b);u[f+14>>1]=h&31;u[f+12>>1]=l;d=Xe(d,j,x[lf(f+14|0,f+12|0)>>1]);if(!(h&224)){break b}c:{if(!(h&128)){break c}n=d,o=Gd(a),t[n+5|0]=o;d:{e=Gd(a);if(e>>>0>=26){break d}e=w[e+31824|0];t[d+3|0]=e;e:{switch(e-1|0){case 0:if(!w[d+5|0]){break d}break c;case 12:if(w[d+2|0]){break c}t[d+2|0]=1;e=Fd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break c;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break c}t[d+5|0]=e;break c;case 8:e=w[d+5|0];if(e>>>0<=128){n=d,o=Aj(e<<1),t[n+5|0]=o;break c}if((e|0)!=164){break c}t[d+5|0]=145;t[d+3|0]=20;break c;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break c;case 18:vx(d);break c;case 16:if(w[d+5|0]>31){break c}t[d+3|0]=16;break c;case 27:break e;default:break c}}m=d;e=w[d+5|0];g=e&240;f:{if((g|0)==16){g=2}else{if((g|0)!=32){break f}g=3}t[m+3|0]=g}t[d+5|0]=e&15|224;break c}t[d+3|0]=0}g:{if(!(h&64)){break g}dq(f+8|0,a);e=cd(f+8|0);t[d+1|0]=w[f+8|0];e=w[e|0];t[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break g}}t[d|0]=g}if(!(h&32)){break b}t[d+2|0]=1;e=Gd(a);t[d+4|0]=e;if(!c){break b}t[d+4|0]=(e<<6>>>0)/127}if(j>>>0<i>>>0){continue}break}}jb=f+16|0}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-176|0;jb=b;d=Ub(b+8|0,38719);v[114578]=0;Q(85,b+20|0,38724)|0;e=v[114578];v[114578]=0;c=1;a:{b:{if((e|0)==1){break b}v[114578]=0;Q(85,b+32|0,38734)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=2;break b}v[114578]=0;Q(85,b+44|0,38747)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=3;break b}v[114578]=0;Q(85,b+56|0,38765)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=4;break b}v[114578]=0;Q(85,b+68|0,38775)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=5;break b}v[114578]=0;Q(85,b+80|0,38790)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=6;break b}v[114578]=0;Q(85,b+92|0,38798)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=7;break b}v[114578]=0;Q(85,b+104|0,38805)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=8;break b}v[114578]=0;Q(85,b+116|0,38811)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=9;break b}v[114578]=0;Q(85,b+128|0,38816)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=10;break b}v[114578]=0;Q(85,b+140|0,38824)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=11;break b}v[114578]=0;Q(85,b+152|0,38836)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=12;break b}v[114578]=0;v[b+172>>2]=13;v[b+168>>2]=d;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2180,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){c=b+164|0;while(1){c=yb(c-12|0);if((d|0)!=(c|0)){continue}break}jb=b+176|0;return}c=b+164|0;break a}c=(b+8|0)+B(c,12)|0}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((d|0)!=(c|0)){continue}break}S(a|0);L()}function MG(a){var b=0,c=0,d=0,e=0;Xd(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){Xd(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}Xd(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){Xd(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){Xd(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}Xd(d,b)}Xd(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;Xd(a,v[b+8>>2]);Xd(a,v[b+28>>2]);Xd(a,v[b+32>>2]);Xd(a,v[b+2084>>2]);b=v[b+2088>>2];Xd(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}Xd(d,b)}Xd(a,v[a+260>>2]);Xd(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){Xd(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){Xd(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}Xd(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;Xd(a,v[d+800>>2]);Xd(a,v[d+928>>2]);Xd(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Xd(a,v[b+1068>>2]);Xd(a,v[b+1076>>2]);Xd(a,v[b+1084>>2]);Xd(a,v[b+1092>>2]);Xd(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=jb-48|0;jb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;h=v[a+48>>2];v[e+36>>2]=h;l=v[a+52>>2];v[e+40>>2]=l;i=v[a+56>>2];v[e+44>>2]=i;p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;r=a;if(d){while(1){j=g>>>18|0;l=1;i=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;f=0;b=1;h=0;while(1){k=h<<1;g=u[k+i>>1];v[(e+8|0)+(h<<2)>>2]=g+((B(j,u[i+(k|4)>>1]-g|0)|0)/16384|0);g=b;b=0;h=1;if(g){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=v[h>>2];k=v[a+60>>2];g=(e+32|0)+(f<<3)|0;f=v[g>>2];b=Yb(f,-16777216,16776704);n=v[a+64>>2];i=Yb(v[g+4>>2],-16777216,16776704);m=v[a+68>>2];s=m;m=m>>31;v[g+4>>2]=f;t=v[a+72>>2];j=j<<8;f=j;f=Hma(k,k>>31,f,f>>31);k=mb;w=h;h=Hma(n,n>>31,b,b>>31);f=h+f|0;b=mb+k|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=Hma(s,m,i,i>>31);i=h+f|0;b=mb+b|0;b=f>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;v[w>>2]=(b|0)/256;v[g>>2]=b-(j&t);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];b=v[e+28>>2];continue}break}g=v[e+24>>2];b=v[e+28>>2];l=v[e+40>>2];h=v[e+36>>2];f=v[e+32>>2];i=v[e+44>>2]}v[r+56>>2]=i;v[a+52>>2]=l;v[a+48>>2]=h;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=jb-48|0;jb=e;q=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;l=v[a+56>>2];v[e+44>>2]=l;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+q|0;i=0;l=1;b=1;f=0;while(1){h=t[g+f|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){f=(e+8|0)+(i<<2)|0;k=v[f>>2];j=v[a+60>>2];n=j;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Yb(i,-16777216,16776704);p=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);m=v[a+68>>2];u=m;m=m>>31;v[h+4>>2]=i;i=v[a+72>>2];o=j>>31;k=k<<8;j=k;j=Hma(n,o,j,j>>31);n=mb;o=f;f=j;j=Hma(p,p>>31,b,b>>31);f=f+j|0;b=mb+n|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=Hma(u,m,g,g>>31);g=j+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[o>>2]=(b|0)/256;v[h>>2]=b-(i&k);i=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],r);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=l;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;jb=e+48|0}function D_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=Xv(g);g=Hv(g);ng(k,g);a:{b:{if(Wc(k)){v[114578]=0;aa(2471,l|0,a|0,c|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114578]=0;j=Q(2483,l|0,h<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114578]=0;h=Q(2483,l|0,48)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[114578]=0;h=Q(2483,l|0,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}i=0;v[114578]=0;Wj(j,c);h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;o=T(2468,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114578]=0;qo((j-a<<2)+d|0,g);g=v[114578];v[114578]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[kc(k,h)|0]){break f}if(t[kc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114578]=0;n=Q(2483,l|0,n|0)|0;m=v[114578];v[114578]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;yb(k);jb=k+16|0}function Wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-32|0;jb=h;v[h+28>>2]=d;a:{if(w[a+8|0]){d=a+12|0;r=h,s=xc(d)-c|0,v[r+24>>2]=s;a=v[Lb(h+24|0,h+28|0)>>2];r=h,s=bc(d),v[r+24>>2]=s;f=cf(h+24|0,c);r=h,s=bc(d),v[r+8>>2]=s;r=h,s=cf(h+8|0,c),v[r+16>>2]=s;xj(f,cf(h+16|0,a),b);break a}f=jb-32|0;jb=f;v[f+28>>2]=d;b:{c:{if(w[a+24|0]){if(!d){break b}m=a+40|0;break c}n=nb[v[v[a>>2]+44>>2]](a,b,c,d)|0;break b}while(1){j=f;o=c;l=m;k=0;i=jb-16|0;jb=i;e=a;p=e+40|0;g=e+232|0;q=c-(c&4095)|0;d:{while(1){e:{d=v[Ve(g,k)>>2];if(!w[Ii(p,d)+8|0]){break e}if(v[Ii(p,d)>>2]!=(q|0)){break e}r=i,s=v[Ve(g,k)>>2],v[r+8>>2]=s;e=k<<2;Fp(g,e+g|0,(g+e|0)+4|0);e=v[i+8>>2];r=Ve(g,0),s=e,v[r>>2]=s;break d}k=k+1|0;if((k|0)!=16){continue}break}r=i,s=v[Ve(g,15)>>2],v[r+8>>2]=s;Fp(g,g+60|0,g- -64|0);d=v[i+8>>2];r=Ve(g,0),s=d,v[r>>2]=s;d=v[Ve(g,0)>>2];g=Ii(p,d);v[g>>2]=q;Oz(i+8|0,e,d);r=g,s=nb[v[v[e>>2]+44>>2]](e,v[i+8>>2],q,4096)|0,v[r+4>>2]=s;t[g+8|0]=1}jb=i+16|0;e=j;j=o-v[Ii(l,d)>>2]|0;v[e+8>>2]=4096-j;r=f,s=v[Lb(f+8|0,f+28|0)>>2],v[r+24>>2]=s;e=f;if(j>>>0<y[Ii(m,d)+4>>2]){l=v[Ii(m,d)+4>>2]-j|0}else{l=0}v[e+20>>2]=l;e=v[Lb(f+24|0,f+20|0)>>2];Oz(f+8|0,a,d);o=v[f+8>>2];Oz(f,a,d);gf(j+o|0,e+(j+v[f>>2]|0)|0,b);d=v[f+28>>2]-e|0;v[f+28>>2]=d;n=e+n|0;if(e>>>0<y[f+24>>2]){break b}c=c+e|0;b=b+e|0;if(d){continue}break}}jb=f+32|0;a=n}jb=h+32|0;return a|0}function P_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=nu(g);g=Kv(g);ng(k,g);a:{b:{if(Wc(k)){v[114578]=0;aa(2448,l|0,a|0,c|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114578]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114578]=0;h=Q(22,l|0,48)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[114578]=0;h=Q(22,l|0,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}i=0;v[114578]=0;Wj(j,c);h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;o=T(2439,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114578]=0;Wj((j-a|0)+d|0,g);g=v[114578];v[114578]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[kc(k,h)|0]){break f}if(t[kc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114578]=0;n=Q(22,l|0,n|0)|0;m=v[114578];v[114578]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;yb(k);jb=k+16|0}function oY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;b=x[c>>1];if(b>>>0>1114111){break a}c:{d:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break d}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break c}if((g-v[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))+65536>>>0>1114111){break c}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;t[j|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=2;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return f|0}function xy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=255;b:{c:{e=a;f=e+58|0;d=b;b=w[fc(f,d)|0];if((b|0)==255){break c}if(t[fc(f,d)|0]>-1){break b}g=e+22|0;b=b&127;if(x[dd(g,b)>>1]!=65535){if((d|0)!=x[dd(g,b)>>1]){break c}}k=dd(g,b),l=d,u[k>>1]=l;k=fc(f,d),l=b,t[k|0]=l;break b}j=e+4|0;h=e+22|0;b=0;g=255;while(1){if(x[dd(h,b)>>1]==65535){k=dd(h,b),l=d,u[k>>1]=l;k=fc(f,d),l=b,t[k|0]=l;break b}if(!(w[fc(j,b)|0]&32)){i=t[fc(f,x[dd(h,b)>>1])|0]>-1?i:b;g=b}b=b+1|0;if((b|0)!=18){continue}break}if((g&255)!=255){b=(i&255)==255?g:i;g=b&255;k=fc(f,x[dd(h,g)>>1]),l=255,t[k|0]=l;k=dd(h,g),l=d,u[k>>1]=l;k=fc(f,d),l=b,t[k|0]=l}b=uk(e,d)}g=b&255;if((g|0)==255){break a}b=0;if(rj(a)){break a}e=Ii(a+314|0,g);d=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[e+8|0]=d;t[e+9|0]=d>>>8;t[e+10|0]=d>>>16;t[e+11|0]=d>>>24;d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;t[e+4|0]=d;t[e+5|0]=d>>>8;t[e+6|0]=d>>>16;t[e+7|0]=d>>>24;f=vN(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;hh(v[a>>2],(d|32)&65535,w[fc(c,b)|0]);hh(v[a>>2],(d|64)&65535,w[fc(c,b|2)|0]);hh(v[a>>2],(d|96)&65535,w[fc(c,b|4)|0]);hh(v[a>>2],(d|128)&65535,w[fc(c,b|6)|0]);hh(v[a>>2],(d|224)&65535,w[fc(c,b|8)|0]);d=0;b=1;if(e){continue}break}hh(v[a>>2],Ms(g)|192,w[fc(c,10)|0])}}function Gx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;i=cL(b,c);a:{if(!v[b+656>>2]|!(t[i|0]&1)){break a}e=v[i+4>>2];j=a+1074312|0;Eb(f+8|0,j,31);h=Cb(f+8|0);d=mu(v[b+656>>2],c);if(md(d)){break a}g=e+(h^1)|0;Eb(f+8|0,j,31);h=Cb(f+8|0);e=w[d+12|0];k=c;b:{c:{if(!h){d:{if(!(e&2)){break d}h=x[Pb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;e=0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){Eb(f+8|0,j,70);e=Cb(f+8|0)}if((g|0)!=(h|0)|e){break d}g=x[Pb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Pb(d,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Pb(d,w[d+15|0])>>1];Eb(f+8|0,j,93);if(!Cb(f+8|0)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i|0]=w[i|0]&254;break b}if(x[pj(d)>>1]>=g>>>0){break b}g=x[pj(d)>>1];c=0;break c}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(v[i+8>>2]==-1){break f}Eb(f+8|0,j,97);if(Cb(f+8|0)){break f}e=w[d+12|0]}if(e&2){e=x[Pb(d,w[d+13|0])>>1];c=0;h=x[Pb(d,w[d+14|0])>>1]+1|0;break e}e=x[pj(d)>>1];c=g>>>0>e>>>0;h=e;break e}e=x[Pb(d,w[d+15|0])>>1];c=0;h=x[Pb(d,w[d+16|0])>>1]+1|0}g=g>>>0<h>>>0?g:e;c=!c}if(k|c){break b}if(!(w[b+89|0]&8)|v[a+480180>>2]==16384?v[a+480180>>2]&16777248:1){v[b+88>>2]=v[b+88>>2]|4096}if(w[pj(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+808>>1])){break b}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}Eb(f+8|0,j,31);l=i,m=Cb(f+8|0)+g|0,v[l+4>>2]=m}jb=f+16|0}function HG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=C(0);d=(b<<2)+a|0;g=d+1068|0;l=c<<1&-4;r=g,s=Td(a,l),v[r>>2]=s;j=d+1076|0;r=j,s=Td(a,l),v[r>>2]=s;k=Td(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}j=v[j>>2];if(!j|!k){break a}b:{d=c;if((d|0)<4){break b}m=C(d|0);i=C(C(1)/m);q=d>>>2|0;while(1){n=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))*i);r=n+g|0,t=C(ze(f)),z[r>>2]=t;o=e|1;p=o<<2;r=p+g|0,t=C(-C(hi(f))),z[r>>2]=t;f=+C(C(C(o|0)*C(1.5707963705062866))*i);r=j+n|0,t=C(C(ze(f))*C(.5)),z[r>>2]=t;r=j+p|0,t=C(C(hi(f))*C(.5)),z[r>>2]=t;e=e+2|0;h=h+1|0;if((q|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;i=C(C(1)/m);e=0;h=1;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))*i);r=k+(e<<2)|0,t=C(ze(f)),z[r>>2]=t;r=k+(g<<2)|0,t=C(-C(hi(f))),z[r>>2]=t;if((d|0)==(h|0)){break b}e=e+2|0;h=h+1|0;continue}}e=(b<<2)+a|0;d=Td(a,l);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;h=(b|0)>1?b:1;f=1/+(b|0);b=0;while(1){i=C(hi((+(b|0)*1.5707963705062866+.7853981852531433)*f));r=d+(b<<2)|0,t=C(hi(+C(i*i)*1.5707963705062866)),z[r>>2]=t;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=Td(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=ll(a);if((a|0)>=8){c=36-d|0;d=a>>>3|0;a=0;while(1){r=b+(a<<1)|0,s=jl(a)>>>c<<2,u[r>>1]=s;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}dc(a,3);return 0}function p7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=jb-16|0;jb=g;m=a+44|0;if(rh(m)){j=Pd(m,0);k=Pd(m,1);h=id(m,0);i=id(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Lb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){if(!f){break b}e=1;while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;if((e|0)==(f|0)){break b}e=e+1|0;continue}}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=n*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Lb(g+12|0,g+4|0)>>2];c:{d:{if(!(r<C(1))){if(!f){break d}e=1;while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;if((e|0)==(f|0)){break d}e=e+1|0;continue}}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=n*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}oi(a,b,c,id(m,0),id(m,1),d)}jb=g+16|0}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-32|0;jb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;jb=g+32|0}function wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;l=v[a+16>>2];g=Qf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];n=g,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[g+16>>2];if(b){n=g,o=Pf(a+8|0,b),v[n>>2]=o;v[g+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;f=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=f;a:{if(d){while(1){f=0;i=h;v[e+40>>2]=h;v[e+44>>2]=m;h=((((b&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){f=(f&2147483647)<<1|i>>>31;Ad(v[g+8>>2],(u[(f<<1|2)+h>>1]+u[h+((f&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break b}b=b-1|0;i=v[e+40>>2];f=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Kf(b,v[g+12>>2]);h=v[a+32>>2];k=v[a+28>>2]+k|0;f=k>>12;v[c>>2]=v[c>>2]+B(b,f);j=h+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;f=k>>12}v[a+40>>2]=j;v[a+20>>2]=f;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function SU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){Ed(b,32);Qi(d,1,a+4|0);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}yb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;jg(b+30|0,256);u[b+32>>1]=w[a+17|0];jg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;jg(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);on(b);t[b+38|0]=w[(w[a+79|0]&7)+27872|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=d+32|0;return c|0}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-16|0;jb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Yb(k,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);I=v[a+72>>2];J=v[c>>2];e=Hma(j,j>>31,e,e>>31);j=mb;K=e;e=v[a+68>>2];l=Hma(e,e>>31,f,f>>31);e=K+l|0;f=mb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=Hma(G,H,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=B(e,n)+J;v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&I)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=k;k=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function j8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;e=jb-16|0;jb=e;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[e+12>>2]=0;W(1762,a+8|0,e+12|0,e+8|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}v[114578]=0;e=a;R(1755,e|0,11);b=v[114578];v[114578]=0;b:{if((b|0)!=1){b=79888;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){d=Ig(44);if(d){h=v[b>>2];g=v[b+4>>2];v[114578]=0;g=Q(85,c+32|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}v[114578]=0;R(1756,c+48|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break k}f=v[b+8>>2];v[114578]=0;f=Q(85,c|0,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}v[114578]=0;R(1756,c+16|0,f|0);i=v[114578];v[114578]=0;if((i|0)==1){break i}v[114578]=0;ea(1757,d|0,h|0,1,c+48|0,c+16|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}Ib(c+16|0);yb(f);Ib(c+48|0);yb(g);v[114578]=0;v[c+60>>2]=d;R(1758,e|0,c+60|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=80152){continue}break}jb=c- -64|0;return a|0}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;Ib(c+16|0)}yb(f)}Ib(c+48|0)}yb(g)}Xb(d);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}dx(e);S(b|0);L()}function NZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-496|0;jb=a;Bc(a+488|0,d);v[114578]=0;m=T(2457,a+488|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=v[ij(f,0)>>2];v[114578]=0;h=Q(2483,m|0,45)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}n=(g|0)==(h|0)}j=Wb(a+456|0);h=tf(a+440|0);i=tf(a+424|0);v[114578]=0;na(2511,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,h|0,i|0,a+420|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[a+4>>2]=2428;k=Rd(a+8|0,0,a+4|0);c=a+16|0;h:{if((Fb(f)|0)>v[a+420>>2]){g=Fb(f);l=v[a+420>>2];g=(((Fb(i)+(g-l<<1)|0)+Fb(h)|0)+v[a+420>>2]|0)+1|0;break h}g=((Fb(i)+Fb(h)|0)+v[a+420>>2]|0)+2|0}if(g>>>0<101){break e}ye(k,od(g<<2));c=v[k>>2];if(c){break e}v[114578]=0;Y(2429);b=v[114578];v[114578]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}g=v[d+4>>2];l=Tb(f);o=Tb(f);f=Fb(f);v[114578]=0;sa(2512,c|0,a+4|0,a|0,g|0,l|0,(f<<2)+o|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],j|0,h|0,i|0,v[a+420>>2]);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;b=ka(2487,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Gc(k)}Lc(i);Lc(h);yb(j)}Ob(a+488|0);S(f|0);L()}Gc(k);Lc(i);Lc(h);yb(j);Ob(a+488|0);jb=a+496|0;return b|0}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Yb(k,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[c>>2];e=Hma(j,j>>31,e,e>>31);j=mb;L=e;e=v[a+68>>2];l=Hma(e,e>>31,f,f>>31);e=L+l|0;f=mb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=Hma(H,I,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=B(e,n)+K;v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=k;k=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;f=v[a+48>>2];v[b+36>>2]=f;h=v[a+52>>2];v[b+40>>2]=h;k=v[a+56>>2];v[b+44>>2]=k;r=v[a+24>>2];s=v[a+20>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;if(d){while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+q|0;h=u[e>>1];v[b+8>>2]=h;v[b+12>>2]=u[e+2>>1];f=0;k=1;while(1){g=v[a+60>>2];n=g;i=(b+32|0)+(f<<3)|0;l=v[i>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);m=v[a+68>>2];t=m;m=m>>31;v[i+4>>2]=l;l=v[a+72>>2];o=g>>31;h=h<<8;g=h;g=Hma(n,o,g,g>>31);n=mb;o=(b+8|0)+(f<<2)|0;f=g;g=Hma(p,p>>31,e,e>>31);f=f+g|0;e=mb+n|0;e=f>>>0<g>>>0?e+1|0:e;j=Hma(t,m,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[o>>2]=(e|0)/256;v[i>>2]=e-(h&l);if(k){f=1;k=0;h=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],r);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];k=v[b+44>>2];h=v[b+40>>2];j=v[b+32>>2];f=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=h;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;jb=f+32|0}function RZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-192|0;jb=a;Bc(a+184|0,d);v[114578]=0;m=T(21,a+184|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=w[kc(f,0)|0];v[114578]=0;h=Q(22,m|0,45)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}n=(g|0)==(h&255)}j=Wb(a+160|0);h=Wb(a+144|0);i=Wb(a+128|0);v[114578]=0;na(2509,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,h|0,i|0,a+124|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[a+4>>2]=2428;k=Rd(a+8|0,0,a+4|0);c=a+16|0;h:{if((Fb(f)|0)>v[a+124>>2]){g=Fb(f);l=v[a+124>>2];g=(((Fb(i)+(g-l<<1)|0)+Fb(h)|0)+v[a+124>>2]|0)+1|0;break h}g=((Fb(i)+Fb(h)|0)+v[a+124>>2]|0)+2|0}if(g>>>0<101){break e}ye(k,od(g));c=v[k>>2];if(c){break e}v[114578]=0;Y(2429);b=v[114578];v[114578]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}g=v[d+4>>2];l=Tb(f);o=Tb(f);f=Fb(f);v[114578]=0;sa(2510,c|0,a+4|0,a|0,g|0,l|0,f+o|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],j|0,h|0,i|0,v[a+124>>2]);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;b=ka(17,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Gc(k)}yb(i);yb(h);yb(j)}Ob(a+184|0);S(f|0);L()}Gc(k);yb(i);yb(h);yb(j);Ob(a+184|0);jb=a+192|0;return b|0}function Xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;f=v[a+48>>2];v[b+36>>2]=f;h=v[a+52>>2];v[b+40>>2]=h;k=v[a+56>>2];v[b+44>>2]=k;r=v[a+24>>2];s=v[a+20>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;if(d){while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+q|0;h=t[e|0]<<8;v[b+8>>2]=h;v[b+12>>2]=t[e+1|0]<<8;f=0;k=1;while(1){g=v[a+60>>2];n=g;i=(b+32|0)+(f<<3)|0;l=v[i>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);m=v[a+68>>2];u=m;m=m>>31;v[i+4>>2]=l;l=v[a+72>>2];o=g>>31;h=h<<8;g=h;g=Hma(n,o,g,g>>31);n=mb;o=(b+8|0)+(f<<2)|0;f=g;g=Hma(p,p>>31,e,e>>31);f=f+g|0;e=mb+n|0;e=f>>>0<g>>>0?e+1|0:e;j=Hma(u,m,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[o>>2]=(e|0)/256;v[i>>2]=e-(h&l);if(k){f=1;k=0;h=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],r);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];k=v[b+44>>2];h=v[b+40>>2];j=v[b+32>>2];f=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=h;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function ag(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;v[f+12>>2]=d;e=b-1|0;g=0;a:{if(e>>>0>249){break a}h=Lp(a);g=v[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;g=x[((e-B(a,12)&255)<<1)+21424>>1]<<4>>>a|0;break a}if(v[a+480180>>2]!=64?w[a+480208|0]&16:1){Eb(f,a+1074312|0,7);if(i=Cb(f),j=1,k=v[a+480180>>2]!=64,k?i:j){a=((e&255)>>>0)/12|0;b=Hma(v[f+12>>2],0,v[(e-B(a,12)<<6&960)+25312>>2]<<a,0);a=mb;c=a>>>21|0;g=hd((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;g=x[((e-B(a,12)&255)<<1)+21424>>1]<<5>>>a|0;break a}if(!d){v[f+12>>2]=8363}a=((e&255)>>>0)/12|0;Cc(f+12|0,-1>>>a|0);g=hd(Kma(Hma(x[((e-B(a,12)&255)<<1)+21424>>1],0,267616,0),mb,v[f+12>>2]<<a,0),mb);break a}if(g&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Eb(f,a+1074312|0,76);b=Cb(f)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;g=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[f>>2]=c+8;ce(f,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;g=B(x[((((c|0)<95?c:95)<<1)+21904|0)+16>>1],b)+B(x[(v[f>>2]<<1)+21904>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(e>>>0<108?a|e>>>0<24:1){b=B(a,12);a=((e&255)>>>0)/12|0;g=x[(b+(e-B(a,12)&255)<<1)+21024>>1]<<5>>>a|0;break a}g=x[(b<<1)+20798>>1]<<2}jb=f+16|0;return g}function ila(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=w[a+3|0];switch(b-14|0){case 2:case 3:case 4:case 5:break b;case 8:break f;case 6:case 7:break g;case 1:break h;case 0:break i;default:break j}}switch(b-31|0){case 2:break d;case 0:break e;default:break b}}k:{l:{b=w[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}t[a+3|0]=11;break a}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(b>>>0>=16){t[a+5|0]=b|15;break c}t[a+5|0]=b|240;break c}t[c+15|0]=w[a+5|0]>>>4;t[c+14|0]=15;e=a,f=w[pc(c+15|0,c+14|0)|0]|32,t[e+5|0]=f;break c}b=w[a+5|0];if(b>>>0>=16){t[c+13|0]=b>>>4;t[c+12|0]=15;e=a,f=w[pc(c+13|0,c+12|0)|0]|240,t[e+5|0]=f;break c}t[a+5|0]=b|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}e=a,f=Aj(w[a+5|0]<<1),t[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=w[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}t[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}t[a+3|0]=0;break c}t[a+5|0]=119;break c}b=48}t[a+5|0]=d&15|b}b=w[a+3|0]}if(b>>>0>=36){t[a+3|0]=0;break a}t[a+3|0]=w[b+13344|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;b=w[a+5|0];t[a+5|0]=0;t[a+4|0]=b}jb=c+16|0}function WZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-448|0;jb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2490;h=Rd(a+24|0,a+32|0,a+20|0);v[114578]=0;Bc(a+16|0,e);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){v[114578]=0;i=T(2457,a+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[114578]=0;b=ta(2501,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}if(!b){break c}c=jb-16|0;jb=c;b=g;e:{if(Fe(b)){d=v[b>>2];v[c+12>>2]=0;Te(d,c+12|0);we(b,0);break e}v[c+8>>2]=0;Te(b,c+8|0);of(b,0)}jb=c+16|0;if(!w[a+15|0]){break d}v[114578]=0;b=Q(2483,i|0,45)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(112,g|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114578]=0;b=Q(2483,i|0,48)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;while(1){if(!((b|0)!=v[e>>2]|d>>>0<=e>>>0)){e=e+4|0;continue}break}v[114578]=0;W(2507,g|0,e|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break c}break b}v[114578]=0;b=Q(2463,a+440|0,a+432|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Ob(a+16|0);Gc(h);jb=a+448|0;return b|0}e=P()|0;O()|0;Ob(a+16|0)}Gc(h);S(e|0);L()}function faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+24>>2]=b;b=v[a>>2];q=h,r=bc(a),v[q>>2]=r;b=b+B(is(h+24|0,h),6)|0;a:{b:{if(!c){break b}g=v[zb(a)>>2];e=v[a+4>>2];if((g-e|0)/6>>>0>=c>>>0){f=c;i=e-b|0;g=(i|0)/6|0;if(g>>>0<c>>>0){Tz(a,c-g|0,d);f=g;if(!i){break b}}k=jb-16|0;jb=k;n=a;o=e;i=b;m=v[a+4>>2];g=B((m-(B(c,6)+b|0)|0)/6|0,6)+b|0;j=Qp(k,a,(e-g|0)/6|0);c:{d:{if(e>>>0>g>>>0){e=g;while(1){l=zb(n);p=v[j+4>>2];v[114578]=0;U(1568,l|0,p|0,e|0);l=v[114578];v[114578]=0;if((l|0)==1){break d}v[j+4>>2]=v[j+4>>2]+6;e=e+6|0;if(o>>>0>e>>>0){continue}break}}Mb(j);e=g-i|0;if(e){aj(m+B((e|0)/-6|0,6)|0,i,e)}jb=k+16|0;break c}a=P()|0;O()|0;Mb(j);S(a|0);L()}d=b>>>0<=d>>>0?y[a+4>>2]>d>>>0?B(c,6)+d|0:d:d;a=b;if(f){while(1){c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[a+4|0]=c;t[a+5|0]=c>>>8;a=a+6|0;f=f-1|0;if(f){continue}break}}break b}f=zb(a);f=IR(h,Iz(a,cg(a)+c|0),(b-v[a>>2]|0)/6|0,f);v[114578]=0;U(708,f|0,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;b=W(1567,a|0,f|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}ut(f)}a=Ng(b);jb=h+32|0;return a|0}a=P()|0;O()|0;ut(f);S(a|0);L()}function xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;l=v[a+16>>2];g=Qf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];n=g,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[g+16>>2];if(b){n=g,o=Pf(a+8|0,b),v[n>>2]=o;v[g+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;f=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=f;a:{if(d){while(1){f=0;i=h;v[e+40>>2]=h;v[e+44>>2]=m;h=(((b&2147483647)<<1|h>>>31)&-2)+l|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){f=(f&2147483647)<<1|i>>>31;Ad(v[g+8>>2],t[(f|1)+h|0]+t[h+(f&-2)|0]<<5);zd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break b}b=b-1|0;i=v[e+40>>2];f=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);zd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Kf(b,v[g+12>>2]);h=v[a+32>>2];k=v[a+28>>2]+k|0;f=k>>12;v[c>>2]=v[c>>2]+B(b,f);j=h+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;f=k>>12}v[a+40>>2]=j;v[a+20>>2]=f;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function aw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;g=jb-1040|0;jb=g;s=v[114552];m=g+16|0;a:{b:{c:{n=g+16|0;e=b;h=v[21203];d:{e:{while(1){if((e|0)!=w[d+56160|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=56256;break d}d=56256;while(1){i=w[d|0];e=d+1|0;d=e;if(i){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[h+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];j=v[f>>2]+1794895138|0;l=cl(v[f+8>>2],j);h=cl(v[f+12>>2],j);i=cl(v[f+16>>2],j);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((h|i)&3|(c>>>0<=h>>>0|c>>>0<=i>>>0)){break f}u=i>>>2|0;x=h>>>2|0;while(1){o=l>>>1|0;h=o+p|0;i=h<<1;c=(i+x<<2)+f|0;q=cl(v[c>>2],j);c=cl(v[c+4>>2],j);if(c>>>0>=k>>>0|k-c>>>0<=q>>>0|w[(c+q|0)+f|0]){break f}c=ii(d,c+f|0);if(!c){d=(i+u<<2)+f|0;c=cl(v[d>>2],j);d=cl(v[d+4>>2],j);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}r=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?o:l-o|0;p=c?p:h;continue}}}d=r?r:e;e=$e(d);g:{if(e>>>0>=1024){lc(n,d,1023);t[n+1023|0]=0;e=68;break g}lc(n,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[114552]}m=58392;if((e|0)==28){break a}Xa();L()}if(!w[m|0]){v[g>>2]=b;bw(g+16|0,1024,58596,g);m=g+16|0}v[114552]=s;Ub(a,m);jb=g+1040|0}function Fma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;kb=a-B(b,c)|0;lb=0;mb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}kb=a;lb=f&g;a=g>>>Gma(e)|0;mb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}kb=0;a=(g>>>0)/(e>>>0)|0;lb=g-B(a,e)|0;mb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}kb=a&f;lb=0;if((e|0)==1){break a}c=a;a=Gma(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}mb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}kb=l;lb=f;e=b<<1|a>>>31;a=k|a<<1;mb=e|m;return a}kb=a;lb=b;a=0;b=0}mb=b;return a}function kY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){i=v[a+12>>2];if(!(i>>>0>=d>>>0|f>>>0>=g>>>0)){b=t[i|0];c=b&255;c:{if((b|0)>=0){b=2;if(c>>>0>1114111){break a}b=i+1|0;break c}b=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-i|0)<2){break b}j=w[i+1|0];if((j&192)!=128){break a}c=j&63|c<<6&1984;if(c>>>0>1114111){break a}b=i+2|0;break c}if(c>>>0<=239){if((d-i|0)<3){break b}k=w[i+2|0];j=w[i+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((j&224)==160){break d}break a}if((j&224)==128){break d}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(j&63)<<6);if(c>>>0>1114111){break a}b=i+3|0;break c}if(c>>>0>244){break a}if((d-i|0)<4){break b}k=w[i+3|0];l=w[i+2|0];j=w[i+1|0];f:{g:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((l&192)!=128|(k&192)!=128){break a}c=k&63|(l<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}b=i+4|0}v[f>>2]=c;v[a+12>>2]=b;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>i>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function $U(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-1072|0;jb=f;e=Xh(f+16|0);h=im(a,e);Bb(e);v[a+1060>>2]=0;v[a+1064>>2]=0;v[a+1056>>2]=c;e=a+1068|0;v[e>>2]=0;v[e+4>>2]=0;e=0;v[a+1076>>2]=0;t[a+1080|0]=d;a:{b:{if(ue(c)){i=a+1060|0;while(1){v[a+1060>>2]=0;v[a+1064>>2]=0;c:{if(!v[c>>2]){break c}while(1){v[114578]=0;d=Q(258,b|0,2)|0;g=v[114578];v[114578]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}v[114578]=0;d=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}if(!d){break d}v[114578]=0;U(343,f|0,b|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break f}d=im(f+16|0,f);Wd(h,d);lc(h+16|0,d+16|0,1040);Bb(f+16|0);Bb(f);v[a+1072>>2]=0;v[a+1076>>2]=0;g=sq(v[a+1056>>2]);d=v[a+1056>>2];if(g>>>0>=2){d=v[d+20>>2];v[114578]=0;R(360,a|0,d+(e<<1)|0);d=v[114578];v[114578]=0;if((d|0)!=1){break d}break e}d=v[d+20>>2];v[114578]=0;R(361,a|0,d+e|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(76880)|0;if((O()|0)!=(ga(76880)|0)){break a}_(d|0)|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)==1){break b}}if(y[i>>2]<y[c>>2]){continue}break}}e=e+1|0;if(ue(v[a+1056>>2])>>>0>e>>>0){continue}break}}jb=f+1072|0;return a|0}d=P()|0;O()|0}Bb(a);S(d|0);L()}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-144|0;jb=c;e=$k(c+40|0,a);v[114578]=0;d=Q(683,c+24|0,32325)|0;a=v[114578];v[114578]=0;a:{b:{c:{d:{if((a|0)!=1){v[114578]=0;v[c+16>>2]=19468288;v[c+20>>2]=0;U(684,e|0,d|0,c+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ib(d);if(!(v[e>>2]&1073741824)){break c}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(d);break b}a=Ce(b);v[114578]=0;u[c+16>>1]=a;u[c+14>>1]=65535;d=Q(683,c+24|0,32331)|0;a=v[114578];v[114578]=0;e:{if((a|0)!=1){v[114578]=0;a=W(1184,e|0,c+14|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}Ib(d);if((a|0)!=1){u[c+16>>1]=x[c+14>>1]}jg(c+16|0,x[v[19811]+10>>1]);f:{if(x[c+16>>1]<=Ce(b)>>>0){break f}v[114578]=0;R(403,b|0,x[c+16>>1]);a=v[114578];v[114578]=0;if((a|0)!=1){break f}a=P()|0;O()|0;break b}u[c+12>>1]=0;if(!x[c+16>>1]){break a}a=0;g:{while(1){h:{a=_b(b,a);v[114578]=0;R(1589,c+24|0,c+12|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}v[114578]=0;aa(1571,e|0,a|0,c+24|0,1590)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}Ib(c+24|0);a=x[c+12>>1]+1|0;u[c+12>>1]=a;a=a&65535;if(a>>>0<x[c+16>>1]){continue}break a}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(c+24|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(d)}vg(e);S(a|0);L()}vg(e);jb=c+144|0}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{if(!Qb(b,9)){break b}h=a+484344|0;i=a+480280|0;while(1){An(b,c+28|0);d=Cf(b);c:{if(!((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1229999433|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1397771593|((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110104|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110099))){if(Qb(b,d)){break c}}fg(b,8);break b}ud(c+8|0,b,d);d=i;d:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1481001027){while(1){v[114578]=0;e=T(392,c+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}t[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}e:{if(w[c+28|0]!=70){break e}d=w[c+29|0];e=(d|0)==88;if(!((d-48&255)>>>0>9?e:1)){break e}f=w[c+30|0];if((f-48&255)>>>0>9){break e}g=w[c+31|0];if((g-48&255)>>>0>9){break e}d=(B(f,10)+(e?-16:B(d,100)+48|0)|0)+g&255;if(d>>>0>249){break d}v[114578]=0;R(666,c+8|0,(B(d,160)+a|0)+906300|0);d=v[114578];v[114578]=0;if((d|0)!=1){break d}break a}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;j=1}Bb(c+8|0);if(Qb(b,9)){continue}break}}jb=c+32|0;return j|0}a=P()|0;O()|0;Bb(c+8|0);S(a|0);L()}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;e=b;f=Dg(e);d=c;a:{if(f>>>0<d>>>0){l=jb-32|0;jb=l;b:{c:{k=d-f|0;d:{if(k>>>0<=v[zb(e)>>2]-v[e+4>>2]>>3>>>0){f=jb-16|0;jb=f;e:{d=yq(f,e,k);if(v[d+4>>2]!=v[d+8>>2]){while(1){g=zb(e);h=v[d+4>>2];v[114578]=0;R(927,g|0,h|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}g=v[d+4>>2]+8|0;v[d+4>>2]=g;if((g|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=f+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}m=zb(e);g=l+8|0;i=Dg(e)+k|0;h=jb-16|0;jb=h;v[h+12>>2]=i;f=e;f:{d=Nu(e);if(i>>>0<=d>>>0){f=Vi(f);if(f>>>0<d>>>1>>>0){v[h+8>>2]=f<<1;d=v[bd(h+8|0,h+12|0)>>2]}jb=h+16|0;break f}ed();L()}i=Dg(e);f=0;h=jb-16|0;jb=h;v[h+12>>2]=0;Tc(g+12|0,m);if(d){f=d;if(d>>>0>536870911){Fc(16520);L()}f=sc(f<<3,1)}v[g>>2]=f;i=(i<<3)+f|0;v[g+8>>2]=i;v[g+4>>2]=i;n=ec(g),o=(d<<3)+f|0,v[n>>2]=o;jb=h+16|0;v[114578]=0;R(925,g|0,k|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(926,e|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}XP(g)}jb=l+32|0;break b}a=P()|0;O()|0;XP(g);S(a|0);L()}break a}if(d>>>0<f>>>0){d=v[e>>2]+(d<<3)|0;Dg(e);YP(e,d);Vi(e);Dg(e)}}c=Qb(a,c<<3);if(c){e=jb-16|0;jb=e;gc(j+8|0,v[b>>2],Dg(b)<<3);jb=e+16|0;Bd(a,j+8|0)}jb=j+16|0;return c|0}function J9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);h=jb-16|0;jb=h;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Kb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}i=u[d+2>>1];if((i|0)<(g|0)){break a}if((Kb(b)-1&65535)>>>0>(i-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Kb(b)){break b}while(1){if(!(z[Pb(b,f)>>2]<C(0))){f=f+1|0;if(Kb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=cK(Kb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;ol(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=bc(b);f=cc(b);l=h,m=bc(g),v[l+8>>2]=m;i=pp(h+8|0,u[e>>1]-u[d>>1]|0);b=jb-16|0;jb=b;Oc(b+8|0,Dz(Il(c),Il(f),Il(i)));jb=b+16|0;b=u[e>>1];f=u[a+28>>1];c:{if((b|0)<=(f|0)){c=b;break c}while(1){b=b-1|0;j=z[Pb(g,u[a+30>>1]+(b-f|0)|0)>>2];k=z[a+32>>2];l=Pb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;c=u[e>>1];f=u[a+28>>1];if((f|0)>=(b|0)){break c}if((c|0)!=-32768){continue}break}}f=u[a+30>>1];b=f+c|0;d:{if((b|0)>u[d+2>>1]|(32767-f|0)<(c|0)){break d}while(1){j=z[a+32>>2];k=z[Pb(g,b-(u[a+28>>1]+f|0)|0)>>2];l=Pb(g,b-u[a+28>>1]|0),n=C(k*j),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}b=b+1|0;f=u[a+30>>1];if(u[e>>1]<=(32767-f|0)){continue}break}}Mo(a);f=1}jb=h+16|0;return f|0}function $E(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=jb-16|0;jb=k;a:{b:{c:{if((c|0)<=36){h=w[a|0];if(h){break c}f=a;break b}v[114552]=28;d=0;e=0;break a}f=a;d:{while(1){if(!el(h<<24>>24)){break d}h=w[f+1|0];g=f+1|0;f=g;if(h){continue}break}f=g;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=t[f|0];h=g-48|0;h:{if((h&255)>>>0<=9){break h}if((g-97&255)>>>0<=25){h=g-87|0;break h}if((g-65&255)>>>0>25){break g}h=g-55|0}if((h|0)>=(l|0)){break g}$g(k,p,q,j,i);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=Hma(j,i,p,q);n=mb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[114552]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[114552]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[114552]=68;break a}a=m;c=a^j;d=c-a|0;b=a>>31;e=(b^i)-((a>>>0>c>>>0)+b|0)|0}jb=k+16|0;mb=e;return d}function p8(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=jb-32|0;jb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=nb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[de(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[114578]=0;R(508,d+4|0,b+4|0);b=v[114578];v[114578]=0;c:{d:{e:{f:{if((b|0)!=1){b=v[a+20>>2];v[114578]=0;R(698,c+8|0,b+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;v[c>>2]=0;v[c+4>>2]=0;U(1740,c+16|0,c+8|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Q(1741,c+16|0,0)|0;b=v[114578];v[114578]=0;g:{if((b|0)==1){break g}d=v[v[a>>2]+176>>2];b=0;v[114578]=0;R(d|0,a|0,-1);d=v[114578];v[114578]=0;if((d|0)==1){break g}if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[114578]=0;f=C(pa(d|0,a|0,b|0));d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;z[c+8>>2]=f;Q(1742,c+16|0,c+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+180>>2];v[114578]=0;Z(b|0,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(71204)|0;break c}b=V(71204)|0;break c}b=V(71204)|0;break c}b=V(71204)|0;break c}b=V(71204)|0}if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;Es(v[a+20>>2]+4|0);$()}jb=c+32|0;return}S(b|0);L()}function Eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-432|0;jb=d;Jc(b);Cz(b,d+376|0,d+296|0,d+8|0);k=d,l=Aj(w[d+408|0]|w[d+409|0]<<8|(w[d+410|0]<<16|w[d+411|0]<<24)?w[d+427|0]+1|0:1),t[k+4|0]=l;e=w[pc(15087,d+4|0)|0];t[d+7|0]=e;u[d+4>>1]=4;a:{b:{if(!e){break b}while(1){e=w[d+8|0]|w[d+9|0]<<8;c:{d:{if(w[d+291|0]>63){break d}f=(e<<8|e>>>8)<<16>>16;if((f|0)<0){break d}if(e){e=f&65535;i=e>>>0>1?e:1;f=0;while(1){e=w[d+392|0]|w[d+393|0]<<8|(w[d+394|0]<<16|w[d+395|0]<<24);e:{if(!Qc(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+(f<<2)|0)){break e}if(!Qc(b,tA(b))){break e}e=d;f:{if(!c){h=Gd(b);break f}h=Wp(b)}u[e+2>>1]=h;k=d,l=x[Si(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;if((i|0)!=(f|0)){continue}break}}e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0>j>>>0){e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if(Qc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))){break c}}t[d+7|0]=g+1;break b}TB(a);break a}e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);Cz(b,d+376|0,d+296|0,d+8|0);j=e<<8&16711680|e<<24|(e>>>8&65280|e>>>24);g=g+1|0;if(w[d+7|0]>(g&255)>>>0){continue}break}}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}jb=d+432|0}function RT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-32|0;jb=i;t[i+12|0]=0;l=LA(i+16|0,d,i+12|0);h=v[l>>2];v[i+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){n=i;g=b-1|0;f=w[a|0];b:{c:{if(!(!g|(f|0)!=(e&255))){f=w[a+1|0];v[114578]=0;v[i+8>>2]=f;f=Q(33,i+8|0,i+12|0)|0;g=v[114578];v[114578]=0;d:{if((g|0)!=1){k=a+2|0;g=b-2|0;if(!g){break d}j=v[f>>2];if(!(j&255)){break d}g=w[k|0];while(1){t[h|0]=g;f=v[i+12>>2]-1|0;v[i+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}g=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;qq(l);S(a|0);L()}t[h|0]=e;f=v[i+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[i+12>>2]-1|0}v[n+12>>2]=f;h=h+1|0}if(!g){break a}a=k;b=g;if(f){continue}break}}k=v[l>>2];e=d-f|0;e:{if(!e){break e}h=128;g=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+g|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=g+1|0;g=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(h<<8|h)>>>f&255;k=k+1|0;m=m+1|0;if((m|0)!=(e|0)){continue}break}if(!e){break e}j=0;while(1){d=c;f=d;g=j<<24>>24;b=t[d|0];d=128;f:{if((b|0)==-128){break f}a=b;d=a;if((a|0)>-1){break f}d=0-(b&127)|0}j=g-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}qq(l);jb=i+32|0}function Vo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=bc(a),v[f+8>>2]=g;f=c,g=cc(a),v[f>>2]=g;a=1;j:{if(!Jb(c+8|0,c)){break j}while(1){b=v[c+8>>2];if(!(!mh(b)|v[b+12>>2]==64)){a=4;break j}ty(c+8|0);if(Jb(c+8|0,c)){continue}break}}jb=c+16|0;return a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}jb=c+16|0;return d}function Ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;Ed(b,32);e=a+4|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+4>>2]=e;g=e;e=a+14|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b+8>>2]=g+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));e=b;if(c?d:1){c=a+46|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!(w[d|0]|w[d+1|0]<<8)|(w[d|0]|w[d+1|0]<<8)==12288){break a}e=c;c=w[d|0]|w[d+1|0]<<8;c=(e-(((c<<8|c>>>8)&65535)<<7)|0)+6144|0}Vs(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[pc(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}jb=f+16|0}function zR(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{d=w[a|0];b:{if(d>>>0>21){break b}t[a|0]=w[d+14784|0];c:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break b;case 4:t[b|0]=w[b|0]+1>>>1;break b;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 3:break j;case 1:break k;case 0:break l;case 11:case 12:case 13:break b;case 14:break d;default:break m}}t[a|0]=0;break b}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[pc(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break b}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[pc(c+13|0,c+12|0)|0]|240,t[e|0]=f;break b}t[b|0]=d&15|48;break b}t[b|0]=d&15|176;break b}t[b|0]=d&15|64;break b}t[a|0]=15;t[b|0]=w[b|0]&15;break b}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break b}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break b}t[a|0]=10;break b;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){t[b|0]=a<<2&48|15;break b}t[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=w[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}t[b|0]=a>>>2&3|240}jb=c+16|0;return}t[b|0]=a>>>0>63?15:a>>>2|0;jb=c+16|0}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=e+p|0;j=t[g+2|0];n=t[g+1|0];q=t[g|0];r=t[g-1|0];g=v[a+60>>2];s=g;w=g>>31;e=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);x=v[a+72>>2];y=v[a+32>>2];g=c;z=v[g>>2];e=Hma(k,k>>31,e,e>>31);k=mb;A=e;e=v[a+68>>2];o=Hma(e,e>>31,f,f>>31);e=A+o|0;f=mb+k|0;f=e>>>0<o>>>0?f+1|0:f;k=e;e=(i>>>21&2040)+27888|0;i=(((B(q,u[e+2>>1])+B(r,u[e>>1])|0)+B(n,u[e+4>>1])|0)+B(j,u[e+6>>1])<<8)/16384<<8;e=i;j=Hma(s,w,e,e>>31);e=k+j|0;f=mb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(f,j)+z;l=l+y|0;n=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,n);g=e-(i&x)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2];f=b;break a}n=l>>12;j=m>>12;g=b}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=g;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function yL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b:{d=a+484360|0;if(oc(Vb(d))>>>0<=b>>>0){break b}if(np(Vb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(oc(Vb(d))>>>0<=c>>>0){break a}if(!np(Vb(d),b&65535)){continue}break}break a}c=b}if(oc(Vb(d))>>>0>c>>>0){d=a+1074312|0;f=a+1304360|0;c=a+1074984|0;while(1){t[c+819|0]=0;v[c+700>>2]=0;t[c+861|0]=0;t[c+827|0]=0;v[c+708>>2]=0;t[c+841|0]=0;v[c+804>>2]=0;t[c+839|0]=0;t[c+840|0]=0;Eb(e+8|0,d,23);if(Cb(e+8|0)){u[c+798>>1]=0;u[c+800>>1]=1}t[c+859|0]=0;c=c+896|0;if((f|0)!=(c|0)){continue}break}xL(a);c:{if(!(b&65535)){b=a;c=0;while(1){qn((b+B(c,896)|0)+1074984|0,b,c&65535);c=c+1|0;if((c|0)!=256){continue}break}qj(b+1304360|0,1);v[b+1074444>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;gy(b+1074376|0);u[b+1074440>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074440>>1]=b;u[a+1074436>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}jb=e+16|0}function wY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!v[i>>2]){break a}i=i+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){k=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=k;m=1;l=jb-16|0;jb=l;v[l+12>>2]=v[a+8>>2];n=Ah(l+8|0,l+12|0);v[114578]=0;k=fF(f,e,i-c>>2,g-f|0,b);o=v[114578];v[114578]=0;d:{if((o|0)!=1){Ie(n);jb=l+16|0;break d}a=P()|0;O()|0;Ie(n);S(a|0);L()}e:{f:{g:{h:{switch(k+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=Av(f,v[c>>2],j+8|0,v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=k+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=v[e>>2];i=d;continue}i=Av(j+4|0,0,b,v[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-v[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=w[c|0];k=v[h>>2];v[h>>2]=k+1;t[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!v[i>>2]){break b}i=i+4|0;continue}}c=v[e>>2]}m=(c|0)!=(d|0)}jb=j+16|0;return m|0}f=v[h>>2];continue}}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;h=jb-16|0;jb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];k=v[a>>2];v[h+8>>2]=k;v[h+12>>2]=f;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=(f<<1)+p|0;i=u[g>>1];q=u[g-2>>1];r=u[g+2>>1];s=u[g+4>>1];o=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];j=Yb(e,-16777216,16776704);t=v[a+72>>2];w=v[a+32>>2];g=c;x=v[g>>2];e=Hma(n,n>>31,f,f>>31);n=mb;f=e;e=(k>>>21&2040)+27888|0;k=(((B(i,u[e+2>>1])+B(q,u[e>>1])|0)+B(r,u[e+4>>1])|0)+B(s,u[e+6>>1])|0)/16384<<8;e=k;i=Hma(o,o>>31,e,e>>31);f=f+i|0;e=mb+n|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];j=Hma(f,f>>31,j,j>>31);f=i+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(e,j)+x;l=l+w|0;i=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);g=f-(k&t)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=v[h+8>>2];f=v[h+12>>2];e=b;b=g;continue}break}k=v[h+8>>2];f=v[h+12>>2];e=b;break a}i=l>>12;j=m>>12;g=b}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=g;v[a+24>>2]=i;v[a>>2]=k;v[a+4>>2]=f;jb=h+16|0}function gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-32|0;jb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=g+32|0}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-32|0;jb=g;v[g+24>>2]=b;b=v[a>>2];n=g,o=bc(a),v[n>>2]=o;b=b+(Vp(g+24|0,g)<<1)|0;a:{f=py(c,d);b:{if((f|0)<1){break b}h=v[zb(a)>>2];e=v[a+4>>2];if((f|0)<=h-e>>1){v[g>>2]=d;i=e-b|0;h=i>>1;if((h|0)<(f|0)){v[g>>2]=c;v[g>>2]=v[g>>2]+(h<<1);JN(a,v[g>>2],d,f-h|0);if((i|0)<1){break b}}k=jb-16|0;jb=k;h=e;i=b;j=a;l=v[a+4>>2];a=(l-((f<<1)+b|0)|0)+b|0;f=Wh(k,j,e-a>>1);c:{d:{if(a>>>0<e>>>0){d=a;while(1){e=zb(j);m=v[f+4>>2];v[114578]=0;U(1249,e|0,m|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[f+4>>2]=v[f+4>>2]+2;d=d+2|0;if(h>>>0>d>>>0){continue}break}}Mb(f);Fp(i,a,l);jb=k+16|0;break c}a=P()|0;O()|0;Mb(f);S(a|0);L()}gf(c,v[g>>2],b);break b}k=zb(a);h=Ri(a,oc(a)+f|0);f=b-v[a>>2]>>1;j=jb-16|0;jb=j;v[j+12>>2]=0;e=g;Tc(e+12|0,k);if(h){i=h;if(h>>>0>2147483647){Fc(11736);L()}i=sc(i<<1,2)}v[e>>2]=i;f=(f<<1)+i|0;v[e+8>>2]=f;v[e+4>>2]=f;n=ec(e),o=(h<<1)+i|0,v[n>>2]=o;jb=j+16|0;v[114578]=0;U(1247,e|0,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;b=W(1248,a|0,e|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}cC(e)}a=Ng(b);jb=g+32|0;return a|0}a=P()|0;O()|0;cC(e);S(a|0);L()}function a_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-160|0;jb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=2490;b=Rd(a+24|0,a+32|0,a+20|0);v[114578]=0;Bc(a+16|0,e);h=v[114578];v[114578]=0;a:{b:{c:{d:{if((h|0)!=1){v[114578]=0;h=T(21,a+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}t[a+15|0]=0;e=v[e+4>>2];v[114578]=0;c=ta(2491,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(!c){break c}Le(g);if(!w[a+15|0]){break d}v[114578]=0;c=Q(22,h|0,45)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(110,g|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114578]=0;h=Q(22,h|0,48)|0;c=v[114578];v[114578]=0;if((c|0)!=1){e=v[b>>2];i=v[a+20>>2];c=i-1|0;d=c>>>0<e>>>0?e:c;h=h&255;while(1){e:{if(c>>>0>e>>>0){if((h|0)==w[e|0]){break e}d=e}v[114578]=0;W(2499,g|0,d|0,i|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break c}break b}e=e+1|0;continue}}break b}v[114578]=0;c=Q(2431,a+152|0,a+144|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Ob(a+16|0);Gc(b);jb=a+160|0;return c|0}e=P()|0;O()|0;Ob(a+16|0)}Gc(b);S(e|0);L()}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;j=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=Pf(a+8|0,b),v[n>>2]=o;v[f+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){h=0;i=g;v[e+40>>2]=g;v[e+44>>2]=m;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|i>>>31;Ad(v[f+8>>2],(u[(h<<1|2)+g>>1]+u[g+((h&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,(u[(b<<1|2)+g>>1]+u[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=jb-16|0;jb=g;a:{if(w[d|0]){e=Od(g+8|0,b);b=Ci(c,b);d=jb-16|0;jb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Lb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){Uc(a,c,Gma(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){Qy(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){Uc(a,c,Gma(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}Uc(a,c,Gma(e));break b}Uc(a,c,b)}break a}e=Od(g,b);b=Ci(c,b);d=jb-16|0;jb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Lb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){Uc(a,c,Gma(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){Qy(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){Uc(a,c,Gma(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}Uc(a,c,Gma(e));break d}Uc(a,c,b)}}jb=d+16|0;jb=g+16|0}function Fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[zb(a)>>2]){h=jb-16|0;jb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+56;a=zb(a);d=v[c+4>>2];v[114578]=0;U(978,a|0,d|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;Mb(c);jb=h+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}i=jb-32|0;jb=i;h=a;j=zb(a);e=i+8|0;c=vk(a)+1|0;f=jb-16|0;jb=f;v[f+12>>2]=c;d=c;c=jb-16|0;jb=c;g=a;zb(a);v[c+12>>2]=76695844;v[114578]=0;v[c+8>>2]=2147483647;k=Q(33,c+12|0,c+8|0)|0;l=v[114578];v[114578]=0;b:{if((l|0)!=1){jb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Ab();L()}c:{if(c>>>0>=d>>>0){d=tn(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[bd(f+8|0,f+12|0)>>2]}jb=f+16|0;break c}ed();L()}g=vk(a);a=0;d=jb-16|0;jb=d;v[d+12>>2]=0;Tc(e+12|0,j);if(c){a=c;if(a>>>0>76695844){Fc(16924);L()}a=sc(B(a,56),4)}v[e>>2]=a;g=B(g,56)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=ec(e),n=B(c,56)+a|0,v[m>>2]=n;jb=d+16|0;a=v[e+8>>2];v[114578]=0;U(978,j|0,a|0,b|0);a=v[114578];v[114578]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+56;v[114578]=0;R(979,h|0,e|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}sP(e);jb=i+32|0;break d}a=P()|0;O()|0;sP(e);S(a|0);L()}}function zQ(a,b){var c=0,d=0;d=b;a:{b:{c:{d:{if($d(a,15629)){break d}if($d(a,15656)){break d}if($d(a,15661)){break d}if($d(a,16153)){break d}if(!$d(a,16158)){break c}}v[b>>2]=16163;a=4;break b}e:{f:{if($d(a,15634)){break f}if($d(a,15639)){break f}if(!$d(a,16196)){break e}}t[b+10|0]=1;v[b>>2]=16201;a=4;break b}g:{if(!$d(a,16214)){if(!$d(a,16219)){break g}}v[b>>2]=16224;a=8;break b}h:{if(!$d(a,16234)){if(!$d(a,16239)){break h}}v[b>>2]=16244;a=t[a+2|0]-48|0;break b}i:{if(!$d(a,15619)){if(!$d(a,15624)){break i}}v[b+4>>2]=1;v[b>>2]=16262;a=w[a|0]==56?8:4;break b}if(!(pd(a,16293,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=16297;a=t[a+3|0]-48|0;break b}j:{if(pd(a,16313,3)){if(pd(a,16317,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+13|0]=1;t[b+11|0]=1;v[b>>2]=16321;a=t[a+3|0]-48|0;break b}k:{if((w[a|0]-49&255)>>>0>8){break k}c=a;if(!pd(a+1|0,16333,3)){t[b+12|0]=1;v[b>>2]=16337;a=t[a|0]-48|0;break b}if((w[c+1|0]-48&255)>>>0>9|((w[a+2|0]|w[a+3|0]<<8)!=20035?(w[a+2|0]|w[a+3|0]<<8)!=18499:0)){break k}t[b+12|0]=1;v[b>>2]=16337;a=(t[a+1|0]+B(t[a|0],10)|0)-528|0;break b}c=0;if(pd(a,16368,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=16372;a=t[a+3|0]-48|0}u[d+8>>1]=a;c=1}return c}function vma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-32|0;jb=h;v[h+24>>2]=b;b=v[a>>2];o=h,p=bc(a),v[o>>2]=p;b=b+(Vp(h+24|0,h)<<1)|0;a:{b:{if(y[a+4>>2]<y[zb(a)>>2]){j=v[a+4>>2];if((j|0)==(b|0)){f=jb-16|0;jb=f;e=Wh(f,a,1);d=zb(a);a=v[e+4>>2];v[114578]=0;U(521,d|0,a|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[e+4>>2]=v[e+4>>2]+2;Mb(e);jb=f+16|0;break b}a=P()|0;O()|0;Mb(e);S(a|0);L()}l=jb-16|0;jb=l;d=a;e=b;k=v[a+4>>2];g=(k-(b+2|0)|0)+b|0;i=Wh(l,a,j-g>>1);c:{d:{if(g>>>0<j>>>0){f=g;while(1){n=zb(d);m=v[i+4>>2];v[114578]=0;U(522,n|0,m|0,f|0);m=v[114578];v[114578]=0;if((m|0)==1){break d}v[i+4>>2]=v[i+4>>2]+2;f=f+2|0;if(j>>>0>f>>>0){continue}break}}Mb(i);if((e|0)!=(g|0)){while(1){k=k-2|0;g=g-2|0;sT(k,g);if((e|0)!=(g|0)){continue}break}}jb=l+16|0;break c}a=P()|0;O()|0;Mb(i);S(a|0);L()}c=b>>>0<=c>>>0?y[a+4>>2]>c>>>0?c+2|0:c:c;t[b|0]=w[c|0];t[e+1|0]=w[c+1|0];break b}d=zb(a);d=xT(h,Ri(a,oc(a)+1|0),b-v[a>>2]>>1,d);v[114578]=0;R(515,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;b=W(516,a|0,d|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}Vt(d)}a=Ng(b);jb=h+32|0;return a|0}a=P()|0;O()|0;Vt(d);S(a|0);L()}function N3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;b=jb-2144|0;jb=b;Rb(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[114578]=0;b=Q(85,b+80|0,38648)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}g=v[c>>2];d=v[c+12>>2];e=v[c+8>>2];v[b+72>>2]=e;v[b+76>>2]=d;c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;v[b+68>>2]=f;v[b+64>>2]=g;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;c=b;i=b;h=$P(b+16|0);if(h){v[b+48>>2]=e;v[b+52>>2]=d;d=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=d;v[b+44>>2]=f;v[b+40>>2]=g;d=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=d;d=UP(b)}else{d=0}v[i+56>>2]=d;v[c+60>>2]=0;c=0;d=2048;while(1){d:{e=nb[f|0](g,(b+96|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}a=ns(a,Kl(b+32|0,Db(b+96|0),c),h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b+80|0,38633)|0;c=v[114578];v[114578]=0;if((c|0)!=1){mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0);break b}jb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function cp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;f=a+1074312|0;Eb(e+8|0,f,96);d=Cb(e+8|0);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[a+480180>>2]==16384?v[b+88>>2]&1:0)|0;b:{if(Tf(b+810|0)){d=v[b+656>>2];if(d){d=x[dd(d+236|0,w[b+810|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if(!(w[b+88|0]&2)|y[b+84>>2]>c>>>0?y[b+76>>2]>c>>>0:0){break b}Eb(e+8|0,f,57);if(h=Cb(e+8|0),i=1,j=v[a+480180>>2]!=16,j?h:i){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){Eb(e+8|0,f,27);if(Cb(e+8|0)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}jb=e+16|0}function Hd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;v[a+480180>>2]=b;b=Vo(a);DL(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;os(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Xb(rt(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;Ux(a,4);e=jb+-64|0;jb=e;b=a+484344|0;pK(b);f=jf(b);c=px(e+8|0,b);v[114578]=0;U(1582,b|0,f|0,c|0);b=v[114578];v[114578]=0;a:{if((b|0)!=1){ul(c);jb=e- -64|0;break a}a=P()|0;O()|0;ul(c);S(a|0);L()}UN(a+484360|0);Le(a+1304400|0);Le(a+1304412|0);Le(a+1304424|0);c=a+1304436|0;d=Rb(d,0,64);b=LL(d);Gb(c,b);Gb(c+12|0,b+12|0);Gb(c+24|0,b+24|0);Gb(c+36|0,b+36|0);Gb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];rs(b);kA(a+1304500|0);Ks(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}jb=d- -64|0}function hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=jb-32|0;jb=e;a:{b:{c:{f=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;jb=e+32|0}function Xba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;h=jb-16|0;jb=h;s=h,t=B(v[a>>2],ue(a)),v[s+4>>2]=t;Cc(h+4|0,c>>>3|0);c=Db(b);j=A[e+8>>3];i=v[h+4>>2];a:{if(!i){break a}e=i;while(1){k=0;f=c;m=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=g<<24|g<<8&16711680;o=k;k=m<<24|g>>>8;f=m<<8|g>>>24;o=o|0;k=k&65280|f&255|q;f=m;l(0,((f&255)<<24|g>>>8)&-16777216|((f&16777215)<<8|g>>>24)&16711680|(f>>>8&65280|f>>>24)|o);l(1,k&2147483647);j=G(+n(),j);c=c+8|0;e=e-1|0;if(e){continue}break}if(!i|j==0){break a}r=1/j;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24;q=0;m=g<<8&16711680|f;o=a<<24|g>>>8;f=a<<8|g>>>24;e=a;l(0,((e&255)<<24|g>>>8)&-16777216|((e&16777215)<<8|g>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,m|(o&65280|f&255));s=h,x=+n()*r,A[s+8>>3]=x;Rf(h+8|0,-1,1);p=A[h+8>>3]*32768;A[h+8>>3]=p;a=c;p=Sd(p);b:{if(D(p)<2147483648){e=~~p;break b}e=-2147483648}s=a,t=Vc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;i=i-1|0;if(i){continue}break}}if(d){A[d>>3]=j}jb=h+16|0;return v[h+4>>2]<<3}function Vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(zk(c)>>>0>d>>>0){g=BR(c,d);h=jb-16|0;jb=h;c=a;t[c+12|0]=0;uR(c);f=jb-32|0;jb=f;a:{b:{d=c;if(yd(d)>>>0<15){e=zb(d);e=Un(f+8|0,15,Kb(d),e);v[114578]=0;R(370,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}Vh(e)}jb=f+32|0;break a}a=P()|0;O()|0;Vh(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=Cp(h+8|0,f&65535,w[pc(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[zb(d)>>2]){sR(d,j);break d}k=jb-32|0;jb=k;e=d;l=zb(d);d=Un(k+8|0,Be(d,Kb(d)+1|0),Kb(d),l);m=v[d+8>>2];v[114578]=0;U(769,l|0,m|0,j|0);j=v[114578];v[114578]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[114578]=0;R(370,e|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break f}Vh(d);jb=k+32|0;break e}a=P()|0;O()|0;Vh(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}jb=h+16|0}g:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break g}b=md(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c}function nF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=$c(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}e=c-48|0;break a}f=(c|0)==45;d=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=$c(a)}e=c-48|0;if(!(d|e>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(e>>>0<=9){b=0;while(1){d=(b+c|0)-48|0;g=(d|0)>214748363;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=$c(a)}e=c-48|0;if(!(g|e>>>0>9)){b=B(d,10);continue}break}b=d;d=b>>31;h:{if(e>>>0>=10){break h}while(1){d=Hma(b,d,10,0);b=d+c|0;c=mb;c=b>>>0<d>>>0?c+1|0:c;d=b;b=b-48|0;d=c-(d>>>0<48)|0;c=v[a+4>>2];i:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=$c(a)}e=c-48|0;if(e>>>0>9){break h}if((d|0)<21474836?1:(d|0)<=21474836?b>>>0<2061584302:0){continue}break}}if(e>>>0<10){while(1){c=v[a+4>>2];j:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=$c(a)}if(c-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=b;b=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}b=0;d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;mb=-2147483648;return 0}mb=d;return b}function r3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-80|0;jb=d;a:{b:{c:{if(mi(a)){Fo(d+72|0);break c}Qm(d+32|0,a);v[114578]=0;R(2176,d+72|0,d+32|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}rf(d+32|0)}if(mi(a)){c=a+36|0}else{c=v[d+72>>2]}e=v[a+8>>2];d:{if((e|0)==-1){e=Rt(c);e:{if(!Id(c)){break e}while(1){if(!(A[Rc(c,f)>>3]+h<=b)){e=Rc(c,f);break e}h=A[e>>3]+h;f=f+1|0;if(Id(c)>>>0>f>>>0){continue}break}}b=b-h;break d}e=Rc(c,e)}f=a+24|0;c=v[f>>2];g=x[e+12>>1];v[114578]=0;R(2179,c|0,g|0);c=v[114578];v[114578]=0;if((c|0)!=1){f:{g=v[f>>2];i=w[a+64|0];c=iI(uQ(d+32|0,b),w[e+16|0],x[e+12>>1],v[e+8>>2]);v[114578]=0;e=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=e;e=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=e;e=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=e;X(2130,d+56|0,g|0,(i?7:1)|0,d+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}c=Tg(d+56|0);e=t[c+26|0]&1;g=v[(e?c+8|0:c+12|0)>>2];e=x[(e?c+20|0:c+22|0)>>1];b=A[c>>3];Hl(d+56|0);u[v[f>>2]+1074438>>1]=e;u[v[f>>2]+1074440>>1]=e;v[v[f>>2]+1074428>>2]=g;v[v[f>>2]+1074392>>2]=-2;b=b+h;A[a+16>>3]=b;gk(d+72|0);jb=d+80|0;return+b}}f=P()|0;O()|0;gk(d+72|0);break a}f=P()|0;O()|0;rf(d+32|0)}S(f|0);L()}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=jb-144|0;jb=g;l=Wp(a);if(l){p=g+8|4;q=g+8|6;r=g+8|5;k=g+8|2;m=g+8|3;while(1){h=jb-16|0;jb=h;e=jb-16|0;jb=e;i=g+8|0;gc(h+8|0,i,136);jb=e+16|0;f=Hb(h+8|0);e=a;j=nc(e,ac(h,h+8|0));if((f|0)==(j|0)){$b(e,Hb(h+8|0))}jb=h+16|0;if((f|0)!=(j|0)){e=jb-16|0;jb=e;Rb(i,0,136);jb=e+16|0}e=w[g+8|0]|w[g+9|0]<<8;a:{if(!e){break a}e=(e<<8|e>>>8)&65535;if(e>>>0>x[c+480192>>1]){break a}e=v[((e<<2)+c|0)+900380>>2];if(!e){break a}e=pu(e,b);b:{if(!w[m|0]){break b}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break b}t[e+12|0]=w[e+12|0]|2}t[g+4|0]=w[m|0];t[g+7|0]=31;f=w[pc(g+4|0,g+7|0)|0]+1|0;i=f&255;gg(e,i);t[e+13|0]=w[r|0];t[e+14|0]=w[q|0];h=w[p|0];t[e+15|0]=h;t[e+16|0]=h;h=0;if((f|0)!=(i|0)){break a}while(1){j=h<<2;n=g+16|0;f=j+n|0;f=w[f|0]|w[f+1|0]<<8;s=Pb(e,h),y=f<<8|f>>>8,u[s>>1]=y;f=n+(j|2)|0;f=w[f|0]|w[f+1|0]<<8;f=f<<8|f>>>8;u[g+4>>1]=d?(f&65535)+128>>>2|0:f;jg(g+4|0,64);f=w[g+4|0];s=Pb(e,h),y=f,t[s+2|0]=y;h=h+1|0;if((i|0)!=(h|0)){continue}break}}o=o+1|0;if((o&65535)>>>0<l>>>0){continue}break}}jb=g+144|0}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;Ed(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=yk(Vg(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[pc(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+27872|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[pc(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);jb=e+16|0}function Qm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-80|0;jb=c;g=Tw(a);e=b+24|0;a:{b:{if(Mh(v[e>>2]+484360|0)){if(Mh(v[e>>2]+484360|0)){a=0;while(1){f=v[e>>2];b=iI(vQ(c+40|0,1),a&255,0,0);v[114578]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+20>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;X(2130,c- -64|0,f|0,0,c|0);b=v[114578];v[114578]=0;c:{d:{if((b|0)!=1){i=c,j=bc(c- -64|0),v[i+32>>2]=j;i=c,j=cc(c- -64|0),v[i+24>>2]=j;if(Jb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{b=v[c+32>>2];f=x[b+24>>1];h=A[b>>3];d=v[b+16>>2];b=c+40|0;v[b+16>>2]=a;v[b+12>>2]=f;v[b+8>>2]=d;A[b>>3]=h;v[114578]=0;R(2131,g|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}Dy(c+32|0);if(Jb(c+32|0,c+24|0)){continue}break c}break}a=P()|0;O()|0;Hl(c- -64|0);break b}Hl(c- -64|0);a=a+1|0;if(Mh(v[e>>2]+484360|0)>>>0>a>>>0){continue}break}}jb=c+80|0;return}b=ba(8)|0;v[114578]=0;c=Q(85,c+40|0,38586)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0)}rf(g);S(a|0)}L()}function vY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!w[i|0]){break a}i=i+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}l=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=l;k=jb-16|0;jb=k;v[k+12>>2]=v[a+8>>2];m=Ah(k+8|0,k+12|0);v[114578]=0;l=eF(f,e,i-c|0,g-f>>2,b);n=v[114578];v[114578]=0;e:{if((n|0)!=1){Ie(m);jb=k+16|0;break e}a=P()|0;O()|0;Ie(m);S(a|0);L()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{v[h>>2]=f;if(v[e>>2]==(c|0)){break j}k:{l:{m:{n:{b=bE(f,c,i-c|0,j+8|0,v[a+8>>2]);switch(b+2|0){case 1:break m;case 2:break n;case 0:break g;default:break l}}c=c+1|0;break k}v[e>>2]=c;break i}c=b+c|0}f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(l<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break f}c=v[e>>2];if((d|0)==(i|0)){i=d;continue}if(!bE(f,c,1,b,v[a+8>>2])){break h}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!w[i|0]){break b}i=i+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}jb=j+16|0;return a|0}f=v[h>>2];continue}}function sc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(kD(b)){h=jb-16|0;jb=h;i=b>>>0>4?b:4;j=a?a:1;a:{while(1){a=j;e=i;b:{c:{d:{if((e|0)==8){a=od(a);break d}d=e>>>2|0;c=0;while(1){b=c;if(d){d=d-1&d;c=c+1|0;continue}break}c=28;if(e&3|(b|0)!=1){break c}c=48;if(a>>>0>-64-e>>>0){break c}d=a;b=16;a=e>>>0>16?e:16;c=a>>>0>16?a:16;e:{if(!(c-1&c)){a=c;break e}while(1){a=b;b=a<<1;if(a>>>0<c>>>0){continue}break}}f:{if(d>>>0>=-64-a>>>0){v[114552]=48;b=0;break f}f=d>>>0<11?16:d+11&-8;d=od((f+a|0)+12|0);b=0;if(!d){break f}b=d-8|0;g:{if(!(d&a-1)){a=b;break g}e=d-4|0;c=v[e>>2];d=((a+d|0)-1&0-a)-8|0;a=d-b>>>0>15?d:a+d|0;g=a-b|0;d=(c&-8)-g|0;if(!(c&3)){b=v[b>>2];v[a+4>>2]=d;v[a>>2]=b+g;break g}v[a+4>>2]=d|v[a+4>>2]&1|2;c=a+d|0;v[c+4>>2]=v[c+4>>2]|1;v[e>>2]=g|v[e>>2]&1|2;c=b+g|0;v[c+4>>2]=v[c+4>>2]|1;Oq(b,g)}c=v[a+4>>2];h:{if(!(c&3)){break h}b=c&-8;if(b>>>0<=f+16>>>0){break h}v[a+4>>2]=f|c&1|2;d=a+f|0;c=b-f|0;v[d+4>>2]=c|3;b=a+b|0;v[b+4>>2]=v[b+4>>2]|1;Oq(d,c)}b=a+8|0}a=b}c=48;if(!a){break b}v[h+12>>2]=a;c=0}}if(!c){break a}a=v[115885];if(a){nb[a|0]();continue}break}a=ba(4)|0;Yk(a);ha(a|0,71204,2009);L()}jb=h+16|0;return v[h+12>>2]}return Pe(a)}function b9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=mf(a);if(c>>>0<b>>>0){f=jb-32|0;jb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[zb(a)>>2]-v[a+4>>2]>>11>>>0){c=jb-16|0;jb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{if(v[b+4>>2]!=v[b+8>>2]){while(1){a=zb(g);d=v[b+4>>2];v[114578]=0;R(1652,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}a=v[b+4>>2]+2048|0;v[b+4>>2]=a;if((a|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=c+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}h=zb(a);i=f+8|0;b=mf(a)+e|0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=b;b=jb-16|0;jb=b;g=a;zb(a);v[b+12>>2]=2097151;v[114578]=0;v[b+8>>2]=2147483647;j=Q(33,b+12|0,b+8|0)|0;k=v[114578];v[114578]=0;e:{if((k|0)!=1){jb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Ab();L()}f:{if(b>>>0>=c>>>0){c=jk(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[bd(d+8|0,d+12|0)>>2]}jb=d+16|0;break f}ed();L()}b=EJ(i,b,mf(a),h);v[114578]=0;R(1650,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1646,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}ds(b)}jb=f+32|0;break a}a=P()|0;O()|0;ds(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;mf(a);BJ(a,b);FJ(a)}}function UW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(kg(a,v[b+8>>2],e)){lv(b,c,d);return}a:{if(kg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;i=f+(v[a+12>>2]<<3)|0;j=b;b:{c:{while(1){d:{if(f>>>0>=i>>>0){break d}u[b+52>>1]=0;kv(f,b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}h=1;g=1;if(w[a+8|0]&2){break e}break c}h=1;d=g;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}d=g;a=4;if(!h){break b}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;Qq(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(v[b+36>>2]!=1?a&2:1){while(1){if(w[b+54|0]){break a}Qq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Qq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|(v[b+24>>2]==1?v[b+36>>2]==1:0)){break a}Qq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function tH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+40>>2]){case 0:Gr(c,b);break a;case 2:Gr(c,zb(b));break a;case 3:i=Ug(b);b=jb-80|0;jb=b;d=v[c>>2];g=v[d+4>>2];f=v[d+24>>2];v[b+40>>2]=v[d+20>>2];v[b+44>>2]=f;f=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=f;Eh(b- -64|0,b+32|0,g);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];f=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(g){while(1){d=0;if(f){while(1){k=v[Of(c,d,h)>>2];Ve(i,d);l=rn(j,d,h),m=C(C(k|0)*C(7.450580596923828e-9)),z[l>>2]=m;d=d+1|0;if((f|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 1:Gr(c,zb(b));break a;default:break b}}Gr(c,zb(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function Mo(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=C(0);c=v[a+36>>2];if(!c){ti(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:e=a+16|0;if(c>>>0>=1001){ti(e);return}ol(e,c);c=x[a+28>>1];b=a+4|0;Kb(b);g=pl(a,(c<<16)+65536>>16);c=u[a+28>>1];Kb(b);b=1;g=ne(C(g/pl(a,c)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){i=ne(g,C(b>>>0));l=Pb(e,b-1|0),m=i,z[l>>2]=m;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:e=a+16|0;h=x[a+30>>1];if(h>>>0>1e3/(c>>>0)>>>0){ti(e);return}ol(e,B(c,h));c=u[a+28>>1];Kb(a+4|0);b=x[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!h){break b}while(1){d=b&65535;k=a;f=c+j<<16>>16;d:{if((f|0)>=0){b=(f|0)%(d|0)|0;break d}b=d+((f^-1)%(d|0)^-1)|0}b=b<<16;f=b>>16;g=ne(C(pl(k,b+65536>>16)/pl(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));e:{if(!v[a+36>>2]){break e}b=1;d=0;while(1){i=ne(g,C((b&65535)>>>0));l=Pb(e,B(v[a+36>>2],f)+d|0),m=i,z[l>>2]=m;b=b+1|0;d=b&65535;if(d>>>0>y[a+36>>2]){break e}d=d-1|0;continue}}j=j+1|0;if(h>>>0<=(j&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}ti(a+16|0);v[a+36>>2]=0}return}ti(a+16|0)}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a+808|0;c=a+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+40|0]=1;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}c=a;v[c+3832>>2]=0;v[c+3836>>2]=0;d=c+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){Ff((c+B(f,84)|0)+808|0,c);f=f+1|0;if((f|0)!=36){continue}break}while(1){v[(c+B(e,44)|0)+32>>2]=c;e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){d=v[(e<<2)+19808>>2];f=(c+B(e,44)|0)+16|0;a:{if(!(!(1<<e&3591)|e>>>0>11)){d=c+B(d,84)|0;FN(f,d+808|0,d+1060|0,d+1312|0,d+1564|0);break a}d=c+B(d,84)|0;FN(f,d+808|0,d+1060|0,0,0)}e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){mn((c+B(e,84)|0)+808|0);e=e+1|0;if((e|0)!=36){continue}break}EN(c,b);return a|0}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){k=0;g=k;v[e+40>>2]=h;v[e+44>>2]=g;h=(b<<1)+l|0;b:{b=v[f+16>>2];if((b|0)<=0){break b}while(1){Ad(v[f+8>>2],u[(g<<1)+h>>1]/4<<16>>16);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);h=v[a+32>>2];j=v[a+28>>2]+j|0;g=j>>12;v[c>>2]=v[c>>2]+B(b,g);i=h+i|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}k=i>>12;g=j>>12}v[a+40>>2]=i;v[a+20>>2]=g;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function I8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;if(!w[a+4242|0]){gx(a);a:{if(!w[a+4240|0]){break a}e=zL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;as(a)}g=a+4256|0;b:{if(w[a+4244|0]){if(!(A[g>>3]<=1)){A[g>>3]=1}break b}i=(v[a+4232>>2]&-2)!=4;e=A[g>>3];c:{if(D(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<1)){fx(a);e=A[a+4256>>3]}A[g>>3]=e-+(f|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=hi(A[a+4256>>3]*6.283185307179586);break d;case 1:e=D(A[a+4256>>3]+-.5)*-4+1;break d;case 2:e=A[a+4256>>3];e=e+e+-1;break d;case 3:e=A[a+4256>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];j=e*e*e*((e*6+-15)*e+10);e=A[a+4272>>3];e=j*(A[a+4280>>3]-e)+e}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];Rf(h+8|0,0,1);f=kj(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|pt(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],nb[k](l|0,m|0)|0;break f}nb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;oi(f,b,c,Pd(a,0),Pd(a,1),d);jb=h+16|0}function Ic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{f=w[b+8|0];c=v[b>>2];d=v[b+4>>2];b=jb-48|0;jb=b;e=Wb(a);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((f|0)!=1){if(!d|(f|0)!=4){break k}break l}if(d){break l}a=c;break j}d=d-1|0}m:{switch(f-1|0){case 0:case 1:break m;case 2:case 3:break i;default:break h}}a=c+d|0}t[b+32|0]=0;a=Tm(c,a,b+32|0);v[114578]=0;W(119,e|0,c|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}v[114578]=0;W(119,e|0,c|0,c+d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}c=Dd(e);d=sf(e);f=Dd(e);a=jb-32|0;jb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=f;if(Jb(a+24|0,a+16|0)){while(1){c=t[v[a+24>>2]];t[v[a+8>>2]]=c?c:32;qg(a+24|0);qg(a+8|0);if(Jb(a+24|0,a+16|0)){continue}break}}jb=a+32|0;v[114578]=0;c=Q(120,b+16|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break f}v[114578]=0;d=Q(85,b|0,6640)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;U(121,b+32|0,c|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}Gb(e,b+32|0);yb(b+32|0);yb(d);yb(c)}jb=b+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d)}yb(c)}yb(e);S(a|0);L()}}function Dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;i=jb-16|0;jb=i;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];j=v[a>>2];v[i+8>>2]=j;v[i+12>>2]=f;h=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=h;a:{if(d){while(1){h=f+p|0;n=t[h+1|0];f=t[h|0];h=v[a+60>>2];q=h;r=h>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];u=v[a+32>>2];h=c;w=v[h>>2];g=Hma(k,k>>31,g,g>>31);k=mb;x=g;g=v[a+68>>2];o=Hma(g,g>>31,e,e>>31);g=x+o|0;e=mb+k|0;e=g>>>0<o>>>0?e+1|0:e;k=g;j=((B(n-f|0,j>>>10&4194048)|0)/16384|0)+(f<<8)<<8;f=j;g=Hma(q,r,f,f>>31);f=k+g|0;e=mb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;g=m>>12;v[h>>2]=B(e,g)+w;l=l+u|0;n=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,n);h=f-(j&s)|0;Sb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;j=v[i+8>>2];f=v[i+12>>2];e=b;b=h;continue}break}j=v[i+8>>2];f=v[i+12>>2];e=b;break a}n=l>>12;g=m>>12;h=b}v[a+40>>2]=l;v[a+20>>2]=g;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=n;v[a>>2]=j;v[a+4>>2]=f;jb=i+16|0}function Cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;j=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=Pf(a+8|0,b),v[n>>2]=o;v[f+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){h=0;i=g;v[e+40>>2]=g;v[e+44>>2]=m;g=(((b&2147483647)<<1|g>>>31)&-2)+j|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|i>>>31;Ad(v[f+8>>2],t[(h|1)+g|0]+t[g+(h&-2)|0]<<5);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,t[(b|1)+g|0]+t[g+(b&-2)|0]<<5);zd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;v[f+8>>2]=c>>>4;v[f+4>>2]=v[a>>2];d=v[Lb(f+8|0,f+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=g;j=h<<8&16711680|h<<24;k=e<<24|h>>>8;g=e<<8|h>>>24;j=k&65280|g&255|j;v[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|l;v[f+12>>2]=j;Rf(f+8|0,-1,1);i=A[f+8>>3]*32768;A[f+8>>3]=i;e=a;i=Sd(i);a:{if(D(i)<2147483648){g=~~i;break a}g=-2147483648}m=e,n=Vc(g),u[m>>1]=n;e=b;g=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);h=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);e=g;j=h<<8&16711680|h<<24;k=e<<24|h>>>8;g=e<<8|h>>>24;j=k&65280|g&255|j;v[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|l;v[f+12>>2]=j;Rf(f+8|0,-1,1);i=A[f+8>>3]*32768;A[f+8>>3]=i;e=a;i=Sd(i);b:{if(D(i)<2147483648){g=~~i;break b}g=-2147483648}m=e,n=Vc(g),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=f+16|0;return d<<4}function Cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;i=jb-16|0;jb=i;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];j=v[a>>2];v[i+8>>2]=j;v[i+12>>2]=f;h=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=h;a:{if(d){while(1){h=(f<<1)+p|0;n=u[h+2>>1];f=u[h>>1];h=v[a+60>>2];q=h;r=h>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];t=v[a+32>>2];h=c;w=v[h>>2];g=Hma(k,k>>31,g,g>>31);k=mb;x=g;g=v[a+68>>2];o=Hma(g,g>>31,e,e>>31);g=x+o|0;e=mb+k|0;e=g>>>0<o>>>0?e+1|0:e;k=g;j=f+((B(n-f|0,j>>>18|0)|0)/16384|0)<<8;f=j;g=Hma(q,r,f,f>>31);f=k+g|0;e=mb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;g=m>>12;v[h>>2]=B(e,g)+w;l=l+t|0;n=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,n);h=f-(j&s)|0;Sb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;j=v[i+8>>2];f=v[i+12>>2];e=b;b=h;continue}break}j=v[i+8>>2];f=v[i+12>>2];e=b;break a}n=l>>12;g=m>>12;h=b}v[a+40>>2]=l;v[a+20>>2]=g;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=n;v[a>>2]=j;v[a+4>>2]=f;jb=i+16|0}function cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=jb+-64|0;jb=d;o=d,p=nf(a)>>>5|0,u[o+32>>1]=p;u[d+16>>1]=3999;o=c,p=x[lf(d+32|0,d+16|0)>>1],u[o+480190>>1]=p;fz(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=vp(c,j&65535);it(a,d+32|0);Ed(f,0);Hn(d,2,d+32|0);Ic(d+16|0,d);v[114578]=0;Q(371,((i<<5)+c|0)+946304|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}yb(d+16|0);u[f+32>>1]=64;v[f+24>>2]=8287;e=w[m|0]|w[m+1|0]<<8;u[d+16>>1]=e<<8|e>>>8;u[d>>1]=64;o=f,p=x[lf(d+16|0,d)>>1]<<2,u[o+30>>1]=p;e=n;e=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))&-16777217;v[f>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8;g=(g<<8|g>>>8)&65535;b:{if(g>>>0<2){break b}e=(e<<8|e>>>8)&65535;g=e+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=e<<1;u[f+34>>1]=x[f+34>>1]|8}e=w[h|0]|w[h+1|0]<<8?(w[h|0]|w[h+1|0]<<8)==512:1;ee(d+16|0,b,i-1|0);ge(d+16|0,e);j=j+1|0;i=j&65535;if(i>>>0<=x[c+480190>>1]){continue}break}}jb=d- -64|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function lc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Pa(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb+-64|0;jb=g;e=g;h=e+16|0;while(1){l=(i<<2)+h|0;f=0;c=0;j=jb-16|0;jb=j;d=b;Oc(j+8|0,d);a:{b:{c:{d:{e:{if(sd(d+16|0)){while(1){f:{k=v[d+16>>2];v[114578]=0;k=T(98,k|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break f}f=f|k;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(71180)|0;if((O()|0)!=(ga(71180)|0)){break b}_(c|0)|0;t[d+20|0]=0;v[114578]=0;Z(82,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break b}t[d+20|0]=0}if(!w[d+20|0]){d=v[d+24>>2];v[114578]=0;d=T(99,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}f=d^f}jb=j+16|0;break a}c=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break b}V(0)|0;O()|0;Ab();L()}c=P()|0;O()|0}S(c|0);L()}v[l>>2]=f;i=i+1|0;if((i|0)!=12){continue}break}b=jn(e);v[114578]=0;U(109,e|0,h|0,h+48|0);d=v[114578];v[114578]=0;g:{if((d|0)==1){break g}v[114578]=0;b=e;W(106,a|0,e|0,0)|0;a=v[114578];v[114578]=0;h:{if((a|0)!=1){oe(b);jb=g- -64|0;break h}break g}return}a=P()|0;O()|0;oe(b);S(a|0);L()}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){k=0;g=k;v[e+40>>2]=h;v[e+44>>2]=g;h=b+l|0;b:{b=v[f+16>>2];if((b|0)<=0){break b}while(1){Ad(v[f+8>>2],t[h+g|0]<<6);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,t[h+v[e+44>>2]|0]<<6);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);h=v[a+32>>2];j=v[a+28>>2]+j|0;g=j>>12;v[c>>2]=v[c>>2]+B(b,g);i=h+i|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}k=i>>12;g=j>>12}v[a+40>>2]=i;v[a+20>>2]=g;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function pO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;h=jb-16|0;jb=h;if(uj(a)){e=w[(be(w[a+819|0])?a+819|0:a+821|0)|0];Eb(h+8|0,d+1074312|0,34);a:{if(!Cb(h+8|0)){break a}d=e;if(e){if(d>>>0>120){break a}e=w[fc(v[a+656>>2]+108|0,d-1|0)|0];break a}e=0}d=a;k=C(C(v[a+704>>2]<<4)*b);f=(c+e<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];i=v[c+36>>2];a=v[a+876>>2]+v[a+768>>2]|0;b:{if(!(a?i:0)){b=pl(c,a+f<<16>>16);break b}g=i+1|0;c:{if((a|0)>=0){e=a;a=(a|0)/(g|0)|0;e=e-B(g,a)|0;break c}e=i-((a^-1)%(g|0)|0)|0;a=((a+1|0)/(g|0)|0)-1|0}l=u[c+28>>1];j=c+4|0;Kb(j);b=C(1);f=a+f<<16>>16;d:{if((f|0)<(l|0)){break d}if((f|0)>(x[c+28>>1]+Kb(j)<<16)-65536>>16){break d}if(!e){b=z[Pb(j,f-u[c+28>>1]|0)>>2];break b}a=x[c>>1];e:{if((a|0)==3){a=c+16|0;if(Kb(a)){b=z[Pb(a,e-1|0)>>2];break e}a=x[c>>1]}f:{if((a&65535)!=1){break f}a=c+16|0;if(!Kb(a)){break f}g=x[c+30>>1];if((f|0)>=0){g=(f|0)%(g|0)|0}else{g=g+((f^-1)%(g|0)^-1)|0}b=z[Pb(a,(B(g<<16>>16,i)+e|0)-1|0)>>2];break e}b=ne(C(pl(c,(f<<16)+65536>>16)/pl(c,f)),C(C(e|0)/C(g|0)))}b=C(z[Pb(j,f-u[c+28>>1]|0)>>2]*b)}}m=d,n=Ai(C(k*b)),v[m+700>>2]=n}jb=h+16|0}function S7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,t=0,u=C(0);a:{if(!v[a+4272>>2]){break a}h=a+44|0;if(!rh(h)){break a}k=Pd(h,0);l=Pd(h,1);m=id(h,0);n=id(h,1);if(d){j=a+4256|0;e=v[a+4268>>2];o=d;while(1){f=z[l>>2];g=z[k>>2];t=Pb(j,e<<1),u=g,z[t>>2]=u;t=Pb(j,v[a+4268>>2]<<1|1),u=f,z[t>>2]=u;f=C(D(YI(C(C(C(D(g))+C(D(f)))*C(536870912)),31,5)));g=z[a+4276>>2];f=C(f*C(4.656612873077393e-10));f=C(C(C(g-f)*z[(f<g?4240:4236)+a>>2])+f);z[a+4276>>2]=f;p=m;q=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];f=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(f,g))))+C(2147483392));b:{if(f<C(4294967296)&f>=C(0)){i=~~f>>>0;break b}i=0}e=i<<5;r=e|-2147483648;s=e;e=i>>>26|0;f=C(q*C((e?r:s)>>>(e?32-e|0:31)>>>0));e=v[a+4272>>2];e=(((e+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;t=p,u=C(f*z[Pb(j,e)>>2]),z[t>>2]=u;t=n,u=C(f*z[Pb(j,e|1)>>2]),z[t>>2]=u;i=v[a+4268>>2];e=i-1|0;v[a+4268>>2]=e;if(!i){e=v[a+4272>>2]+e|0;v[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}oi(a,b,c,id(h,0),id(h,1),d)}}function gl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;v[a+4>>2]=0;if(w[hj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+24>>2];d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;b=T(2385,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}if(ve(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!ve(b,c)){continue}break}d=0;break a}while(1){if(v[a+4>>2]>=(b|0)){break a}e=v[v[a>>2]-12>>2];v[114578]=0;e=v[(a+e|0)+24>>2];g=v[114578];v[114578]=0;d:{if((g|0)==1){break d}v[114578]=0;e=T(2385,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(ve(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!ve(e,c)){continue}break a}break}}b=V(0)|0;O()|0;_(b|0)|0;fj(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];c=v[114578];v[114578]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break f}S(a|0);L()}$();d=1;break a}V(0)|0;O()|0;Ab()}L()}d=2}Ag(v[v[a>>2]-12>>2]+a|0,d)}jb=f+16|0;return a|0}function efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;jb=g+16|0}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-32|0;jb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;jb=f+32|0}function pH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+40>>2]){case 0:Fr(c,b);break a;case 2:Fr(c,zb(b));break a;case 3:i=Ug(b);b=jb-80|0;jb=b;d=v[c>>2];f=v[d+4>>2];v[b+40>>2]=v[d+20>>2];g=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=g;Do(b- -64|0,b+32|0,f);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);f=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(f){while(1){d=0;if(g){while(1){k=v[Of(c,d,h)>>2];Ve(i,d);l=Of(j,d,h),m=C(C(k|0)*C(7.450580596923828e-9)),z[l>>2]=m;d=d+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((f|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 1:Fr(c,zb(b));break a;default:break b}}Fr(c,zb(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;jb=f+16|0}function FG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){dk(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=kl(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}dc(a,21);return 0}k=B(d,l);m=((k+m|0)+j|0)>(p|0)?(p-k|0)+j|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}dc(a,21);return 0}ia(50752,50496,1872,50788);L()}function UH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;a:{j=$P(e);b:{if(j){i=e+24|0;g=jb-48|0;jb=g;d=sc(324,4);h=Uc(g+16|0,g+40|0,1);f=jb-16|0;jb=f;v[f+12>>2]=d;v[114578]=0;d=g+24|0;W(2203,d|0,f+12|0,h|0)|0;h=v[114578];v[114578]=0;c:{if((h|0)!=1){jb=f+16|0;break c}break a}f=v[d>>2];v[114578]=0;Q(2164,f|0,b|0)|0;b=v[114578];v[114578]=0;d:{if((b|0)!=1){co(i,ec(v[d>>2]),Nd(d));GH(d);jb=g+48|0;break d}a=P()|0;O()|0;GH(d);S(a|0);L()}Iu(e+32|0,e+24|0);break b}i=e+16|0;g=jb-48|0;jb=g;d=sc(56,4);h=Uc(g+16|0,g+40|0,1);f=jb-16|0;jb=f;v[f+12>>2]=d;v[114578]=0;d=g+24|0;W(2205,d|0,f+12|0,h|0)|0;h=v[114578];v[114578]=0;e:{if((h|0)!=1){jb=f+16|0;break e}break a}f=v[d>>2];v[114578]=0;Q(2165,f|0,b|0)|0;b=v[114578];v[114578]=0;f:{if((b|0)!=1){co(i,ec(v[d>>2]),Nd(d));FH(d);jb=g+48|0;break f}a=P()|0;O()|0;FH(d);S(a|0);L()}Iu(e+32|0,e+16|0)}b=a;a=fm(e+40|0,e+32|0);zC(b,a,c);Bb(a);Bb(e+32|0);g:{if(!j){Bb(e+16|0);break g}Bb(e+24|0)}jb=e+48|0;return}V(0)|0;O()|0;Ab();L()}function Z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{c=u[b>>1];b=jb-32|0;jb=b;v[114578]=0;h=Q(15,b+24|0,a|0)|0;d=v[114578];v[114578]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[h|0]){break e}d=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];Bc(b+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;f=T(2393,b+16|0)|0;e=v[114578];v[114578]=0;f:{g:{if((e|0)!=1){Ob(b+16|0);e=Rk(b+8|0,a);g=v[v[a>>2]-12>>2];v[114578]=0;g=a+g|0;j=T(16,g|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}e=v[e>>2];v[114578]=0;k=f;f=c&65535;i=c;c=d&74;c=ea(2394,k|0,e|0,g|0,j|0,((c|0)==64?f:(c|0)==8?f:i)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Pk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+c|0,5);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Hf(h);break d}Hf(h);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=b+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb+-64|0;jb=e;g=Xm(a);a:{if(b-1>>>0>1023){break a}f=v[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break a}f=v[a+12>>2]}f=B(lk(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=cc(a);break d}d=bc(a)}v[c+48>>2]=d;c=Md(e+56|0,e+48|0);Ph(e+40|0);c=v[c>>2];v[114578]=0;aa(1565,a|0,c|0,f|0,e+40|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}a=V(71204)|0;break c}if(d){i=e,j=cc(a),v[i+48>>2]=j;i=e,j=wK(e+48|0,0-f|0),v[i+40>>2]=j;c=Md(e+32|0,e+40|0);i=e,j=cc(a),v[i+16>>2]=j;d=v[Md(e+24|0,e+16|0)>>2];c=v[c>>2];v[114578]=0;W(1566,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}a=V(71204)|0;break c}i=e,j=bc(a),v[i+40>>2]=j;c=Md(e+8|0,e+40|0);i=e,j=bc(a),v[i+16>>2]=j;i=e,j=wK(e+16|0,f),v[i+48>>2]=j;d=v[Md(e,e+48|0)>>2];c=v[c>>2];v[114578]=0;W(1566,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}a=V(71204)|0}if((O()|0)==(ga(71204)|0)){_(a|0)|0;$();break a}S(a|0);L()}v[a+12>>2]=b;h=1}jb=e- -64|0;return h|0}function EQ(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Je(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Je(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Je(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Je(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Je(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}jb=f+16|0}function rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=h+n|0;h=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Yb(b,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);w=v[a+72>>2];x=v[c>>2];e=Hma(j,j>>31,e,e>>31);j=mb;y=e;e=v[a+68>>2];k=Hma(e,e>>31,f,f>>31);e=y+k|0;f=mb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=(i>>>21&2040)+27888|0;h=(((B(u[e+2>>1],p)+B(q,u[e>>1])|0)+B(u[e+4>>1],o)|0)+B(h,u[e+6>>1])<<8)/16384<<8;e=h;i=Hma(r,s,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=B(e,m)+x;v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(h&w)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;g=jb-16|0;jb=g;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(h<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(f,-16777216,16776704);s=v[a+72>>2];f=v[c>>2];e=Hma(k,k>>31,e,e>>31);k=mb;t=c;w=f;f=(i>>>21&2040)+27888|0;i=(((B(j,u[f+2>>1])+B(u[f>>1],p)|0)+B(u[f+4>>1],q)|0)+B(r,u[f+6>>1])|0)/16384<<8;f=i;j=Hma(l,l>>31,f,f>>31);e=j+e|0;f=mb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];h=Hma(e,e>>31,h,h>>31);e=j+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[t>>2]=w+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(i&s)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function Kd(a){var b=0,c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;v[c+12>>2]=0;v[c+8>>2]=2556;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;e=jb-16|0;jb=e;d=a;if(v[a>>2]!=-1){f=e+8|0;Oc(f,b);Oc(e,f);b=e;while(1){if(v[d>>2]==1){continue}break}a:{b:{c:{if(!v[d>>2]){Ff(d,1);v[114578]=0;f=v[114578];v[114578]=0;d:{if((f|0)==1){break d}v[114578]=0;Z(2565,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[d>>2]=-1;v[114578]=0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;a=v[114578];v[114578]=0;e:{if((a|0)==1){break e}Ff(d,0);v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)==1){break c}S(a|0);L()}break a}V(0)|0;O()|0;Ab()}L()}}jb=e+16|0;jb=c+32|0;return v[a+4>>2]-1|0}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;jb=f+32|0}function tJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=jb+-64|0;jb=c;d=fo(c+48|0,Od(c+40|0,b),0);v[114578]=0;b=T(332,d|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;b=W(1703,d|0,c|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}b:{if(!b|v[c>>2]!=542066252){break b}b=c|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+8|0;f=a,g=hn((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+12|0;f=a,g=hn((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+16|0;f=a,g=hn((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+20|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+24|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+28|0]!=0;t[a+4241|0]=w[c+29|0]!=0;t[a+4242|0]=w[c+30|0]!=0;t[a+4243|0]=w[c+31|0]!=0;t[a+4244|0]=w[c+32|0]!=0;bs(a)}Bb(d);jb=c- -64|0;return}a=P()|0;O()|0;Bb(d);S(a|0);L()}function u$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;a=Gv(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((cr(b,c,0)|0)!=-1){while(1){f=cr(b,c,e);v[114578]=0;X(199,d|0,b|0,e|0,f-e|0);f=v[114578];v[114578]=0;if((f|0)==1){break j}v[114578]=0;R(200,d+16|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break i}v[114578]=0;R(201,a|0,d+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break h}yb(d+16|0);yb(d);e=cr(b,c,e)+Fb(c)|0;if((cr(b,c,e)|0)!=-1){continue}break}}k:{if(md(a)){v[114578]=0;X(199,d+16|0,b|0,e|0,-1);c=v[114578];v[114578]=0;if((c|0)==1){break f}c=Fb(d+16|0);yb(d+16|0);if(!c){break k}}v[114578]=0;X(199,d|0,b|0,e|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;R(200,d+16|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;R(201,a|0,d+16|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+16|0);yb(d)}jb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;yb(d+16|0)}yb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(d+16|0)}yb(d)}bl(a);S(e|0);L()}function t6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=SM(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(Hs(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!Hs(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(40,4);i=Ak(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1259,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(1257,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(2110,h|0,c|0,38127,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;RM(b);S(a|0);L()}Bk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;RM(d+8|0)}Ei(f+24|0,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+12|0}function dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;t[d+16|0]=44;v[d+8>>2]=-1;v[d+12>>2]=0;v[d>>2]=1042;v[d+4>>2]=2;h=a;g=d;a=jb-16|0;jb=a;i=a;c=jb-176|0;jb=c;e=dh(c+40|0);f=v[v[e>>2]-12>>2];v[114578]=0;j=da(122)|0;k=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{if((k|0)==1){break f}v[114578]=0;U(123,c+32|0,(c+40|0)+f|0,j|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}Ob(c+32|0);v[114578]=0;R(148,e|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;R(132,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;R(125,c|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;U(140,c+16|0,c|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(141,i|0,c+16|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}yb(c+16|0);yb(c);Yd(e);jb=c+176|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c+16|0)}yb(c)}Yd(e);S(a|0);L()}v[114578]=0;U(13,h|0,0,a|0);b=v[114578];v[114578]=0;g:{if((b|0)!=1){yb(a);jb=a+16|0;break g}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+32|0}function Jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=SM(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{zb(c);h=b+14|0;e:{if(QL(g,h)){if(!v[b>>2]){break b}e=b;break e}zb(c);if(!QL(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(20,4);i=Ak(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1387,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(1383,c+14|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(1386,h|0,c|0,20485,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;RL(b);S(a|0);L()}Bk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;RL(d+8|0)}Ei(f+24|0,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=tt(f+24|0);jb=f+32|0;return a+4|0}function aK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(fs(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!fs(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(32,4);i=Ak(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1625,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(733,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(1624,h|0,c|0,32530,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;UJ(b);S(a|0);L()}Bk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;UJ(d+8|0)}Ei(f+24|0,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+4|0}function Rw(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=jb-96|0;jb=g;h=a+24|0;So(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=XH(g+32|0,g+80|0,YH(g+80|0),b);e=v[a+32>>2];i=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;c=jb-16|0;jb=c;d=v[g+12>>2];v[c+8>>2]=v[g+8>>2];v[c+12>>2]=d;d=v[g+4>>2];v[c>>2]=v[g>>2];v[c+4>>2]=d;f=g+48|0;d=f;Lr(d);v[d+8>>2]=e;v[d+4>>2]=0;v[d>>2]=83888;e=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=e;e=v[c+12>>2];v[d+20>>2]=v[c+8>>2];v[d+24>>2]=e;z[d+28>>2]=i;v[d>>2]=83832;jb=c+16|0;a:{b:{if(b){e=0;while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114578]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=Q(2154,g+24|0,g+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}d=v[d>>2];v[114578]=0;c=W(2155,c|0,d|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}e=c+e|0;if(c){b=b-c|0;if(b){continue}}break}if(e){break b}}e=0;if(v[a+52>>2]!=1){break b}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+96|0;return e}a=P()|0;O()|0;S(a|0);L()}function Qw(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=jb-96|0;jb=g;h=a+24|0;So(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=XH(g+32|0,g+80|0,YH(g+80|0),b);e=v[a+32>>2];i=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;c=jb-16|0;jb=c;d=v[g+12>>2];v[c+8>>2]=v[g+8>>2];v[c+12>>2]=d;d=v[g+4>>2];v[c>>2]=v[g>>2];v[c+4>>2]=d;f=g+48|0;d=f;Lr(d);v[d+8>>2]=e;v[d+4>>2]=0;v[d>>2]=83984;e=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=e;e=v[c+12>>2];v[d+20>>2]=v[c+8>>2];v[d+24>>2]=e;z[d+28>>2]=i;v[d>>2]=83936;jb=c+16|0;a:{b:{if(b){e=0;while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114578]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=Q(2154,g+24|0,g+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}d=v[d>>2];v[114578]=0;c=W(2155,c|0,d|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}e=c+e|0;if(c){b=b-c|0;if(b){continue}}break}if(e){break b}}e=0;if(v[a+52>>2]!=1){break b}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+96|0;return e}a=P()|0;O()|0;S(a|0);L()}function tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+14|0;e:{if(yn(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!yn(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(20,4);i=Ak(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(831,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(824,c+14|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(830,h|0,c|0,15166,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;QQ(b);S(a|0);L()}Bk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;QQ(d+8|0)}Ei(f+24|0,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=tt(f+24|0);jb=f+32|0;return a+2|0}function pz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;tQ(a,b);i=jb-16|0;jb=i;Ed(c,1);a=b+22|0;a=w[a|0]|w[a+1|0]<<8;v[c>>2]=((a<<8|a>>>8)&65535)<<1;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[pc(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;a=w[a|0]|w[a+1|0]<<8;j=(a<<8|a>>>8)&65535;a=j<<1;f=b+28|0;f=w[f|0]|w[f+1|0]<<8;g=(f<<8|f>>>8)&65535;f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(f-a>>>0>3?f>>>0<4|a>>>0>f>>>0:1){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}jb=i+16|0;Tl(h,3,b);Ic(h+16|0,h);v[114578]=0;Q(371,d|0,h+16|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){a=d+32|0;yb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=qz(b);jb=h+32|0;return a}a=P()|0;O()|0;yb(h+16|0);S(a|0);L()}function nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(yn(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!yn(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(32,4);i=Ak(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(731,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(729,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(730,h|0,c|0,14646,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;YR(b);S(a|0);L()}Bk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;YR(d+8|0)}Ei(f+24|0,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+4|0}function gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=Db(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break c}c=0;while(1){f:{g:{h:{d=w[c+h|0];switch(d-10|0){case 3:break h;case 0:break g;default:break f}}e=e+1|0;break f}f=f+1|0}i=((g&255)==13&(c|0)!=0&(d|0)==10)+i|0;g=d;c=c+1|0;if((c|0)!=(b|0)){continue}break}c=(e|0)==(i|0);break d}if((d|0)!=4){break b}b=0;c=1}i:{if((e|0)==(f|0)){d=2;if(c){break i}}if(e){d=0;if(!f){break i}}d=e?3:f?1:3}if(!b){break b}}g=0;f=(d|0)!=2;c=0;e=0;while(1){e=(f|w[c+h|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}break a}b=0;g=1;e=0}Co(a,e);if(!g){g=(d|0)==2;f=d&-3;i=(d|0)==1?32:13;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=t[c+h|0];switch(d-10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}j=pm(a,e),k=i,t[j|0]=k;c=c+g|0;break j}d=pm(a,e);if(f){t[d|0]=13;break j}t[d|0]=32;break j}if(!d){break k}}j=pm(a,e),k=d,t[j|0]=k;break j}j=pm(a,e),k=32,t[j|0]=k}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function Gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{zb(c);h=b+16|0;e:{if(OL(g,h)){if(!v[b>>2]){break b}e=b;break e}zb(c);if(!OL(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=SL(1);i=Ak(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1391,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(1388,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(1390,h|0,c|0,20485,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;PL(b);S(a|0);L()}Bk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;PL(d+8|0)}Ei(f+24|0,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+8|0}function wx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;e=a+2|0;if(!(w[e|0]==255|!w[e|0])){v[f+12>>2]=w[e|0]+1;v[f+8>>2]=10;gg(b,v[de(f+12|0,f+8|0)>>2]);e=w[a+3|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=511;e=0;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Kb(b)){i=g>>>1|e;while(1){h=(d<<2)+a|0;c=h+6|0;c=w[c|0]|w[c+1|0]<<8;j=Pb(b,d),k=c>>>4|0,u[j>>1]=k;c:{d:{if(!d){e=0;c=0;break d}c=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,c)>>1]){break c}e=d;c=x[Pb(b,c)>>1]+1|0}j=Pb(b,e),k=c,u[j>>1]=k}c=h+8|0;v[f+12>>2]=(i+((w[c|0]|w[c+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;c=v[Js(f+12|0,f+8|0,f+4|0)>>2];j=Pb(b,d),k=c,t[j+2|0]=k;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;if(w[a|0]&2){d=w[b+15|0];e=Kb(b);d=w[b+12|0]&-5|(e>>>0>=d>>>0)<<2}else{d=w[b+12|0]&-5}t[c+12|0]=d;c=b;e:{f:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break f}}a=w[b+12|0]&-3;break e}d=Kb(b);a=w[b+12|0]&-3|(a>>>0<=d>>>0)<<1}t[c+12|0]=a}jb=f+16|0}function wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=oc(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>1>>>0){g=jb-16|0;jb=g;e:{d=Wh(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(829,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+2|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Ri(f,oc(f)+h|0);m=oc(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>2147483647){Fc(15088);L()}g=sc(g<<1,1)}v[e>>2]=g;j=(m<<1)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<1)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(827,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(828,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}RQ(e)}jb=k+32|0;break b}a=P()|0;O()|0;RQ(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<1)|0;oc(f);SQ(f,d);Nn(f)}}c=Qb(a,c<<1);if(c){$A(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=Kb(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>2>>>0){g=jb-16|0;jb=g;e:{d=qe(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(741,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+4|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Be(f,Kb(f)+h|0);m=Kb(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>1073741823){Fc(14480);L()}g=sc(g<<2,1)}v[e>>2]=g;j=(m<<2)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<2)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(739,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(740,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}NR(e)}jb=k+32|0;break b}a=P()|0;O()|0;NR(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<2)|0;Kb(f);OR(f,d);Qg(f)}}c=Qb(a,c<<2);if(c){Kz(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=Kb(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>2>>>0){g=jb-16|0;jb=g;e:{d=qe(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(822,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+4|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Be(f,Kb(f)+h|0);m=Kb(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>1073741823){Fc(15088);L()}g=sc(g<<2,1)}v[e>>2]=g;j=(m<<2)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<2)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(820,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(821,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}YQ(e)}jb=k+32|0;break b}a=P()|0;O()|0;YQ(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<2)|0;Kb(f);ZQ(f,d);Qg(f)}}c=Qb(a,c<<2);if(c){Kz(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function wU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=oc(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>1>>>0){g=jb-16|0;jb=g;e:{d=Wh(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(427,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+2|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Ri(f,oc(f)+h|0);m=oc(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>2147483647){Fc(12065);L()}g=sc(g<<1,1)}v[e>>2]=g;j=(m<<1)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<1)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(425,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(426,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}_A(e)}jb=k+32|0;break b}a=P()|0;O()|0;_A(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<1)|0;oc(f);aB(f,d);Nn(f)}}c=Qb(a,c<<1);if(c){$A(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function BA(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b:{if((w[a|0]-1&255)>>>0>14){break b}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<=-2){break b}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){c=B(d,13)+a|0;if(w[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break a}b=e+422|0;if(w[c+942|0]|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=1048576){break a}c=B(d,11)+a|0;g=c+1346|0;if(w[g|0]>=16|w[c+1351|0]>=4|w[c+1356|0]>=4){break a}c:{if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break c}c=e+430|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048574){break c}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break a}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break a}}d:{e:{if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)|f){break e}if(pd(g,12323,11)){break e}f=0;break d}f=1}d=d+1|0;if((d|0)!=32){continue}break}}return f}return 0}function EG(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}ia(51904,50496,2408,51917);L()}function eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-144|0;jb=f;Vy(a);a:{b:{if(!Df(a,64)){break b}c:{d:{e:{if(!xk(a,60)){break e}if(!eP(a,17213)){break e}b=15;break d}Vy(a);if(!Df(a,128)){break b}b=0;c=1;if(!xk(a,124)){break d}e=31;if(eP(a,17218)){break c}}e=b;if(c){break a}}Vy(a);b=1;while(1){c=0;d=jb-16|0;jb=d;if(bP(a,d+8|0)){c=d+8|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}jb=d+16|0;if(c>>>0>131072){break a}if((b&65535)>>>0<e>>>0){b=b+1|0;continue}break}Xc(a,4);if(!Df(a,2)){break b}c=0;g=jb-16|0;jb=g;d=jb-16|0;jb=d;Ok(d+8|0,g+8|0);b=a;i=Hb(d+8|0);j=ld(a,ac(d,d+8|0));if((i|0)==(j|0)){Xc(b,Hb(d+8|0))}jb=d+16|0;jb=g+16|0;if((i|0)==(j|0)){b=g+8|0;b=w[b|0]|w[b+1|0]<<8;c=b<<8|b>>>8}if((c&65535)>>>0<178){break a}h=-1;b=B(e,30);if(!Df(a,b)){break a}Xc(a,b);b=jb-16|0;jb=b;e=f+8|0;kQ(b+8|0,e);c=Hb(b+8|0);d=ld(a,ac(b,b+8|0));if((c|0)==(d|0)){Xc(a,Hb(b+8|0))}jb=b+16|0;a=(c|0)==(d|0);if(!a){lQ(e)}if(!a){break a}h=dP(f+8|0);break a}h=-1}jb=f+144|0;return h|0}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-16|0;jb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;j=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=j;a:{if(d){while(1){k=u[(f<<1)+p>>1];g=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];i=Yb(e,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];j=c;s=v[c>>2];o=k<<8;e=o;e=Hma(g,g>>31,e,e>>31);k=mb;g=Hma(n,n>>31,f,f>>31);f=g+e|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=v[a+68>>2];i=Hma(f,f>>31,i,i>>31);f=g+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;k=m>>12;v[j>>2]=B(e,k)+s;l=l+r|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,g);j=f-(o&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;f=v[h+12>>2];e=b;b=j;continue}break}i=v[h+8>>2];f=v[h+12>>2];e=b;break a}g=l>>12;k=m>>12;j=b}v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function Ada(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;g=Wb(a+4|0);c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=0;e=a+16|0;W(83,e|0,c+12|0,c+8|0)|0;b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){jb=c+16|0;break b}break a}c=e;t[a+20|0]=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;e=a+24|0;W(84,e|0,b+12|0,b+8|0)|0;f=v[114578];v[114578]=0;c:{if((f|0)!=1){jb=b+16|0;break c}break a}v[114578]=0;Z(80,d+8|0);b=v[114578];v[114578]=0;d:{e:{f:{if((b|0)!=1){qy(c,Nd(d+8|0));wf(d+8|0);t[a+20|0]=0;b=0;break f}b=Ca(71204,71180)|0;f=O()|0;if((ga(71204)|0)==(f|0)){_(b|0)|0;v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)==1){b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break e}V(0)|0;O()|0;Ab()}L()}if((ga(71180)|0)!=(f|0)){break e}_(b|0)|0;t[a+20|0]=0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;break e}b=w[a+20|0]}if(b&255){break d}v[114578]=0;Z(82,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0}wf(e);wf(c);yb(g);S(b|0);L()}jb=d+16|0;return a|0}V(0)|0;O()|0;Ab();L()}function iw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;qf(g+16|0,a,b,c,e,h-15233|0);Gm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}jb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-16|0;jb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;j=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=j;a:{if(d){while(1){k=t[f+p|0];g=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];i=Yb(e,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];j=c;s=v[c>>2];o=k<<16;e=o;e=Hma(g,g>>31,e,e>>31);k=mb;g=Hma(n,n>>31,f,f>>31);f=g+e|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=v[a+68>>2];i=Hma(f,f>>31,i,i>>31);f=g+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;k=m>>12;v[j>>2]=B(e,k)+s;l=l+r|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,g);j=f-(o&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;f=v[h+12>>2];e=b;b=j;continue}break}i=v[h+8>>2];f=v[h+12>>2];e=b;break a}g=l>>12;k=m>>12;j=b}v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function sL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-560|0;jb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=kO(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;Px(b+48|0,c+48|0);Px(b+68|0,c+68|0);Px(b+88|0,c+88|0);lc(b+108|0,c+108|0,448);rt(c);break c}b=Ig(556);if(!b){f=0;v[d>>2]=0;break b}v[114578]=0;f=Q(1437,b|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[((x[e+558>>1]<<2)+a|0)+900380>>2]=b}h=a,i=x[Si(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}jb=e+560|0;return f|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function dr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Fb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Ev(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+64400|0];d:{e:{switch(Lma(f-88|0,30)|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Bc(g,d);v[114578]=0;b=T(2457,g|0)|0;a=v[114578];v[114578]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Bc(g,d);v[114578]=0;a=T(2458,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}Ob(g);v[114578]=0;R(2459,g|0,a|0);d=v[114578];v[114578]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114578]=0;R(2460,g|12,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;d=g+24|0;a=ua(2461,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Lc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;while(1){d=Lc(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;Lc(g)}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function v$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Bc(g,d);v[114578]=0;b=T(21,g|0)|0;a=v[114578];v[114578]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Bc(g,d);v[114578]=0;a=T(2424,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}Ob(g);v[114578]=0;R(2425,g|0,a|0);d=v[114578];v[114578]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114578]=0;R(2426,g|12,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;d=g+24|0;a=ua(2427,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;yb(g)}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function tL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{switch(v[a+480224>>2]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Hma(c,c>>31,5e4,0);f=mb;b=v[bd(d+12|0,d+8|0)>>2];c=Ac(Ima(c,f,b,b>>31),mb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Hma(c,c>>31,1e4,0);f=mb;b=v[bd(d+12|0,d+8|0)>>2];c=Ac(Ima(c,f,b,b>>31),mb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(Hma(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(mb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!dg(c,x[b+60>>1])){break d}if(!(md(_b(c,x[b+60>>1])+24|0)^1)){break d}c=_b(c,x[b+60>>1])+24|0;break c}c=a+480248|0}if(!md(c)){e=e*5.960464477539063e-8*+y[Pb(c,y[b+48>>2]%(Kb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074384>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=Hma(v[a+480244>>2],0,c,0)+32768|0;a=mb;a=b>>>0<32768?a+1|0:a;a=hd((a&65535)<<16|b>>>16,a>>>16|0);jb=d+16|0;return(a?a:1)|0}function j5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=v[b>>2];b=v[b+4>>2];c=jb-32|0;jb=c;v[114578]=0;g=Q(15,c+24|0,a|0)|0;h=v[114578];v[114578]=0;b:{c:{d:{if((h|0)!=1){e:{if(!w[g|0]){break e}Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;h=T(2393,c+16|0)|0;d=v[114578];v[114578]=0;f:{g:{if((d|0)!=1){Ob(c+16|0);d=Rk(c+8|0,a);e=v[v[a>>2]-12>>2];v[114578]=0;e=a+e|0;i=T(16,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}d=v[d>>2];v[114578]=0;b=Ea(2396,h|0,d|0,e|0,i|0,f|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[c+16>>2]=b;if(!Pk(c+16|0)){break e}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,5);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;Ob(c+16|0);break f}b=V(0)|0;O()|0}Hf(g);break d}Hf(g);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=c+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function qn(a,b,c){var d=0;d=jb-16|0;jb=d;t[a+861|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+819|0]=0;v[a+804>>2]=0;v[a+824>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;Eb(d+8|0,b+1074312|0,23);if(Cb(d+8|0)){u[a+798>>1]=0;u[a+800>>1]=1}t[a+866|0]=0;t[a+859|0]=0;t[a+871|0]=255;v[a+660>>2]=0;t[a+872|0]=w[a+872|0]&252;gt(a+810|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+865|0]=0;t[a+858|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+840>>1]=0;t[a+839|0]=0;u[a+856>>1]=32512;u[a+862>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+876>>2]=0;v[a+880>>2]=0;t[a+872|0]=w[a+872|0]&243;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+760>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|1024;break a}v[a+760>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+796>>1]=0;t[a+817|0]=0;t[a+818|0]=0;jb=d+16|0}function fr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Fb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Tm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+64400|0];d:{e:{switch(f-22|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function zo(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function mY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break a}b=w[a|0];if(b>>>0>1114111){break a}f=a+1|0;b:{if(b<<24>>24>=0){break b}if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=w[a+1|0];if((f&192)!=128|(f&63|b<<6&1984)>>>0>1114111){break a}f=a+2|0;break b}c:{d:{if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((b|0)==237){break d}if((b|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break a}g=g+1|0;f=a+4|0;break b}if((f&224)!=128){break a}}if((h&192)!=128|(h&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break a}f=a+3|0}a=f;g=g+1|0;continue}break}return a-c|0}function ZV(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb+-64|0;jb=c;a=fd(a);v[114578]=0;b=da(228)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[114578]=0;d=Q(2,c+32|0,10984)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=da(228)|0;e=v[114578];v[114578]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[114578]=0;v[c+12>>2]=b;R(234,c+16|0,c+12|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;U(3,c+48|0,d|0,c+16|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}Gb(a,c+48|0);yb(c+48|0);yb(c+16|0);yb(d);v[114578]=0;b=da(230)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(!b){break e}v[114578]=0;Q(235,a|0,10987)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(c+16|0)}yb(d);break a}v[114578]=0;b=da(229)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(!b){break d}v[114578]=0;Q(235,a|0,10989)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}}jb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}yb(a);S(b|0);L()}function Dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;i=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}j=v[a+24>>2];k=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;if(d){while(1){g=0;v[e+40>>2]=h;v[e+44>>2]=l;h=(b<<1)+i|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){Ad(v[f+8>>2],u[(g<<1)+h>>1]/4<<16>>16);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-2608|0;jb=f;d=f+8|0;im(d,a);v[d+1056>>2]=0;v[d+1060>>2]=0;Rb(d+1064|0,0,1536);v[114578]=0;Z(565,d|0);a=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){v[114578]=0;j=Q(260,d|0,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break f}a=0;g:{while(1){v[114578]=0;e=Q(260,d|0,1)|0;k=v[114578];v[114578]=0;if((k|0)==1){break g}a=B(a,6)+d|0;a=u[(e?a+1066|0:a+1064|0)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1068|0];if(u[e+1064>>1]<0){break h}if(u[e+1066>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break d}break}b=V(76880)|0;break e}b=V(76880)|0;break e}b=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break a}_(b|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break c}}v[114578]=0;a=T(566,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}Bb(d);jb=f+2608|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0}Bb(d);S(b|0);L()}function Jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;f=Wb(e+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[114578]=0;c=T(341,b|0)|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){v[e+12>>2]=c;if((c|0)>0){break d}v[114578]=0;Q(85,a|0,30880)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break b}}break a}v[114578]=0;c=T(332,b|0)|0;d=v[114578];v[114578]=0;e:{if((d|0)==1){break e}v[114578]=0;c=T(858,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;v[e+8>>2]=c;c=Q(464,e+12|0,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}c=v[c>>2];v[114578]=0;R(111,f|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[114578]=0;c=T(389,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}if(!c){break f}v[114578]=0;W(1533,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}v[114578]=0;Q(340,b|0,4)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}td(a,f)}yb(f);jb=e+32|0;return}a=P()|0;O()|0;yb(f);S(a|0);L()}function PH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;a:{b:{c:{d:{e:{f:{g:{if(mi(a)){Fo(c+24|0);break g}Qm(c+8|0,a);v[114578]=0;R(2176,c+24|0,c+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break f}rf(c+8|0)}if(mi(a)){d=a+36|0}else{d=v[c+24>>2]}if((b|0)==-1){e=4194304;break d}if((b|0)>=0){f=b;if((Id(d)|0)>(b|0)){break d}}b=ba(8)|0;v[114578]=0;d=Q(85,c+8|0,38703)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}mc(b,d);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break c}a=P()|0;O()|0;rf(c+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|e;b=v[b>>2];e=w[Rc(d,f)+16|0];v[114578]=0;R(489,b+484360|0,e|0);b=v[114578];v[114578]=0;h:{if((b|0)==1){break h}b=v[Rc(d,f)+12>>2];d=v[Rc(d,f)+8>>2];v[114578]=0;+oa(2026,a|0,b|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;gk(c+24|0);jb=c+32|0;return}a=P()|0;O()|0}gk(c+24|0)}S(a|0)}L()}function pM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=B(b,896)+a|0;a:{if(c){Eb(e+8|0,a+1074312|0,90);if(!Cb(e+8|0)){t[(B(b,896)+a|0)+1075815|0]=c}t[(B(b,896)+a|0)+1075816|0]=c;break a}c=w[g+1075816|0]}f=g+1074984|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);jM(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,896)+a|0)+1075640>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){iM(a,f,240-h|0);break b}if(!(b>>>0<224|d)){hM(f,224-h|0);break b}gM(f,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=65535}if((c&255)>>>0>223&i){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}dM(a,f,d);break b}if(v[a+480180>>2]==524288){break d}lM(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){Eb(e+8|0,a+1074312|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}eM(a,f,h<<2)}jb=e+16|0}function u8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{d=jb-16|0;jb=d;f=fd(a);b:{if(Fb(b)){while(1){c=v[ij(b,i)>>2];c:{if(c>>>0>=2097152){v[114578]=0;R(118,f|0,63);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}e=0;d:{e:{f:{while(1){h=c&63;t[(d+10|0)+e|0]=h;a=e+1|0;c=c>>>6|0;if(!c){break f}e=a;if((a|0)!=6){continue}break}a=7;c=1;break e}if(!e){v[114578]=0;R(118,f|0,t[d+10|0]);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}c=7-e|0;if((a|0)!=2){break e}if((h|0)==1){break d}a=2;c=6}e=a+d|0;h=(-1<<a^-1)<<c;c=a;while(1){g:{h:{if((a|0)==(c|0)){g=w[e+9|0];v[114578]=0;R(118,f|0,(g|h)<<24>>24);g=v[114578];v[114578]=0;if((g|0)==1){break g}c=c-1|0;break h}v[114578]=0;c=c-1|0;R(118,f|0,t[c+(d+10|0)|0]|-128);g=v[114578];v[114578]=0;if((g|0)==1){break g}}if(c){continue}break c}break}break b}v[114578]=0;R(118,f|0,t[d+10|0]|64);a=v[114578];v[114578]=0;if((a|0)==1){break b}}i=i+1|0;if(Fb(b)>>>0>i>>>0){continue}break}}jb=d+16|0;break a}a=P()|0;O()|0;yb(f);S(a|0);L()}}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=jb-16|0;jb=h;g=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=f+o|0;p=t[e+1|0];e=t[e|0];f=v[a+60>>2];q=f;r=f>>31;f=Yb(b,-16777216,16776704);j=v[a+64>>2];g=Yb(g,-16777216,16776704);s=v[a+72>>2];u=v[c>>2];f=Hma(j,j>>31,f,f>>31);j=mb;k=f;f=v[a+68>>2];l=Hma(f,f>>31,g,g>>31);f=k+l|0;g=mb+j|0;g=f>>>0<l>>>0?g+1|0:g;k=f;f=((B(p-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=f;i=Hma(q,r,e,e>>31);e=k+i|0;g=mb+g|0;g=e>>>0<i>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;v[c>>2]=B(e,n)+u;v[c+4>>2]=v[c+4>>2]+B(e,m);e=g-(f&s)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];f=v[h+12>>2];g=b;b=e;continue}break}i=v[h+8>>2];f=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function D6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[b>>2];b=jb-32|0;jb=b;v[114578]=0;g=Q(15,b+24|0,a|0)|0;d=v[114578];v[114578]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[g|0]){break e}Bc(b+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;d=T(2393,b+16|0)|0;e=v[114578];v[114578]=0;f:{g:{if((e|0)!=1){Ob(b+16|0);e=Rk(b+8|0,a);f=v[v[a>>2]-12>>2];v[114578]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}e=v[e>>2];v[114578]=0;c=ea(2394,d|0,e|0,f|0,h|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Pk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+c|0,5);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Hf(g);break d}Hf(g);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=b+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{g=A[b>>3];b=jb-32|0;jb=b;v[114578]=0;f=Q(15,b+24|0,a|0)|0;c=v[114578];v[114578]=0;b:{c:{d:{if((c|0)!=1){e:{if(!w[f|0]){break e}Bc(b+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;c=T(2393,b+16|0)|0;d=v[114578];v[114578]=0;f:{g:{if((d|0)!=1){Ob(b+16|0);d=Rk(b+8|0,a);e=v[v[a>>2]-12>>2];v[114578]=0;e=a+e|0;h=T(16,e|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}d=v[d>>2];v[114578]=0;c=Ya(2397,c|0,d|0,e|0,h|0,+g)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Pk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+c|0,5);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Hf(f);break d}Hf(f);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=b+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=jb-16|0;jb=h;g=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=(f<<1)+o|0;p=u[e+2>>1];e=u[e>>1];f=v[a+60>>2];q=f;r=f>>31;f=Yb(b,-16777216,16776704);j=v[a+64>>2];g=Yb(g,-16777216,16776704);s=v[a+72>>2];t=v[c>>2];f=Hma(j,j>>31,f,f>>31);j=mb;k=f;f=v[a+68>>2];l=Hma(f,f>>31,g,g>>31);f=k+l|0;g=mb+j|0;g=f>>>0<l>>>0?g+1|0:g;k=f;f=e+((B(p-e|0,i>>>18|0)|0)/16384|0)<<8;e=f;i=Hma(q,r,e,e>>31);e=k+i|0;g=mb+g|0;g=e>>>0<i>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;v[c>>2]=B(e,n)+t;v[c+4>>2]=v[c+4>>2]+B(e,m);e=g-(f&s)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];f=v[h+12>>2];g=b;b=e;continue}break}i=v[h+8>>2];f=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function jY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=h>>>0|a>>>0>=d>>>0){break a}f=t[a|0];b=f&255;b:{if((f|0)>=0){if(b>>>0>1114111){break a}a=a+1|0;break b}if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=w[a+1|0];if((f&192)!=128|(f&63|b<<6&1984)>>>0>1114111){break a}a=a+2|0;break b}c:{d:{if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];if((b|0)==237){break d}if((b|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>244){break a}g=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(g&192)!=128|(g&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break a}a=a+4|0;break b}if((f&224)!=128){break a}}if((g&192)!=128|(g&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break a}a=a+3|0}h=h+1|0;continue}break}return a-c|0}function qM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;h=B(b,896)+a|0;a:{if(c){Eb(e+8|0,a+1074312|0,90);if(!Cb(e+8|0)){t[(B(b,896)+a|0)+1075816|0]=c}t[(B(b,896)+a|0)+1075815|0]=c;break a}c=w[h+1075815|0]}f=h+1074984|0;g=c&255;i=d?i:!(v[a+480180>>2]&204473357);jM(a,b,g,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}h=v[(B(b,896)+a|0)+1075640>>2];if(!h|!v[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){iM(a,f,g-240|0);break b}if(!(b>>>0<224|d)){hM(f,g-224|0);break b}gM(f,g);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=1}if((c&255)>>>0>223&i){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}fM(a,f,d);break b}if(v[a+480180>>2]==524288){break d}kM(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){Eb(e+8|0,a+1074312|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}eM(a,f,0-(g<<2)|0)}jb=e+16|0}function mG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;v[d+8>>2]=1;v[d+12>>2]=0;a:{h=b<<2;if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(g+4|0)+b|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}b:{f=(a+h|0)-4|0;if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e|0)==3){mw(a,c,b,d+16|0);yr(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){xr(a,c,d+8|0,b,0,d+16|0);break d}mw(a,c,b,d+16|0)}if((b|0)==1){wr(d+8|0,1);b=0;break c}wr(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0<=a>>>0){break b}e=e&3;continue}}xr(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(e|0)!=1)){if(v[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=lG(d+8|0);yr(d+8|0,f);e=v[d+8>>2];b=b+f|0;break e}wr(d+8|0,2);v[d+8>>2]=v[d+8>>2]^7;yr(d+8|0,1);g=a-4|0;f=b-2|0;xr(g-v[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b-1|0,1,d+16|0);wr(d+8|0,1);e=v[d+8>>2]|1;v[d+8>>2]=e;xr(g,c,d+8|0,f,1,d+16|0);b=f}a=a-4|0;continue}}jb=d+208|0}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-32|0;jb=f;g=jb-16|0;jb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;LK(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);LK(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=dd(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;e=1;h=w[d+31|0];a:{if(h>>>0>=1){e=16;if(h>>>0<=16){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[lf(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];jb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=dd(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Tl(f,3,a+4|0);Ic(f+16|0,f);v[114578]=0;Q(371,b+492|0,f+16|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){yb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}jb=f+32|0;return}a=P()|0;O()|0;yb(f+16|0);S(a|0);L()}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;Ed(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[lf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[lf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+31850|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}jb=e+16|0}function cj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;Bc(i+8|0,d);v[114578]=0;j=T(2457,i+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Ob(i+8|0);v[e>>2]=0;c=1;a:{while(1){if(!(c&1)|(g|0)==(h|0)){break a}b:{if(_j(i+24|0,i+16|0)){break b}c:{if((vm(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}k=0;b=vm(j,v[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=vm(j,v[g+8>>2])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if($j(j,8192,v[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if($j(j,8192,v[g>>2])){continue}}break}while(1){if(!kr(i+24|0,i+16|0)){break c}if(!$j(j,8192,fl(i+24|0))){break c}Cm(i+24|0);continue}}if((Lk(j,fl(i+24|0))|0)==(Lk(j,v[g>>2])|0)){g=g+4|0;Cm(i+24|0);break c}v[e>>2]=4}c=!v[e>>2];continue}break}v[e>>2]=4}if(_j(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Ob(i+8|0);S(a|0);L()}function fI(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){v[114578]=0;b=c;T(1405,b|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;vf(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=zb(f);v[114578]=0;d=d-4|0;R(1441,e|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[f+4>>2]=g;Re(zb(a),v[a>>2],yd(a))}Xb(c)}v[b+4>>2]=0;Wx(b+1304500|0);rs(b+1304436|0);yb(b+1304424|0);yb(b+1304412|0);yb(b+1304400|0);qs(b+1304396|0);ps(b+1304392|0);$o(b+1304360|0);a=b+946300|0;c=b+906300|0;while(1){a=an(a-160|0);if((c|0)!=(a|0)){continue}break}Rs(b+484360|0);Vx(b+484344|0);oe(b+480248|0);break a}V(0)|0;O()|0;Wx(b+1304500|0);rs(b+1304436|0);yb(b+1304424|0);yb(b+1304412|0);yb(b+1304400|0);qs(b+1304396|0);ps(b+1304392|0);$o(b+1304360|0);a=b+946300|0;c=b+906300|0;while(1){a=an(a-160|0);if((c|0)!=(a|0)){continue}break}Rs(b+484360|0);Vx(b+484344|0);oe(b+480248|0);Ab();L()}Xb(b)}}}function Mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-80|0;jb=d;c=v[a+28>>2];Dn(v[v[c>>2]-12>>2]+c|0,0);if(!xd(a,4)){gv(a)}a:{if(!v[a+4>>2]){break a}if(xd(a,6)){break a}if(xd(a,7)){break a}g=v[a+28>>2];h=v[a+84>>2];f=B(v[a+20>>2],v[a+4>>2]);e=f+v[a+80>>2]|0;e=Og(d- -64|0,e,e>>>0<f>>>0?h+1|0:h);f=v[e+12>>2];v[d+24>>2]=v[e+8>>2];v[d+28>>2]=f;c=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=c;ej(g,d+16|0)}c=0;b:{if(!xd(a,5)){break b}h=0;i=a+44|0;e=nd(i);c=0;if(!e){break b}g=a+32|0;while(1){c:{j=(v[a+96>>2]+h>>>0)%(e>>>0)|0;if(y[tc(i,j)>>2]>=xc(g)>>>0){break c}f=nm(d+48|0,wc(g,v[tc(i,j)>>2]),x[tc(i,j)+12>>1]);c=iv(b,f);Ib(f);if(!c){break c}v[a+96>>2]=(j+1>>>0)%(e>>>0);if(v[tc(i,j)+4>>2]){f=v[a+28>>2];c=v[a+12>>2];b=v[a+8>>2];a=v[tc(i,j)+4>>2];g=b+a|0;c=Og(d+32|0,g,a>>>0>g>>>0?c+1|0:c);a=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=a;a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;ej(f,d)}c=tc(i,j);break b}h=h+1|0;if((e|0)!=(h|0)){continue}break}c=0}jb=d+80|0;return c}function Eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;i=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}j=v[a+24>>2];k=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;if(d){while(1){g=0;v[e+40>>2]=h;v[e+44>>2]=l;h=b+i|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){Ad(v[f+8>>2],t[h+g|0]<<6);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,t[h+v[e+44>>2]|0]<<6);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function dj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;Bc(i+8|0,d);v[114578]=0;j=T(21,i+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Ob(i+8|0);v[e>>2]=0;c=1;a:{while(1){if(!(c&1)|(g|0)==(h|0)){break a}b:{if(gj(i+24|0,i+16|0)){break b}c:{if((wm(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}k=0;b=wm(j,t[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=wm(j,t[g+2|0])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(Kg(j,8192,t[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Kg(j,8192,t[g|0])){continue}}break}while(1){if(!to(i+24|0,i+16|0)){break c}if(!Kg(j,8192,bk(i+24|0))){break c}hl(i+24|0);continue}}if((Jv(j,bk(i+24|0))|0)==(Jv(j,t[g|0])|0)){g=g+1|0;hl(i+24|0);break c}v[e>>2]=4}c=!v[e>>2];continue}break}v[e>>2]=4}if(gj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Ob(i+8|0);S(a|0);L()}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;An(b,f+44|0);a:{if(!yO(f+44|0)){break a}c=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(d,6)+18424|0)+(e<<1)>>1]<<g;e=B(B(w[e+(B(d,3)+18201|0)|0],x[((B(d,90)+18208|0)+B(e,30)|0)+(c>>>3&30)>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+18400|0)+(c&6)>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[g+((d<<1)+18436|0)|0];if(e+8>>>0>(c&65535)>>>0){break a}d=f;c=jb-16|0;jb=c;v[c+12>>2]=e+4;v[c>>2]=36;g=v[Lb(c+12|0,c)>>2];if(!Qb(b,g)){g=nf(b)}tq(c,d);xg(b,v[c>>2],g);tq(c,d);Rb(v[c>>2]+g|0,0,36-g|0);$b(b,v[c+12>>2]);jb=c+16|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+f|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){d=1}else{d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=d}jb=f+48|0;return a|0}function Wy(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?42:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=33;return;case 27:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-32|0;jb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;jb=f+32|0}function Uv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;v[114578]=0;g=Q(15,c+24|0,a|0)|0;d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)!=1){d:{if(!w[g|0]){break d}Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;d=T(2393,c+16|0)|0;e=v[114578];v[114578]=0;e:{f:{if((e|0)!=1){Ob(c+16|0);e=Rk(c+8|0,a);f=v[v[a>>2]-12>>2];v[114578]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break f}e=v[e>>2];v[114578]=0;b=ea(2395,d|0,e|0,f|0,h|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}v[c+16>>2]=b;if(!Pk(c+16|0)){break d}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,5);b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0);break e}b=V(0)|0;O()|0}Hf(g);break c}Hf(g);break b}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=c+32|0;return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;jb=f+16|0}function lY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if((b&-2048)==55296|b>>>0>1114111){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<1){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return c|0}function wj(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=42;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function cV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-80|0;jb=d;Jc(b);Fq(a);a:{if(!Gu(b,d+40|0)){break a}if(!nC(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(!Qb(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-28|0)){break a}bv(a);av(d+24|0);$u(Tg(a)+28|0,d+24|0);Eq(d+24|0);e=v[Tg(a)+28>>2];v[114578]=0;f=T(352,b|0)|0;b=v[114578];v[114578]=0;c:{if((b|0)==1){break c}c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);v[114578]=0;c=aa(353,f|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-28|0,e|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}f=0;if(!c){break a}Wi(d+8|0,e);Xu(d+16|0,d+8|0);b=fo(d+24|0,d+16|0,0);Wd(Tg(a)+12|0,b);Bb(b);break b}b=Ca(71204,77224)|0;a=O()|0;d:{if((ga(71204)|0)==(a|0)){break d}if((ga(77224)|0)==(a|0)){break d}S(b|0);L()}_(b|0)|0;$();f=0;break a}f=1}jb=d+80|0;return f|0}function jV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-48|0;jb=b;c=-1;a:{if(!sC(a,b+8|0)){break a}c=0;if(!MK(b+8|0)){break a}d=b+8|0;i=$e(11555);if(i){m=v[a+12>>2];if(xk(a,w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24))){b:{if(!(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))){break b}n=i?0:-1;while(1){if(!Df(a,4)){break b}c:{if((w[d+4|0]|w[d+5|0]<<8)>>>0>=64){c=a;g=$p(a);e=g&63;d:{if(!(g&64)){break d}f=6;while(1){h=$p(c);e=(h&127)<<f|e;if(!(h&128)){break d}h=f>>>0<25;f=f+7|0;if(h){continue}break}}if(((g&128?0-e|0:e)|0)<1){break c}}f=$p(a);e:{if(f){g=1;e=0;while(1){h=Io(f<<24>>24);j=e>>>0>=i>>>0;f=j&g;c=f;f:{if(j){break f}c=f;if(!(g&1)){break f}c=w[e+11555|0]==(h&255)}g=c;e=e+1|0;f=$p(a);if(f){continue}break}c=(e|0)==(i|0)&g;break e}c=n}Xc(a,4);k=c&1?1:k}l=l+1|0;if(l>>>0<(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))>>>0){continue}break}}e=k&1}xk(a,m)}c=e}a=c;jb=b+48|0;return a|0}function LG(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];a:{b:{c:{b=v[a+1380>>2];d:{if((b|0)==-1){h=1;b=-1;break d}d=v[a+1116>>2];e:{if((d|0)<=(b|0)){break e}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break e}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){break c}b=(b|0)==(d|0)?-1:b}while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){dc(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[84480]|w[84481]<<8|(w[84482]<<16|w[84483]<<24))){dc(a,21);break a}if(w[c+4|0]){dc(a,21);break a}f:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break f}dc(a,21);break a}if(t[c+5|0]&1){break f}dc(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break b}h=0;b=0;f=0;g:{if(!e){break g}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break g}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}dc(a,1);break a}dc(a,1);break a}dc(a,1)}return 0}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;jb=f+16|0}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);c=0;while(1){if((l|0)>=1){i=(k<<1)+b|0;m=i+(l<<1)|0;while(1){n=c;u[e+6>>1]=0;EQ(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{h=w[e+15|0];if(!h){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;g=(f&65534)>>>0>255;t[e+14|0]=g;f=e;if(!c){if(!Je(a,e+5|0)){break b}g=w[e+5|0];c=g<<1&254|1;u[e+12>>1]=c;g=g>>>7|0}j=x[e+6>>1]<<1|g;u[f+6>>1]=j;h=h-1|0;if(h&255){continue}break}break a}j=x[e+6>>1]}c=1;g=j&65535;c:{if(g>>>0<4){break c}h=15;while(1){c=h;f=c&255;if(g>>>f&1){break c}h=c-1|0;if(f>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;f=c-1^(j&65534)>>>1;c=f+x[e+8>>1]|0;u[e+6>>1]=c;u[i>>1]=c;v[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);ce(e+8|0,-32768,32767);i=(d<<1)+i|0;if(m>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function mR(a){var b=0,c=0,d=0,e=0;b=jb-48|0;jb=b;c=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+8>>2]=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+788;v[b+12>>2]=0;c=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+16>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);v[b+20>>2]=0;c=b;e=b;if(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24)){d=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}else{d=52}v[e+24>>2]=d;v[c+28>>2]=0;c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+44>>2]=4;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;v[b+32>>2]=(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+80;v[b+36>>2]=0;c=jb-16|0;jb=c;a=v[b>>2];d=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(d|0)){break a}e=a+8|0;if((d|0)==(e|0)){break a}while(1){a=ru(a,e)?e:a;e=e+8|0;if((d|0)!=(e|0)){continue}break}}jb=c+16|0;jb=b+48|0;b=v[a>>2];c=b-52|0;mb=v[a+4>>2]-(b>>>0<52)|0;return c}function kO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=Hy(a+48|0);e=Hy(a+68|0);f=Hy(a+88|0);v[114578]=0;T(1163,a+492|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;T(1163,a+524|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;U(910,a|0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;U(911,a|0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[114578]=0;R(779,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=fc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;un(f);un(e);un(d);S(a|0);L()}function dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;e=a;c=jb-16|0;jb=c;z[c+8>>2]=2;u[c+14>>1]=12;v[c+4>>2]=15;d=Pe(64);v[114578]=0;g=T(1429,d|0)|0;h=v[114578];v[114578]=0;a:{b:{c:{if((h|0)!=1){d=Rx(c,g);g=v[d>>2];v[114578]=0;R(1430,g|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=v[d>>2];v[114578]=0;b=W(1431,b|0,c+14|0,c+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}d:{if(!b){Qx(e);break d}b=v[d>>2];v[114578]=0;R(1432,b|0,c+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Gp(e,d)}bg(d);jb=c+16|0;break a}a=P()|0;O()|0;Xb(d);break b}a=P()|0;O()|0;bg(d)}S(a|0);L()}b=0;e:{f:{g:{while(1){c=v[a>>2];v[114578]=0;u[f+14>>1]=b;e=Q(2,f|0,(b<<2)+20768|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;U(1428,c|0,f+14|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}yb(e);b=b+1|0;if((b|0)!=12){continue}break}jb=f+16|0;return}b=P()|0;O()|0;break e}b=P()|0;O()|0;yb(e)}bg(a);S(b|0);L()}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-16|0;jb=f;v[f+12>>2]=b;a:{if(th(a)>>>0>=b>>>0){n=f,o=xe(a),v[n+8>>2]=o;b=v[a>>2];d=c;l=v[Lb(f+12|0,f+8|0)>>2];if(l){while(1){g=d;if((d|0)!=(b|0)){i=bc(g);j=cc(g);h=jb-16|0;jb=h;k=nA(i,j);e=b;b:{if(k>>>0<=Vf(e)>>>0){v[h+8>>2]=j;if(oc(e)>>>0<k>>>0){v[h+8>>2]=i;m=oc(e);v[h+8>>2]=v[h+8>>2]+(m<<1);xj(i,v[h+8>>2],v[e>>2]);ZN(e,v[h+8>>2],j,k-oc(e)|0);break b}Pn(e,xj(i,j,v[e>>2]));break b}YN(e);gz(e,Ri(e,k));ZN(e,i,j,k)}jb=h+16|0;Xi(b+12|0,g+12|0);u[b+28>>1]=x[g+28>>1]}b=b+32|0;l=l-1|0;if(l){continue}break}}b=v[f+12>>2];d=v[f+8>>2];if(b>>>0>d>>>0){Cy(a,b-d|0,c);break a}TN(a,v[a>>2]+(b<<5)|0);break a}d=a;if(v[d>>2]){xe(d);NN(d);Wu(d);sh(zb(d),v[d>>2],th(d));n=zb(d),o=0,v[n>>2]=o;v[d>>2]=0;v[d+4>>2]=0}e=em(a,b);if(GC(a)>>>0<e>>>0){ed();L()}g=LN(zb(d),e);v[d>>2]=g;v[d+4>>2]=g;n=zb(d),o=g+(e<<5)|0,v[n>>2]=o;Aq(d,0);Cy(a,b,c)}jb=f+16|0}function Tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;jb=f+32|0}function kJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=jb-32|0;jb=b;d=v[a+20>>2];a:{if(!d){break a}if(xc(d+4|0)>>>0<4){break a}Wi(b+8|0,v[a+20>>2]+4|0);c=jb-16|0;jb=c;WJ(c+8|0,ac(c,b+8|0));d=b+16|0;Uu(d,c+8|0);v[d+12>>2]=0;v[d+8>>2]=0;jb=c+16|0;v[114578]=0;c=T(392,d|0)|0;f=v[114578];v[114578]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[114578]=0;c=T(c|0,a|0)|0;f=v[114578];v[114578]=0;c:{if((f|0)==1){break c}if(xc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+168>>2];f=0;v[114578]=0;R(e|0,a|0,-1);e=v[114578];v[114578]=0;if((e|0)==1){break c}if(c){while(1){v[114578]=0;g=C(Aa(701,d|0));e=v[114578];v[114578]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[114578]=0;ya(e|0,a|0,f|0,C(g));e=v[114578];v[114578]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+172>>2];v[114578]=0;Z(c|0,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;Bb(d);S(a|0);L()}Bb(d)}jb=b+32|0}function $8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=0,y=C(0);if(v[a+4220>>2]){f=a+44|0;i=Pd(f,0);j=Pd(f,1);k=id(f,0);l=id(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];w=h;e=e-v[a+4228>>2]|0;if((e|0)<=-1){e=e+v[a+4220>>2]|0}e=e<<1;p=z[Pb(w,e)>>2];e=Pb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));x=Pb(h,v[a+4224>>2]<<1),y=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[x>>2]=y;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));x=Pb(h,v[a+4224>>2]<<1|1),y=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[x>>2]=y;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}oi(a,b,c,id(f,0),id(f,1),d)}}function ej(a,b){var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;d=v[(v[v[a>>2]-12>>2]+a|0)+16>>2]&-3;Dn(v[v[a>>2]-12>>2]+a|0,d);a:{b:{if(w[hj(c+56|0,a,1)|0]){e=v[v[a>>2]-12>>2];v[114578]=0;e=v[(a+e|0)+24>>2];f=v[114578];v[114578]=0;c:{d:{if((f|0)==1){break d}v[114578]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;X(2388,c+40|0,e|0,c+8|0,8);b=v[114578];v[114578]=0;if((b|0)==1){break d}b=Og(c+24|0,-1,-1);v[114578]=0;b=OS(c+40|0,b);e=v[114578];v[114578]=0;if((e|0)==1){break d}b=b?d|4:d;break c}b=V(0)|0;O()|0;_(b|0)|0;b=d|1;fj(v[v[a>>2]-12>>2]+a|0,b);d=v[v[a>>2]-12>>2];v[114578]=0;d=v[(a+d|0)+20>>2];e=v[114578];v[114578]=0;e:{if((e|0)!=1){if(!(d&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,b)}jb=c- -64|0;return}V(0)|0;O()|0;Ab()}L()}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-16|0;jb=h;f=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];b=v[a+44>>2];p=v[a+16>>2];i=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=i;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){j=u[(i<<1)+p>>1];g=v[a+60>>2];k=g;e=Yb(b,-16777216,16776704);m=v[a+64>>2];i=Yb(f,-16777216,16776704);q=v[a+72>>2];f=v[c>>2];l=g>>31;j=j<<8;g=j;g=Hma(k,l,g,g>>31);k=mb;l=c;r=f;f=g;g=Hma(m,m>>31,e,e>>31);e=f+g|0;f=mb+k|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=v[a+68>>2];i=Hma(e,e>>31,i,i>>31);e=g+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[l>>2]=r+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=f-(j&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+12>>2];f=b;b=e;continue}break}j=v[h+8>>2];i=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=i;jb=h+16|0}function Bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;v[f>>2]=c;v[f+8>>2]=b;if(Jb(f+8|0,f)){while(1){b=d;g=jb-16|0;jb=g;c=v[f+8>>2];if(!(w[c+3|0]!=4|w[c+5|0])){ee(g+8|0,b,x[b+14>>1]);ge(g+8|0,0);t[c+3|0]=0}e=w[c+2|0];a:{if((e|0)!=11){break a}e=11;if(w[c+4|0]){break a}ee(g+8|0,b,x[b+14>>1]);e=0;ge(g+8|0,0);t[c+2|0]=0}b:{c:{d:{if(!w[c|0]){ee(g+8|0,b,x[b+14>>1]);if(Cb(g+8|0)){break d}e=w[c+2|0]}h=w[c+3|0];ee(g+8|0,b,x[b+14>>1]);ge(g+8|0,(h|0)==4|(e|0)==11);e=w[c+3|0];break c}e=w[c+3|0];h=w[c+2|0];if(!(e|(h|0)==11)){t[c+5|0]=0;t[c+3|0]=4;break b}if(h|(e|0)==4){break c}t[c+4|0]=0;t[c+2|0]=11}e:{if(!(!w[b+16|0]|e)){t[c+5|0]=125;t[c+3|0]=17;break e}f:{switch(e-16|0){case 1:break e;case 0:break f;default:break b}}if(w[c+5|0]){break b}t[c+5|0]=6;t[b+16|0]=1;break b}t[b+16|0]=0}u[b+14>>1]=(x[b+14>>1]+1>>>0)%x[b+12>>1];jb=g+16|0;Dj(f+8|0);if(Jb(f+8|0,f)){continue}break}}MO(a,d);jb=f+16|0}function mF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-32|0;jb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;qf(h+16|0,a,b,g,e,f-16129|0);Gm(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}jb=h+32|0;return l(2,d&-2147483648|e),q()}function Lw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];g=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=g;g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;Eh(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];j=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;k=c+16|0;a=c;d=jb-16|0;jb=d;if(g){l=b+4|0;while(1){e=0;if(j){while(1){f=A[ch(a,e,h)>>3];fc(b,e);m=d,n=+(tj(Sd(f*134217728))-1024+((Ir(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,A[m+8>>3]=n;Rf(d+8|0,-1,1);f=A[d+8>>3]*32768;A[d+8>>3]=f;f=Sd(f);a:{if(D(f)<2147483648){i=~~f;break a}i=-2147483648}i=Vc(i);m=Nm(k,e,h),o=i,u[m>>1]=o;e=e+1|0;if((j|0)!=(e|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=d+16|0;jb=c+80|0}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-16|0;jb=h;f=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];b=v[a+44>>2];p=v[a+16>>2];i=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=i;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){j=t[i+p|0];g=v[a+60>>2];k=g;e=Yb(b,-16777216,16776704);m=v[a+64>>2];i=Yb(f,-16777216,16776704);q=v[a+72>>2];f=v[c>>2];l=g>>31;j=j<<16;g=j;g=Hma(k,l,g,g>>31);k=mb;l=c;r=f;f=g;g=Hma(m,m>>31,e,e>>31);e=f+g|0;f=mb+k|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=v[a+68>>2];i=Hma(e,e>>31,i,i>>31);e=g+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[l>>2]=r+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=f-(j&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+12>>2];f=b;b=e;continue}break}j=v[h+8>>2];i=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=i;jb=h+16|0}function vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-80|0;jb=d;Le(b);a:{b:{if(Qb(a,1)){c:{d:{e:{f:{g:{h:{while(1){v[114578]=0;e=W(602,a|0,d+16|0,64)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[d+8>>2]=e;e=Fb(b);v[114578]=0;v[d+4>>2]=c-e;e=Q(33,d+8|0,d+4|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}e=v[e>>2];if(!e){break c}t[d+8|0]=0;f=e+(d+16|0)|0;e=Tm(d+16|0,f,d+8|0);h=d,i=sf(b),v[h+8>>2]=i;Md(d,d+8|0);v[114578]=0;aa(603,b|0,v[d>>2],d+16|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}v[114578]=0;Q(340,a|0,e-(d+16|0)|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}if(e>>>0>=f>>>0){continue}break}v[114578]=0;Q(340,a|0,1)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break c}a=V(71204)|0;break d}a=V(71204)|0;break d}a=V(71204)|0;break d}a=V(71204)|0;break d}a=V(71204)|0}if((O()|0)!=(ga(71204)|0)){break b}_(a|0)|0;$()}e=(Fb(b)|0)!=0}jb=d+80|0;break a}S(a|0);L()}return e|0}function LK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;t[k+15|0]=c;t[k+14|0]=12;gg(b,w[pc(k+15|0,k+14|0)|0]);if(Kb(b)){c=0;l=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(h|0){case 0:i=c<<2;j=i+l|0;j=w[j|0]|w[j+1|0]<<8;n=Pb(b,c),o=j,u[n>>1]=o;i=(i|2)+l|0;break b;case 1:break c;default:break a}}i=c<<2;j=i+a|0;j=w[j|0]|w[j+1|0]<<8;n=Pb(b,c),o=j,u[n>>1]=o;i=a+(i|2)|0}i=w[i|0];n=Pb(b,c),o=i,t[n+2|0]=o}d:{if(!c){break d}i=c-1|0;if(x[Pb(b,c)>>1]>=x[Pb(b,i)>>1]){break d}if(x[Pb(b,c)>>1]>255){break d}j=w[Pb(b,i)+1|0];m=Pb(b,c);u[m>>1]=x[m>>1]|j<<8;if(x[Pb(b,c)>>1]>=x[Pb(b,i)>>1]){break d}i=Pb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Kb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(md(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}jb=k+16|0}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=4;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);m=(l|0)<1;c=0;while(1){if(!m){i=b+k|0;n=l+i|0;while(1){o=c;t[e+7|0]=0;DQ(a,e+14|0,e+12|0,e+7|0);a:{b:{h=w[e+15|0];if(!h){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;g=(f&65534)>>>0>255;t[e+14|0]=g;f=e;if(!c){if(!Je(a,e+6|0)){break b}g=w[e+6|0];c=g<<1&254|1;u[e+12>>1]=c;g=g>>>7|0}j=w[e+7|0]<<1|g;t[f+7|0]=j;h=h-1|0;if(h&255){continue}break}break a}j=w[e+7|0]}c=1;g=j&255;c:{if(g>>>0<4){break c}h=7;while(1){c=h;f=c&255;if(g>>>f&1){break c}h=c-1|0;if(f>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;f=c-1^(j&254)>>>1;c=f+w[e+8|0]|0;t[e+7|0]=c;t[i|0]=c;v[e+8>>2]=((f>>1)-(o<<24>>24)|0)+(c<<24>>24<<1);ce(e+8|0,-128,127);i=d+i|0;if(n>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;k=c;e=jb-32|0;jb=e;j=b;f=b;b=Ke(b);d=hc(f);a:{b:{if(b){c:{while(1){d:{g=b+14|0;e:{if(Xn(zb(f),c,g)){if(!v[b>>2]){break b}d=b;break e}if(!Xn(zb(f),g,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=hc(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){f=jb-16|0;jb=f;g=hc(j);b=sc(16,4);i=Ak(f+8|0,g);d=jb-16|0;jb=d;v[d+12>>2]=b;v[114578]=0;b=e+8|0;W(1169,b|0,d+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=d+16|0;break f}V(0)|0;O()|0;Ab();L()}d=v[b>>2]+14|0;v[114578]=0;U(1168,g|0,d|0,k|0);d=v[114578];v[114578]=0;g:{if((d|0)!=1){l=hc(b),m=1,t[l+4|0]=m;jb=f+16|0;break g}a=P()|0;O()|0;fO(b);S(a|0);L()}Bk(j,v[e+28>>2],c,v[e+8>>2]);b=Nd(e+8|0);t[e+27|0]=1;fO(e+8|0)}Ei(h+8|0,Oc(e+8|0,b),e+27|0);jb=e+32|0;gO(a,h+8|0);jb=h+16|0}function WH(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=jb-80|0;jb=e;g=a+24|0;So(v[g>>2]);t[v[g>>2]+1304512|0]=v[a+52>>2]!=0;c=me(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;h=e+48|0;c=h;Lr(c);v[c+8>>2]=f;v[c+4>>2]=0;v[c>>2]=84056;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=84008;jb=d+16|0;a:{b:{if(b){c=0;while(1){d=v[g>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114578]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;f=Q(2154,e+24|0,e+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}f=v[f>>2];v[114578]=0;d=W(2155,d|0,f|0,h|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}c=c+d|0;if(d){b=b-d|0;if(b){continue}}break}if(c){break b}}c=0;if(v[a+52>>2]!=1){break b}a=v[g>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=e+80|0;return c}a=P()|0;O()|0;S(a|0);L()}function VH(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=jb-80|0;jb=e;g=a+24|0;So(v[g>>2]);t[v[g>>2]+1304512|0]=v[a+52>>2]!=0;c=me(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;h=e+48|0;c=h;Lr(c);v[c+8>>2]=f;v[c+4>>2]=0;v[c>>2]=84128;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=84080;jb=d+16|0;a:{b:{if(b){c=0;while(1){d=v[g>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114578]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;f=Q(2154,e+24|0,e+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}f=v[f>>2];v[114578]=0;d=W(2155,d|0,f|0,h|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}c=c+d|0;if(d){b=b-d|0;if(b){continue}}break}if(c){break b}}c=0;if(v[a+52>>2]!=1){break b}a=v[g>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=e+80|0;return c}a=P()|0;O()|0;S(a|0);L()}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;k=c;e=jb-32|0;jb=e;j=b;f=b;b=Ke(b);d=hc(f);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(PK(zb(f),c,g)){if(!v[b>>2]){break b}d=b;break e}if(!PK(zb(f),g,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=hc(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){f=jb-16|0;jb=f;g=hc(j);b=sc(28,4);i=Ak(f+8|0,g);d=jb-16|0;jb=d;v[d+12>>2]=b;v[114578]=0;b=e+8|0;W(1529,b|0,d+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=d+16|0;break f}V(0)|0;O()|0;Ab();L()}d=v[b>>2]+16|0;v[114578]=0;U(1528,g|0,d|0,k|0);d=v[114578];v[114578]=0;g:{if((d|0)!=1){l=hc(b),m=1,t[l+4|0]=m;jb=f+16|0;break g}a=P()|0;O()|0;OK(b);S(a|0);L()}Bk(j,v[e+28>>2],c,v[e+8>>2]);b=Nd(e+8|0);t[e+27|0]=1;OK(e+8|0)}Ei(h+8|0,Oc(e+8|0,b),e+27|0);jb=e+32|0;gO(a,h+8|0);jb=h+16|0}function OO(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+17520|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&240)!=32?(d&15)!=2:0)){t[a|0]=20;t[b|0]=159;d=159}if((d&15)!=12&(d&240)!=192|c>>>0<51){break b}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:d:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break d;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function _J(a,b,c){var d=0;a:{b:{switch(b|0){case 0:KJ(a,c);return;case 1:b=0;a=tf(a);d=Fb(c);v[114578]=0;R(113,a|0,d|0);d=v[114578];v[114578]=0;c:{if((d|0)!=1){d:{if(Fb(c)){while(1){d=t[kc(c,b)|0];e:{if((d|0)>=0){v[114578]=0;R(112,a|0,d&255);d=v[114578];v[114578]=0;if((d|0)!=1){break e}break d}v[114578]=0;R(112,a|0,65533);d=v[114578];v[114578]=0;if((d|0)==1){break d}}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=tf(a);d=Fb(c);v[114578]=0;R(113,a|0,d|0);d=v[114578];v[114578]=0;f:{if((d|0)!=1){g:{if(Fb(c)){while(1){d=w[kc(c,b)|0];v[114578]=0;R(112,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break f}}break a}return;case 3:Jo(a,c,1520);return;case 4:Jo(a,c,2544);return;case 5:Jo(a,c,3568);return;case 6:Jo(a,c,4592);return;case 7:Jo(a,c,5616);return;default:break b}}tf(a);return}b=P()|0;O()|0;Lc(a);S(b|0);L()}function b4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;hI(c+24|0);fI(a+24|0,Nd(c+24|0));Gh(c+24|0);u[a+28>>1]=0;e=c+24|0;f=UL();d=Pe(44);v[114578]=0;f=Q(2136,d|0,f|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){d=jb-16|0;jb=d;v[114578]=0;v[d+12>>2]=f;W(2140,e|0,d+12|0,d+8|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;Xb(d);S(a|0);L()}Fs(a+32|0,c+24|0);wf(c+24|0);gI(c+24|0,v[a>>2]);sI(a+4|0,Nd(c+24|0));Yc(c+24|0);Pm(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;h=c,i=vn(b),v[h+24>>2]=i;h=c,i=Hi(b),v[h+16>>2]=i;b:{if(Gi(c+24|0,c+16|0)){while(1){d=jh(c+24|0);b=Af(c,d);v[114578]=0;X(2082,a|0,b|0,d+12|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(b);Bp(c+24|0);if(Gi(c+24|0,c+16|0)){continue}break}}jb=c+32|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function S4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114578]=0;Z(2089,a|0);e=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[114578]=0;Z(2042,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=0;v[114578]=0;Z(2090,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!w[b|0]){break b}if(ii(b,37350)|(d|0)!=8){break d}v[a+4>>2]=2091;v[a>>2]=2092;break c}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37374,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();return 0}if(ii(b,37362)|(d|0)!=64){break b}v[a+60>>2]=2093;v[a+56>>2]=2094;v[a+52>>2]=2095;v[a+48>>2]=2096;v[a+44>>2]=2097;v[a+40>>2]=2098;v[a+36>>2]=2099;v[a+32>>2]=2100;v[a+28>>2]=2101;v[a+24>>2]=2102;v[a+20>>2]=2103;v[a+16>>2]=2104;v[a+12>>2]=2105;v[a+8>>2]=2106;v[a+4>>2]=2107;v[a>>2]=2108}e=1}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function o2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f>>2]=c;v[f+8>>2]=b;Cq(v[f+8>>2]);c=jb-32|0;jb=c;v[c+24>>2]=v[f>>2];b=v[c+24>>2];d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=jb-16|0;jb=e;b=v[c+20>>2];v[e+8>>2]=v[c+16>>2];v[e+12>>2]=b;b=v[c+12>>2];v[e>>2]=v[c+8>>2];v[e+4>>2]=b;d=UP(e);b=a;Kp(b);t[b+8|0]=0;v[b+4>>2]=d;v[b>>2]=76256;d=Oi(b+12|0);t[b+24|0]=0;v[114578]=0;Q(35,b+28|0,0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){d=b+40|0;g=d+192|0;while(1){v[d>>2]=0;v[d+4>>2]=0;t[d+8|0]=0;d=d+12|0;if((g|0)!=(d|0)){continue}break}if(w[b+24|0]){b=b+232|0;d=0;while(1){h=Ve(b,d),i=d,v[h>>2]=i;d=d+1|0;if((d|0)!=16){continue}break}}break a}a=P()|0;O()|0;Pg(d);S(a|0);L()}v[a>>2]=76372;b=v[c+12>>2];v[a+296>>2]=v[c+8>>2];v[a+300>>2]=b;b=v[c+20>>2];v[a+304>>2]=v[c+16>>2];v[a+308>>2]=b;jb=e+16|0;jb=c+32|0;jb=f+16|0;return a|0}function $F(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[zf(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;b:{while(1){if((d|0)!=(h|0)){f=tr(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(ZF(v[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=tr(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((ur(Cg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}j=a,k=Cg(t[c+23|0]),v[j+48>>2]=k}d=Cg(t[c+23|0]);break a}d=-1}jb=c+32|0;return d}function D7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=C(0),s=C(0),t=C(0),u=0,x=0,y=C(0);f=jb-16|0;jb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!rh(g)){break a}t=z[a+4220>>2];u=f,x=Pd(g,0),v[u+8>>2]=x;u=f,x=Pd(g,1),v[u+12>>2]=x;u=f,x=id(g,0),v[u>>2]=x;u=f,x=id(g,1),v[u+4>>2]=x;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;e=v[a+4244>>2]-v[((n<<2)+a|0)+4248>>2]|0;if((e|0)<=-1){e=v[a+4240>>2]+e|0}o=h<<2;p=o+(f+8|0)|0;q=v[p>>2];v[p>>2]=q+4;l=z[q>>2];r=z[Pb(m,(e<<1)+n|0)>>2];s=C(C(z[a+4224>>2]*r)+C(l*z[a+4260>>2]));u=Pb(m,v[a+4244>>2]<<1|h),y=C(D(s))<C(1.0000000195414814e-24)?C(0):s,z[u>>2]=y;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(r-l)*t);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}oi(a,b,c,id(g,0),id(g,1),d)}jb=f+16|0}function _L(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=b;f=0;a:{if(!b){break a}if(v[a+480180>>2]&20){b=a+1074312|0;Eb(e,b,73);if(Cb(e)){v[e+12>>2]=x[e+12>>1]}if(w[a+480208|0]&16){Eb(e,b,73);b=Cb(e);a=v[e+12>>2];f=v[((a>>>0)%768<<2)+22112>>2]<<6>>>(b?14-((9983-a>>>0)/768|0)&31:((a>>>0)/768|0)+2|0)|0;break a}a=v[e+12>>2];if(!a){v[e+12>>2]=1;a=1}f=229079296/(a>>>0)|0;break a}f=227001280/(b>>>0)|0;if(Lp(a)){break a}f=(b+c<<4)-133808|0;if(v[a+480180>>2]==64){break a}b=v[a+480180>>2];Cc(e+12|0,16777215);if(b&17408){f=hd(Kma(Hma(c?c:8363,0,3506176,0),mb,(v[e+12>>2]<<8)+d|0,0),mb);break a}if(w[a+480208|0]&16){Eb(e,a+1074312|0,7);if(Cb(e)){c=d>>31;b=d;a=v[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=hd(Kma(Hma(c?c:8363,0,7012352,0),mb,(v[e+12>>2]<<8)+d|0,0),mb);break a}f=hd(Kma(-1485242368,13,(v[e+12>>2]<<8)+d|0,0),mb)}jb=e+16|0;return f}function KJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=tf(a);f=d,g=Dd(b),v[f+8>>2]=g;f=d,g=sf(b),v[f>>2]=g;a:{b:{if(!Jb(d+8|0,d)){break b}a=0;b=0;while(1){c=w[v[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;v[114578]=0;R(112,e|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;v[114578]=0;R(112,e|0,65533);c=v[114578];v[114578]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){v[114578]=0;R(112,e|0,65533);a=v[114578];v[114578]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a-1|0;if(a){b=c;break c}b=0;v[114578]=0;R(112,e|0,c|0);c=v[114578];v[114578]=0;a=0;if((c|0)==1){break a}}qg(d+8|0);if(Jb(d+8|0,d)){continue}break}if(!a){break b}v[114578]=0;R(112,e|0,65533);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}jb=d+16|0;return}a=P()|0;O()|0;Lc(e);S(a|0);L()}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=(g>>>21&2040)+27888|0;g=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;jb=e+32|0}function c0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[hj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;d=T(2378,c+16|0)|0;e=v[114578];v[114578]=0;d:{e:{f:{g:{if((e|0)==1){break g}e=Dm(c+8|0,a);f=Ek(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114578]=0;ka(2381,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}Ob(c+16|0);break f}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;fj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];d=v[114578];v[114578]=0;if((d|0)!=1){if(!(b&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function bca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-16|0;jb=h;n=h,o=B(v[a>>2],ue(a)),v[n+12>>2]=o;Cc(h+12|0,c>>>2|0);c=Db(b);i=v[e+4>>2];f=v[h+12>>2];a:{if(!f){g=i;break a}while(1){e=Db(w[c|0]);e=e|Db(w[c+1|0])<<8|Db(w[c+2|0])<<16|Db(w[c+3|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>i>>>0?e:i}c=c+4|0;i=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[h+12>>2];if(!e){break c}k=g-1|0;l=g>>>1|0;i=g;c=v[a+20>>2];while(1){a=Db(w[b|0]);m=c;a=a|Db(w[b+1|0])<<8|Db(w[b+2|0])<<16|Db(w[b+3|0])<<24;j=a>>31;f=a;a=j<<31|a>>>1;f=l|f<<31;d:{if((a|0)>0?1:(a|0)>=0){a=Kma(f,a,i,0);f=mb;break d}j=k;f=Kma(j-f|0,0-((f>>>0>j>>>0)+a|0)|0,i,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}n=m,o=Ac(a,f)>>>16|0,u[n>>1]=o;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return v[h+12>>2]<<2}function aca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-16|0;jb=h;n=h,o=B(v[a>>2],ue(a)),v[n+12>>2]=o;Cc(h+12|0,c>>>2|0);c=Db(b);i=v[e+4>>2];f=v[h+12>>2];a:{if(!f){g=i;break a}while(1){e=Db(w[c+3|0]);e=e|Db(w[c+2|0])<<8|Db(w[c+1|0])<<16|Db(w[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>i>>>0?e:i}c=c+4|0;i=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[h+12>>2];if(!e){break c}k=g-1|0;l=g>>>1|0;i=g;c=v[a+20>>2];while(1){a=Db(w[b+3|0]);m=c;a=a|Db(w[b+2|0])<<8|Db(w[b+1|0])<<16|Db(w[b|0])<<24;j=a>>31;f=a;a=j<<31|a>>>1;f=l|f<<31;d:{if((a|0)>0?1:(a|0)>=0){a=Kma(f,a,i,0);f=mb;break d}j=k;f=Kma(j-f|0,0-((f>>>0>j>>>0)+a|0)|0,i,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}n=m,o=Ac(a,f)>>>16|0,u[n>>1]=o;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return v[h+12>>2]<<2}function hW(){var a=0,b=0,c=0,d=0;c=jb-32|0;jb=c;a:{a=Ub(c+16|0,10940);if(!Fb(a)){break a}b:{if((Zf(a,10946)|0)!=-1){b=Zf(a,10946);v[114578]=0;X(232,c|0,a|0,b+1|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Zf(a,10948)|0)!=-1){b=Zf(a,10948);v[114578]=0;X(232,c|0,a|0,b+1|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Zf(a,10950)|0)!=-1){b=Zf(a,10950);v[114578]=0;X(232,c|0,a|0,0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Zf(a,10952)|0)!=-1){b=Zf(a,10952);v[114578]=0;X(232,c|0,a|0,0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Zf(a,10954)|0)!=-1){b=Zf(a,10954);v[114578]=0;X(232,c|0,a|0,0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}v[114578]=0;b=T(233,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;yb(a);S(c|0);L()}yb(a);jb=c+32|0;return b|0}function e5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){d=Wb(b+32|0);c=v[a+24>>2];v[114578]=0;R(2076,b+16|0,c|0);c=v[114578];v[114578]=0;d:{if((c|0)!=1){e=b,f=bc(b+16|0),v[e+8>>2]=f;e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[114578]=0;Q(1251,d|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}zn(b+8|0);e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}v[114578]=0;Q(1996,d|0,34201)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;kd(b+16|0);break d}c=V(0)|0;O()|0}yb(d);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[114578]=0;X(1990,36905,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}c=Zd(Tb(d));kd(b+16|0);yb(d)}jb=b+48|0;return c|0}function N5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){d=Wb(b+32|0);c=v[a+24>>2];v[114578]=0;R(2041,b+16|0,c|0);c=v[114578];v[114578]=0;d:{if((c|0)!=1){e=b,f=bc(b+16|0),v[e+8>>2]=f;e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[114578]=0;Q(1251,d|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}zn(b+8|0);e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}v[114578]=0;Q(1996,d|0,34201)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;kd(b+16|0);break d}c=V(0)|0;O()|0}yb(d);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[114578]=0;X(1990,35662,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}c=Zd(Tb(d));kd(b+16|0);yb(d)}jb=b+48|0;return c|0}function kl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;dk(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=jl(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}dc(a,21);v[a+1396>>2]=0}return-1}ia(50714,50496,1690,50725);L()}function XF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[zf(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;b:{while(1){if((d|0)!=(h|0)){f=tr(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(ZF(v[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=tr(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((ur(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}jb=c+32|0;return d}function Qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=jb-112|0;jb=j;a:{b:{if(!De(a)){break b}if(yc(b)>>>0<2){break b}f=Ry(j+8|0,a);v[f+20>>2]=0;v[f>>2]=0;d=yc(b);c:{if(!d){break c}while(1){c=qd(b,g);e=v[a>>2];h=v[c>>2];if(e>>>0<=h>>>0){break c}c=v[c+4>>2];if(c>>>0>e-h>>>0){break c}e=v[f>>2];if(e>>>0>268435456-c>>>0){break c}v[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!Ws(f)){break b}if(g){d=0;c=0;while(1){e=qd(b,d);h=v[f+20>>2];v[114578]=0;h=T(467,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=v[a+20>>2];v[114578]=0;i=T(467,i|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break a}lc(c+h|0,i+v[e>>2]|0,v[e+4>>2]);v[e>>2]=c;if(!(!d|d>>>0>9)){v[((d<<2)+f|0)- -64>>2]=c}c=v[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}}pn(a);Ry(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}jb=j+112|0;return}V(0)|0;O()|0;Ab();L()}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=(h>>>21&2040)+27888|0;h=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;jb=e+32|0}function B9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=d;i=Mj(a,c);pf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!i){if(xd(a,5)){break a}}k=v[e+24>>2];d=jb-48|0;jb=d;h=v[a+28>>2];Nj(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>256|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){xf(h,d+38|0);f=Wb(d+24|0);v[114578]=0;W(724,h|0,f|0,255)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[114578]=0;U(13,d+8|0,k|0,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}v[114578]=0;g=Q(1619,b|0,d+38|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break d}Gb(g,d+8|0);yb(d+8|0);yb(f);f=v[d+44>>2];j=j+1|0;if(!f&j>>>0<y[d+40>>2]|f){continue}break}}jb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+8|0)}yb(f);S(a|0);L()}}_i(a,i,c,e+16|0);jb=e+32|0}function fy(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=B(d,896)+a|0;c=e+1075060|0;b:{if(v[c>>2]){break b}if(!oj(e+1074984|0)){break a}if(v[c>>2]){break b}if(w[e+1075073|0]&24){break a}}if(w[e+1075073|0]&2){if(!sd(f)){break a}if(!vM(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,896)+a|0;if(!v[b+1075680>>2]){d=65535;if(v[b+1075060>>2]){break a}}g=v[b+1075672>>2]|v[b+1075664>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,896)+a|0;if(!(v[c+1075680>>2]?0:v[c+1075060>>2])){f=(v[c+1075672>>2]|v[c+1075664>>2]<<9)>>>(v[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function dca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-16|0;jb=h;n=h,o=B(v[a>>2],ue(a)),v[n+12>>2]=o;Cc(h+12|0,(c>>>0)/3|0);c=Db(b);i=v[e+4>>2];f=v[h+12>>2];a:{if(!f){g=i;break a}while(1){e=Db(w[c|0]);e=Db(w[c+1|0])<<16|e<<8|Db(w[c+2|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>i>>>0?e:i}c=c+3|0;i=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[h+12>>2];if(!e){break c}k=g-1|0;l=g>>>1|0;i=g;c=v[a+20>>2];while(1){a=Db(w[b|0]);m=c;a=Db(w[b+1|0])<<16|a<<8|Db(w[b+2|0])<<24;j=a>>31;f=a;a=j<<31|a>>>1;f=l|f<<31;d:{if((a|0)>0?1:(a|0)>=0){a=Kma(f,a,i,0);f=mb;break d}j=k;f=Kma(j-f|0,0-((f>>>0>j>>>0)+a|0)|0,i,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}n=m,o=Ac(a,f)>>>16|0,u[n>>1]=o;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return B(v[h+12>>2],3)|0}function cca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-16|0;jb=h;n=h,o=B(v[a>>2],ue(a)),v[n+12>>2]=o;Cc(h+12|0,(c>>>0)/3|0);c=Db(b);i=v[e+4>>2];f=v[h+12>>2];a:{if(!f){g=i;break a}while(1){e=Db(w[c+2|0]);e=Db(w[c+1|0])<<16|e<<8|Db(w[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>i>>>0?e:i}c=c+3|0;i=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[h+12>>2];if(!e){break c}k=g-1|0;l=g>>>1|0;i=g;c=v[a+20>>2];while(1){a=Db(w[b+2|0]);m=c;a=Db(w[b+1|0])<<16|a<<8|Db(w[b|0])<<24;j=a>>31;f=a;a=j<<31|a>>>1;f=l|f<<31;d:{if((a|0)>0?1:(a|0)>=0){a=Kma(f,a,i,0);f=mb;break d}j=k;f=Kma(j-f|0,0-((f>>>0>j>>>0)+a|0)|0,i,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}n=m,o=Ac(a,f)>>>16|0,u[n>>1]=o;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return B(v[h+12>>2],3)|0}function Iw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;Mm(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];j=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;k=c+16|0;a=c;d=jb-16|0;jb=d;if(g){l=b+4|0;while(1){e=0;if(j){while(1){f=A[ch(a,e,h)>>3];fc(b,e);m=d,n=+(tj(Sd(f*134217728))-1024+((Ir(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,A[m+8>>3]=n;Rf(d+8|0,-1,1);f=A[d+8>>3]*32768;A[d+8>>3]=f;f=Sd(f);a:{if(D(f)<2147483648){i=~~f;break a}i=-2147483648}i=Vc(i);m=Lm(k,e,h),o=i,u[m>>1]=o;e=e+1|0;if((j|0)!=(e|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=d+16|0;jb=c+80|0}function Rv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=$e(a);a:{if(!v[115363]|!w[a|0]){break a}b=a;b:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break b}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];c:{if((c^-1)&c-16843009&-2139062144){break c}while(1){c=c^1027423549;if((c^-1)&c-16843009&-2139062144){break c}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=w[b|0];if(d){b=c+1|0;if((d|0)!=61){continue}}break}b=c}if(w[b|0]==61?b:0){break a}e=v[v[115363]>>2];if(!e){break a}d:{while(1){h=v[115363];b=a;c=g;d=0;e:{if(!c){break e}d=w[b|0];f:{if(d){while(1){i=w[e|0];if(!i){break f}c=c-1|0;if(!c){break f}g:{if((d|0)==(i|0)){break g}break f}e=e+1|0;d=w[b+1|0];b=b+1|0;if(d){continue}break}}d=0}d=d-w[e|0]|0}if(!d){b=v[(f<<2)+h>>2]+g|0;if(w[b|0]==61){break d}}f=f+1|0;e=v[(f<<2)+h>>2];if(e){continue}break}return 0}f=b+1|0}return f}function lr(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;c=v[v[a>>2]-12>>2];v[114578]=0;c=v[(a+c|0)+24>>2];b=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[114578]=0;c=Q(15,d+8|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+24>>2];e=v[114578];v[114578]=0;f:{if((e|0)==1){break f}v[114578]=0;b=T(2377,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Hf(c);break c}b=V(0)|0;O()|0;break c}Hf(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function PG(a,b,c,d){var e=0,f=0,g=0,h=C(0),i=0,j=C(0),k=0,l=C(0),m=C(0),n=C(0),o=0;e=jb-96|0;jb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){g=f<<3;i=f<<4;j=z[(i|8)+a>>2];h=z[(i|4)+a>>2];z[(e+48|0)+(g|4)>>2]=j+h;k=f<<1;z[(8-k<<2)+e>>2]=h-j;j=z[(a+i|0)+16>>2];h=z[(i|12)+a>>2];z[(7-k<<2)+e>>2]=j-h;z[(e+g|0)+56>>2]=-C(h+j);f=f+1|0;if((f|0)!=4){continue}break}OG(e+48|0);OG(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=z[g>>2];k=g;h=z[f+48928>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];g=f+36|0;n=z[g+48928>>2];z[k>>2]=C(h*l)-C(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=C(C(h*m)+C(n*l));z[k>>2]=C(j*z[f>>2])-C(z[g>>2]*h);z[(17-i<<2)+a>>2]=C(z[f>>2]*h)+C(j*z[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}jb=e+96|0}function s5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2062,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2063,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2010,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((yc(d)|0)<=(b|0)){break j}a=Tb(qd(d,b))}b=Zd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114578]=0;X(1990,36407,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2064,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2063,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2010,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((yc(d)|0)<=(b|0)){break j}a=Tb(qd(d,b))}b=Zd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114578]=0;X(1990,36439,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2065,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2063,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2010,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((yc(d)|0)<=(b|0)){break j}a=Tb(qd(d,b))}b=Zd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114578]=0;X(1990,36471,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function p5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2066,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2063,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2010,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((yc(d)|0)<=(b|0)){break j}a=Tb(qd(d,b))}b=Zd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114578]=0;X(1990,36501,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function o5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2067,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2063,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2010,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((yc(d)|0)<=(b|0)){break j}a=Tb(qd(d,b))}b=Zd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114578]=0;X(1990,36533,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function n5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2068,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2063,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2010,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((yc(d)|0)<=(b|0)){break j}a=Tb(qd(d,b))}b=Zd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114578]=0;X(1990,36568,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function $4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[114578]=0;Z(2042,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;Z(2042,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}d=v[a+24>>2];v[114578]=0;b=Q(85,e+16|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;c=Q(85,e|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;X(2082,d|0,b|0,c|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break e}yb(c);yb(b);b=1;break b}d=V(0)|0;O()|0;break c}d=V(0)|0;O()|0;break d}d=V(0)|0;O()|0;yb(c)}yb(b)}_(d|0)|0;b=0;v[114578]=0;X(1990,37079,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=e+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}
function KF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;v[114578]=0;g=Q(15,d+24|0,a|0)|0;e=v[114578];v[114578]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=Rk(d+8|0,a);h=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];f=v[v[a>>2]-12>>2];v[114578]=0;f=a+f|0;i=T(16,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break d}e=v[e>>2];v[114578]=0;c=b+c|0;b=ka(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Pk(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,5);b=v[114578];v[114578]=0;if((b|0)!=1){break e}break d}Hf(g);break b}b=V(0)|0;O()|0;Hf(g);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}$()}jb=d+32|0;return a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){V(0)|0;O()|0;Ab();L()}S(a|0);L()}function fM(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}c=$x(a,c&15);f=Hma(c,c>>31,d,d>>31)+32768|0;c=mb;c=Ac(Ima(f,f>>>0<32768?c+1|0:c,65536,0),mb);v[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074312|0;Eb(e+8|0,a,7);if(!(!Cb(e+8|0)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}Eb(e+8|0,a,7);if(Cb(e+8|0)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}c=d-((c&255)<<2)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=e+16|0}function sQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}b=w[d+42|0]|w[d+43|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>32768){break a}b=w[d+42|0]|w[d+43|0]<<8;h=((b<<8|b>>>8)&65535)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}e=jb-16|0;jb=e;b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}jb=e+16|0;b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function f0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[hj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2378,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Dm(c+8|0,a);f=Ek(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2379,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;fj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function b0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[hj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2378,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Dm(c+8|0,a);f=Ek(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2382,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;fj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function _$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[hj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2378,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Dm(c+8|0,a);f=Ek(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2384,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;fj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function $$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[hj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2378,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Dm(c+8|0,a);f=Ek(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2383,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;fj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);while(1){if((l|0)>=1){i=(k<<1)+b|0;n=i+(l<<1)|0;while(1){u[e+10>>1]=0;EQ(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){h=c<<1;c=h&254;u[e+12>>1]=c;f=(h&65534)>>>0>255;t[e+14|0]=f;h=e;if(!c){if(!Je(a,e+9|0)){break b}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}j=x[e+10>>1]<<1|f;u[h+10>>1]=j;g=g-1|0;if(g&255){continue}break}break a}j=x[e+10>>1]}c=1;g=j&65535;c:{if(g>>>0<4){break c}h=15;while(1){c=h;f=c&255;if(g>>>f&1){break c}h=c-1|0;if(f>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;m=(c-1^(j&65534)>>>1)+m|0;u[i>>1]=m;i=(d<<1)+i|0;if(n>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function kq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{if(!b){break a}if(c){c=Od(f+8|0,a);a=jb-16|0;jb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Lb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Rb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}jb=a+16|0;break a}c=Od(f,a);a=jb-16|0;jb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Lb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Rb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}jb=a+16|0}jb=f+16|0}function rw(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+52256>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=_h(c,b)}return c}return a+1}function fz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-80|0;jb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){g=Qf(d+72|0);f=b-e|0;b=ft(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){wk(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}zb(a);b=ez(d+56|0);e=v[a+4>>2];v[114578]=0;e=Q(933,a|0,e+f|0)|0;h=v[114578];v[114578]=0;c:{if((h|0)==1){break c}v[114578]=0;R(934,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;vj(d+40|0,a);wk(d+32|0,a);vj(d+24|0,b);v[114578]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;X(935,d+48|0,d+8|0,d|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;dz(a,b);ke(b);break b}a=P()|0;O()|0;ke(b);S(a|0);L()}v[a+4>>2]=b;break a}kq(Od(d+16|0,g),f,c)}jb=d+80|0}function nma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Wb(a);h=Fb(b);v[114578]=0;R(524,f|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[kc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[kc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114578]=0;d=Q(533,e|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){V(0)|0;O()|0;Ab();L()}if(d>>>0<=g>>>0){d=a;break b}v[114578]=0;d=Q(525,c|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;Q(526,f|0,d|0)|0;e=v[114578];v[114578]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114578]=0;W(527,f|0,1,37)|0;g=v[114578];v[114578]=0;d=a;if((g|0)==1){break a}}v[114578]=0;W(527,f|0,1,e<<24>>24)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;yb(f);S(a|0);L()}function qP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-48|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;zb(b);Zc(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){lq(a,v[b+4>>2]);vj(c+32|0,b);wk(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=jb-80|0;jb=b;i=a;f=v[a+4>>2];d=v[c+20>>2];j=d;g=v[c+16>>2];v[b+72>>2]=g;v[b+76>>2]=d;e=v[c+12>>2];k=e;h=v[c+8>>2];v[b+64>>2]=h;v[b+68>>2]=e;v[b+24>>2]=g;v[b+28>>2]=d;v[b+16>>2]=h;v[b+20>>2]=e;d=oP(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){e=v[i>>2];v[(d>>>0<33?e:(d-1>>>3&536870908)+e|0)>>2]=0}v[b+48>>2]=h;v[b+52>>2]=k;v[b+56>>2]=g;v[b+60>>2]=j;Tn(b+40|0,i,f);d=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=d;d=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=d;SP(b+32|0,b+8|0,b,b+40|0);jb=b+80|0}jb=c+48|0;return a|0}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=gh(a);f=b+24|0;a=v[f>>2];v[114578]=0;a=T(2195,a+484344|0)|0;c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)==1){break c}v[114578]=0;R(1534,e|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[114578]=0;c=T(2195,c+484344|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[114578]=0;R(2192,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(2186,d+16|0,b|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break g}v[114578]=0;R(1536,e|0,d+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}a=a+1|0;yb(d+16|0);yb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(d+16|0)}yb(d);break a}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}kd(e);S(a|0);L()}function DL(a,b){var c=0;c=jb-16|0;jb=c;a=Xx(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(a,7,1);Nb(a,9,1);Nb(a,10,1);Nb(a,13,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,20,1);Nb(a,21,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,28,1);Nb(a,30,1);Nb(a,31,1);Nb(a,33,1);Nb(a,34,1);Nb(a,39,1);Nb(a,41,1);Nb(a,44,1);Nb(a,46,1);Nb(a,45,1);Nb(a,47,1);Nb(a,48,1);Nb(a,50,1);Nb(a,99,1);Nb(a,102,1);Nb(a,104,1);Nb(a,105,1);break a;case 1:Tx(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;wg(a,107);break a;case 3:Tx(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;wg(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}Tx(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}jb=c+16|0}function vI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb+-64|0;jb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[114578]=0;v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[j+20>>2]=d?d:1998;U(1999,j+24|0,j+20|0,j+60|0);a=v[114578];v[114578]=0;a:{b:{c:{d:{if((a|0)!=1){b=Ho(j+32|0,j+24|0);v[114578]=0;a=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=a;a=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=a;c=+xa(2e3,j|0,+c,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}Yc(b);Yc(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Yc(b);Yc(j+24|0)}_(a|0)|0;v[114578]=0;ja(2001,34536,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}jb=j- -64|0;return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-4112|0;jb=c;i=nb[v[v[a>>2]+112>>2]](a)|0;if(!i){nb[v[v[a>>2]+116>>2]](a)}v[c+12>>2]=0;d=jb-16|0;jb=d;h=a+44|0;if(mf(h)){while(1){f=Zl(h,e);g=Zl(h,e);v[d+12>>2]=0;g=(g+2048|0)-f>>2;if((g|0)>=1){while(1){z[f>>2]=z[d+12>>2];f=f+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}e=e+1|0;if(mf(h)>>>0>e>>>0){continue}break}}jb=d+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;Cc(c+8|0,512);sp(c+16|0);nb[v[v[a>>2]+60>>2]](a,c+16|0,f,v[c+8>>2]);e=0;if(v[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[d>>2]);k=c,l=z[ex(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[d+2048>>2]);k=c,l=z[ex(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=e+1|0;d=v[c+8>>2];if(e>>>0<d>>>0){continue}break}b=b-d|0}if(b){continue}break}}if(!i){nb[v[v[a>>2]+120>>2]](a)}jb=c+4112|0;return C(z[c+12>>2])}function Rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function X6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=jb-16|0;jb=i;j=a+44|0;if(rh(j)){h=Pd(j,0);v[i+8>>2]=h;k=Pd(j,1);v[i+12>>2]=k;e=id(j,0);v[i>>2]=e;f=id(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;lc(e,g,h);lc(f,k,h)}oi(a,b,c,id(j,0),id(j,1),d)}jb=i+16|0}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fd(a);h=Fb(b);v[114578]=0;R(73,f|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[kc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[kc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114578]=0;d=Q(79,e|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){V(0)|0;O()|0;Ab();L()}if(d>>>0<=g>>>0){d=a;break b}v[114578]=0;d=Q(74,c|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;Q(75,f|0,d|0)|0;e=v[114578];v[114578]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114578]=0;W(76,f|0,1,37)|0;g=v[114578];v[114578]=0;d=a;if((g|0)==1){break a}}v[114578]=0;W(76,f|0,1,e<<24>>24)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;yb(f);S(a|0);L()}function FT(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+12560|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function eF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;h=jb-1040|0;jb=h;i=v[b>>2];v[h+12>>2]=i;g=a?d:256;j=a?a:h+16|0;d=0;a:{b:{c:{if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(f>>>0<g>>>0?c>>>0<=131:0){break b}while(1){f=k?g:f;c=c-f|0;f=Ov(j,h+12|0,f,e);if((f|0)==-1){g=0;i=v[h+12>>2];d=-1;break c}i=(h+16|0)==(j|0);g=g-(i?0:f)|0;j=i?j:(f<<2)+j|0;d=d+f|0;i=v[h+12>>2];if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(c>>>0>131|f>>>0>=g>>>0){continue}break}break b}if(!i){break a}}if(!g|!c){break a}f=d;while(1){d:{d=so(j,i,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[h+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}i=v[h+12>>2]+d|0;v[h+12>>2]=i;f=f+1|0;g=g-1|0;if(g){break d}}d=f;break a}j=j+4|0;c=c-d|0;d=f;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}jb=h+1040|0;return d|0}function Oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-48|0;jb=e;i=e+24|0;f=jb-144|0;jb=f;g=dh(f+8|0);h=v[v[g>>2]-12>>2];v[114578]=0;j=da(122)|0;k=v[114578];v[114578]=0;a:{b:{if((k|0)==1){break b}v[114578]=0;U(123,f|0,h+(f+8|0)|0,j|0);h=v[114578];v[114578]=0;if((h|0)==1){break b}Ob(f);v[114578]=0;R(134,g|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(125,i|0,g|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}Yd(g);jb=f+144|0;break a}a=P()|0;O()|0;Yd(g);S(a|0);L()}v[114578]=0;U(667,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;c:{d:{if((c|0)!=1){v[114578]=0;R(668,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(518,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break c}}c=P()|0;O()|0;ef(e+24|0);break d}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((mf(a)|0)==(b|0)){if((mf(a+12|0)|0)==(c|0)){break b}}v[114578]=0;R(1643,a|0,b|0);d=v[114578];v[114578]=0;c:{d:{if((d|0)==1){break d}v[114578]=0;e=a+12|0;R(1643,e|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}v[114578]=0;f=a+24|0;R(1644,f|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}v[114578]=0;g=a+36|0;R(1644,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Zl(a,d);i=Pb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;OJ(a);NJ(a);b=a+12|0;OJ(b);NJ(b);b=a+24|0;MJ(b);LJ(b);a=a+36|0;MJ(a);LJ(a);$();return 0}a=0;while(1){b=Zl(e,a);i=Pb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function To(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{b:{switch(v[a+480224>>2]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=Hma(b,d,5e4,0);e=mb;b=v[bd(c+8|0,c)>>2];b=Ac(Ima(d,e,b,b>>31),mb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Hma(v[a+1074420>>2],0,Hma(v[a+1074408>>2],0,v[a+1074416>>2],0),mb),v[g>>2]=h;v[c+4>>2]=mb;d=jb-16|0;jb=d;e=c+8|0;f=ru(e,c);jb=d+16|0;d=Hma(b,0,6e5,0);b=f?c:e;b=Kma(d,mb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=Hma(b,d,1e4,0);e=mb;b=v[bd(c+8|0,c)>>2];b=Ac(Ima(d,e,b,b>>31),mb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=Hma(a,a>>31,b,b>>31)+32768|0;a=mb;a=Ac(Ima(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[d>>2]=a?a:1;jb=c+16|0}function Qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a>>2]=b;c=DM(Pe(229984),b+1074376|0);b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;f=a+4|0;W(1378,f|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){jb=b+16|0;break b}break a}d=jb-16|0;jb=d;e=d+8|0;b=jb-16|0;jb=b;v[114578]=0;g=a+8|0;c=g;T(1379,c+4|0)|0;h=v[114578];v[114578]=0;c:{if((h|0)!=1){v[114578]=0;v[b+12>>2]=0;W(1380,c+8|0,b+12|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}break a}break a}i=c,j=hc(c),v[i>>2]=j;jb=b+16|0;jb=d+16|0;b=jb-16|0;jb=b;c=a+20|0;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1381,c+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){jb=b+16|0;break d}break a}v[114578]=0;Z(1341,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;BM(c);ZL(g);wf(f);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(y[a+4>>2]<y[zb(a)>>2]){g=jb-16|0;jb=g;e=Ik(g,a,1);f=zb(a);d=v[e+4>>2];v[114578]=0;X(559,f|0,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[e+4>>2]=v[e+4>>2]+24;Mb(e);jb=g+16|0;break a}a=P()|0;O()|0;Mb(e);S(a|0);L()}i=jb-32|0;jb=i;g=a;k=zb(a);e=Hk(a,Id(a)+1|0);h=Id(a);j=jb-16|0;jb=j;v[j+12>>2]=0;d=i+8|0;Tc(d+12|0,k);if(e){f=e;if(e>>>0>178956970){Fc(12706);L()}f=sc(B(f,24),4)}v[d>>2]=f;h=B(h,24)+f|0;v[d+8>>2]=h;v[d+4>>2]=h;l=ec(d),m=B(e,24)+f|0,v[l>>2]=m;jb=j+16|0;e=v[d+8>>2];v[114578]=0;X(559,k|0,e|0,b|0,c|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[d+8>>2]=v[d+8>>2]+24;v[114578]=0;R(560,g|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}VS(d);jb=i+32|0;break b}a=P()|0;O()|0;VS(d);S(a|0);L()}}return Rt(a)|0}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=4;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);n=(l|0)<1;while(1){if(!n){i=b+k|0;o=l+i|0;while(1){t[e+11|0]=0;DQ(a,e+14|0,e+12|0,e+11|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){h=c<<1;c=h&254;u[e+12>>1]=c;f=(h&65534)>>>0>255;t[e+14|0]=f;h=e;if(!c){if(!Je(a,e+10|0)){break b}f=w[e+10|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}j=w[e+11|0]<<1|f;t[h+11|0]=j;g=g-1|0;if(g&255){continue}break}break a}j=w[e+11|0]}c=1;g=j&255;c:{if(g>>>0<4){break c}h=7;while(1){c=h;f=c&255;if(g>>>f&1){break c}h=c-1|0;if(f>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;m=(c-1^(j&254)>>>1)+m|0;t[i|0]=m;i=d+i|0;if(o>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;Ed(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;f=c,g=w[pc(d+16|0,d)|0]<<2,u[f+30>>1]=g;e=b+14|0;v[c+24>>2]=(w[e|0]|w[e+1|0]<<8)<<1;Fk(d,2,b+1|0);Ic(d+16|0,d);v[114578]=0;Q(372,c+43|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){yb(d+16|0);e=ad(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}dA(e);Vl(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;Ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=aq(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=aq(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Xs(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[pc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}jb=d+16|0}function v3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb+-64|0;jb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((sj(Vb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[rc(Vb(v[e>>2]+484360|0),b)>>1];c:{if(!Kn(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074438>>1]=b;c=b&65535;yL(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;Cs(d+48|0,e,f?7:1,d);h=a,i=A[Tg(d+48|0)>>3],A[h+16>>3]=i;Hl(d+48|0);a=a+16|0}jb=d- -64|0;return+A[a>>3]}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;xf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=v[19811];if(x[c+62>>1]>x[e+12>>1]){f=v[b+12>>2];sA(c+16|0,18533);v[114578]=0;X(1182,c+32|0,c+16|0,c+62|0,e+12|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;d=Q(649,c+48|0,c+32|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[114578]=0;R(624,f|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}yb(d);yb(c+32|0);Ib(c+16|0);u[c+62>>1]=x[e+12>>1]}eg(Di(b,0),x[c+62>>1]);b=Di(b,0);h=c,i=bc(b),v[h+48>>2]=i;h=c,i=cc(b),v[h+16>>2]=i;if(Jb(c+48|0,c+16|0)){break b}break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d)}yb(c+32|0)}Ib(c+16|0);S(b|0);L()}while(1){b=v[c+48>>2];xf(a,c+14|0);u[b>>1]=x[c+14>>1];te(c+48|0);if(Jb(c+48|0,c+16|0)){continue}break}}jb=c- -64|0}function _ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=jb-16|0;jb=f;k=f,m=B(v[a>>2],ue(a)),v[k+8>>2]=m;Cc(f+8|0,c>>>2|0);c=Db(b);h=z[e+4>>2];e=v[f+8>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);h=C(G(C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q()))),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f+8>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());ae(f+12|0,C(-1));i=C(z[f+12>>2]*C(32768));z[f+12>>2]=i;a=c;i=je(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Vc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}jb=f+16|0;return v[f+8>>2]<<2}function jF(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Rv(60416);if(w[b|0]?b:0){break a}b=Rv(B(a,12)+60432|0);if(w[b|0]?b:0){break a}b=Rv(60504);if(w[b|0]?b:0){break a}b=60509}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=60509;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!ii(d,60509)){break e}if(ii(d,60517)){break d}}if(!a){c=60340;if(w[d+1|0]==46){break c}}return 0}c=v[115366];if(c){while(1){if(!ii(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115366];if(c){while(1){if(!ii(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=od(28);g:{if(!c){c=0;break g}b=v[15086];v[c>>2]=v[15085];v[c+4>>2]=b;b=c+8|0;lc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115366];v[115366]=c}c=a|c?c:60340}return c}function d$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;a:{b:{c:{if((b|0)!=(c|0)){j=v[114552];v[114552]=0;g=jb-16|0;jb=g;le();h=jb-16|0;jb=h;e=jb-16|0;jb=e;Lv(e,b,f+28|0,2);b=v[e+4>>2];v[h>>2]=v[e>>2];v[h+4>>2]=b;b=h;h=v[e+12>>2];v[b+8>>2]=v[e+8>>2];v[b+12>>2]=h;jb=e+16|0;e=v[b+4>>2];v[g>>2]=v[b>>2];v[g+4>>2]=e;e=g;g=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=g;jb=b+16|0;b=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=b;b=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=b;jb=e+16|0;e=v[f+8>>2];g=v[f+12>>2];h=v[f>>2];i=v[f+4>>2];b=v[114552];if(!b){break c}if(v[f+28>>2]!=(c|0)){break b}k=h;l=i;m=e;n=g;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[114552]=j;if(v[f+28>>2]==(c|0)){break a}}v[d>>2]=4;h=k;i=l;e=m;g=n}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=e;v[a+12>>2]=g;jb=f+32|0}function Yba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=jb-16|0;jb=f;m=f,o=B(v[a>>2],ue(a)),v[m+4>>2]=o;Cc(f+4|0,c>>>3|0);c=Db(b);h=A[e+8>>3];g=v[f+4>>2];a:{if(!g){break a}e=g;while(1){j=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,j|0);h=G(+n(),h);c=c+8|0;e=e-1|0;if(e){continue}break}if(!g|h==0){break a}k=1/h;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=+n()*k,A[m+8>>3]=p;Rf(f+8|0,-1,1);i=A[f+8>>3]*32768;A[f+8>>3]=i;a=c;i=Sd(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Vc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;g=g-1|0;if(g){continue}break}}if(d){A[d>>3]=h}jb=f+16|0;return v[f+4>>2]<<3}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;Ed(b,4);u[b+30>>1]=w[a+12|0]<<2;jg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Ub(d,31680);v[114578]=0;Q(372,b+43|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){yb(a);jb=d+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function M3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-48|0;jb=e;h=Go(a,c);i=TH(a+4|0);j=SH(a+24|0);k=RH(a+32|0);l=Tw(a+36|0);v[a+56>>2]=3;m=gh(a+68|0);v[114578]=0;R(2166,a|0,d|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{if((c|0)!=1){c=v[b>>2];f=v[b+4>>2];g=v[b+12>>2];b=v[b+8>>2];v[e+8>>2]=b;v[e+12>>2]=g;v[114578]=0;v[e+24>>2]=b;v[e+28>>2]=g;v[e+16>>2]=c;v[e+20>>2]=f;v[e>>2]=c;v[e+4>>2]=f;U(2167,e+32|0,e|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(2168,a|0,e+32|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Bb(e+32|0);v[114578]=0;Z(2169,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}jb=e+48|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bb(e+32|0);break a}a=P()|0;O()|0}kd(m);rf(l);wf(k);Gh(j);Yc(i);Yc(h);S(a|0);L()}function bU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){v[d+4>>2]=w[d+8|0];g=v[Lb(d+4|0,d+12|0)>>2];c=jb+-64|0;jb=c;Me(c+40|0,a,g);a=v[c+40>>2];v[114578]=0;e=T(414,c+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,c+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,c+24|0,c+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(470,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,c|0,c+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(c+24|0);Ec(c+40|0);jb=c- -64|0;c=!g|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+24|0)}Ec(c+40|0);S(a|0);L()}}jb=d+16|0;return c|0}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Ik(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1563,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Hk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(31753);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1563,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(1564,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}DK(c);jb=f+32|0;break b}a=P()|0;O()|0;DK(c);S(a|0);L()}}function e4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Ik(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(2133,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Hk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(39501);L()}h=sc(B(a,24),8)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(2133,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(2134,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}xH(c);jb=f+32|0;break b}a=P()|0;O()|0;xH(c);S(a|0);L()}}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Lb(e+12|0,e+8|0)>>2];i=z[d>>2];b=Db(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;d=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Vc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;d=a;f=je(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Vc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return h<<3}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Ik(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(605,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Hk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(12852);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(605,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(606,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}NS(c);jb=f+32|0;break b}a=P()|0;O()|0;NS(c);S(a|0);L()}}function pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Ik(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(529,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Hk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(12489);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(529,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(530,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}uT(c);jb=f+32|0;break b}a=P()|0;O()|0;uT(c);S(a|0);L()}}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Ik(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(771,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Hk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(14703);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(771,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(772,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}pR(c);jb=f+32|0;break b}a=P()|0;O()|0;pR(c);S(a|0);L()}}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Ik(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(987,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Hk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(16924);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(987,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(988,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}uP(c);jb=f+32|0;break b}a=P()|0;O()|0;uP(c);S(a|0);L()}}function Vr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-176|0;jb=d;e=dh(d+40|0);f=v[v[e>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114578]=0;U(123,d+32|0,f+(d+40|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}Ob(d+32|0);v[114578]=0;R(142,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;R(133,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;R(125,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(140,d+16|0,d|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(141,a|0,d+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}yb(d+16|0);yb(d);Yd(e);jb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(d+16|0)}yb(d)}Yd(e);S(c|0);L()}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(v[a+4>>2]!=v[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1520,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(30794);L()}h=sc(a<<2,4)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1520,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1521,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}RK(c);jb=f+32|0;break b}a=P()|0;O()|0;RK(c);S(a|0);L()}}function tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1058,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(17993);L()}h=sc(a<<2,1)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1058,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1059,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}DO(c);jb=f+32|0;break b}a=P()|0;O()|0;DO(c);S(a|0);L()}}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1423,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(20588);L()}h=sc(a<<2,4)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1423,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1424,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}lL(c);jb=f+32|0;break b}a=P()|0;O()|0;lL(c);S(a|0);L()}}function RJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1637,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(32555);L()}h=sc(a<<2,4)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1637,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1638,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}PJ(c);jb=f+32|0;break b}a=P()|0;O()|0;PJ(c);S(a|0);L()}}function Rja(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}zR(g+15|0,g+13|0);zR(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}tx(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){sx(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(Ym(c)>>>0<=Ym(w[g+14|0])>>>0){break b}lh(g+15|0,g+14|0);lh(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];jb=g+16|0}function XY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Kb(a);if(c>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{g=b-c|0;c:{if(g>>>0<=v[Tq(a)>>2]-v[a+4>>2]>>2>>>0){uE(a,g);break c}i=_k(a);d=h+8|0;f=Kb(a)+g|0;e=jb-16|0;jb=e;v[e+12>>2]=f;b=a;d:{c=XD(a);if(f>>>0<=c>>>0){b=Zk(b);if(b>>>0<c>>>1>>>0){v[e+8>>2]=b<<1;c=v[bd(e+8|0,e+12|0)>>2]}jb=e+16|0;break d}ed();L()}f=Kb(a);b=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(d+12|0,i);if(c){b=VD(v[d+16>>2],c)}v[d>>2]=b;f=(f<<2)+b|0;v[d+8>>2]=f;v[d+4>>2]=f;j=ec(d),k=(c<<2)+b|0,v[j>>2]=k;jb=e+16|0;v[114578]=0;R(2560,d|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(2561,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}QD(d)}jb=h+32|0;break a}a=P()|0;O()|0;QD(d);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Kb(a);SD(a,b);qE(a)}}function K3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-32|0;jb=f;d=Go(a,d);h=TH(a+4|0);i=SH(a+24|0);j=RH(a+32|0);k=Tw(a+36|0);v[a+56>>2]=3;l=gh(a+68|0);v[114578]=0;R(2166,a|0,e|0);g=v[114578];v[114578]=0;a:{b:{c:{d:{if((g|0)!=1){v[114578]=0;b=T(2173,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;U(2174,f+8|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(2175,f+16|0,f+8|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(2168,a|0,f+16|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Bb(f+16|0);v[114578]=0;Z(2169,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(f+16|0)}kd(l);rf(k);wf(j);Gh(i);Yc(h);Yc(d);S(a|0);L()}jb=f+32|0;return a|0}function ni(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;e=a+24|0;f=v[v[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|v[v[e>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}jL(v[e>>2],1);break a}lc(d+8|0,v[e>>2]+24604|0,40);g=v[d+40>>2];h=v[d+44>>2];v[d+28>>2]=c;v[d+24>>2]=b;tl(d+8|0,g);ln(d+8|0,h);Lx(v[e>>2],d+8|0);if((b|0)==(f|0)){break a}b=v[e>>2];f=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(nb[v[v[b>>2]+112>>2]](b)|0)){break b}nb[v[v[b>>2]+104>>2]](b,0);nb[v[v[b>>2]+92>>2]](b);nb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((f|0)!=(c|0)){continue}break}b=v[e>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(nb[v[v[b>>2]+112>>2]](b)|0){break c}nb[v[v[b>>2]+104>>2]](b,1);nb[v[v[b>>2]+116>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}}t[a+29|0]=1;jb=d+48|0}function eM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{if(!v[b+700>>2]){break a}f=v[a+480180>>2]==64?B(c,-20):c;b:{if(!(!(w[a+480208|0]&16)|v[a+480180>>2]==4)){g=v[b+700>>2];c=f>>31;v[e+12>>2]=(c+f^c)>>>2;Cc(e+12|0,255);d=v[e+12>>2];c:{if(!d){break c}h=b;c=v[b+700>>2];i=c;c=c>>31;d:{if((f|0)<=-1){d=$x(a,d);break d}d=_x(a,d)}d=Hma(i,c,d,d>>31)+32768|0;c=mb;c=Ac(Ima(d,d>>>0<32768?c+1|0:c,65536,0),mb);v[h+700>>2]=c;if((c|0)!=(g|0)){break c}Eb(e,a+1074312|0,7);g=Cb(e);d=v[b+700>>2];c=b;e:{if((g|0)==(f>>>31|0)){if((d|0)==2147483647){break c}d=v[b+700>>2]+1|0;break e}if((d|0)<2){break c}d=d-1|0}v[c+700>>2]=d}c=v[b+700>>2];break b}c=f+v[b+700>>2]|0;v[b+700>>2]=c}if((c|0)>0){break a}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=e+16|0}function Jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;jb=e+32|0}function eI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-176|0;jb=d;e=dh(d+40|0);f=v[v[e>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114578]=0;U(123,d+32|0,f+(d+40|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}Ob(d+32|0);v[114578]=0;R(147,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;R(130,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;R(125,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(140,d+16|0,d|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(141,a|0,d+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}yb(d+16|0);yb(d);Yd(e);jb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(d+16|0)}yb(d)}Yd(e);S(c|0);L()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;c=lk(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((cg(a)|0)!=(c|0)){break b}b=jb-16|0;jb=b;c=bc(a);d=cc(a);Ph(b+8|0);a=jb-16|0;jb=a;v[a>>2]=d;v[a+8>>2]=c;d=is(a,a+8|0);g=jb-16|0;jb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){c=v[g+8>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;Dj(g+8|0);d=d-1|0;if(c){continue}break}}jb=g+16|0;jb=a+16|0;jb=b+16|0;break a}Ph(f+8|0);c=pS(f+16|0,c,f+8|0);sK(a);El(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[zb(c)>>2];h=zb(a),i=d,v[h>>2]=i;h=zb(c),i=0,v[h>>2]=i;v[c>>2]=0;v[c+4>>2]=0;Ll(c);v[a+12>>2]=b}a=1}else{a=0}jb=f+32|0;return a|0}function G6(){var a=0,b=0,c=0,d=0,e=0;a=jb-48|0;jb=a;c=Wb(a+32|0);v[114578]=0;Z(1995,a+16|0);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){d=a,e=bc(a+16|0),v[d+8>>2]=e;d=a,e=cc(a+16|0),v[d>>2]=e;if(!Jb(a+8|0,a)){break c}while(1){e:{b=v[a+8>>2];v[114578]=0;Q(1251,c|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}zn(a+8|0);d=a,e=cc(a+16|0),v[d>>2]=e;if(!Jb(a+8|0,a)){break c}v[114578]=0;Q(1996,c|0,34201)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;kd(a+16|0);break d}b=V(0)|0;O()|0}yb(c);_(b|0)|0;b=0;v[114578]=0;X(1990,34203,0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$();break b}b=Zd(Tb(c));kd(a+16|0);yb(c)}jb=a+48|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function zda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;b=A[a+8>>3];d=jb-32|0;jb=d;o(+A[a>>3]);a=j(1)|0;e=j(0)|0;o(+b);f=j(1)|0;i=j(0)|0;f=f&2147483647;c=f;g=a&2147483647;k=(c|0)==(g|0)&e>>>0<i>>>0|c>>>0>g>>>0;a=k?e:i;c=k?g:c;k=c;l(0,a|0);l(1,c|0);b=+n();c=c>>>20|0;a:{if((c|0)==2047){break a}p=e;e=(f|0)==(g|0)&e>>>0>i>>>0|f>>>0<g>>>0;l(0,(e?p:i)|0);e=e?g:f;l(1,e|0);h=+n();f=!(a|k);a=e>>>20|0;if(!(f|(a|0)==2047)){if((a-c|0)>=65){b=h+b;break a}b:{if(a>>>0>=1534){b=b*1.90109156629516e-211;h=h*1.90109156629516e-211;m=5.260135901548374e210;break b}m=1;if(c>>>0>572){break b}b=b*5.260135901548374e210;h=h*5.260135901548374e210;m=1.90109156629516e-211}uG(d+24|0,d+16|0,h);uG(d+8|0,d,b);b=m*K(A[d>>3]+A[d+16>>3]+A[d+8>>3]+A[d+24>>3]);break a}b=h}jb=d+32|0;return+b}function Xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);t[e+15|0]=w[a+4|0];t[e+14|0]=64;f=b,g=w[pc(e+15|0,e+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;v[b+8>>2]=a;d=v[b+4>>2];c=v[b>>2];if(d>>>0>=c>>>0){d=c-1|0;v[b+4>>2]=d}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}v[b+68>>2]=d;u[b+34>>1]=x[b+34>>1]|2}jb=e+16|0}function yo(a){var b=C(0),c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=Ch(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-Ch(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=Dh(f+1.5707963267948966);break a}b=Dh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Ch(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=Dh(-4.71238898038469-+a);break a}b=Dh(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(qw(a,c+8|0)&3){case 0:b=Ch(A[c+8>>3]);break a;case 1:b=Dh(-A[c+8>>3]);break a;case 2:b=C(-Ch(A[c+8>>3]));break a;default:break b}}b=Dh(A[c+8>>3])}a=b;jb=c+16|0;return a}function SJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-16|0;jb=d;a:{if(Kb(a)>>>0>511){break a}if(!Gf(v[v[b>>2]-12>>2]+b|0)){break a}j=d+8|0;f=b;g=c;h=jb-16|0;jb=h;e=Pe(64);v[114578]=0;i=T(1429,e|0)|0;k=v[114578];v[114578]=0;b:{c:{if((k|0)!=1){e=Rx(h+8|0,i);i=v[e>>2];v[114578]=0;f=W(1635,i|0,f|0,g|0)|0;g=v[114578];v[114578]=0;d:{e:{if((g|0)!=1){if((f|0)==1){break e}Qx(j);break d}a=P()|0;O()|0;bg(e);break c}Gp(j,e)}bg(e);jb=h+16|0;break b}a=P()|0;O()|0;Xb(e)}S(a|0);L()}f:{g:{if(!sd(d+8|0)){v[114578]=0;U(1633,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}$R(d+8|0,Nd(d));bg(d)}f=0;if(!sd(d+8|0)){break f}f=v[d+8>>2];v[114578]=0;R(1634,a|0,d+8|0);a=v[114578];v[114578]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;bg(d+8|0);S(a|0);L()}bg(d+8|0)}jb=d+16|0;return f}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;i=Wb(a);a=Wb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!x[v[g>>2]+480192>>1]){break d}b=0;f=1;while(1){c=v[g>>2];v[114578]=0;c=Q(2184,c|0,f&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;c=Q(85,e|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}d=Wc(c);v[114578]=0;Q(1251,a|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;Q(1996,a|0,38845)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}b=d^1|b;yb(c);f=f+1|0;if(x[v[g>>2]+480192>>1]>=(f&65535)>>>0){continue}break}if(!(b&1)){break d}v[114578]=0;Q(450,i|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}yb(a);jb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(a);yb(i);S(b|0);L()}function l3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;i=Wb(a);a=Wb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!x[v[g>>2]+480190>>1]){break d}b=0;f=1;while(1){c=v[g>>2];v[114578]=0;c=Q(2185,c|0,f&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;c=Q(85,e|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}d=Wc(c);v[114578]=0;Q(1251,a|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;Q(1996,a|0,38845)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}b=d^1|b;yb(c);f=f+1|0;if(x[v[g>>2]+480190>>1]>=(f&65535)>>>0){continue}break}if(!(b&1)){break d}v[114578]=0;Q(450,i|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}yb(a);jb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(a);yb(i);S(b|0);L()}function Zj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Fb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Tm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+64400|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+64400|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=k+16|0;return a|0}function Yj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=jb-16|0;jb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Fb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=Ev(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+64400|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+64400|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=k+16|0;return a|0}function JL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;f=jb-16|0;jb=f;g=a+128e3|0;while(1){d=jb-32|0;jb=d;jO(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;jb=d+32|0;a=a+32|0;if((g|0)!=(a|0)){continue}break}jb=f+16|0;jb=e+16|0}function Hf(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114578]=0;b=v[(b+c|0)+24>>2];c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114578]=0;b=Gf(b+c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(FD()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114578]=0;b=v[(b+c|0)+24>>2];c=v[114578];v[114578]=0;c:{if((c|0)==1){break c}v[114578]=0;b=T(2377,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function Hq(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a=fd(a);a:{b:{c:{switch(b|0){case 0:v[114578]=0;b=Q(2,d|0,7167)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}Gb(a,b);yb(b);break b;case 1:v[114578]=0;b=Q(2,d|0,7192)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 2:v[114578]=0;b=Q(2,d|0,7237)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 3:v[114578]=0;b=Q(2,d|0,7264)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 4:v[114578]=0;b=Q(2,d|0,7290)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 5:break c;default:break b}}v[114578]=0;b=Q(2,d|0,7319)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}Gb(a,b);yb(b)}jb=d+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function K7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;g=jb-16|0;jb=g;j=a+44|0;if(rh(j)){r=g,s=Pd(j,0),v[r+8>>2]=s;r=g,s=Pd(j,1),v[r+12>>2]=s;r=g,s=id(j,0),v[r>>2]=s;r=g,s=id(j,1),v[r+4>>2]=s;if(d){p=w[a+4273|0];q=w[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=C(z[a+4260>>2]*YI(C(i*C(1073741824)),q,p));e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(i-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}oi(a,b,c,id(j,0),id(j,1),d)}jb=g+16|0}function Mw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-80|0;jb=c;d=v[a>>2];g=v[d+4>>2];f=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=f;f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Eh(c- -64|0,c+32|0,g);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;a=c;if(g){j=b+4|0;while(1){d=0;if(f){while(1){e=v[Of(a,d,h)>>2];fc(b,d);e=(e+((Ir(j)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;e=e>>>0>491520?e:491520;k=Nm(i,d,h),l=(e|0)<557055?e:557055,u[k>>1]=l;d=d+1|0;if((f|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=c+80|0}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;jb=e+32|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>4;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[e+8>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=g;Rf(e+8|0,-1,1);f=A[e+8>>3]*32768;A[e+8>>3]=f;g=a;f=Sd(f);a:{if(D(f)<2147483648){h=~~f;break a}h=-2147483648}i=g,j=Vc(h),u[i>>1]=j;g=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[e+8>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[e+12>>2]=g;Rf(e+8|0,-1,1);f=A[e+8>>3]*32768;A[e+8>>3]=f;g=a;f=Sd(f);b:{if(D(f)<2147483648){h=~~f;break b}h=-2147483648}i=g,j=Vc(h),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function yG(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Dh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-Ch(d+1.5707963267948966));break a}a=Ch(d+-1.5707963267948966);break a}a=Dh(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=Ch(d+4.71238898038469);break a}a=C(-Ch(d+-4.71238898038469));break a}a=Dh(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(qw(a,b+8|0)&3){case 0:a=Dh(A[b+8>>3]);break a;case 1:a=Ch(A[b+8>>3]);break a;case 2:a=Dh(-A[b+8>>3]);break a;default:break b}}a=C(-Ch(A[b+8>>3]))}jb=b+16|0;return a}function f7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=pi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=81440;c=a+4960|0;e=a+4504|0;b=e;while(1){kk(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[114578]=0;W(1641,a+44|0,2,2)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){v[114578]=0;Z(1642,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Sf(c);if((c|0)!=(e|0)){continue}break}bf(d);S(a|0);L()}return a|0}function pf(a,b){var c=0,d=0,e=0;d=jb-32|0;jb=d;a=Og(a,-1,-1);a:{b:{if(w[hj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[114578]=0;c=v[(b+c|0)+24>>2];e=v[114578];v[114578]=0;c:{d:{if((e|0)==1){break d}v[114578]=0;Oa(2387,d+8|0,c|0,0,0,1,8);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;_(a|0)|0;fj(v[v[b>>2]-12>>2]+b|0,1);a=v[v[b>>2]-12>>2];v[114578]=0;a=v[(a+b|0)+20>>2];c=v[114578];v[114578]=0;e:{if((c|0)!=1){if(!(a&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}$();a=1}Ag(v[v[b>>2]-12>>2]+b|0,a)}jb=d+32|0;return}V(0)|0;O()|0;Ab()}L()}function Au(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;g=a+1|0;gg(b,w[pc(g,f+15|0)|0]);d=w[pc(a+2|0,f+15|0)|0];t[b+13|0]=d;j=b,k=Fd(w[a+3|0],d,w[f+15|0]),t[j+14|0]=k;d=w[pc(a+4|0,f+15|0)|0];t[b+15|0]=d;j=b,k=Fd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[pc(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Yb(w[e+6|0]+c<<24>>24,0,64);j=Pb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Pb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}if(x[Pb(b,d)>>1]>255){break a}h=w[Pb(b,e)+1|0];i=Pb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}e=Pb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[pc(f+14|0,g)|0]){continue}break}}jb=f+16|0}function eL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=-1;a:{if(!Hx(a,b,2)){break a}h=v[b+656>>2];f=a+1074312|0;Eb(e+8|0,f,31);b:{if(Cb(e+8|0)){d=v[b+752>>2];if(d){break b}break a}d=v[b+752>>2]}Eb(e+8|0,f,31);f=d-Cb(e+8|0)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=qp(h+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+748|0]&16){g=fp(a,b,!(v[b+88>>2]&32768),d);break a}if(uj(b)){if((d|0)==v[b+768>>2]){break a}v[b+768>>2]=d;t[b+872|0]=w[b+872|0]|8;break a}b=Zo(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;Ti(e+8|0,255);a=(v[e+8>>2]<<2)+(b?26336:25312)|0;break c}Ti(e+8|0,255);a=(v[e+8>>2]<<2)+(b?25312:26336)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];i=f,j=Ac(Ima(Hma(b,d,a,a>>31),mb,65536,0),mb),v[i>>2]=j}jb=e+16|0;return g}function dM(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{c:{if(!(t[b+872|0]&1)){break c}d=v[b+700>>2];if(!d|!(c&255)){break c}if(!(w[a+480208|0]&16)){break b}d=v[b+700>>2];if(v[a+480180>>2]==4){break b}c=_x(a,c&15);f=Hma(c,c>>31,d,d>>31)+32768|0;c=mb;c=Ac(Ima(f,f>>>0<32768?c+1|0:c,65536,0),mb);v[b+700>>2]=c;if((c|0)!=(d|0)){break c}a=a+1074312|0;Eb(e+8|0,a,7);if(!(Cb(e+8|0)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break c}Eb(e+8|0,a,7);if(!Cb(e+8|0)){break c}a=v[b+700>>2];if((a|0)<2){break c}v[b+700>>2]=a-1}jb=e+16|0;return}a=((c&255)<<2)+d|0;v[b+700>>2]=(a|0)<65535?a:65535;jb=e+16|0}function OG(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function dn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+724|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|v[b+732>>2]!=-1){break a}a=f+48|0;h=b,i=qp(a,v[b+728>>2],256,64),v[h+732>>2]=i;h=b,i=x[Pb(a,w[f+65|0])>>1],v[h+728>>2]=i}}function P2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;g=gh(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[114578]=0;R(1534,g|0,a|0);c=v[114578];v[114578]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[114578]=0;c=Q(2184,c|0,a&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;c=Q(85,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;U(2186,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(1536,g|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}yb(d+16|0);yb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+16|0)}yb(c);break a}a=P()|0;O()|0}kd(g);S(a|0);L()}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;g=gh(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[114578]=0;R(1534,g|0,a|0);c=v[114578];v[114578]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[114578]=0;c=Q(2185,c|0,a&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;c=Q(85,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;U(2186,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(1536,g|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}yb(d+16|0);yb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+16|0)}yb(c);break a}a=P()|0;O()|0}kd(g);S(a|0);L()}function PZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=BE(c);b:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break b}Yq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}ai(i,k);Lc(k);l=e,m=ei(a),v[l>>2]=m;l=f,m=di(a),v[l>>2]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);ai(h,k);Lc(k);a=Qj(a);break a}a=AE(c);c:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break c}Yq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}ai(i,k);Lc(k);l=e,m=ei(a),v[l>>2]=m;l=f,m=di(a),v[l>>2]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);ai(h,k);Lc(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=(f>>>21&2040)+27888|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);ae(e+12|0,C(-1));g=C(z[e+12>>2]*C(32768));z[e+12>>2]=g;f=a;g=je(g);a:{if(C(D(g))<C(2147483648)){h=~~g;break a}h=-2147483648}i=f,j=Vc(h),u[i>>1]=j;f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);ae(e+12|0,C(-1));g=C(z[e+12>>2]*C(32768));z[e+12>>2]=g;f=a;g=je(g);b:{if(C(D(g))<C(2147483648)){h=~~g;break b}h=-2147483648}i=f,j=Vc(h),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function nR(a){var b=0,c=0;a:{if(pd(a,15083,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return 0}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Ed(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<5){t[c+38|0]=w[w[d|0]+31850|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function TZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=GE(c);b:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break b}Yq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}Gb(i,k);yb(k);l=e,m=ei(a),t[l|0]=m;l=f,m=di(a),t[l|0]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);Gb(h,k);yb(k);a=Qj(a);break a}a=EE(c);c:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break c}Yq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}Gb(i,k);yb(k);l=e,m=ei(a),t[l|0]=m;l=f,m=di(a),t[l|0]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);Gb(h,k);yb(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function GI(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=Se(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(Vg(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(Vg(d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=Vg(l*+(j+v[(e+h|0)+16>>2]>>>0));b=Vg(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=Vg(+FI(z[a+4208>>2])*.16609640474436813);b=Vg(+FI(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function f2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-80|0;jb=d;a=v[a+4>>2];Ou(d+16|0,b);v[114578]=0;b=Q(2,d|0,38630)|0;e=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[114578]=0;U(3,d+32|0,d+16|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}v[114578]=0;U(721,d+48|0,d+32|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break g}v[114578]=0;U(9,d- -64|0,0,d+48|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[114578]=0;R(c|0,a|0,d- -64|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}yb(d- -64|0);yb(d+48|0);yb(d+32|0);yb(b);yb(d+16|0);jb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(d- -64|0)}yb(d+48|0)}yb(d+32|0)}yb(b)}yb(d+16|0);S(a|0);L()}function Mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=$n(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1374,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+32;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}g=jb-32|0;jb=g;d=a;i=zb(a);c=em(a,xe(a)+1|0);f=xe(a);e=jb-16|0;jb=e;v[e+12>>2]=0;a=g+8|0;Tc(a+12|0,i);if(c){h=SL(c)}v[a>>2]=h;f=(f<<5)+h|0;v[a+8>>2]=f;v[a+4>>2]=f;j=ec(a),k=(c<<5)+h|0,v[j>>2]=k;jb=e+16|0;c=v[a+8>>2];v[114578]=0;U(1374,i|0,c|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+32;v[114578]=0;R(1375,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}TL(a);jb=g+32|0;break b}b=P()|0;O()|0;TL(a);S(b|0);L()}}function vx(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function k4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=mm(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(2128,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+16;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}g=jb-32|0;jb=g;d=a;i=zb(a);c=Lq(a,nd(a)+1|0);f=nd(a);e=jb-16|0;jb=e;v[e+12>>2]=0;a=g+8|0;Tc(a+12|0,i);if(c){h=BH(c)}v[a>>2]=h;f=(f<<4)+h|0;v[a+8>>2]=f;v[a+4>>2]=f;j=ec(a),k=(c<<4)+h|0,v[j>>2]=k;jb=e+16|0;c=v[a+8>>2];v[114578]=0;U(2128,i|0,c|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+16;v[114578]=0;R(2129,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}zH(a);jb=g+32|0;break b}b=P()|0;O()|0;zH(a);S(b|0);L()}}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-80|0;jb=c;h=lN(a,1<<b-1);v[a+12>>2]=b;a:{b=1<<b;f=b>>>2|0;if(f){i=1/+(b>>>0);b=f;e=1;while(1){v[114578]=0;A[c+40>>3]=+(b>>>0)*-6.283185307179586*i;U(1531,c+48|0,30864,c+40|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1220,c- -64|0,c+48|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=tc(h,e);g=v[c+76>>2];v[d+8>>2]=v[c+72>>2];v[d+12>>2]=g;g=v[c+68>>2];v[d>>2]=v[c+64>>2];v[d+4>>2]=g;e=e<<1;b=b>>>1|0;if(b){continue}break}}b=Bl(c+24|0,1,0);v[114578]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;X(1532,a|0,0,f|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}jb=c+80|0;return a|0}a=P()|0;O()|0;ip(h);S(a|0);L()}function oma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-48|0;jb=e;a:{b:{if(v[a+8>>2]!=v[ec(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];f=v[a>>2];if(c>>>0>f>>>0){i=((c-f>>1)+1|0)/-2<<1;f=i+c|0;d=g;g=v[d>>2];if((g|0)!=(c|0)){while(1){sT(f,c);f=f+2|0;c=c+2|0;if((g|0)!=(c|0)){continue}break}}v[d>>2]=f;v[h>>2]=i+v[h>>2];break b}j=e,k=v[ec(a)>>2]-v[a>>2]|0,v[j+24>>2]=k;v[e+44>>2]=1;d=v[bd(e+24|0,e+44|0)>>2];d=xT(e+24|0,d,d>>>2|0,v[a+16>>2]);c=Oc(e+16|0,v[a+4>>2]);f=v[Oc(e+8|0,v[a+8>>2])>>2];c=v[c>>2];v[114578]=0;U(523,d|0,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}Zb(a,d);Zb(h,d+4|0);Zb(g,d+8|0);Zb(ec(a),ec(d));Vt(d)}oA(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+2;jb=e+48|0;return}a=P()|0;O()|0;Vt(d);S(a|0);L()}function v2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|((e|0)==1?(h|0)==24:0)){break a}h=v[b+44>>2];if(h){g=h-Tb(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;i=e;j=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((d|0)<0|((d|0)>(g|0)?1:(g|0)<=(d|0)?e>>>0>m>>>0:0)){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(d){Om(b,v[b+8>>2],e+v[b+8>>2]|0,v[b+44>>2])}if(f&16){Nw(b,v[b+20>>2],v[b+28>>2]);Kr(b,e)}k=e;l=c}Og(a,k,l)}function Vha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-16|0;jb=g;e=b;f=Kb(e);d=c;a:{if(f>>>0<d>>>0){j=jb-32|0;jb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[zb(e)>>2]-v[e+4>>2]>>2>>>0){MP(e,h);break d}i=zb(e);k=Be(e,Kb(e)+h|0);m=Kb(e);f=0;l=jb-16|0;jb=l;v[l+12>>2]=0;d=j+8|0;Tc(d+12|0,i);if(k){f=IP(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=ec(d),o=(k<<2)+f|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(951,d|0,h|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;R(952,e|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}GP(d)}jb=j+32|0;break b}a=P()|0;O()|0;GP(d);S(a|0);L()}break a}if(d>>>0<f>>>0){d=v[e>>2]+(d<<2)|0;Kb(e);HP(e,d);Qg(e)}}c=Qb(a,c<<2);if(c){Kz(g+8|0,b);Bd(a,g+8|0)}jb=g+16|0;return c|0}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;Ed(b,0);Qi(d,1,a);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Vs(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;e=b,f=w[pc(d+16|0,d)|0]<<2,u[e+30>>1]=f;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function nN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ls(b);d=jb-16|0;jb=d;e=a;f=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1227,a+8|0,d+12|0,d+8|0)|0;h=v[114578];v[114578]=0;a:{if((h|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}v[114578]=0;R(1221,a|0,2048);a=v[114578];v[114578]=0;b:{if((a|0)!=1){v[114578]=0;R(1223,e|0,2048);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;uy(f);S(a|0);L()}a=0;c:{while(1){c=1;if((a|0)!=1024){v[114578]=0;c=+(a-1024|0);i=+hb(1215,+(K(c*c*-9.5367431640625e-7+1)*b));f=v[114578];v[114578]=0;if((f|0)==1){break c}c=c*.0372006759294457;c=i*hi(c)/(c*g)}j=Tk(e,a),k=c*.011841342921061943,A[j>>3]=k;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Mf(e);S(a|0);L()}function kW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-96|0;jb=g;Bi(g+48|0,g+40|0,c);v[114578]=0;c=g+60|0;U(224,c|0,g+32|0,d|0);d=v[114578];v[114578]=0;a:{b:{h=g+48|0;c:{d:{e:{f:{if((d|0)!=1){v[114578]=0;U(224,g+72|0,g+24|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[114578]=0;U(224,g+84|0,g+16|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break e}v[114578]=0;R(225,g+8|0,g+48|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,g+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}hD(g+48|0);jb=g+96|0;return}a=P()|0;O()|0;break c}a=P()|0;O()|0;b=2;break d}a=P()|0;O()|0;b=3}c=h+B(b,12)|0}while(1){c=yb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break a}a=P()|0;O()|0;hD(g+48|0)}S(a|0);L()}function V3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;b=v[a+4>>2];c=f;a=v[a>>2];v[c>>2]=a;v[c+4>>2]=b;v[c+8>>2]=a;v[c+12>>2]=b;b=jb+-64|0;jb=b;a:{b:{e=v[c+4>>2];if(!e){break b}d=78208;while(1){a=v[c+4>>2];v[b+56>>2]=v[c>>2];v[b+60>>2]=a;a=qc(b+48|0,v[d+8>>2]);g=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=g;g=v[a+4>>2];v[b+16>>2]=v[a>>2];v[b+20>>2]=g;if(WK(b+24|0,b+16|0)){break b}d=d+12|0;if((d|0)!=78724){continue}break}d=78736;while(1){c:{a=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=a;a=qc(b+32|0,v[d+8>>2]);e=v[b+44>>2];v[b+8>>2]=v[b+40>>2];v[b+12>>2]=e;e=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=e;a=WK(b+8|0,b);if(a){break c}d=d+12|0;if((d|0)!=78784){continue}}break}jb=b- -64|0;break a}jb=b- -64|0;a=(e|0)!=0}jb=f+16|0;return a|0}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=yc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/12>>>0){e=jb-16|0;jb=e;d:{b=al(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(1025,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+12|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Ty(d+8|0,um(a,yc(a)+c|0),yc(a),b);v[114578]=0;R(1020,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1021,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}SO(b)}jb=d+32|0;break a}a=P()|0;O()|0;SO(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,12)|0;yc(a);TO(a,b);ct(a)}}function XK(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Qo(a,C(1));Po(a,C(3.725290298461914e-9));Oo(a,C(268435456));No(a,0);break b;case 1:Qo(a,C(32));Po(a,C(4.656612873077393e-10));Oo(a,C(2147483648));No(a,0);break b;case 2:Qo(a,C(2));Po(a,C(7.450580596923828e-9));Oo(a,C(134217728));No(a,1);break b;default:Qo(a,C(1));Po(a,C(7.450580596923828e-9));Oo(a,C(134217728));No(a,1);Ex(a,0);tl(a,1);Dx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Qo(a,C(.75));Po(a,C(7.450580596923828e-9));Oo(a,C(134217728));No(a,1);Ex(a,0);b=(b|0)==4;tl(a,b?2:3);Dx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Ex(a,1);tl(a,0);Dx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function X4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{c:{if((e|0)==1){break c}v[114578]=0;Z(2042,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Z(2042,c|0);f=v[114578];v[114578]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);v[114578]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;X(2086,f|0,d+8|0,d|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37201,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}jb=d+32|0;return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Ni(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=jb-16|0;jb=e;d:{b=$S(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(742,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+48|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=YS(d+8|0,_S(a,Ni(a)+c|0),Ni(a),b);v[114578]=0;R(697,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(558,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Kt(b)}jb=d+32|0;break a}a=P()|0;O()|0;Kt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Ni(a);aT(a,b);jT(a)}}function xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=(f>>>21&2040)+27888|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function a9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=qe(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(1654,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=CJ(d+8|0,Be(a,Kb(a)+c|0),Kb(a),b);v[114578]=0;R(1651,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1648,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}cs(b)}jb=d+32|0;break a}a=P()|0;O()|0;cs(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Kb(a);xJ(a,b);Qg(a)}}function aH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}b=ba(8)|0;v[114578]=0;c=Q(85,f|0,40657)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,896)|0)+1075072|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,896);if((b|0)==x[(e+v[d>>2]|0)+1075792>>1]){e=(e+v[d>>2]|0)+1075072|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}jb=f+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function LS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=b;k=e,l=Dd(a),v[k+8>>2]=l;g=am(e+24|0,e+8|0);b=Pi(c,d);a:{b:{if(!b){break b}if($z(c,Tb(a),Tb(a)+Fb(a)|0)){b=qi(e+8|0,c,d);c=v[e+24>>2];d=Tb(b);g=Tb(b);h=Fb(b);v[114578]=0;c=aa(610,a|0,c|0,d|0,g+h|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}h=Fb(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Tb(a);i=h-g|0;if(!i){break c}j=g+f|0;$l(b+j|0,j,i);break c}Rl(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;Sg(a,b);t[e+8|0]=0;he(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){he(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=Dd(a),v[k+8>>2]=l;c=cf(e+8|0,g)}jb=e+32|0;return c|0}function $ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=0,j=C(0),k=0,m=0;f=jb-16|0;jb=f;k=f,m=B(v[a>>2],ue(a)),v[k+8>>2]=m;Cc(f+8|0,c>>>2|0);c=Db(b);g=z[e+4>>2];e=v[f+8>>2];if(e){while(1){g=C(G(C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f+8>>2];if(!e){break a}j=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=j*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());ae(f+12|0,C(-1));h=C(z[f+12>>2]*C(32768));z[f+12>>2]=h;a=c;h=je(h);b:{if(C(D(h))<C(2147483648)){i=~~h;break b}i=-2147483648}k=a,m=Vc(i),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}jb=f+16|0;return v[f+8>>2]<<2}function tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;v[d+28>>2]=0;Fi(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Wb(d+16|0);v[114578]=0;u[d+14>>1]=0;f=W(722,a|0,e|0,255)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!f){break d}v[114578]=0;Q(713,a|0,d+14|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;U(13,d|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;f=Q(723,b|0,d+14|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}Gb(f,d);yb(d);yb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Gf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}yb(e)}jb=d+32|0;return}a=P()|0;O()|0}yb(e);S(a|0);L()}function ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;u[d+30>>1]=0;xf(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Wb(d+16|0);v[114578]=0;u[d+14>>1]=0;f=W(724,a|0,e|0,255)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!f){break d}v[114578]=0;Q(713,a|0,d+14|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;U(13,d|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;f=Q(723,b|0,d+14|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}Gb(f,d);yb(d);yb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Gf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}yb(e)}jb=d+32|0;return}a=P()|0;O()|0}yb(e);S(a|0);L()}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{if(nj(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[lf(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){ee(d+8|0,b,c);if(!Cb(d+8|0)){v[114578]=0;e=Q(1427,a|0,c&65535)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(e){v[114578]=0;e=Q(85,d+8|0,20525)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;Q(371,((c<<5)+a|0)+946304|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}yb(e);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}jb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(e);break a}c=P()|0;O()|0}S(c|0);L()}function FK(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;t[h+15|0]=b;t[h+14|0]=10;gg(g,w[pc(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Kb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Pb(g,c),j=d>>>4|0,u[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(x[Pb(g,c)>>1]>=x[Pb(g,d)>>1]){break a}e=c;d=x[Pb(g,d)>>1]+1|0}i=Pb(g,e),j=d,u[i>>1]=j}b=Fd(w[b+2|0],0,64);i=Pb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Kb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;c=g;if(a&2){b=w[g+15|0];d=Kb(g);b=w[g+12|0]&-5|(b>>>0<=d>>>0)<<2}else{b=b&251}t[c+12|0]=b;c=g;c:{d:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break d}}a=b&253;break c}b=Kb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[c+12|0]=a;jb=h+16|0}function aj(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){lc(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}t[a|0]=w[b|0];b=b+1|0;c=c-1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[a>>2]=v[b>>2];b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[a|0]=w[b|0];a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}}function vo(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);e=j(1)|0;g=j(0)|0;a:{b:{c:{b=e;e=b;if(!((b|0)>-1?b>>>0>=1048576:0)){if(!(b&2147483647|g)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;h=-1023;if((e|0)!=1072693248){b=e;break b}if(g){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;g=j(0)|0;h=-1077}b=b+614242|0;d=+((b>>>20|0)+h|0);a=d*.6931471803691238;l(0,g|0);l(1,(b&1048575)+1072079006|0);f=+n()+-1;c=f/(f+2);i=a;k=d*1.9082149292705877e-10;m=c;a=f*(f*.5);d=c*c;c=d*d;a=i+(f+(k+m*(a+(c*(c*(c*.15313837699209373+.22222198432149784)+.3999999999940942)+d*(c*(c*(c*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-a))}return a}function fv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=xc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){e=jb-16|0;jb=e;d:{b=Mi(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(218,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=nh(d+8|0,Ki(a,xc(a)+c|0),xc(a),b);v[114578]=0;R(213,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(209,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}om(b)}jb=d+32|0;break a}a=P()|0;O()|0;om(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+b|0;xc(a);jD(a,b);tp(a)}}function a1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;b=d+16|0;a:{b:{c:{if(!vr(wa(v[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!vr(wa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}jb=d+32|0;return a|0}function Jw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];v[c+40>>2]=v[d+20>>2];g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;Mm(c- -64|0,c+32|0,f);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];g=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;a=c;if(f){j=b+4|0;while(1){d=0;if(g){while(1){e=v[Of(a,d,h)>>2];fc(b,d);e=(e+((Ir(j)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;e=e>>>0>491520?e:491520;k=Lm(i,d,h),l=(e|0)<557055?e:557055,u[k>>1]=l;d=d+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((f|0)!=(h|0)){continue}break}}jb=c+80|0}function Kw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Eh(c- -64|0,c+32|0,f);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(f){while(1){d=0;if(e){while(1){i=A[ch(a,d,g)>>3];fc(b,d);j=tj(Sd(i*134217728));k=rn(h,d,g),l=C(+(j|0)*7.450580596923828e-9),z[k>>2]=l;d=d+1|0;if((e|0)!=(d|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Lb(e+12|0,e+8|0)>>2];i=z[d>>2];b=Db(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Vc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Vc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return c<<3}function d5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114578]=0;Z(2042,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114578]=0;c=Q(85,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;X(2077,d+16|0,e|0,c|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break d}b=Zd(Tb(d+16|0));yb(d+16|0);yb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(c)}_(b|0)|0;b=0;v[114578]=0;X(1990,36929,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=d+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Rb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=Hma(d,0,1,1);f=mb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function qF(a,b,c,d,e,f){var g=0;g=jb-80|0;jb=g;a:{if((f|0)>=16384){rd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}rd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}rd(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}rd(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}rd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;jb=g+80|0}function M5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114578]=0;Z(2042,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114578]=0;c=Q(85,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(2043,d+16|0,e|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}b=Zd(Tb(d+16|0));yb(d+16|0);yb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(c)}_(b|0)|0;b=0;v[114578]=0;X(1990,35695,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=d+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function C6(a){a=a|0;var b=0;b=34280;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=34317;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=34181;break a}b=34294;break a}b=34336;break a}b=34350;break a}b=34364;break a}b=34376;break a}b=34396;break a}b=34417;break a}b=34429;break a}b=34448;break a}b=34480;break a}b=34502;break a}if((a|0)!=357){break a}b=34519}return Zd(b)|0}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=qe(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(373,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Un(d+8|0,Be(a,Kb(a)+c|0),Kb(a),b);v[114578]=0;R(369,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(370,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Vh(b)}jb=d+32|0;break a}a=P()|0;O()|0;Vh(b);S(a|0);L()}return}if(b>>>0<c>>>0){zu(a,v[a>>2]+(b<<2)|0)}}function ak(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;v[a+4>>2]=0;a:{b:{d=4;c:{if(!w[hj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[114578]=0;d=v[(a+d|0)+24>>2];f=v[114578];v[114578]=0;d:{if((f|0)==1){break d}v[114578]=0;b=W(2386,d|0,b|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;fj(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];c=v[114578];v[114578]=0;e:{if((c|0)!=1){if(!(b&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}$();d=1}Ag(v[v[a>>2]-12>>2]+a|0,d);jb=e+16|0;return}V(0)|0;O()|0;Ab()}L()}function bN(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c;if(x[a+28>>1]!=(b|0)){Ks(a+12|0);u[a+28>>1]=b}c=a+12|0;if(md(c)){dN(c,sy(a,x[rc(hp(a),b)>>1]))}f=e+12|0;a:{if(v[c+4>>2]!=v[zb(c)>>2]){b=jb-16|0;jb=b;a=qe(b,c,1);c=zb(c);d=v[a+4>>2];v[114578]=0;U(413,c|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+4;Mb(a);jb=b+16|0;break a}b=P()|0;O()|0;Mb(a);S(b|0);L()}d=jb-32|0;jb=d;a=c;g=zb(a);b=ks(d+8|0,Be(a,Kb(a)+1|0),Kb(a),g);c=v[b+8>>2];v[114578]=0;U(413,g|0,c|0,f|0);c=v[114578];v[114578]=0;b:{c:{if((c|0)==1){break c}v[b+8>>2]=v[b+8>>2]+4;v[114578]=0;R(96,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}nk(b);jb=d+32|0;break b}a=P()|0;O()|0;nk(b);S(a|0);L()}}jb=e+16|0}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=jb-16|0;jb=g;v[g+8>>2]=c>>>3;v[g+4>>2]=v[a>>2];d=v[Lb(g+8|0,g+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){k=0;e=b;h=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);i=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24|i>>>8;e=0;l=f&65280;f=e;e=h<<8|i>>>24;f=f|k;k=e&255|l|(i<<24|i<<8&16711680);e=g;v[e+8>>2]=((h&255)<<24|i>>>8)&-16777216|((h&16777215)<<8|i>>>24)&16711680|(h>>>8&65280|h>>>24)|f;v[e+12>>2]=k;Rf(e+8|0,-1,1);j=A[e+8>>3]*32768;A[e+8>>3]=j;e=a;j=Sd(j);a:{if(D(j)<2147483648){f=~~j;break a}f=-2147483648}m=e,n=Vc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=g+16|0;return d<<3}function pG(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}nb[d|0](a,c)}}function sz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;gg(b,w[pc(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Kb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Pb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}e=x[Pb(b,e)>>1];h=Pb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Yb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Pb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=g+16|0}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=(f>>>21&2040)+27888|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function ol(a,b){var c=0,d=0,e=0,f=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=qe(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(1623,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=lx(d+8|0,Be(a,Kb(a)+c|0),Kb(a),b);v[114578]=0;R(1600,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1599,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Wm(b)}jb=d+32|0;break a}a=P()|0;O()|0;Wm(b);S(a|0);L()}return}if(b>>>0<c>>>0){mx(a,v[a>>2]+(b<<2)|0)}}function FF(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[114578]=0;c=Q(2390,d+8|0,a|0)|0;b=v[114578];v[114578]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[114578]=0;b=T(2391,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[114578]=0;R(2392,a+b|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;DF(c);break c}DF(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(764,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,d|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(519,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,d|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function iS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(512,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,d|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function L9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;qL(a);zb(a);i=b+4|0;g=i;f=v[a+4>>2];j=v[a>>2];if((f|0)!=(j|0)){c=v[g>>2];while(1){d=c-52|0;f=f-52|0;c=f;e=fK(d,zb(c));v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];h=v[zb(c)>>2];l=zb(e),m=h,v[l>>2]=m;l=zb(c),m=0,v[l>>2]=m;v[c>>2]=0;v[c+4>>2]=0;v[d+20>>2]=v[c+20>>2];e=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=e;e=c+24|0;h=nB(d+24|0,zb(e));v[d+24>>2]=v[e>>2];v[d+28>>2]=v[e+4>>2];k=v[zb(e)>>2];l=zb(h),m=k,v[l>>2]=m;l=zb(e),m=0,v[l>>2]=m;v[e>>2]=0;v[e+4>>2]=0;td(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];c=v[g>>2]-52|0;v[g>>2]=c;if((f|0)!=(j|0)){continue}break}}Zb(a,i);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];gK(a,jf(a))}function fU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;Ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=aq(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=aq(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[pc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Xs(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}jb=d+16|0}function en(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+829|0]=c;break a}c=w[b+829|0]}d=v[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;c:{if((f|0)==15){if(e){bp(a,b,(d&240)>>>4|0,0);return}e=-60;if(t[b+872|0]&1){break c}break b}if((e|0)!=240){break b}if(f){ap(a,b,f,0);return}e=60;if(!(t[b+872|0]&1)){break b}}c=(w[a+480208|0]&2?0:e)+c|0}d:{if(!(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288?!(t[b+872|0]&1)|w[a+480208|0]&2:1)){break d}e=d&255;d=d&15;e:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break e}c=c-(d<<2)|0;break e}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break d}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Yb(c,0,256),v[g+688>>2]=h}function A1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;a:{b:{if(!ve(b,-1)){f=v[a+12>>2];g=v[a+8>>2];if(v[a+24>>2]==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}h=v[a+24>>2];i=v[a+20>>2];j=v[a+44>>2];k=v[a+20>>2];v[114578]=0;c=a+32|0;R(110,c|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break b}d=Kc(c);v[114578]=0;R(149,c|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}d=Tb(c);Nw(a,d,Fb(c)+d|0);Kr(a,h-i|0);v[a+44>>2]=v[a+20>>2]+(j-k|0)}v[e+12>>2]=v[a+24>>2]+1;l=a,m=v[bd(e+12|0,a+44|0)>>2],v[l+44>>2]=m;if(w[a+48|0]&8){c=Tb(a+32|0);Om(a,c,c+(f-g|0)|0,v[a+44>>2])}c=UG(a,Km(b));break a}c=Er(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$();c=-1}jb=e+16|0;return c|0}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=(f>>>21&2040)+27888|0;b=(((B(t[b|0],u[f+2>>1])+B(t[b-1|0],u[f>>1])|0)+B(t[b+1|0],u[f+4>>1])|0)+B(t[b+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;jb=e+16|0}function Gr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Eh(c- -64|0,c+32|0,f);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(f){while(1){d=0;if(e){while(1){i=v[Of(a,d,g)>>2];fc(b,d);j=rn(h,d,g),k=C(C(i|0)*C(7.450580596923828e-9)),z[j>>2]=k;d=d+1|0;if((e|0)!=(d|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function uJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-48|0;jb=c;v[c+8>>2]=542066252;d=c+8|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Dk(b,33);lc(v[b>>2],c+8|0,33);Wi(c,b);Od(a,c);jb=c+48|0}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-32|0;jb=b;e=gh(a);Cd(b+24|0);v[114578]=0;a=Q(2201,v[b+24>>2],v[b+28>>2])|0;c=v[114578];v[114578]=0;a:{b:{if((c|0)==1){break b}v[114578]=0;R(1534,e|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}a=0;c:{while(1){v[114578]=0;c=Q(2201,v[b+24>>2],v[b+28>>2])|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}jb=b+32|0;return}a=P()|0;O()|0;break a}c=v[v[b+24>>2]+(a<<3)>>2];v[114578]=0;c=Q(85,b+8|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(1536,e|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0}kd(e);S(a|0);L()}function XJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;f=Wb(e+32|0);v[114578]=0;Q(1621,a|0,e+24|0)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){g=v[e+28>>2];d=v[e+24>>2];Le(f);v[114578]=0;g=!g&d>>>0<255?d:255;R(149,f|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=kc(f,d);v[114578]=0;Q(1622,a|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((KD(f)|0)!=-1){a=KD(f);v[114578]=0;R(149,f|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}}v[114578]=0;U(13,e+8|0,c|0,f|0);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}break a}Gb(b,e+8|0);yb(e+8|0);yb(f);jb=e+48|0;return}a=P()|0;O()|0;yb(f);S(a|0);L()}function Cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-48|0;jb=c;d=c+24|0;f=Oi(d+8|0);v[114578]=0;e=T(332,b|0)|0;g=v[114578];v[114578]=0;a:{b:{if((g|0)==1){break b}v[114578]=0;U(423,d|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}d=v[d>>2];v[114578]=0;Q(340,b|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Pg(f);S(a|0);L()}v[114578]=0;R(703,c+8|0,c+24|0);b=v[114578];v[114578]=0;c:{if((b|0)==1){break c}v[114578]=0;R(704,c+16|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=v[c+16>>2];d=v[c+20>>2];v[114578]=0;W(705,a|0,b|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}Ec(c+24|0);jb=c+48|0;return}a=P()|0;O()|0;Ec(c+24|0);S(a|0);L()}function Iea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=TE(v[v[a>>2]-12>>2]+a|0,10);e=jb-16|0;jb=e;v[114578]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=Rk(e,c);v[114578]=0;Q(2398,b|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){if(!Pk(b)){break e}b=v[v[c>>2]-12>>2];v[114578]=0;R(18,b+c|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Hf(d);break d}Hf(d);break c}b=V(0)|0;O()|0}_(b|0)|0;d=v[v[c>>2]-12>>2];v[114578]=0;Z(19,c+d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}$()}jb=e+16|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}lr(a);return a|0}function Hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-528|0;jb=d;c=-1;a:{if(!Df(a,1468)){break a}xk(a,1464);BQ(a,d+524|0);if(!$d(d+524|0,16026)){c=0;if(!$d(d+524|0,16031)){break a}}xk(a,20);b=1;while(1){c=-1;if(!yQ(a,d)){break a}e=qz(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;c=jb-16|0;jb=c;b=a;b:{if(Df(a,2)){Ok(c+8|0,e);iz(b,c+8|0);break b}t[c+7|0]=0;gB(e,c+7|0)}jb=c+16|0;e=cd(d+520|0);c=0;if(w[d+520|0]>128){break a}b=d;c=jb-16|0;jb=c;c:{if(Df(a,512)){Xt(c+8|0,b);iz(a,c+8|0);break c}hQ(b)}jb=c+16|0;a=d+512|0;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}jb=d+528|0;return c|0}function bK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=C(0),j=0,k=C(0);f=jb-16|0;jb=f;if(!(!x[b>>1]|u[d>>1]>u[d+2>>1]|(!(z[c>>2]>C(0))|(u[d+2>>1]-u[d>>1]|0)>32766))){u[a>>1]=3;g=a+4|0;ti(g);u[a+28>>1]=65472;v[f+12>>2]=1065353216;dK(g,128,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;ti(a+16|0);u[a+28>>1]=x[d>>1];e=jb-16|0;jb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[lf(e+14|0,e+12|0)>>1];jb=e+16|0;u[a+30>>1]=b;h=C(D(z[c>>2]));z[a+32>>2]=h;h=ne(h,C(C(1)/C(u[a+30>>1])));e=1;ol(g,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){i=ne(h,C(b|0));j=Pb(g,b-u[a+28>>1]|0),k=i,z[j>>2]=k;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}Mo(a)}jb=f+16|0;return e|0}function Ko(a,b,c){var d=0,e=0,f=0;d=Wb(a);a=Fb(b);v[114578]=0;R(111,d|0,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){a:{if(Fb(b)){while(1){f=v[ij(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[114578]=0;R(110,d|0,63);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Fb(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;yb(d);S(a|0);L()}function K9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-16|0;jb=c;u[a>>1]=0;e=kk(a+4|0);h=kk(a+16|0);v[a+36>>2]=0;j=fd(a+40|0);f=jb-16|0;jb=f;g=f+8|0;b=jb-16|0;jb=b;v[114578]=0;i=a+52|0;d=i;T(1596,d+4|0)|0;k=v[114578];v[114578]=0;a:{b:{c:{if((k|0)!=1){v[114578]=0;v[b+12>>2]=0;W(1597,d+8|0,b+12|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break c}break b}break b}l=d,m=hc(d),v[l>>2]=m;jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=f+16|0;ti(e);u[a+28>>1]=65472;v[114578]=0;v[c+12>>2]=1065353216;U(1594,e|0,128,c+12|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;ti(h);jb=c+16|0;return a|0}a=P()|0;O()|0;XR(i);yb(j);Sf(h);Sf(e);S(a|0);L()}function so(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=d?d:461448;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[21203]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+60112>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[114552]=25;e=-1;break a}v[f>>2]=d}jb=h+16|0;return e|0}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){v[e+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=h,j=Vc(g),u[i>>1]=j;v[e+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=h,j=Vc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;a:{b:{if(v[a+8>>2]!=v[ec(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];e=v[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,j=gf(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=d,j=v[ec(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[d+44>>2]=1;c=v[bd(d+24|0,d+44|0)>>2];c=Un(d+24|0,c,c>>>2|0,v[a+16>>2]);e=Oc(d+16|0,v[a+4>>2]);f=v[Oc(d+8|0,v[a+8>>2])>>2];e=v[e>>2];v[114578]=0;U(1162,c|0,e|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Zb(a,c);Zb(h,c+4|0);Zb(g,c+8|0);Zb(ec(a),ec(c));Vh(c)}rR(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;jb=d+48|0;return}a=P()|0;O()|0;Vh(c);S(a|0);L()}function cy(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{if(!d){break a}if(c){t[b+835|0]=c;break a}c=w[b+835|0]}c=v[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{if(!(v[a+480180>>2]&1048580)){d=c&240;c=c&15;if(!(!d|(c|0)!=15)){if(!(w[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=v[a+480208>>2]&4096;if(!(!c|(d|0)!=240)){if(!f){break b}c=c<<2;break c}if(f){break b}if(c){c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Eb(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(e+8|0)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Yb(v[b+692>>2]+c|0,0,256);u[b+796>>1]=0;v[b+692>>2]=a}jb=e+16|0}function rQ(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Qb(a,1024)){jz(c+24|0,b);Bd(a,c+24|0);break a}v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;a=64;while(1){d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}jb=c+32|0}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;Le(b);Me(e+56|0,a,d);a=v[e+56>>2];v[114578]=0;f=T(414,e+56|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114578]=0;f=T(415,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;X(416,e+8|0,3,f|0,a|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;R(417,e+24|0,e+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;U(13,e+40|0,c|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Gb(b,e+40|0);yb(e+40|0);yb(e+24|0);Ec(e+56|0);jb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+24|0)}Ec(e+56|0);S(a|0);L()}return a|0}
function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{f=jb-16|0;jb=f;d=c;zb(c);a=b;h=fK(a,f+8|0);b:{g=cg(c);if(!g){break b}v[114578]=0;R(680,a|0,g|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[d+4>>2];d=v[d>>2];v[114578]=0;X(1592,a|0,d|0,e|0,g|0);d=v[114578];v[114578]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;At(h);S(a|0);L()}jb=f+16|0;d=a;v[b+20>>2]=v[c+20>>2];a=v[c+16>>2];v[b+12>>2]=v[c+12>>2];v[b+16>>2]=a;v[114578]=0;e=Q(1591,b+24|0,c+24|0)|0;a=v[114578];v[114578]=0;c:{d:{if((a|0)!=1){v[114578]=0;Q(120,b+36|0,c+36|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break d}v[b+48>>2]=v[c+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;oe(e)}Ll(d);S(a|0);L()}}function J8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=pi(a,b,c,d);v[a>>2]=79476;c=Oi(a+4208|0);d=a+4288|0;v[d>>2]=0;v[d+4>>2]=0;v[a+4280>>2]=0;v[a+4284>>2]=0;v[114578]=0;d=da(1396)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;d=T(1397,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[a+4296>>2]=d;t[a+4244|0]=0;v[a+4236>>2]=2147483647;v[a+4240>>2]=0;bs(a);as(a);v[114578]=0;W(1641,a+44|0,2,2)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;Z(1642,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Pg(c);bf(b);S(a|0);L()}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;Le(b);Me(e+56|0,a,d);a=v[e+56>>2];v[114578]=0;f=T(414,e+56|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114578]=0;f=T(415,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;X(416,e+8|0,2,f|0,a|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;R(417,e+24|0,e+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;U(13,e+40|0,c|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Gb(b,e+40|0);yb(e+40|0);yb(e+24|0);Ec(e+56|0);jb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+24|0)}Ec(e+56|0);S(a|0);L()}return a|0}function cH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=jb-16|0;jb=d;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114578]=0;d=Q(85,d|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,d);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}if(c<=1?c<0:1){a=ba(8)|0;v[114578]=0;d=Q(85,d|0,40635)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,d);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=nn(c*64);v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]=e;jb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Hw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Do(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(e){while(1){d=0;if(f){while(1){i=A[ch(a,d,g)>>3];fc(b,d);j=tj(Sd(i*134217728));k=Of(h,d,g),l=C(+(j|0)*7.450580596923828e-9),z[k>>2]=l;d=d+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function WK(a,b){var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;if(v[a+4>>2]==v[b+4>>2]){c=v[a+4>>2];g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=c;d=v[b+4>>2];a=f;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=d;v[a+8>>2]=g;v[a+12>>2]=c;v[a>>2]=b;v[a+4>>2]=d;c=jb-16|0;jb=c;d=a+8|0;v[c+12>>2]=v[d+4>>2];b=a;v[c+8>>2]=v[a+4>>2];a:{b:{if(!v[Lb(c+12|0,c+8|0)>>2]){break b}while(1){a=Io(t[wc(d,e)|0]);g=Io(t[wc(b,e)|0]);if((a|0)!=(g|0)){a=(a&255)>>>0<(g&255)>>>0?-1:1;break a}if(a){v[c+12>>2]=v[d+4>>2];v[c+8>>2]=v[b+4>>2];e=e+1|0;if(e>>>0>=y[Lb(c+12|0,c+8|0)>>2]){break b}continue}break}a=0;break a}a=0;if(v[d+4>>2]==v[b+4>>2]){break a}a=y[d+4>>2]<y[b+4>>2]?-1:1}jb=c+16|0;e=!a}jb=f+32|0;return e}function Ox(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-16|0;jb=c;if(!md(a)){l=c,m=bc(a),v[l+8>>2]=m;l=c,m=cc(a),v[l>>2]=m;if(Jb(c+8|0,c)){while(1){b=v[c+8>>2];Yn(b,4194304,67108864);e=v[b>>2];f=e+f|0;b=g;b=f>>>0<e>>>0?b+1|0:b;g=b;_d(c+8|0);if(Jb(c+8|0,c)){continue}break}}b=Kb(a);h=Kb(a);l=c,m=bc(a),v[l+8>>2]=m;l=c,m=cc(a),v[l>>2]=m;b=Kma(f,g,b,0);e=mb;f=h<<24;g=0;if(Jb(c+8|0,c)){h=b;e=((e&1)<<31|b>>>1)&2147483647;while(1){b=v[c+8>>2];i=b;d=v[b>>2];b=d>>>8|0;d=e+(d<<24)|0;b=b+j|0;b=hd(Kma(d,e>>>0>d>>>0?b+1|0:b,h,k),mb);v[i>>2]=b;d=f;f=d-b|0;g=g-(b>>>0>d>>>0)|0;_d(c+8|0);if(Jb(c+8|0,c)){continue}break}}a=Dc(a,0);v[a>>2]=f+v[a>>2]}jb=c+16|0}function Bk(a,b,c,d){var e=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}d=v[hc(a)>>2];b=v[c>>2];c=(d|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}e=ug(v[b+8>>2]);c=v[b+8>>2];b:{if(e){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!ug(b)){b=v[b+8>>2];Ep(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Dp(b);break a}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(ug(b)){b=v[b+8>>2];Dp(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Ep(b);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(b|0)==(d|0);t[c+12|0]=1;if((b|0)!=(d|0)){continue}break}}a=zb(a);v[a>>2]=v[a>>2]+1}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb+-64|0;jb=d;e=v[a+28>>2];Dn(v[v[e>>2]-12>>2]+e|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];e=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;f=Og(d+48|0,f,f>>>0<g>>>0?e+1|0:e);g=v[f+12>>2];v[d+16>>2]=v[f+8>>2];v[d+20>>2]=g;e=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=e;ej(h,d+8|0)}pf(d+24|0,v[a+28>>2]);e=v[d+36>>2];v[d+40>>2]=v[d+32>>2];v[d+44>>2]=e;nb[1187](v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];e=nm(d+24|0,wc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114578]=0;a=aa(1632,a|0,c|0,e|0,d+40|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){Ib(e);jb=d- -64|0;break a}a=P()|0;O()|0;Ib(e);S(a|0);L()}return a|0}function lJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-16|0;jb=f;vh(f+8|0,b);e=jb-16|0;jb=e;ho(e+8|0,wh(e,f+8|0));c=e+8|0;g=jb-16|0;jb=g;d=v[a+8>>2];b=v[a+12>>2];a:{if((b|0)<0){break a}if(k=1,l=(n=Hb(a)>>>0<d>>>0,o=0,p=(b|0)>=0,p?n:o),m=(b|0)>0,m?k:l){break a}d=Hb(a);h=v[a+8>>2];i=0-((d>>>0<h>>>0)+v[a+12>>2]|0)|0;b=g;v[b+8>>2]=d-h;v[b+12>>2]=i;k=b,l=oh(c),v[k>>2]=l;v[b+4>>2]=0;b=Az(b+8|0,b);b=bR(v[b>>2],v[b+4>>2]);if((b|0)!=(oh(c)|0)){break a}gf(v[c>>2],v[c>>2]+b|0,Db(v[a>>2]+v[a+8>>2]|0));c=a;d=b+v[a+8>>2]|0;a=v[a+12>>2];v[c+8>>2]=d;v[c+12>>2]=b>>>0>d>>>0?a+1|0:a;j=1}jb=g+16|0;jb=e+16|0;jb=f+16|0;return j|0}function zP(a,b){var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;Me(c+40|0,a,4);a=v[c+40>>2];v[114578]=0;d=T(414,c+40|0)|0;e=v[114578];v[114578]=0;b:{c:{d:{if((e|0)==1){break d}v[114578]=0;d=T(415,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;X(416,c+8|0,3,d|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(417,c+24|0,c+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(986,c|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}v[114578]=0;Q(471,c|0,c+24|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}yb(c+24|0);Ec(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+24|0)}Ec(c+40|0);S(a|0);L()}}function eW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-32|0;jb=c;a:{b:{c:{d:{if(i=Wc(b),j=1,k=v[b+12>>2],k?i:j){fd(a);break d}e=jb-16|0;jb=e;f=aF(c+16|0,e+8|0);d=Fb(b);g=$e(7063);h=Tb(b);v[114578]=0;X(195,f|0,h|0,d|0,d+g|0);d=v[114578];v[114578]=0;e:{if((d|0)!=1){v[114578]=0;W(196,f|0,7063,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;yb(f);S(a|0);L()}jb=e+16|0;v[114578]=0;R(234,c|0,b+12|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;U(3,a|0,c+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}yb(c);yb(c+16|0)}jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(c+16|0);S(b|0);L()}function $c(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=v[a+112>>2];d=v[a+116>>2];b:{if(c|d){b=c>>>0<=y[a+120>>2];c=v[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=gw(a);if((g|0)>-1){break a}}v[a+104>>2]=0;return-1}h=a;b=v[a+116>>2];i=b;d=v[a+8>>2];c=d;f=v[a+112>>2];c:{if(!(b|f)){break c}c=d;e=v[a+120>>2]^-1;f=e+f|0;b=(v[a+124>>2]^-1)+i|0;b=f>>>0<e>>>0?b+1|0:b;i=v[a+4>>2];e=d-i|0;j=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?j:0){break c}c=f+i|0}v[h+104>>2]=c;h=v[a+4>>2];if(d){c=a;b=(d-h|0)+1|0;d=b+v[a+120>>2]|0;a=v[a+124>>2]+(b>>31)|0;v[c+120>>2]=d;v[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=h-1|0;if(w[a|0]!=(g|0)){t[a|0]=g}return g}function Nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;jb=e+32|0}function Mg(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=z[a+4268>>2];f=LI(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));e=ne(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(z[a+4268>>2]*C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))));c=C(C(ne(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-yo(c>C(1)?C(3.1415927410125732):C(C(f*C(6.2831854820251465))/d))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(C(D(g))<=C(1)){break a}g=C(C(-C(c+d))/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;Ed(b,0);yP(d,a+1|0);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;Cc(b+8|0,v[b>>2]);Cc(b+4|0,v[b+8>>2]);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function dl(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&(c|0)!=0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&(g|0)!=0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jf(a);if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{e=b-d|0;c:{if(e>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/52>>>0){ox(a,e,c);break c}f=zb(a);h=nK(a,jf(a)+e|0);j=jf(a);d=0;i=jb-16|0;jb=i;v[i+12>>2]=0;b=g+8|0;Tc(b+12|0,f);if(h){d=hK(v[b+16>>2],h)}v[b>>2]=d;f=B(j,52)+d|0;v[b+8>>2]=f;v[b+4>>2]=f;k=ec(b),l=B(h,52)+d|0,v[k>>2]=l;jb=i+16|0;v[114578]=0;U(1587,b|0,e|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1588,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}eK(b)}jb=g+32|0;break a}a=P()|0;O()|0;eK(b);S(a|0);L()}return}if(b>>>0<d>>>0){oK(a,v[a>>2]+B(b,52)|0)}}function oO(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+820|0]=0;return}t[a+820|0]=1;return}t[a+820|0]=2;return}t[a+820|0]=3;return}t[a+724|0]=w[a+724|0]&254;return}t[a+724|0]=w[a+724|0]|1;return}t[a+736|0]=w[a+736|0]&254;return}t[a+736|0]=w[a+736|0]|1;return}t[a+748|0]=w[a+748|0]&254;return}t[a+748|0]=w[a+748|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+748|0];t[c+748|0]=(b|0)==13?a&238|1:a|17}}function G$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;a:{if(iF(c)){while(1){if(a>>>d&1){i=(d<<2)+c|0,j=jF(d,b),v[i>>2]=j}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){h=(e+8|0)+(d<<2)|0;f=1<<d&a;if(f|!c){f=jF(d,f?b:60523)}else{f=v[(d<<2)+c>>2]}v[h>>2]=f;g=((f|0)!=0)+g|0;d=d+1|0;if((d|0)!=6){continue}break}c=60368;b:{c:{switch(g|0){case 0:break a;case 1:break c;default:break b}}if(v[e+8>>2]!=60340){break b}c=60392;break a}c=od(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}jb=e+32|0;return c|0}function Saa(a,b){a=a|0;b=b|0;var c=0,d=0;b=78208;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1519,a+8|0,c+12|0,c+8|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{while(1){c:{if(!md(a)){if(!ii(v[b+8>>2],v[pj(a)>>2])){break c}}v[114578]=0;R(1518,a|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)!=1){break c}break b}b=b+12|0;if((b|0)!=78724){continue}break}b=78736;while(1){d:{if(!md(a)){if(!ii(v[b+8>>2],v[pj(a)>>2])){break d}}v[114578]=0;R(1518,a|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)!=1){break d}break b}b=b+12|0;if((b|0)!=78784){continue}break}return}b=P()|0;O()|0;Cx(a);S(b|0);L()}function g_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;c=jb-416|0;jb=c;v[c+12>>2]=c+416;d=jb-144|0;jb=d;v[d+28>>2]=d+132;ME(a+8|0,d+32|0,d+28|0,e,f,g);v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=d+32;f=c+16|0;h=VQ(f,v[c+12>>2]);e=jb-16|0;jb=e;v[e+12>>2]=v[a+8>>2];g=Ah(e+8|0,e+12|0);v[114578]=0;a=Ov(f,d+12|0,h,d+16|0);h=v[114578];v[114578]=0;a:{if((h|0)!=1){Ie(g);jb=e+16|0;break a}a=P()|0;O()|0;Ie(g);S(a|0);L()}if((a|0)==-1){$q(65220);L()}v[c+12>>2]=f+(a<<2);jb=d+144|0;d=c+16|0;e=v[c+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((d|0)!=(e|0)){wF(a+8|0,v[d>>2]);d=d+4|0;continue}break}jb=a+16|0;jb=c+416|0;return v[a+8>>2]}function l9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+56>>2]=d;d=v[a+28>>2];Dn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];f=v[a+12>>2];g=v[v[b>>2]+4>>2];d=g+v[a+8>>2]|0;f=Og(e+40|0,d,d>>>0<g>>>0?f+1|0:f);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;ej(h,e)}pf(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;XJ(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=nm(e+16|0,wc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114578]=0;aa(1632,a|0,c|0,b|0,e+32|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){Ib(b);jb=e- -64|0;return}a=P()|0;O()|0;Ib(b);S(a|0);L()}function j9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+56>>2]=d;d=v[a+28>>2];Dn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];f=v[a+12>>2];g=v[v[b>>2]+4>>2];d=g+v[a+8>>2]|0;f=Og(e+40|0,d,d>>>0<g>>>0?f+1|0:f);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;ej(h,e)}pf(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;SJ(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=nm(e+16|0,wc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114578]=0;aa(1632,a|0,c|0,b|0,e+32|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){Ib(b);jb=e- -64|0;return}a=P()|0;O()|0;Ib(b);S(a|0);L()}function Fr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Do(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(e){while(1){d=0;if(f){while(1){i=v[Of(a,d,g)>>2];fc(b,d);j=Of(h,d,g),k=C(C(i|0)*C(7.450580596923828e-9)),z[j>>2]=k;d=d+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function ep(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;if(e){t[e|0]=0}i=a+484344|0;a:{if(!dg(i,b)){break a}d=Xe(_b(i,b),c,d);g=w[d+5|0];b:{c:{d:{h=w[d+3|0];switch(h-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}v[f+12>>2]=2;j=0;break b}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4}l=f,m=v[_b(i,b)+12>>2]+(c^-1)|0,v[l+8>>2]=m;a=v[Lb(f+8|0,f+12|0)>>2];if(!a){break a}while(1){k=B(lk(_b(i,b)),6);c=k+d|0;if(w[c+3|0]!=34){break a}h=g<<8;g=j?g>>>0<256?h+-8192|0:h:h;d=w[(d+k|0)+5|0];a=a-1|0;if(e){t[e|0]=1}g=d|g;d=c;if(a){continue}break}}jb=f+16|0;return g|0}function pi(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=79680;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;e=qJ(b);f=qJ(b+12|0);g=pJ(b+24|0);d=pJ(b+36|0);v[114578]=0;W(1641,b|0,2,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){a=P()|0;O()|0;_r(d);_r(g);Zr(f);Zr(e);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;e=v[a+16>>2];v[e+946300>>2]=v[e+946300>>2]+1;v[c>>2]=a+99&-8;f=v[a+20>>2];if((f|0)!=(e+906300|0)){g=a+4200|0;while(1){c=b+1|0;if((f|0)!=((e+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[g|0]=c}return a}function Ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+16|0}function _G(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb-16|0;jb=e;a:{b:{c:{d=a+8|0;d:{if(!ml(d)){if((b|0)<0|(Or(d)|0)<=(b|0)){break d}a=vp(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=ml(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[114578]=0;c=Q(85,e|0,40673)|0;b=v[114578];v[114578]=0;e:{if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}jb=e+16|0;return}L()}function qba(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}pK(a+484344|0);Le(a+1304400|0);Le(a+1304412|0);Le(a+1304424|0);kA(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){pn(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Xb(rt(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){jJ(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function HW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=jb-32|0;jb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[114578]=0;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ia(2008,a|0,b|0,k|0)|0;b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;ja(2001,34684,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();a=-255}jb=l+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function Lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+16|0}function Gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;Ed(b,0);Qi(d,1,a);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;e=b,f=w[pc(d+16|0,d)|0]<<2,u[e+30>>1]=f;jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function F_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Bc(f+24|0,c);v[114578]=0;a=T(2458,f+24|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){_g(f+24|0,a);break c}Zg(f+24|0,a)}g=f,h=Dd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=Vj(f+24|0),v[g+8>>2]=h;if(!Jb(f+16|0,f+8|0)){c=v[f+40>>2];Lc(f+24|0);break a}a=v[v[f+16>>2]>>2];v[114578]=0;Q(2481,f+40|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_d(f+16|0);continue}break}c=P()|0;O()|0;Lc(f+24|0);break b}c=P()|0;O()|0;Ob(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(372,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(372,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(380,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,1,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(372,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function wB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(371,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)==1){break c}v[114578]=0;Z(2042,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[114578]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;X(2081,c+16|0,d|0,c|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(c+16|0));yb(c+16|0);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1990,37051,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=c+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function gT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(0-c|0,6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-48|0;jb=e;f=Tb(b);g=Fb(b);i=Tb(c);j=Fb(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(_n(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=Dd(b),v[k+32>>2]=l;c=Md(e+40|0,e+32|0);k=e,l=Dd(b),v[k+8>>2]=l;k=e,l=cf(e+8|0,h),v[k+16>>2]=l;d=Md(e+24|0,e+16|0);ax(b,v[c>>2],v[d>>2]);break c}if(!Fb(b)){break c}f=Tb(b);h=Fb(b);g=Tb(c);d=-1;i=Fb(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!_n(g,i,c)){continue}break}d=c-f|0}}if((Fb(b)-1|0)!=(d|0)){break c}fd(a);break b}td(a,b)}jb=e+48|0}function R_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Bc(f+24|0,c);v[114578]=0;a=T(2424,f+24|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){_g(f+24|0,a);break c}Zg(f+24|0,a)}g=f,h=Dd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=sf(f+24|0),v[g+8>>2]=h;if(!Jb(f+16|0,f+8|0)){c=v[f+40>>2];yb(f+24|0);break a}a=t[v[f+16>>2]];v[114578]=0;Q(2398,f+40|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){qg(f+16|0);continue}break}c=P()|0;O()|0;yb(f+24|0);break b}c=P()|0;O()|0;Ob(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function Cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(607,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!a){break d}v[114578]=0;U(599,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(600,d|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}hf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;hf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}bA(d);S(a|0);L()}
function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(773,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114578]=0;a=Q(258,b|0,6)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!a){break d}v[114578]=0;U(760,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(761,d|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}hf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;hf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}Gz(d);S(a|0);L()}
function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;jb=b+16|0}function FW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[114578]=0;Z(2016,a|0);f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;Z(2042,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}f=v[a+24>>2];b=qc(e+8|0,b);v[114578]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ga(2084,f|0,e|0,c|0,d|0,1);c=v[114578];v[114578]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37133,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();b=0}jb=e+16|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return b|0}function iO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;f=jb-16|0;jb=f;g=f+8|0;c=jb-16|0;jb=c;v[114578]=0;e=a;T(1165,a+4|0)|0;a=v[114578];v[114578]=0;a:{b:{c:{if((a|0)!=1){v[114578]=0;v[c+12>>2]=0;W(1166,e+8|0,c+12|0,g|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}break b}h=e,i=hc(e),v[h>>2]=i;jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=f+16|0;a=b+236|0;b=$s(a);d:{if((a|0)!=(b|0)){while(1){c=x[a>>1];u[d+14>>1]=c;if(c){v[114578]=0;U(1164,d|0,e|0,d+14|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}jb=d+16|0;return}a=P()|0;O()|0;Ap(e);S(a|0);L()}function hj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;t[a|0]=0;f=Gf(v[v[b>>2]-12>>2]+b|0);e=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){if(v[e+72>>2]){lr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}Bc(d+24|0,v[v[b>>2]-12>>2]+b|0);v[114578]=0;f=T(21,d+24|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}Ob(d+24|0);c=Dm(d+16|0,b);e=Ek(d+8|0);while(1){d:{if(!to(c,e)){break d}if(!Kg(f,8192,bk(c))){break d}hl(c);continue}break}if(!gj(c,e)){break c}Ag(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Gf(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}Ag(e,4)}jb=d+32|0;return a}a=P()|0;O()|0;Ob(d+24|0);S(a|0);L()}function LT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(531,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!a){break d}v[114578]=0;U(513,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(514,d|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}hf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;hf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}rA(d);S(a|0);L()}function kM(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=cM(a,c&15);b=Hma(a,a>>31,d,d>>31)+32768|0;a=mb;a=Ac(Ima(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}}function dF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;jb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[21203]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+60112>>2];if(d<<B(c,6)-6<0?c>>>0<=3:0){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[114552]=25;e=-1}return e|0}function qG(a,b,c,d,e){var f=0,g=0,h=0;f=jb-208|0;jb=f;v[f+204>>2]=c;Rb(f+160|0,0,40);v[f+200>>2]=v[f+204>>2];a:{if((ow(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}g=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}h=c&32;b:{if(v[a+48>>2]){b=ow(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;v[a+16>>2]=f+80;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=ow(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!c){break b}nb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|h;b=a&32?-1:b;if(!g){break a}}jb=f+208|0;return b}function Zaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}iO(g+16|0,b);i=g,j=aR(g+16|0),v[i+8>>2]=j;i=g,j=zj(g+16|0),v[i>>2]=j;while(1){b:{v[114578]=0;b=Q(788,g+8|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}if(!b){Ap(g+16|0);break a}v[114578]=0;b=T(789,g+8|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}st(g+8|0);continue}break}a=P()|0;O()|0;Ap(g+16|0);S(a|0);L()}jb=g+32|0}function xQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[rc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}eg(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(Lj(a)&-2)){break c}Qc(a,i+(c<<10)|0);if(!nz(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Qc(a,i+((j&65535)<<10)|0);h=nz(a,64,1)?h:j}Qc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(Lj(a)|0)){break d}}if(c>>>0>=255){mz(b,254,65534);mz(b,255,65535)}k=h}return k&65535}function mO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b=jb-16|0;jb=b;g=b;d=jb-144|0;jb=d;e=dh(d+8|0);f=v[v[e>>2]-12>>2];v[114578]=0;h=da(122)|0;i=v[114578];v[114578]=0;b:{c:{if((i|0)==1){break c}v[114578]=0;U(123,d|0,f+(d+8|0)|0,h|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}Ob(d);v[114578]=0;R(133,e|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}v[114578]=0;R(125,g|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Yd(e);jb=d+144|0;break b}a=P()|0;O()|0;Yd(e);S(a|0);L()}v[114578]=0;U(13,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function OD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=1;a:{b:{switch(b-a>>2){case 2:b=b-4|0;if(!Jd(b,a)){break a}Zb(a,b);break a;case 3:rm(a,a+4|0,b-4|0);break a;case 4:uv(a,a+4|0,a+8|0,b-4|0);break a;case 5:tv(a,a+4|0,a+8|0,a+12|0,b-4|0);break a;case 0:case 1:break a;default:break b}}d=a+8|0;rm(a,a+4|0,d);c=a+12|0;while(1){if((b|0)==(c|0)){break a}c:{if(Jd(c,d)){v[f+12>>2]=v[c>>2];h=c;while(1){d:{e=d;v[h>>2]=v[e>>2];if((a|0)==(e|0)){e=a;break d}h=e;d=e-4|0;if(Jd(f+12|0,d)){continue}}break}v[e>>2]=v[f+12>>2];i=i+1|0;if((i|0)==8){break c}}d=c;c=c+4|0;continue}break}g=(c+4|0)==(b|0)}jb=f+16|0;return g}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;jb=b+16|0}function GG(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Ae(a)){dc(a,31);return 0}f=a,g=Ae(a),t[f+1375|0]=g;e=ki(a);b=ki(a);ki(a);f=a,g=ki(a),v[f+1112>>2]=g;ki(a);c=Ae(a);v[a+1116>>2]=c;if(!xw(a,a+1120|0,c)){dc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b|0)==-1?(e|0)==-1:0){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=e;v[a+1404>>2]=b}if(w[a+1377|0]){c=0;d=v[a+1116>>2];b:{if((d|0)>0){b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}b=(c+d|0)+27|0;break b}b=d+27|0}v[a- -64>>2]=e;v[a+60>>2]=b+v[a+56>>2]}v[a+1380>>2]=0;return 1}function rg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb+-64|0;jb=e;a:{b:{if(c-1>>>0>1023){break b}if(dg(a,b)){break b}c:{d:{if(jf(a)>>>0<=b>>>0){d=px(e+8|0,a);v[114578]=0;U(1584,a|0,b+1|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}ul(d)}d=Ge(a,b);v[114578]=0;Q(1585,d|0,c|0)|0;c=v[114578];v[114578]=0;e:{if((c|0)!=1){c=Ge(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=Ge(a,b);v[114578]=0;Q(1586,c|0,32324)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break e}}a=V(71204)|0;b=O()|0;break c}g=mh(Ge(a,b));break b}a=V(71204)|0;b=O()|0;ul(d)}if((ga(71204)|0)!=(b|0)){break a}_(a|0)|0;$()}jb=e- -64|0;return g|0}S(a|0);L()}function sU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;v[c+16>>2]=b;v[c+24>>2]=a;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;a:{b:{if(!Jb(d+24|0,d+16|0)){break b}v[d+8>>2]=v[d+24>>2];if(!Jb(_d(d+8|0),d+16|0)){break b}while(1){if(rl(v[d+24>>2],v[d+8>>2])){a=v[d+24>>2];break a}v[d+24>>2]=v[d+8>>2];if(Jb(_d(d+8|0),d+16|0)){continue}break}}a=v[d+16>>2]}jb=d+32|0;v[c+24>>2]=a;if(Jb(c+24|0,c+16|0)){v[c>>2]=v[c+24>>2];_d(c);if(Jb(_d(c),c+16|0)){while(1){if(!rl(v[c+24>>2],v[c>>2])){a=v[v[c>>2]>>2];e=v[_d(c+24|0)>>2],f=a,v[e>>2]=f}if(Jb(_d(c),c+16|0)){continue}break}}_d(c+24|0)}jb=c+32|0;return v[c+24>>2]}function GW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114578]=0;Z(2042,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[a+24>>2];e=qc(d+8|0,b);v[114578]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=wD(c,d,1);e=v[114578];v[114578]=0;c=mb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36983,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();b=0;c=0}jb=d+16|0;a=c;break a}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}qa(a|0);return b|0}function wJ(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;gx(a);ae(d+12|0,C(0));a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];bs(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);bs(a);break a;case 4:b=a;a=Lh(C(z[d+12>>2]*C(32)));v[b+4232>>2]=(a|0)<5?a:5;jb=d+16|0;return;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){fx(a);c=z[d+12>>2]}A[b+4256>>3]=c}jb=d+16|0}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{c:{if((e|0)==1){break c}v[114578]=0;Z(2042,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}e=v[a+24>>2];b=qc(d+8|0,b);v[114578]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;X(2083,e|0,d|0,(c|0)!=0|0,1);c=v[114578];v[114578]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37102,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;bj(a);zb(a);j=b+4|0;h=j;e=v[a+4>>2];k=v[a>>2];if((e|0)!=(k|0)){f=v[h>>2];while(1){e=e-12|0;d=e;i=zb(d);g=jb-16|0;jb=g;c=f-12|0;f=c;v[c>>2]=0;v[c+4>>2]=0;v[g+12>>2]=0;v[114578]=0;W(1027,c+8|0,g+12|0,i|0)|0;i=v[114578];v[114578]=0;a:{if((i|0)!=1){jb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];c=v[zb(d)>>2];l=zb(f),m=c,v[l>>2]=m;l=zb(d),m=0,v[l>>2]=m;v[d>>2]=0;v[d+4>>2]=0;f=v[h>>2]-12|0;v[h>>2]=f;if((e|0)!=(k|0)){continue}break}}Zb(a,j);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,yc(a))}function YZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=BE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);ai(i,k);Lc(k);Zg(k,a);ai(h,k);Lc(k);l=d,m=ei(a),v[l>>2]=m;l=e,m=di(a),v[l>>2]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);ai(g,k);Lc(k);a=Qj(a);break a}a=AE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);ai(i,k);Lc(k);Zg(k,a);ai(h,k);Lc(k);l=d,m=ei(a),v[l>>2]=m;l=e,m=di(a),v[l>>2]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);ai(g,k);Lc(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function Fv(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;Bc(f+8|0,b);v[114578]=0;b=T(2457,f+8|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;aa(2471,b|0,64400,64432,c|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;b=T(2458,f+8|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;c=T(2472,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}v[d>>2]=c;v[114578]=0;c=T(2468,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[e>>2]=c;v[114578]=0;R(2469,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;Ob(f+8|0);S(a|0);L()}function s6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-32|0;jb=d;e=jb-16|0;jb=e;c=a;k=c;g=b;f=Ke(c);h=hc(c);i=jb-16|0;jb=i;if(f){while(1){j=Hs(zb(k),f+16|0,g);h=j?h:f;f=v[(j?4:0)+f>>2];if(f){continue}break}}g=v[Oc(i+8|0,h)>>2];jb=i+16|0;v[e+8>>2]=g;l=e,m=zj(c),v[l>>2]=m;a:{b:{if(!Jb(e+8|0,e)){break b}if(Hs(zb(c),b,jh(e+8|0))){break b}b=v[e+8>>2];break a}b=zj(c)}jb=e+16|0;v[d+24>>2]=b;l=d,m=zj(a),v[l+16>>2]=m;b=0;if(!rl(d+24|0,d+16|0)){c=v[Oc(d+8|0,v[d+24>>2])>>2];b=jb-16|0;jb=b;v[b+8>>2]=c;c=v[b+8>>2];TJ(a,c);hc(a);kn(jh(b+8|0));ny(c);jb=b+16|0;b=1}jb=d+32|0;return b|0}function mn(a){var b=0,c=0,d=0;b=(x[a+24>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+40>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+32>>1]=d;u[a+36>>1]=b?1:1<<c-12;u[a+34>>1]=-1<<d^-1;if(x[a+24>>1]==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+52>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+44>>1]=d;u[a+48>>1]=b?1:1<<c-12;u[a+46>>1]=-1<<d^-1;b=(x[a+30>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+64>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+56>>1]=d;u[a+60>>1]=b?1:1<<c-12;u[a+58>>1]=-1<<d^-1}function Yz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;gg(b,Fd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Kb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Si(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Pb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[de(e+8|0,e+4|0)>>2];h=Pb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=e+16|0}function d_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=GE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);Gb(i,k);yb(k);Zg(k,a);Gb(h,k);yb(k);l=d,m=ei(a),t[l|0]=m;l=e,m=di(a),t[l|0]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);Gb(g,k);yb(k);a=Qj(a);break a}a=EE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);Gb(i,k);yb(k);Zg(k,a);Gb(h,k);yb(k);l=d,m=ei(a),t[l|0]=m;l=e,m=di(a),t[l|0]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);Gb(g,k);yb(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function Dr(a,b,c){var d=0,e=0;d=a,e=li(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=li(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function Iv(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;Bc(f+8|0,b);v[114578]=0;b=T(21,f+8|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;aa(2448,b|0,64400,64432,c|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;b=T(2424,f+8|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;c=T(2449,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d|0]=c;v[114578]=0;c=T(2439,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}t[e|0]=c;v[114578]=0;R(2440,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;Ob(f+8|0);S(a|0);L()}function s_(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-160|0;jb=c;a=Em(c+16|0,a,8);d=v[v[a>>2]-12>>2];v[114578]=0;b=da(122)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)==1){break b}v[114578]=0;U(123,c+8|0,d+(c+16|0)|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}Ob(c+8|0);v[114578]=0;d=Q(180,a|0,144)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;d=Q(181,d|0,c+4|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}b=v[v[d>>2]-12>>2];v[114578]=0;d=T(174,b+d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}b=v[c+4>>2];If(a);jb=c+160|0;a=d?0:b;break a}c=P()|0;O()|0;If(a);S(c|0);L()}return a|0}function mI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;g=c;d=jb-144|0;jb=d;e=dh(d+8|0);h=v[v[e>>2]-12>>2];v[114578]=0;i=da(122)|0;f=v[114578];v[114578]=0;a:{b:{if((f|0)==1){break b}v[114578]=0;U(123,d|0,(d+8|0)+h|0,i|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}Ob(d);v[114578]=0;R(130,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(125,g|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Yd(e);jb=d+144|0;break a}a=P()|0;O()|0;Yd(e);S(a|0);L()}v[114578]=0;U(13,a|0,0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function Y4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=jb-16|0;jb=e;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)==1){break c}v[114578]=0;Z(2042,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(e+8|0,b);v[114578]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;eb(2085,d|0,e|0,+c,1);d=v[114578];v[114578]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37164,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}jb=e+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Ss(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{b:{c:{if(b>>>0<=4294967279){f=Kc(a);h=c,i=Fb(a),v[h+8>>2]=i;b=v[bd(c+12|0,c+8|0)>>2];v[c+12>>2]=b;d=Uk(b);v[c+12>>2]=d;if((d|0)==(f|0)){break a}if((d|0)==10){g=1;b=a;e=v[a>>2];break b}b=v[c+12>>2]+1|0;if(d>>>0>f>>>0){b=$h(b);break c}v[114578]=0;b=Q(30,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}Hg();L()}g=Fe(a);e=Tb(a)}xh(b,e,Fb(a)+1|0);if(g){pg(a,e,f+1|0)}d:{if((d|0)!=10){Fg(a,v[c+12>>2]+1|0);we(a,v[c+8>>2]);Ff(a,b);break d}of(a,v[c+8>>2])}}jb=c+16|0}function ZG(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{c=a+8|0;d:{if(!ml(c)){if((b|0)<0|(Or(c)|0)<=(b|0)){break d}c=(w[vp(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=ml(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[114578]=0;c=Q(85,d|0,40673)|0;b=v[114578];v[114578]=0;e:{if((b|0)!=1){mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}jb=d+16|0;return c|0}L()}function mX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{b:{c:{if(b>>>0<=1073741807){f=Uq(a);h=c,i=Fb(a),v[h+8>>2]=i;b=v[bd(c+12|0,c+8|0)>>2];v[c+12>>2]=b;d=tm(b);v[c+12>>2]=d;if((d|0)==(f|0)){break a}g=1;if((d|0)==1){b=a;e=v[a>>2];break b}b=v[c+12>>2]+1|0;if(d>>>0>f>>>0){b=sm(b);break c}v[114578]=0;b=Q(2836,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}Hg();L()}g=Fe(a);e=Tb(a)}gi(b,e,Fb(a)+1|0);if(g){lo(e,f+1|0)}d:{if((d|0)!=1){Fg(a,v[c+12>>2]+1|0);we(a,v[c+8>>2]);Ff(a,b);break d}of(a,v[c+8>>2])}}jb=c+16|0}function xO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Le(a);Ss(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Lb(f+12|0,f+4|0)>>2];eo(a,Db(b)+g|0,h);Os(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[pm(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=pm(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Lb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}jb=f+16|0;return(d|0)!=0|0}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=al(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1022,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=Ty(c+8|0,um(a,yc(a)+1|0),yc(a),e);f=v[a+8>>2];v[114578]=0;U(1022,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(1016,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}bt(a);jb=c+32|0;break b}b=P()|0;O()|0;bt(a);S(b|0);L()}}function b5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)==1){break c}v[114578]=0;Z(2042,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[114578]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(2080,d|0,c|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37014,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}jb=c+16|0;return+e}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function _da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=$n(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1180,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+32;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=HN(c+8|0,em(a,xe(a)+1|0),xe(a),e);f=v[a+8>>2];v[114578]=0;U(1180,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+32;v[114578]=0;R(1181,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Ps(a);jb=c+32|0;break b}b=P()|0;O()|0;Ps(a);S(b|0);L()}}function FA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)==1){break c}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Q(371,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}function DA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)==1){break c}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Q(380,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}function TM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=al(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1255,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=PM(c+8|0,um(a,yc(a)+1|0),yc(a),e);f=v[a+8>>2];v[114578]=0;U(1255,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(1256,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Gs(a);jb=c+32|0;break b}b=P()|0;O()|0;Gs(a);S(b|0);L()}}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1606,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=lx(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(1606,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(1599,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Wm(a);jb=c+32|0;break b}b=P()|0;O()|0;Wm(a);S(b|0);L()}}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=mm(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(608,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+16;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=MS(c+8|0,Lq(a,nd(a)+1|0),nd(a),e);f=v[a+8>>2];v[114578]=0;U(608,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+16;v[114578]=0;R(609,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Ft(a);jb=c+32|0;break b}b=P()|0;O()|0;Ft(a);S(b|0);L()}}function qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=al(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(728,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=xE(c+8|0,um(a,yc(a)+1|0),yc(a),e);f=v[a+8>>2];v[114578]=0;U(728,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(205,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Xq(a);jb=c+32|0;break b}b=P()|0;O()|0;Xq(a);S(b|0);L()}}function f8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1763,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=hJ(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(1763,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(1760,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Yr(a);jb=c+32|0;break b}b=P()|0;O()|0;Yr(a);S(b|0);L()}}function c5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)==1){break c}v[114578]=0;Z(2042,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}c=v[a+24>>2];b=qc(d+8|0,b);v[114578]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(2078,c|0,d|0,1)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36952,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function mT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=$S(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(557,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=YS(c+8|0,_S(a,Ni(a)+1|0),Ni(a),e);f=v[a+8>>2];v[114578]=0;U(557,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[114578]=0;R(558,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Kt(a);jb=c+32|0;break b}b=P()|0;O()|0;Kt(a);S(b|0);L()}}function zl(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=a+1074312|0;Eb(e+8|0,f,84);a:{if(Cb(e+8|0)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Eb(e+8|0,f,10);if(!Cb(e+8|0)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+796>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Eb(e+8|0,f,10);if(!Cb(e+8|0)){break a}t[b+851|0]=0;u[b+790>>1]=0}jb=e+16|0}function eV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=$n(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(349,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+32;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=KC(c+8|0,em(a,xe(a)+1|0),xe(a),e);f=v[a+8>>2];v[114578]=0;U(349,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+32;v[114578]=0;R(267,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Bq(a);jb=c+32|0;break b}b=P()|0;O()|0;Bq(a);S(b|0);L()}}function H_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=al(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(204,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=xE(c+8|0,um(a,yc(a)+1|0),yc(a),e);f=v[a+8>>2];v[114578]=0;U(204,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(205,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Xq(a);jb=c+32|0;break b}b=P()|0;O()|0;Xq(a);S(b|0);L()}}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;Ht(d,2,a+2|0);Ic(d+16|0,d);v[114578]=0;Q(371,b+492|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){yb(d+16|0);f=b+236|0;c=c+1|0;while(1){g=w[(a+e|0)+31|0];h=dd(f,e),i=c+g|0,u[h>>1]=i;e=e+1|0;if(e>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;FK(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);FK(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function gV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(348,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=qC(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(348,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(345,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}uq(a);jb=c+32|0;break b}b=P()|0;O()|0;uq(a);S(b|0);L()}}function OA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=Wh(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(383,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=fq(c+8|0,Ri(a,oc(a)+1|0),oc(a),e);f=v[a+8>>2];v[114578]=0;U(383,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[114578]=0;R(382,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Ej(a);jb=c+32|0;break b}b=P()|0;O()|0;Ej(a);S(b|0);L()}}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function RW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(kg(a,v[b+8>>2],f)){mv(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;kv(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;kv(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function mC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}d=b+80|0;f=a;c=v[b+84>>2];if(c>>>0<=15){c=v[d>>2]}else{v[e+12>>2]=c-16;c=v[bd(d,e+12|0)>>2]}v[f+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+816|0]){break a}b:{c:{d:{if(!((v[b+88>>2]&2050)==2?(w[v[b+104>>2]+34|0]&8)>>>3|0:0)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}g=a,h=v[a>>2]+B(Zn(c),b)|0,v[g+4>>2]=h}jb=e+16|0}function ly(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(95,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=ks(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(95,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(96,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}nk(a);jb=c+32|0;break b}b=P()|0;O()|0;nk(a);S(b|0);L()}}function Vu(a,b,c,d){var e=0,f=0;e=jb-32|0;jb=e;v[e+28>>2]=d;a:{f=v[b>>2];b:{if(!(nb[v[v[f>>2]+40>>2]](f,c,d)|0)){Xh(a);break b}Sk(e+8|0,b);v[114578]=0;b=T(271,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[114578]=0;b=T(d|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;v[e+4>>2]=b-c;b=Q(33,e+28|0,e+4|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}b=v[b>>2];v[114578]=0;X(272,e+16|0,e+8|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}zC(a,e+16|0,0);Bb(e+16|0);Bb(e+8|0)}jb=e+32|0;return}a=P()|0;O()|0;Bb(e+8|0);S(a|0);L()}function $T(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;d=b;f=xc(d);e=c;a:{if(f>>>0<e>>>0){h=jb-32|0;jb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[zb(d)>>2]-v[d+4>>2]>>>0){dC(d,f);break d}e=zb(d);e=nh(h+8|0,Ki(d,xc(d)+f|0),xc(d),e);v[114578]=0;R(365,e|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;R(366,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}Rg(e)}jb=h+32|0;break b}a=P()|0;O()|0;Rg(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Cu(d,e+v[d>>2]|0)}}c=Qb(a,c);if(c){d=jb-16|0;jb=d;gc(g+8|0,v[b>>2],xc(b));jb=d+16|0;Bd(a,g+8|0)}jb=g+16|0;return c|0}function it(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;_P(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function T0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;d=ve(b,-1);e=w[a+52|0];f=a;a:{b:{if(d){d=b;if(e){break a}b=v[a+48>>2];a=ve(b,-1)^1;break b}if(e){g=c,h=Km(v[a+48>>2]),t[g+19|0]=h;c:{d:{switch(qr(v[a+36>>2],v[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break c}d=d-1|0;v[c+20>>2]=d;if((ur(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break d}}d=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;d=b}jb=c+32|0;return d|0}function DF(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Gf(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(FD()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[114578]=0;b=T(2391,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114578]=0;R(2392,a+b|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function fha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;Bi(f+40|0,f+32|0,c);v[114578]=0;c=f+52|0;U(240,c|0,f+24|0,d|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){c:{v[114578]=0;c=f- -64|0;U(224,c|0,f+16|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(241,f+8|0,f+40|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,f+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}jm(f+40|0);jb=f+80|0;return}}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;jm(f+40|0)}S(a|0);L()}function ela(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;Bi(f+40|0,f+32|0,c);v[114578]=0;c=f+52|0;U(224,c|0,f+24|0,d|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){c:{v[114578]=0;c=f- -64|0;U(224,c|0,f+16|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(241,f+8|0,f+40|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,f+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}jm(f+40|0);jb=f+80|0;return}}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;jm(f+40|0)}S(a|0);L()}function U9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(lj(a)>>>0>=b>>>0){h=e,i=jf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Lb(e+12|0,e+8|0)>>2];if(f){while(1){uK(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){ox(a,b-d|0,c);break a}oK(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){jf(d);pL(d);jK(d);Mx(zb(d),v[d>>2],lj(d));h=zb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=nK(a,b);if(iK(a)>>>0<f>>>0){ed();L()}g=hK(zb(d),f);v[d>>2]=g;v[d+4>>2]=g;h=zb(d),i=B(f,52)+g|0,v[h>>2]=i;gK(d,0);ox(a,b,c)}jb=e+16|0}function qp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=Kb(a)-1|0;a:{if((Kb(a)|0)==1){break a}while(1){if(x[Dc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Kb(a)-1>>>0){continue}break}}h=x[Dc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Dc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Dc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Dc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}j=f,k=((B(((w[Dc(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,v[j+12>>2]=k}ce(f+12|0,0,65536);jb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function aW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;km(f+40|0,f+32|0,c);v[114578]=0;c=f+52|0;U(240,c|0,f+24|0,d|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){c:{v[114578]=0;c=f- -64|0;U(240,c|0,f+16|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(241,f+8|0,f+40|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,f+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}jm(f+40|0);jb=f+80|0;return}}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;jm(f+40|0)}S(a|0);L()}function Aw(a,b,c){var d=0,e=0,f=0,g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=0;d=jb-32|0;jb=d;NG(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),d+20|0);NG(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),d+8|0);z[d+12>>2]=-z[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=z[f>>2];n=f;f=e+49008|0;g=z[f>>2];i=z[e+(d+20|0)>>2];j=z[e+(d+8|0)>>2];k=z[f+12>>2];z[n>>2]=C(g*i)-C(j*k);f=b+e|0;l=z[(0-a<<2)+49016>>2];e=5-a<<2;m=z[e+49008>>2];g=C(C(g*j)+C(k*i));z[f>>2]=C(h*l)-C(m*g);z[b+e>>2]=C(m*h)+C(g*l);a=a+1|0;if((a|0)!=3){continue}break}jb=d+32|0}function ko(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=Mi(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(210,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+1;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=nh(c+8|0,Ki(a,xc(a)+1|0),xc(a),e);f=v[a+8>>2];v[114578]=0;U(210,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+1;v[114578]=0;R(209,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}om(a);jb=c+32|0;break b}b=P()|0;O()|0;om(a);S(b|0);L()}}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;f=gh(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[114578]=0;R(2193,c|0,(d+(a<<5)|0)+480289|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;U(2186,c+16|0,b|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}v[114578]=0;R(1536,f|0,c+16|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}yb(c+16|0);yb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}jb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+16|0)}yb(c)}kd(f);S(a|0);L()}function M0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;a:{b:{c:{if(ve(b,-1)){break c}h=c,i=Km(b),t[h+23|0]=i;if(w[a+44|0]){if(($i(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=qr(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if(($i(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if(($i(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Er(b);break a}a=-1}jb=c+32|0;return a|0}function Kj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[a+28>>2];if((c|0)>=(b|0)){e=v[a+24>>2];break a}i=a+32|0;f=v[a+20>>2];d=v[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=Yu(a,i,1024);v[a+16>>2]=0;v[a+20>>2]=f;if(!f){break b}d=0;g=v[a+28>>2]}h=d+1|0;v[a+16>>2]=h;d=w[(a+d|0)+32|0];c=g+8|0;v[a+28>>2]=c;e=v[a+24>>2]|d<<g;v[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=ba(8)|0;v[114578]=0;T(264,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(a|0,76880,265);L()}v[a+28>>2]=c-b;v[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function Vg(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+72128>>3];a=a-(e+-26388279066624)-A[(b|8)+72128>>3];return _h(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function aC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=w[a+8|0];f=v[a>>2];a=v[a+4>>2];d=Tb(b);b=Fb(b);c=jb-16|0;jb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Lb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=f;break b}b=e;a=f;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{d:{e:{switch(g-1|0){case 0:case 1:d=v[c+12>>2];t[c+7|0]=0;Xr(a,((a+d|0)-e|0)+b|0,c+7|0);break d;case 2:case 3:break e;default:break c}}d=v[c+12>>2];t[c+6|0]=32;Xr(a,((a+d|0)-e|0)+b|0,c+6|0)}f:{switch(g-1|0){case 0:case 3:break f;default:break c}}t[(v[c+12>>2]+f|0)-1|0]=0}jb=c+16|0}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;Ed(b,0);yP(d,a+1|0);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;Cc(b+8|0,v[b>>2]);Cc(b+4|0,v[b+8>>2]);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function jv(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=0;e=c;f=w[c+74|0];t[c+74|0]=f-1|f;f=v[c>>2];b:{if(f&8){v[e>>2]=f|32;e=-1;break b}v[e+4>>2]=0;v[e+8>>2]=0;f=v[e+44>>2];v[e+28>>2]=f;v[e+20>>2]=f;v[e+16>>2]=f+v[e+48>>2];e=0}if(e){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<g>>>0){return nb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]>-1){d=b;while(1){g=d;d=b;if(!g){break c}d=g-1|0;if(w[d+a|0]!=10){continue}break}d=nb[v[c+36>>2]](c,a,g)|0;if(g>>>0>d>>>0){break a}a=a+g|0;f=v[c+20>>2];d=b-g|0;break c}d=b}e=d;lc(f,a,e);v[c+20>>2]=e+v[c+20>>2];d=b}return d}function bv(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[zb(a)>>2]){b=jb-16|0;jb=b;c=$n(b,a,1);d=zb(a);e=v[c+4>>2];v[114578]=0;R(266,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Mb(c);jb=b+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}d=jb-32|0;jb=d;c=a;e=zb(a);b=KC(d+8|0,em(a,xe(a)+1|0),xe(a),e);f=v[b+8>>2];v[114578]=0;R(266,e|0,f|0);e=v[114578];v[114578]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+32;v[114578]=0;R(267,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Bq(b);jb=d+32|0;break b}a=P()|0;O()|0;Bq(b);S(a|0);L()}}Tg(a)}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=0;_D(a,c+12|0,1);d=v[c+12>>2];e=d>>>2&3;t[c+11|0]=e;if(e){t[c+4|0]=3;d=w[pc(c+4|0,c+11|0)|0];t[c+4|0]=0;t[c|0]=0;t[c+10|0]=0;a:{if(!d){break a}yh(a,c+4|0);if((d|0)==1){break a}yh(a,c);if(d>>>0<3){break a}yh(a,c+10|0);f=w[c+10|0]<<24}d=w[c+12|0]|w[c+4|0]<<8|w[c|0]<<16|f;v[c+12>>2]=d}v[c+4>>2]=d>>>4;v[c>>2]=1e6;Co(b,v[Lb(c+4|0,c)>>2]);if(Fb(b)){d=0;while(1){ak(a,kc(b,d),1);d=d+1|0;if(Fb(b)>>>0>d>>>0){continue}break}}b=(v[c+12>>2]>>>4|0)-Fb(b)|0;v[c+12>>2]=b;if(b){gl(a,b,-1)}jb=c+16|0}function $J(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(yd(a)>>>0>=b>>>0){h=e,i=Kb(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Lb(e+12|0,e+8|0)>>2];if(f){while(1){z[d>>2]=z[b>>2];d=d+4|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){jx(a,b-d|0,c);break a}mx(a,v[a>>2]+(b<<2)|0);break a}d=a;if(v[d>>2]){ti(d);Re(zb(d),v[d>>2],yd(d));h=zb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=Be(a,b);if(Zm(a)>>>0<f>>>0){ed();L()}zb(d);g=VJ(f);v[d>>2]=g;v[d+4>>2]=g;h=zb(d),i=(f<<2)+g|0,v[h>>2]=i;mk(d,0);jx(a,b,c)}jb=e+16|0}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=(f>>>21&2040)+27888|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Ls(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;e=1;a:{while(1){b:{iN(b,A[Tk(c,0)>>3]);if((e|0)==1e4){f=d,g=bc(c),v[f+8>>2]=g;f=d,g=cc(c),v[f>>2]=g;if(Jb(d+8|0,d)){break b}break a}else{e=e+1|0;continue}}break}while(1){e=v[d+8>>2];f=e,h=iN(b,A[e>>3]),A[f>>3]=h;vy(d+8|0);if(Jb(d+8|0,d)){continue}break}}b=hN(a,zb(c));v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];a=v[zb(c)>>2];f=zb(b),g=a,v[f>>2]=g;f=zb(c),g=0,v[f>>2]=g;v[c>>2]=0;v[c+4>>2]=0;jb=d+16|0}function xr(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;h=v[c>>2];v[g+232>>2]=h;c=v[c+4>>2];v[g>>2]=a;v[g+236>>2]=c;a:{b:{c:{d:{if((h|0)!=1){h=a;i=1;break d}h=a;i=1;if(c){break d}c=a;break c}while(1){c=h-v[(d<<2)+f>>2]|0;if((nb[b|0](c,a)|0)<1){c=h;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=h-4|0;if((nb[b|0](j,c)|0)>-1){break e}if((nb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+g>>2]=c;e=lG(g+232|0);yr(g+232|0,e);i=i+1|0;d=d+e|0;e=0;h=c;if(v[g+236>>2]|v[g+232>>2]!=1){continue}break b}break}c=h;break b}if(e){break a}}kG(g,i);mw(c,b,d,f)}jb=g+240|0}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;jb=b+16|0}function P0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=ve(b,-1);e=w[a+52|0];f=a;a:{b:{if(d){d=b;if(e){break a}b=v[a+48>>2];a=ve(b,-1)^1;break b}if(e){v[c+16>>2]=v[a+48>>2];c:{d:{switch(qr(v[a+36>>2],v[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break c}d=d-1|0;v[c+20>>2]=d;if((ur(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break d}}d=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;d=b}jb=c+32|0;return d|0}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=(f>>>21&2040)+27888|0;e=(((B(t[e|0],u[f+2>>1])+B(t[e-1|0],u[f>>1])|0)+B(t[e+1|0],u[f+4>>1])|0)+B(t[e+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;jb=b+16|0}function fL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{if(w[b+813|0]!=27){a=t[b+851|0];break a}e=a+1074312|0;Eb(c+8|0,e,21);d=Cb(c+8|0);f=a;a=w[b+841|0];a=Ix(f,w[b+848|0],d?a:a+16>>>2|0);Eb(c+8|0,e,45);b:{if(!(!Cb(c+8|0)|w[b+848|0]!=3)){f=b;d=w[b+841|0];c:{if(!(!d|d>>>0>=w[b+849|0])){a=w[b+852|0];d=d+1|0;break c}t[b+852|0]=a;d=1}t[f+841|0]=d;a=a<<24>>24;break b}t[b+841|0]=w[b+841|0]+w[b+849|0]}Eb(c+8|0,e,47);if(!Cb(c+8|0)){break a}t[b+851|0]=a}if(a){g=b,h=Yb(v[b+684>>2]+((B(w[b+850|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}jb=c+16|0}function UX(){var a=0;a:{if(t[462560]&1){break a}if(!wd(462560)){break a}a=462272;while(1){a=Wb(a)+12|0;if((a|0)!=462560){continue}break}vd(462560)}Mc(462272,69644);Mc(462284,69652);Mc(462296,69661);Mc(462308,69667);Mc(462320,69673);Mc(462332,69677);Mc(462344,69682);Mc(462356,69687);Mc(462368,69694);Mc(462380,69704);Mc(462392,69712);Mc(462404,69721);Mc(462416,69730);Mc(462428,69734);Mc(462440,69738);Mc(462452,69742);Mc(462464,69673);Mc(462476,69746);Mc(462488,69750);Mc(462500,69754);Mc(462512,69758);Mc(462524,69762);Mc(462536,69766);Mc(462548,69770)}function RX(){var a=0;a:{if(t[462864]&1){break a}if(!wd(462864)){break a}a=462576;while(1){a=tf(a)+12|0;if((a|0)!=462864){continue}break}vd(462864)}_c(462576,69776);_c(462588,69808);_c(462600,69844);_c(462612,69868);_c(462624,69892);_c(462636,69908);_c(462648,69928);_c(462660,69948);_c(462672,69976);_c(462684,70016);_c(462696,70048);_c(462708,70084);_c(462720,70120);_c(462732,70136);_c(462744,70152);_c(462756,70168);_c(462768,69892);_c(462780,70184);_c(462792,70200);_c(462804,70216);_c(462816,70232);_c(462828,70248);_c(462840,70264);_c(462852,70280)}function fi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=jb-16|0;jb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);qf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;jb=f+16|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Lb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;h=v[Lb(e+8|0,e+4|0)>>2]>>>1|0;c=Db(b);i=f>>>1|0;if(i){g=v[a+20>>2];f=i;j=d;while(1){j=(Db(w[c|0])+j|0)+(Db(w[c+1|0])<<8)|0;u[g>>1]=j;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(Db(w[c|0])+d|0)+(Db(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}jb=e+16|0;return h+i<<1}function J0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;a:{b:{c:{if(ve(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if(($i(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=qr(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if(($i(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if(($i(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Er(b);break a}a=-1}jb=c+32|0;return a|0}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Lb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;h=v[Lb(e+8|0,e+4|0)>>2]>>>1|0;c=Db(b);i=f>>>1|0;if(i){g=v[a+20>>2];f=i;j=d;while(1){j=(Db(w[c+1|0])+j|0)+(Db(w[c|0])<<8)|0;u[g>>1]=j;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(Db(w[c+1|0])+d|0)+(Db(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}jb=e+16|0;return h+i<<1}function yV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;v[e+24>>2]=d;v[e+28>>2]=c;h=e+8|0;f=jb-48|0;jb=f;d=f+40|0;c=FC(d,1);d=Uc(f+16|0,d,1);g=jb-16|0;jb=g;v[g+12>>2]=c;v[114578]=0;c=f+24|0;W(286,c|0,g+12|0,d|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){jb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}d=v[c>>2];v[114578]=0;aa(285,d|0,b|0,e+28|0,e+24|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){co(h,ec(v[c>>2]),Nd(c));yC(c);jb=f+48|0;break b}a=P()|0;O()|0;yC(c);S(a|0);L()}Iu(e+16|0,e+8|0);fm(a,e+16|0);Bb(e+16|0);Bb(e+8|0);jb=e+32|0}function eg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[lf(12e3,d+14|0)>>1];c=oc(a);a:{if(b>>>0>c>>>0){e=jb-32|0;jb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>1>>>0){gq(a,c,f);break d}b=zb(a);b=fq(e+8|0,Ri(a,oc(a)+c|0),oc(a),b);v[114578]=0;U(381,b|0,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}v[114578]=0;R(382,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}Ej(b)}jb=e+32|0;break b}a=P()|0;O()|0;Ej(b);S(a|0);L()}break a}if(b>>>0<c>>>0){Pn(a,v[a>>2]+(b<<1)|0)}}jb=d+16|0}function Kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=(Db(w[c|0])|Db(w[c+1|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=(Db(w[c|0])|Db(w[c+1|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function Hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=(Db(w[c+1|0])|Db(w[c|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=(Db(w[c+1|0])|Db(w[c|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=16384;e=v[Lb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Kj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}oq(d+4|0,Kj(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}oq(d+4|0,e-c|0);break b}hC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}hC(a,c,0,b)}if(!v[a+1068>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}jb=d+16|0}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;yg(d,2,a+6|0);Ic(d+16|0,d);v[114578]=0;Q(371,b+492|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){f=b+236|0;yb(d+16|0);g=c+1|0;c=0;e=1;while(1){a:{h=w[(a+c|0)+38|0];i=dd(f,c),j=g+h|0,u[i>>1]=j;c=e&255;if(c>>>0>=128){break a}e=e+1|0;continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;wx(a+180|0,b+48|0,0);wx(a+228|0,b+88|0,2);wx(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){Rb(f,0,256)}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function YU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=32768;e=v[Lb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Kj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}oq(d+4|0,Kj(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}oq(d+4|0,e-c|0);break b}gC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}gC(a,c,0,b)}if(!v[a+1068>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}jb=d+16|0}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=xx(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(a){v[114578]=0;U(1556,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(1557,f|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}hf(e+8|0);a=Rt(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(e+8|0);break a}a=P()|0;O()|0}sl(f);S(a|0);L()}function cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;f=x[Fj(a,b)>>1];a:{if(!np(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=bc(d),v[j+8>>2]=k;j=c,k=cc(d),v[j>>2]=k;if(!Jb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=St(g);if(i){e=0;while(1){if(!(x[rc(g,e)>>1]!=(h|0)|((a|0)==(g|0)?(b|0)==(e|0):0))){d=mK(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}Dy(c+8|0);if(Jb(c+8|0,c)){continue}break a}break}j=Fj(a,b),k=d,u[j>>1]=k;f=d}jb=c+16|0;return f&65535}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;g=d+8|0;e=b;h=e;if(oR(e,d+24|0)){f=d+26|0;f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)}ud(g,h,f);e=w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;e=w[d+28|0]|w[d+29|0]<<8;t[a+4|0]=e;t[a+5|0]=e>>>8;cm(a+8|0,d+8|0);Bb(d+8|0);a:{if(!c){break a}e=(f>>>0)%(c>>>0)|0;if(!e){break a}v[114578]=0;Q(340,b|0,c-e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;hf(a);S(b|0);L()}jb=d+32|0}function E_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;e=g>>>9&1;g=af(f,e+13|0,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-((e<<3)+107&112)|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2482,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];g=v[Lb(e+8|0,e+4|0)>>2];i=z[d>>2];b=Db(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;a=d;f=je(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Vc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return g<<2}function Nj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-16|0;jb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Wg(a,d+15|0);e=w[d+15|0];v[b>>2]=(e&252)>>>2;v[b+4>>2]=0;a:{c=e&3;if(!c){break a}c=-1<<c;k=(c>>>0<4294967294?c:-2)^-1;h=1;c=0;while(1){t[d+15|0]=0;l=Wg(a,d+15|0);m=v[b+4>>2];j=w[d+15|0];g=(h<<3)-2|0;f=g&31;e=b;n=b;if((g&63)>>>0>=32){g=j<<f;f=0}else{g=(1<<f)-1&j>>>32-f;f=j<<f}v[n>>2]=f|v[b>>2];v[e+4>>2]=g|m;i=i&l;if(!c&(h|0)==(k|0)){break a}e=h+1|0;c=e>>>0<1?c+1|0:c;h=e;continue}}jb=d+16|0;return i|0}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,26);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function TT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-208|0;jb=d;bu(c,a);MA(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}t[d+12|0]=64;gg(b,w[pc(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Kb(b)){break a}a=0;while(1){if(a){c=x[Pb(b,a-1|0)>>1];v[d+12>>2]=1;e=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[e+1|0]&1)<<8|w[e|0];e=x[zf(d+12|0,d+8|0)>>1];f=Pb(b,a),g=c+e|0,u[f>>1]=g}c=w[((d+16|0)+B(a,3)|0)+2|0];f=Pb(b,a),g=c,t[f+2|0]=g;a=a+1|0;if(Kb(b)>>>0>a>>>0){continue}break}}jb=d+208|0}function Nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=cz(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(a){v[114578]=0;U(973,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(974,f|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}hf(e+8|0);a=Rt(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(e+8|0);break a}a=P()|0;O()|0}Gl(f);S(a|0);L()}function gX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;f=jb-16|0;jb=f;c=jb-16|0;jb=c;h=c,i=Hma(v[a>>2],v[a+4>>2],1e9,0),v[h>>2]=i;v[c+4>>2]=mb;a=pk(c+8|0,c);g=v[a+4>>2];a=v[a>>2];jb=c+16|0;jb=f+16|0;v[d+8>>2]=a;v[d+12>>2]=g;a=v[d+12>>2];c=e+8|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=a;jb=d+16|0;d=v[c>>2];c=v[c+4>>2];a=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];d=d+b|0;v[a+16>>2]=d;v[a+20>>2]=b>>>0>d>>>0?c+1|0:c;a=pk(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];jb=e+32|0;mb=b;return a|0}function g5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[114578]=0;Z(2016,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114578]=0;ja(2074,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(g));yb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1990,36818,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=g+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function f5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[114578]=0;Z(2016,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114578]=0;ja(2075,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(g));yb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1990,36860,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=g+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=Db(w[c|0])|Db(w[c+1|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=Db(w[c|0])|Db(w[c+1|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function Ica(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=Db(w[c+1|0])|Db(w[c|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=Db(w[c+1|0])|Db(w[c|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function H6(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;a:{b:{if(!a){a=Zd(34181);break b}v[114578]=0;c=Q(85,b|0,a|0)|0;a=v[114578];v[114578]=0;c:{d:{if((a|0)!=1){v[114578]=0;R(1994,b+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}a=Zd(Tb(b+16|0));yb(b+16|0);yb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;yb(c)}_(a|0)|0;a=0;v[114578]=0;X(1990,34182,0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$()}jb=b+32|0;return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function tha(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-160|0;jb=b;a=Em(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114578]=0;c=da(122)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)==1){break b}v[114578]=0;U(123,b+8|0,d+(b+16|0)|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}Ob(b+8|0);v[114578]=0;d=Q(177,a|0,b+6|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}c=v[v[d>>2]-12>>2];v[114578]=0;d=T(174,c+d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}c=x[b+6>>1];If(a);jb=b+160|0;a=(d?0:c)&65535;break a}b=P()|0;O()|0;If(a);S(b|0);L()}return a|0}function ov(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Rb(d+24|0,0,39);a=a+f|0;a:{if(kg(e,c,0)){v[d+56>>2]=1;nb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}nb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}jb=d- -64|0;return b}function oM(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074444|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));ce(d+12|0,0,256);v[c>>2]=v[d+12>>2]}jb=d+16|0}function Ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;oN(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function hX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;d=jb-16|0;jb=d;f=jb-16|0;jb=f;e=jb-16|0;jb=e;h=e,i=Hma(v[a>>2],v[a+4>>2],1e6,0),v[h>>2]=i;v[e+4>>2]=mb;a=pk(e+8|0,e);g=v[a+4>>2];a=v[a>>2];jb=e+16|0;jb=f+16|0;v[d+8>>2]=a;v[d+12>>2]=g;a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;jb=d+16|0;d=v[c+8>>2];e=v[c+12>>2];a=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=a;e=v[c+4>>2]+e|0;b=v[c>>2];d=d+b|0;v[c+16>>2]=d;v[c+20>>2]=b>>>0>d>>>0?e+1|0:e;a=pk(c+24|0,c+16|0);b=v[a+4>>2];a=v[a>>2];jb=c+32|0;mb=b;return a|0}function lM(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=bM(a,c&15);b=Hma(a,a>>31,d,d>>31)+32768|0;a=mb;a=Ac(Ima(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e+700>>2]=a-((a|0)==(d|0));return}a=(c&255)+d|0;v[b+700>>2]=(a|0)<65535?a:65535}}function Q_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;g=af(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-32|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2473,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Yl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Lha(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;t[b+15|0]=128;d=Qt(a,127,b+15|0);v[114578]=0;t[b+14|0]=64;e=W(886,a+12|0,127,b+14|0)|0;c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;t[b+13|0]=0;W(975,a+24|0,127,b+13|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;t[a+44|0]=0;t[a+45|0]=0;t[a+46|0]=0;t[a+47|0]=0;t[a+48|0]=0;t[a+49|0]=0;t[a+50|0]=0;t[a+51|0]=0;t[a+52|0]=0;t[a+53|0]=0;jb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;fe(e)}fe(d);S(a|0);L()}function N_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;g=af(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-32|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2473,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Yl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function B_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;g=af(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-96|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2482,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Iy(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(md(a)){break a}u[v[a>>2]>>1]=0;Ue(v[a>>2]+2|0,b);e=c,f=bc(a),v[e>>2]=f;e=c,f=pp(c,1),v[e+8>>2]=f;e=c,f=cc(a),v[e>>2]=f;if(!Jb(c+8|0,c)){break a}while(1){d=v[c+8>>2];e=c,f=lO(c+8|0,1),v[e>>2]=f;d=x[Si(d,v[c>>2])>>1];u[v[c+8>>2]>>1]=d;Ue(v[c+8>>2]+2|0,b);tB(c+8|0);e=c,f=cc(a),v[e>>2]=f;if(Jb(c+8|0,c)){continue}break}}Ue(a+14|0,Kb(a)-1&255);Ue(a+13|0,w[a+14|0]);Ue(a+16|0,Kb(a)-1&255);Ue(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){Ue(a+17|0,Kb(a)-1&255)}jb=c+16|0}function w3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=Pe(12);f=c;e=zb(b);d=jb-16|0;jb=d;v[c>>2]=0;v[c+4>>2]=0;v[d+12>>2]=0;v[114578]=0;W(2210,c+8|0,d+12|0,e|0)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){jb=d+16|0;break b}break a}v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];d=v[zb(b)>>2];g=zb(f),h=d,v[g>>2]=h;g=zb(b),h=0,v[g>>2]=h;v[b>>2]=0;v[b+4>>2]=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2178,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;c:{if((a|0)!=1){jb=b+16|0;break c}break a}return}V(0)|0;O()|0;Ab();L()}function i5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[114578]=0;Z(2016,a|0);g=v[114578];v[114578]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114578]=0;ma(2072,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(f));yb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1990,36715,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=f+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function h5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[114578]=0;Z(2016,a|0);g=v[114578];v[114578]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114578]=0;ma(2073,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(f));yb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1990,36765,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=f+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;e=jb-16|0;jb=e;j=v[a+4>>2];tH(a,b,c,d);h=z[a+28>>2];b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=jb-16|0;jb=a;b=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=b;b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=a;if(!(!d|h==C(1))){while(1){if(c){k=g+j|0;f=0;while(1){i=rn(b,f,k);z[i>>2]=z[i>>2]*h;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}jb=a+16|0;jb=e+16|0}function Vz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Kb(c);a:{if(d>>>0<b>>>0){f=jb-32|0;jb=f;b:{d=b-d|0;c:{if(d>>>0<=v[zb(c)>>2]-v[c+4>>2]>>2>>>0){rB(c,d,g);break c}b=zb(c);b=ks(f+8|0,Be(c,Kb(c)+d|0),Kb(c),b);v[114578]=0;U(736,b|0,d|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(96,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}nk(b)}jb=f+32|0;break a}a=P()|0;O()|0;nk(b);S(a|0);L()}if(b>>>0<d>>>0){UR(c,v[c>>2]+(b<<2)|0)}}Ox(a);jb=e+16|0}function TW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(kg(a,v[b+8>>2],e)){lv(b,c,d);return}a:{if(kg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];nb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function PU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;vF(b);a:{if(!(w[a|0]|w[a+1|0]<<8)){c=a+2|0;if(!(w[c|0]|w[c+1|0]<<8)){break a}}v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[d+16>>2]=e;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[d+12>>2]=e;c=a+2|0;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>11|0,0,23),v[d+8>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>5&63,0,59),v[d+4>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)<<1&62,0,59),v[d>>2]=e}a=a+4|0;v[b+44>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function w_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-208|0;jb=a;u[a+204>>1]=w[64454]|w[64455]<<8;v[a+200>>2]=w[64450]|w[64451]<<8|(w[64452]<<16|w[64453]<<24);f=le();v[a>>2]=e;h=af(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=mg(a+176|0,e,c);Bc(a+8|0,c);v[114578]=0;g=T(2457,a+8|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){Ob(a+8|0);VE(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=xm(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)-688|0,b,c,d);jb=a+208|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Gm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Wb(a);a:{b:{c:{if(yc(b)){a=0;while(1){d:{if(!a){break d}v[114578]=0;Q(1251,f|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=qd(b,a);v[114578]=0;R(1252,e|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;Q(1251,f|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(e);a=a+1|0;if(yc(b)>>>0>a>>>0){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e)}yb(f);S(a|0);L()}function Pga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!De(a)){break b}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}pn(b);Ry(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Ws(b)){break b}if(v[a>>2]!=(d|0)){Rb(b+68|0,0,36)}f=v[b+20>>2];v[114578]=0;f=T(467,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}a=v[a+20>>2];v[114578]=0;a=T(467,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}lc(f,a+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}return}V(0)|0;O()|0;Ab();L()}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=jb-16|0;jb=e;c=w[c|0]|w[c+1|0]<<8;u[e+14>>1]=c<<8|c>>>8;c=jb-16|0;jb=c;oI(c,e+14|0);v[114578]=0;U(13,d+16|0,0,c|0);f=v[114578];v[114578]=0;a:{if((f|0)!=1){yb(c);jb=c+16|0;break a}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=e+16|0;v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;b:{if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Ix(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;Eb(e+8|0,a+1074312|0,21);a:{if(Cb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+21616|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=aL(cn(a))+-64|0;break a}d=t[(c>>>1&31)+20720|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+21488|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+21552|0]}a=d;jb=e+16|0;return a}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;a=_E(a,e+12|0,d,le());d=mb;f=v[114552];d:{if(f){if(v[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}v[114552]=g;if(v[e+12>>2]==(b|0)){break c}}}v[c>>2]=4;b=0;break a}if(((d|0)<-1?1:(d|0)<=-1?a>>>0<2147483648:0)|((d|0)>0?1:(d|0)>=0?a>>>0>2147483647:0)){break b}b=a;break a}v[c>>2]=4;b=2147483647;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break a}b=-2147483648}jb=e+16|0;return b|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>3;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[e+8>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=g;Rf(e+8|0,-1,1);f=A[e+8>>3]*32768;A[e+8>>3]=f;g=a;f=Sd(f);a:{if(D(f)<2147483648){h=~~f;break a}h=-2147483648}i=g,j=Vc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){c=v[a+20>>2];a=d;while(1){f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);ae(e+12|0,C(-1));g=C(z[e+12>>2]*C(32768));z[e+12>>2]=g;f=c;g=je(g);a:{if(C(D(g))<C(2147483648)){h=~~g;break a}h=-2147483648}i=f,j=Vc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}jb=e+16|0;return d<<2}function Fx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=Ro(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(Ro(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=Ro(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!Ro(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}jb=h+16|0}function $5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;Z(2027,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[a+24>>2];v[114578]=0;b=Q(2028,d|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35262,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Yka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Qb(b,c<<2);a:{if(!g){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];Bt(b,f+24|0);c=f+24|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return g|0}function XV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=fd(a);a:{b:{c:{if(yc(b)){a=0;while(1){d:{if(!a){break d}v[114578]=0;Q(192,f|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=qd(b,a);v[114578]=0;R(252,e|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;Q(192,f|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(e);a=a+1|0;if(yc(b)>>>0>a>>>0){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e)}yb(f);S(a|0);L()}function Xh(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=a;d=jb-16|0;jb=d;h=d+8|0;e=jb-48|0;jb=e;b=sc(16,4);f=Uc(e+16|0,e+40|0,1);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=e+24|0;W(280,b|0,c+12|0,f|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;T(279,c|0)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){co(h,ec(v[b>>2]),Nd(b));IC(b);jb=e+48|0;break b}a=P()|0;O()|0;IC(b);S(a|0);L()}fm(g,d+8|0);Bb(d+8|0);jb=d+16|0;v[a+8>>2]=0;v[a+12>>2]=0;return a|0}function G_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-96|0;jb=a;u[a+92>>1]=w[64454]|w[64455]<<8;v[a+88>>2]=w[64450]|w[64451]<<8|(w[64452]<<16|w[64453]<<24);f=le();v[a>>2]=e;h=af(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=mg(a- -64|0,e,c);Bc(a+8|0,c);v[114578]=0;g=T(21,a+8|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){Ob(a+8|0);WE(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=Yl(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)-48|0,b,c,d);jb=a+96|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function $N(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function Uu(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;h=wh(f+8|0,b);d=jb-16|0;jb=d;i=d+8|0;e=jb-48|0;jb=e;b=sc(24,4);g=Uc(e+16|0,e+40|0,1);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=e+24|0;W(274,b|0,c+12|0,g|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;Q(273,c|0,h|0)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){co(i,ec(v[b>>2]),Nd(b));TC(b);jb=e+48|0;break b}a=P()|0;O()|0;TC(b);S(a|0);L()}fm(a,d+8|0);Bb(d+8|0);jb=d+16|0;jb=f+16|0}function _F(a){var b=0,c=0,d=0,e=0;b=jb-160|0;jb=b;a=Em(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114578]=0;c=da(122)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;U(123,b+8|0,d+(b+16|0)|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}Ob(b+8|0);v[114578]=0;d=Q(173,a|0,b+4|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[v[d>>2]-12>>2];v[114578]=0;d=T(174,c+d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2];If(a);jb=b+160|0;return d?0:c}b=P()|0;O()|0;If(a);S(b|0);L()}function Ur(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;f=a;c=v[b>>2];e=v[b+4>>2]?c&24576?c:c&-12289|8192:c;b=v[b+8>>2];c=(b|0)!=-1?e:c;a:{if(c&1){e=143}else{if(!(c&2)){break a}e=144}sw(f,e)}b:{if(c&4096){break b}if(c&8192){g=d,h=Ng(4),v[g+24>>2]=h;xG(a,d+24|0);break b}if(!(c&16384)){break b}g=d,h=Ng(256),v[g+16>>2]=h;xG(a,d+16|0)}f=a;c:{if(c&16){c=145}else{if(!(c&32)){break c}c=146}sw(f,c)}if((b|0)!=-1){g=d,h=Ng(b),v[g+8>>2]=h;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[d+8>>2]}jb=d+32|0}function qf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);Db(w[b+2|0]);Db(w[b+3|0]);Db(w[b+4|0]);Db(w[b+5|0]);f=a,g=Db(w[b+6|0])|Db(w[b+7|0])<<8,u[f>>1]=g;Db(w[b+8|0]);Db(w[b+9|0]);Db(w[b+10|0]);Db(w[b+11|0]);Db(w[b+12|0]);Db(w[b+13|0]);f=a,g=Db(w[b+14|0])|Db(w[b+15|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+7|0]);Db(w[b+6|0]);Db(w[b+5|0]);Db(w[b+4|0]);Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;Db(w[b+15|0]);Db(w[b+14|0]);Db(w[b+13|0]);Db(w[b+12|0]);Db(w[b+11|0]);Db(w[b+10|0]);f=a,g=Db(w[b+9|0])|Db(w[b+8|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function jM(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}Eb(e+8|0,a+1074312|0,3);if(Cb(e+8|0)){break c}if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,896)+a|0)+1075856|0]&1){Eb(e+8|0,a+1074312|0,3);if(!Cb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=ay(a,b);if(!d){break a}f=d;a=v[(B(b,896)+a|0)+1075640>>2];if(a){a=w[a+33|0]}else{a=13}nb[v[v[d>>2]+80>>2]](f,c,a<<24>>24,b)}jb=e+16|0}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;g=d;e=u[b>>1];f=e;b=u[a+30>>1];a:{if(!b){break a}if((e|0)>=0){f=(e|0)%(b|0)|0;break a}f=b+((e^-1)%(b|0)^-1)|0}u[g+14>>1]=f;b:{if(!Wc(c)){Xi(aK(a+52|0,d+14|0),c);break b}f=a+52|0;h=d,i=kx(f,d+14|0),v[h+8>>2]=i;h=d,i=Hi(f),v[h>>2]=i;if(!Gi(d+8|0,d)){break b}g=jb-16|0;jb=g;a=v[Oc(g,v[d+8>>2])>>2];e=jb-16|0;jb=e;v[e+8>>2]=a;c=v[e+8>>2];b=TJ(f,c);a=hc(f);xt(jh(e+8|0));sh(a,c,1);jb=e+16|0;Oc(g+8|0,b);jb=g+16|0}jb=d+16|0}function nw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-32|0;jb=e;v[e+24>>2]=b;m=e,n=Dd(a),v[m+16>>2]=n;j=am(e+24|0,e+16|0);h=j;i=jb-16|0;jb=i;a:{b=a;g=Fb(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Tb(b);k=g-h|0;if(!k){break b}l=f+h|0;$l(l+c|0,l,k);break b}Rl(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}yy(f+h|0,c,d);d=b;b=c+g|0;Sg(d,b);t[i+15|0]=0;he(b+f|0,i+15|0)}jb=i+16|0;break a}qm();L()}m=e,n=Dd(a),v[m+8>>2]=n;a=cf(e+8|0,j);jb=e+32|0;return a|0}function Xaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;while(1){e=g&255;c=0;b=1;while(1){c=e&1|c;if((b|0)!=8){e=(e&254)>>>1|0;c=c<<1;b=b+1|0;continue}break}f=0;b=(c&255)<<24;e=1;while(1){d=f;c=b<<1|d>>>31;d=d<<1;b=(b|0)>-1;f=b?d:d^-1798752855;b=b?c:c^-1382821323;if((e|0)!=8){e=e+1|0;continue}break}d=0;c=0;e=1;while(1){d=f&1|d;if((e|0)!=64){f=(b&1)<<31|f>>>1;b=b>>>1|0;c=c<<1|d>>>31;d=d<<1;e=e+1|0;continue}break}b=(g<<3)+85376|0;v[b>>2]=d;v[b+4>>2]=c;g=g+1|0;if((g|0)!=256){continue}break}return a|0}function VZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=Fb(a);e=Uq(a);g=ot(b,c);a:{if(!g){break a}if($z(b,Tb(a),Tb(a)+(Fb(a)<<2)|0)){d=jb-16|0;jb=d;ZE(f,b,c);jb=d+16|0;b=f;c=Tb(b);d=Fb(b);v[114578]=0;W(2508,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Lc(b);break a}a=P()|0;O()|0;Lc(b);S(a|0);L()}if(e-d>>>0<g>>>0){HD(a,e,(d+g|0)-e|0,d,d)}e=Tb(a)+(d<<2)|0;while(1){if((b|0)!=(c|0)){Te(e,b);b=b+4|0;e=e+4|0;continue}break}v[f>>2]=0;Te(e,f);Sg(a,d+g|0)}jb=f+16|0;return a|0}function Nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=jb-16|0;jb=e;d=c;zb(d);a=b;h=KN(b,e+8|0);b:{f=oc(d);if(!f){break b}v[114578]=0;R(921,a|0,f|0);g=v[114578];v[114578]=0;if((g|0)!=1){g=v[d+4>>2];d=v[d>>2];v[114578]=0;X(1196,a|0,d|0,g|0,f|0);d=v[114578];v[114578]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;bq(h);S(a|0);L()}jb=e+16|0;v[114578]=0;Q(4,b+12|0,c+12|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[b+24>>2]=v[c+24>>2];u[b+28>>1]=x[c+28>>1];break a}b=P()|0;O()|0;kf(a);S(b|0);L()}}function k$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=w[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=v[114552];v[114552]=0;a=Mv(a,e+12|0,d,le());d=mb;g=v[114552];f:{if(g){if(v[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}v[114552]=h;if(v[e+12>>2]==(b|0)){break b}}}}v[c>>2]=4;a=0;b=0;break a}v[c>>2]=4;a=-1;b=-1;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}jb=e+16|0;mb=b;return a|0}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{if((h|0)==1){break b}v[114578]=0;U(123,c|0,e+(c+8|0)|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}Ob(c);v[114578]=0;R(135,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Yd(d);jb=c+144|0;break a}a=P()|0;O()|0;Yd(d);S(a|0);L()}jb=f+16|0}function x2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{if((h|0)==1){break b}v[114578]=0;U(123,c|0,e+(c+8|0)|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}Ob(c);v[114578]=0;R(136,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Yd(d);jb=c+144|0;break a}a=P()|0;O()|0;Yd(d);S(a|0);L()}jb=f+16|0}function qw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=wG(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}jb=e+16|0;return c}function op(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){if(d&512){eO(a)}u[a+34>>1]=x[a+34>>1]&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Ws(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function zT(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Le(b);Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)==1){break a}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Gb(b,d+24|0);yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Ec(d+40|0);S(a|0);L()}function xm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((Wl(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=UE(i,b,f);h=Tb(f);v[114578]=0;h=W(2485,a|0,h|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}Lc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((Wl(a,c,b)|0)!=(b|0)){break b}}Vy(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;Lc(f);S(a|0);L()}function GA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Le(b);Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)==1){break a}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Gb(b,d+24|0);yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Ec(d+40|0);S(a|0);L()}function rS(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{f:{g:{switch(w[a+3|0]){case 9:c=2;break d;case 10:case 17:case 18:c=1;break d;case 11:break f;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:break g;default:break e}}c=w[a|0];if(c&7){break f}c=c>>>3|0;break d}c=b+1>>>1|0;b=(w[a+3|0]==11)<<4;break c}c=0}c=B(c,b);b=(w[a+3|0]==11)<<4}c=b+B(lS(a),c)|0}return c|0}function jW(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;c=Ub(b,7035);v[114578]=0;U(226,b+16|0,a|0,c|0);a=v[114578];v[114578]=0;a:{b:{c:{if((a|0)!=1){yb(c);if(yc(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;yb(c);break b}a=0;while(1){d:{c=qd(b+16|0,d);v[114578]=0;c=T(227,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=yc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;bl(b+16|0)}S(d|0);L()}bl(b+16|0);jb=b+32|0;return a|0}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];c=v[Lb(e+8|0,e+4|0)>>2];h=z[d>>2];b=Db(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;i=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Vc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return c<<2}function x3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;a:{b:{if(mi(a)){Fo(b+24|0);break b}Qm(b+8|0,a);v[114578]=0;R(2176,b+24|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}rf(b+8|0)}if(mi(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){e=b,f=bc(c),v[e+8>>2]=f;e=b,f=cc(c),v[e>>2]=f;if(!Jb(b+8|0,b)){break c}while(1){d=A[v[b+8>>2]>>3]+d;Gk(b+8|0);if(Jb(b+8|0,b)){continue}break}break c}d=A[Rc(c,a)>>3]}gk(b+24|0);jb=b+32|0;return+d}a=P()|0;O()|0;rf(b+8|0);S(a|0);L()}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;jb=b+16|0}function C_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=af(g,e+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-((e<<3)+187&240)|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2482,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=af(g,e+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-((e<<3)+187&240)|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2482,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function o4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=jb-16|0;jb=f;d=b+4|0;zb(d);c=jb-16|0;jb=c;b=a;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(2125,a+8|0,c+12|0,f+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{c=nd(d);if(!c){break b}v[114578]=0;R(2123,a|0,c|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[d+4>>2];d=v[d>>2];v[114578]=0;X(2124,a|0,d|0,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;kI(b);S(a|0);L()}jb=f+16|0}function aO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=b?33:32;e=v[a+8>>2]-1|0;j=e-(w[a+17|0]!=0&(e|0)!=0)|0;f=v[a+12>>2];g=v[a>>2]+B(f,62)|0;d=b?1:-1;k=B(f,d)<<1;c=e;while(1){if((f|0)>=1){l=B(c,f);m=v[a+4>>2];b=0;while(1){u[(b<<1)+g>>1]=x[(b+l<<1)+m>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}a:{if(!((c|0)!=(e|0)|(d|0)<=0)){b=w[a+16|0];d=b?-1:1;c=b?j:0;break a}if(!((d|0)>-1|c)){b=w[a+16|0];d=b?1:-1;c=b?0:e;break a}c=d+c|0}g=g+k|0;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function Ama(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];cu(b,f+24|0);c=f+24|0;c=w[c|0]|w[c+1|0]<<8;c=c<<8|c>>>8;u[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return g|0}function Np(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Qb(b,c);a:{if(!g){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);i=f,j=bc(a),v[i+16>>2]=j;i=f,j=cc(a),v[i+8>>2]=j;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Xf(b,c)){h=jb-16|0;jb=h;ff(c);jb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return g|0}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;jb=b+16|0}function o$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114552];v[114552]=0;a=Mv(a,e+12|0,d,le());d=mb;g=v[114552];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114552]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a&65535}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=jb-608|0;jb=g;c=jb-16|0;jb=c;d=g+8|0;iQ(c+8|0,d);e=Hb(c+8|0);b=a;f=ld(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(b,Hb(c+8|0))}jb=c+16|0;c=(e|0)==(f|0);if(!c){jQ(d)}b=-1;a:{if(!c){break a}b=0;if(!sQ(g+8|0)){break a}b=-1;if(!Df(a,1024)){break a}b=0;d=jb-1024|0;jb=d;c=jb-16|0;jb=c;jz(c+8|0,d);e=Hb(c+8|0);f=ld(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;if((e|0)==(f|0)){b=kz(d,0)>>>0<17}jb=d+1024|0}jb=g+608|0;return b|0}function rM(a,b){var c=0,d=0,e=0;a:{b:{if(!w[b+866|0]|v[a+480180>>2]!=1){break b}d=v[b+104>>2];if(!d){break b}if(!De(d)|(x[d+34>>1]&3)!=2){break b}c=w[b+867|0]+w[(w[b+866|0]&15)+21408|0]|0;t[b+867|0]=c;if(c<<24>>24>-1){break b}t[b+867|0]=0;c=v[b+784>>2]+1|0;v[b+784>>2]=c>>>0<v[d+8>>2]-v[d+4>>2]>>>0?c:0;c=v[d+20>>2];v[114578]=0;c=T(467,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}b=Db(c)+(v[b+784>>2]+v[d+4>>2]|0)|0;t[b|0]=w[b|0]^-1;Gy(d,a,0)}return}V(0)|0;O()|0;Ab();L()}function V5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114578]=0;Z(2016,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114578]=0;b=ua(2033,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35378,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function S5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114578]=0;Z(2016,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114578]=0;b=ua(2036,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35467,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Wca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Lb(d+8|0,d+4|0)>>2];c=Db(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Db(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Db(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}jb=d+16|0;return g+h|0}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];h=v[Lb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Lb(e+8|0,e+4|0)>>2];c=Db(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=Db(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=Db(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=Db(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}jb=e+16|0;return h+i|0}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+(B(t[e|0],h)<<8);v[c+4>>2]=v[c+4>>2]+(B(f,g)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function JE(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;mb=v[e+4>>2];return v[e>>2]}function Yl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((Wl(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=Hj(i,b,f);g=Tb(f);v[114578]=0;g=W(28,a|0,g|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}yb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((Wl(a,c,b)|0)!=(b|0)){break b}}Vy(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;yb(f);S(a|0);L()}function $Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;d=Fb(a);e=Kc(a);g=Pi(b,c);a:{if(!g){break a}if($z(b,Tb(a),Tb(a)+Fb(a)|0)){b=qi(f+16|0,b,c);c=Tb(b);d=Fb(b);v[114578]=0;W(2500,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Rl(a,e,(d+g|0)-e|0,d,d,0,0)}e=Tb(a)+d|0;while(1){if((b|0)!=(c|0)){he(e,b);b=b+1|0;e=e+1|0;continue}break}t[f+15|0]=0;he(e,f+15|0);Sg(a,d+g|0)}jb=f+32|0;return a|0}function O_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;f=af(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-48|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2473,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Yl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function O4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[114578]=0;Z(2089,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[114578]=0;b=bb(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,38080,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function M_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;f=af(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-48|0;jb=e;Bc(a+8|0,c);v[114578]=0;ja(2473,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Yl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function kP(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}return(w[a|0]|w[a+1|0]<<8)>>>0<129}return 0}function Qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if(vt(a)){v[b>>2]=0;a=0;break a}f=xg(a,e,16);d=Db(w[e|0]);c=d&127;v[b>>2]=c;d=d<<24>>24;b:{if(!(f>>>0<2|(d|0)>-1)){d=c?32-E(c)|0:0;c=1;while(1){g=Db(w[c+e|0]);v[b>>2]=g&127|v[b>>2]<<7;d=d+7|0;c=c+1|0;if((f|0)==(c|0)){$b(a,f);f=xg(a,e,16);c=0}g=g<<24>>24;if((g|0)<0?c>>>0<f>>>0:0){continue}break}$b(a,c);a=(g|0)<0;if(d>>>0<33){break b}v[b>>2]=-1;a=0;break a}$b(a,1);a=(d|0)<0}a=!a}jb=e+16|0;return a|0}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!De(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}pn(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;op(e,0,c)}jb=c+32|0;return f|0}function Ar(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function $k(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;WD(a+32|0);b=jb-16|0;jb=b;c=a+44|0;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(208,c+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function Xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Lb(d+8|0,d+4|0)>>2];c=Db(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=gn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=gn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}jb=d+16|0;return g+h|0}function DQ(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Je(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Je(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}jb=f+16|0}function R4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114578]=0;Z(2089,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[114578]=0;b=aa(f|0,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37764,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function ck(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[21203]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[114552]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function XE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114552];v[114552]=0;a=Mv(a,e+12|0,d,le());d=mb;g=v[114552];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114552]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a|0}function Q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114578]=0;Z(2089,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[114578]=0;b=aa(f|0,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37721,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);v[a>>2]=80800;d=kk(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=Se(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[114578]=0;W(1641,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1642,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(d);bf(b);S(a|0);L()}function _T(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];cu(b,f+24|0);c=f+24|0;c=w[c|0]|w[c+1|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return g|0}function uK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=jb-16|0;jb=e;f=v[d+4>>2];d=v[d>>2];g=(f-d|0)/6|0;a:{if(g>>>0<=Li(c)>>>0){v[e+12>>2]=f;if(cg(c)>>>0<g>>>0){v[e+12>>2]=d;h=cg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);rx(d,v[e+12>>2],v[c>>2]);qx(c,v[e+12>>2],f,g-cg(c)|0);break a}Sz(c,rx(d,f,v[c>>2]));break a}sK(c);gS(c,Iz(c,g));qx(c,d,f,g)}jb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];tK(a+24|0,b+24|0);Xi(a+36|0,b+36|0)}function M4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114578]=0;Z(2089,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[114578]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,38026,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function K4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114578]=0;Z(2089,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[114578]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37978,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function sj(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;if(!md(a)){XN(b+32|0,a);WN(b+24|0,a);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!Ts(c,e)){break a}while(1){d=jb-16|0;jb=d;v[d+8>>2]=v[c+4>>2];f=ON(d+8|0);jb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}ON(c+4|0);if(Ts(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=nA(bc(a),v[b+44>>2])}jb=b+48|0;return c&65535}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;xP(a);zb(a);h=b+4|0;f=h;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){c=v[f>>2];while(1){c=c-56|0;e=e-56|0;d=e;nP(c,d);nP(c+12|0,d+12|0);Xy(c+24|0,d+24|0);u[c+52>>1]=x[d+52>>1];g=v[d+48>>2];v[c+44>>2]=v[d+44>>2];v[c+48>>2]=g;g=v[d+40>>2];v[c+36>>2]=v[d+36>>2];v[c+40>>2]=g;c=v[f>>2]-56|0;v[f>>2]=c;if((d|0)!=(i|0)){continue}break}}Zb(a,h);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];vk(a);tn(a);tn(a)}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){v[e+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=h,j=Vc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function Y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;e=jb-16|0;jb=e;j=v[a+4>>2];pH(a,b,c,d);h=z[a+24>>2];v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=jb-16|0;jb=a;v[a+8>>2]=v[e+8>>2];b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=a;if(!(!d|h==C(1))){while(1){if(c){k=g+j|0;f=0;while(1){i=Of(b,f,k);z[i>>2]=z[i>>2]*h;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}jb=a+16|0;jb=e+16|0}function _u(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,20);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cg(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/6>>>0){Tz(a,d,c);break c}b=zb(a);b=IR(e+8|0,Iz(a,cg(a)+d|0),cg(a),b);v[114578]=0;U(708,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(709,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}ut(b)}jb=e+32|0;break a}a=P()|0;O()|0;ut(b);S(a|0);L()}return}if(b>>>0<d>>>0){Sz(a,v[a>>2]+B(b,6)|0)}}function xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=xx(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!a){break c}v[114578]=0;U(1556,d+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(1557,e|0,d+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}hf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(d+8|0);break a}jb=d+32|0;return}a=P()|0;O()|0}sl(e);S(a|0);L()}function gJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);v[a>>2]=80160;c=kk(a+4260|0);v[a+4232>>2]=1061997773;d=a+4224|0;v[d>>2]=1061158912;v[d+4>>2]=1059082943;d=a+4216|0;v[d>>2]=1038174126;v[d+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[114578]=0;W(1641,a+44|0,2,2)|0;d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;Z(1642,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(c);bf(b);S(a|0);L()}function Uja(a,b){a=a|0;b=b|0;var c=0,d=0;c=nd(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>4>>>0){pB(a,c);break c}b=zb(a);b=MS(d+8|0,Lq(a,nd(a)+c|0),nd(a),b);v[114578]=0;R(763,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(609,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Ft(b)}jb=d+32|0;break a}a=P()|0;O()|0;Ft(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<4)|0;nd(a);XA(a,b);nD(a)}}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xe(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>5>>>0){Cy(a,d,c);break c}b=zb(a);b=HN(e+8|0,em(a,xe(a)+d|0),xe(a),b);v[114578]=0;U(1194,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1181,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Ps(b)}jb=e+32|0;break a}a=P()|0;O()|0;Ps(b);S(a|0);L()}return}if(b>>>0<d>>>0){TN(a,v[a>>2]+(b<<5)|0)}}function Hc(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;if(v[a+4>>2]==v[b+4>>2]){c=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=c;v[d+8>>2]=b;v[d+12>>2]=c;e=jb-16|0;jb=e;v[e+12>>2]=v[a+4>>2];b=d;c=v[b+4>>2];v[114578]=0;v[e+8>>2]=c;c=Q(33,e+12|0,e+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){c=Vm(v[a>>2],v[b>>2],v[c>>2]);b:{if(c){break b}c=0;if(v[a+4>>2]==v[b+4>>2]){break b}c=y[a+4>>2]<y[b+4>>2]?-1:1}jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}c=!c}jb=d+16|0;return c}function dK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Kb(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){jx(a,d,c);break c}b=zb(a);b=lx(e+8|0,Be(a,Kb(a)+d|0),Kb(a),b);v[114578]=0;U(1598,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1599,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Wm(b)}jb=e+32|0;break a}a=P()|0;O()|0;Wm(b);S(a|0);L()}return}if(b>>>0<d>>>0){mx(a,v[a>>2]+(b<<2)|0)}}function _la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=a;e=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(568,a+8|0,c+12|0,c+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(561,d|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(562,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;cT(e);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function T1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-48|0;jb=e;f=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=f;f=v[b+4>>2];v[e+32>>2]=v[b>>2];v[e+36>>2]=f;b=Go(e+24|0,c);v[114578]=0;c=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=c;c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;aa(2014,a+8|0,e+8|0,b|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Yc(b);nH(a);b=mH(a+88|0);v[a>>2]=84152;v[b>>2]=84240;jb=e+48|0;return a|0}a=P()|0;O()|0;Yc(b);S(a|0);L()}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=cz(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!a){break c}v[114578]=0;U(973,d+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(974,e|0,d+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}hf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(d+8|0);break a}jb=d+32|0;return}a=P()|0;O()|0}Gl(e);S(a|0);L()}function ID(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=jb-16|0;jb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Tb(a);a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=tm(v[bd(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=sm(k);if(e){gi(c,j,e)}if(g){gi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;gi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){lo(j,b)}Ff(a,c);Fg(a,k);b=a;a=d+(e+g|0)|0;we(b,a);v[i+4>>2]=0;Te(c+(a<<2)|0,i+4|0);jb=i+16|0;return}Hg();L()}function k5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114578]=0;Z(2016,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114578]=0;b=ea(2071,f|0,b|0,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36668,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function W5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114578]=0;Z(2016,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114578]=0;b=ea(2032,f|0,b|0,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35351,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function T5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114578]=0;Z(2016,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114578]=0;b=ea(2035,f|0,b|0,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35434,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function I4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[114578]=0;Z(2089,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[114578]=0;db(f|0,d|0,b|0,+c);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37940,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function dT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1060>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1068|0,g=Kj(a,7),t[f|0]=g;d=Kj(a,1);e=Kj(a,1);c=v[a+1056>>2];if((c|0)>255){break a}b=v[a+1060>>2]+1|0;v[a+1056>>2]=b;v[a+1060>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1064>>1]=b;dT(a);b=v[a+1060>>2];break b}u[(B(c,6)+a|0)+1064>>1]=65535}v[a+1056>>2]=b;if(e){u[(B(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1066>>1]=65535}}function jc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){c:{if((b|0)>(c|0)){if((b|0)>=25){break b}if(!c){v[a+1392>>2]=0}while(1){c=-1;e=Cr(a);d=0;if((e|0)==-1){break c}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}return jc(a,24)+(jc(a,b-24|0)<<24)|0}ia(50550,50496,1617,50569);L()}function Ow(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Nr(b)){break a}a=a+24|0;if(!dg(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0){break a}if(!(x[v[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){b=Xe(b,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}f=w[b|0]}}return f|0}function gN(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;d=3546895/+(b>>>0);c=d*.25;a:{if(D(c)<2147483648){b=~~c;break a}b=-2147483648}v[e+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(D(c)<0x8000000000000000){f=~~c>>>0;b=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break b}b=-2147483648}v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=f;v[a+12>>2]=b}function Mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xc(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){Pp(a,d,c);break c}b=zb(a);b=nh(e+8|0,Ki(a,xc(a)+d|0),xc(a),b);v[114578]=0;U(702,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(366,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Rg(b)}jb=e+32|0;break a}a=P()|0;O()|0;Rg(b);S(a|0);L()}return}if(b>>>0<d>>>0){Cu(a,v[a>>2]+b|0)}}function oI(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;f=da(122)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;U(123,c|0,e+(c+8|0)|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Ob(c);v[114578]=0;R(132,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Yd(d);jb=c+144|0;return}a=P()|0;O()|0;Yd(d);S(a|0);L()}function Zw(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;f=da(122)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;U(123,c|0,e+(c+8|0)|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Ob(c);v[114578]=0;R(124,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Yd(d);jb=c+144|0;return}a=P()|0;O()|0;Yd(d);S(a|0);L()}function zx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=jb-48|0;jb=f;a:{if(!c){c=tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;zx(a,b,g,e+16|0);Jh(e+32|0,d,tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;zx(a,b|c,g,e)}jb=f+48|0}function Uia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=0;g=jb-16|0;jb=g;a:{if(!d){break a}a=a+e|0;e=1;while(1){z[g+12>>2]=z[b>>2];ae(g+12|0,C(-1));h=C(z[g+12>>2]*C(128));z[g+12>>2]=h;h=je(h);b:{if(C(D(h))<C(2147483648)){i=~~h;break b}i=-2147483648}f=jb-16|0;jb=f;v[f+12>>2]=i;v[f+8>>2]=-128;v[f+4>>2]=127;i=t[zf(f+8|0,de(f+12|0,f+4|0))|0];jb=f+16|0;t[a|0]=i;if((d|0)==(e|0)){break a}a=a+c|0;b=b+4|0;e=e+1|0;continue}}jb=g+16|0}function Tv(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function xda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;b=Pe(1);v[114578]=0;d=Q(85,c|0,1434)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){v[114578]=0;e=Q(86,b|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=e;W(90,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;c:{if((a|0)!=1){jb=b+16|0;break c}V(0)|0;O()|0;Ab();L()}yb(d);jb=c+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d)}Xb(b);S(a|0);L()}function TV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;c=jb-16|0;jb=c;e=b+16|0;NC(c+8|0,e);f=Hb(c+8|0);d=a;g=ld(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(f|0)==(g|0);if(!c){OC(e)}d=-1;a:{if(!c){break a}d=0;if(!bD(b+16|0)){break a}c=jb-16|0;jb=c;d=b;LC(c+8|0,b);f=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((f|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(e|0);if(!a){MC(d)}d=-1;if(!a){break a}d=aD(b)}jb=b+32|0;return d|0}function P4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[114578]=0;R(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,38090,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function L6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Bc(a,b);v[114578]=0;U(128,d+8|0,b|0,c|0);e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}Ob(d+8|0);v[114578]=0;e=T(27,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}if(e){v[114578]=0;b=T(27,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}v[114578]=0;U(129,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}Ob(d)}jb=d+16|0;return}b=P()|0;O()|0;Ob(a);S(b|0);L()}function HK(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1095062050?(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;c=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return c}function B4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[114578]=0;R(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37818,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function A4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[114578]=0;R(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37800,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function l2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;Cq(v[d+8>>2]);b=jb-32|0;jb=b;v[b+24>>2]=v[d>>2];c=v[b+24>>2];e=v[c+12>>2];v[b+16>>2]=v[c+8>>2];v[b+20>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;Kp(a);v[a>>2]=76312;Oi(a+4|0);t[a+20|0]=0;v[a+16>>2]=0;v[a>>2]=76428;c=v[b+12>>2];v[a+24>>2]=v[b+8>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+32>>2]=v[b+16>>2];v[a+36>>2]=c;t[a+40|0]=0;jb=b+32|0;jb=d+16|0;return a|0}function X5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2031,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35326,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function U5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2034,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35403,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function R5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2037,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35498,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Q5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2038,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35537,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function P5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2039,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35574,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function O5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2016,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2040,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35619,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function G4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[114578]=0;ra(e|0,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114578]=0;X(1990,37904,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[114578]=0;ra(e|0,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114578]=0;X(1990,37870,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function C4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[114578]=0;ra(e|0,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114578]=0;X(1990,37836,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function xB(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>1>>>0){eB(a,c);break c}b=zb(a);b=fq(d+8|0,Ri(a,oc(a)+c|0),oc(a),b);v[114578]=0;R(412,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(382,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Ej(b)}jb=d+32|0;break a}a=P()|0;O()|0;Ej(b);S(a|0);L()}return}if(b>>>0<c>>>0){Pn(a,v[a>>2]+(b<<1)|0)}}function rka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;j=e+8|0;c=jb-16|0;jb=c;f=a;k=b;d=Ke(a);g=hc(a);h=jb-16|0;jb=h;if(d){while(1){i=yn(zb(f),d+16|0,k);g=i?g:d;d=v[(i?4:0)+d>>2];if(d){continue}break}}f=v[Oc(h+8|0,g)>>2];jb=h+16|0;v[c+8>>2]=f;l=c,m=zj(a),v[l>>2]=m;a:{b:{if(!Jb(c+8|0,c)){break b}if(yn(zb(a),b,jh(c+8|0))){break b}a=v[c+8>>2];break a}a=zj(a)}jb=c+16|0;a=v[Oc(j,a)>>2];jb=e+16|0;return a|0}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[114578]=0;d=+cb(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37959,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ba(8)|0;v[114578]=0;c=Q(85,h|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,4);c=Rw(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function C3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ba(8)|0;v[114578]=0;c=Q(85,h|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,4);c=Qw(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function kx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;j=e+8|0;c=jb-16|0;jb=c;f=a;k=b;d=Ke(a);g=hc(a);h=jb-16|0;jb=h;if(d){while(1){i=fs(zb(f),d+16|0,k);g=i?g:d;d=v[(i?4:0)+d>>2];if(d){continue}break}}f=v[Oc(h+8|0,g)>>2];jb=h+16|0;v[c+8>>2]=f;l=c,m=zj(a),v[l>>2]=m;a:{b:{if(!Jb(c+8|0,c)){break b}if(fs(zb(a),b,jh(c+8|0))){break b}a=v[c+8>>2];break a}a=zj(a)}jb=c+16|0;a=v[Oc(j,a)>>2];jb=e+16|0;return a|0}function cW(a,b){a=a|0;b=b|0;var c=0;a=fd(a);a:{if(w[b+16|0]){v[114578]=0;Q(235,a|0,7065)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[114578]=0;Q(235,a|0,7072)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}}if(Wc(a)){v[114578]=0;Q(235,a|0,7079)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[114578]=0;Q(235,a|0,7085)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;yb(a);S(b|0);L()}function NJ(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(jk(a)>>>0<=mf(a)>>>0){break b}b=zb(a);d=mf(a);e=mf(a);v[114578]=0;b=aa(1645,c+8|0,d|0,e|0,b|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[114578]=0;R(1646,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}ds(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;ds(b)}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function N4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[114578]=0;b=Q(d|0,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,38053,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function LJ(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(yd(a)>>>0<=Kb(a)>>>0){break b}b=zb(a);d=Kb(a);e=Kb(a);v[114578]=0;b=aa(1647,c+8|0,d|0,e|0,b|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[114578]=0;R(1648,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}cs(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;cs(b)}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function L4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2089,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[114578]=0;b=Q(d|0,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,38002,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function wO(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=Wb(a);d=Fb(b);v[114578]=0;R(111,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){a:{e=c,f=Dd(b),v[e+8>>2]=f;e=c,f=sf(b),v[e>>2]=f;if(Jb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[114578]=0;R(110,a|0,10);break b}v[114578]=0;R(110,a|0,b<<24>>24)}b=v[114578];v[114578]=0;if((b|0)==1){break a}qg(c+8|0);if(Jb(c+8|0,c)){continue}break}}jb=c+16|0;return}}b=P()|0;O()|0;yb(a);S(b|0);L()}function df(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=$m(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=$m(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=su(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}jb=e+16|0;return a}function Ul(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-32|0;jb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=0;f=v[Lb(d+8|0,d+12|0)>>2];h=v[a>>2];if((f|0)!=((j=h,k=Db(d+16|0),l=v[a+8>>2]+g|0,m=f,i=v[v[h>>2]+28>>2],nb[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(pd(d+16|0,b+g|0,f)){break a}e=v[d+12>>2]-f|0;v[d+12>>2]=e;g=f+g|0;if(e){continue}break}}$b(a,c);e=1}jb=d+32|0;return e}function qY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=jb-16|0;jb=f;v[f+12>>2]=v[a+8>>2];i=Ah(f+8|0,f+12|0);v[114578]=0;j=bF(c,d-c|0,b);l=v[114578];v[114578]=0;b:{if((l|0)!=1){Ie(i);jb=f+16|0;break b}a=P()|0;O()|0;Ie(i);S(a|0);L()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function _0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!vr(Za(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}jb=d+32|0;return e|0}function Zd(a){var b=0,c=0,d=0;d=jo($e(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function JW(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;v[114578]=0;a=xD(2006,a,b,c,d,e,f);b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;ja(2001,34615,g|0,h|0,i|0,j|0,k|0,l|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function dS(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(yf(a)>>>0<=xc(a)>>>0){break b}b=zb(a);d=xc(a);e=xc(a);v[114578]=0;b=aa(39,c+8|0,d|0,e|0,b|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[114578]=0;R(40,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}_p(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;_p(b)}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function d4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Fb(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[kc(b,0)|0]==43){break b}if(w[kc(b,0)|0]==45){break b}}i=d,j=Dd(b),v[i+8>>2]=j;i=d,j=cf(d+8|0,e-c|0),v[i+16>>2]=j;Md(d+24|0,d+16|0);nw(b,v[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}td(a,b);jb=d+32|0}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,18);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function ax(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;j=d,k=Dd(a),v[j+8>>2]=k;h=am(d+24|0,d+8|0);f=h;b=am(d+16|0,d+24|0);e=jb-16|0;jb=e;v[e+12>>2]=b;a:{c=Fb(a);if(f>>>0<=c>>>0){if(b){i=Tb(a);g=c-f|0;v[e+8>>2]=g;b=v[Lb(e+12|0,e+8|0)>>2];v[e+12>>2]=b;g=g-b|0;if(g){f=f+i|0;$l(f,b+f|0,g);b=v[e+12>>2]}f=a;a=c-b|0;Sg(f,a);t[e+7|0]=0;he(a+i|0,e+7|0)}jb=e+16|0;break a}qm();L()}cf(d+8|0,h);jb=d+32|0}function T7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);v[a>>2]=80392;c=kk(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[114578]=0;W(1641,a+44|0,2,2)|0;d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;Z(1642,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(c);bf(b);S(a|0);L()}function Jx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=e;a:{if(!uj(b)){c=_L(a,c,v[b+704>>2],d);break a}c=v[b+700>>2]}v[f+12>>2]=c;b=v[b+656>>2];b:{if(!b){break b}f=v[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=v[a+1074420>>2];b=Hma(b,b>>31,c,c>>31);c=d+b|0;d=mb+(d>>31)|0;g=e,h=Ac(Ima(c,b>>>0>c>>>0?d+1|0:d,f,f>>31),mb),v[g+12>>2]=h}Cc(e+12|0,2147483647);a=Ima(0,v[e+12>>2],v[a+24620>>2]<<4,0);jb=e+16|0;return a|0}function s0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+16>>2];g=v[a+12>>2];if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[de(e+12|0,de(e+8|0,e+4|0))>>2];xh(b,v[a+12>>2],d);v[a+12>>2]=d+v[a+12>>2];f=d+f|0;b=b+d|0;continue}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Km(d),t[h|0]=i;f=f+1|0;b=b+1|0;continue}break}jb=e+16|0;return f|0}function Y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114578]=0;U(2030,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35294,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=v[b>>2];e=QS(b);c=jb-16|0;jb=c;f=ot(d,e);a:{if(f>>>0<=yd(a)>>>0){v[c+12>>2]=e;if(Kb(a)>>>0<f>>>0){v[c+12>>2]=d;XQ(c+12|0,Kb(a));gf(d,v[c+12>>2],v[a>>2]);Ln(a,v[c+12>>2],e,f-Kb(a)|0);break a}zu(a,gf(d,e,v[a>>2]));break a}WQ(a);b=a;g=Be(a,f);if(g>>>0>Zm(a)>>>0){ed();L()}zb(b);h=SB(g);v[b>>2]=h;v[b+4>>2]=h;i=zb(b),j=(g<<2)+h|0,v[i>>2]=j;mk(b,0);Ln(a,d,e,f)}jb=c+16|0}function a6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114578]=0;e=+oa(2026,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35224,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=bc(b);f=cc(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Jb(c+24|0,c+16|0)){break a}while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]==(w[e|0]|w[e+1|0]<<8)){break a}Gk(c+24|0);if(Jb(c+24|0,c+16|0)){continue}break}}jb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=cc(b),v[g>>2]=h;b:{if(Jb(d+8|0,d)){Ze(a,zb(v[d+8>>2]));break b}Xh(a)}jb=d+16|0}function Dk(a,b){a=a|0;b=b|0;var c=0,d=0;c=xc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){kS(a,c);break c}b=zb(a);b=nh(d+8|0,Ki(a,xc(a)+c|0),xc(a),b);v[114578]=0;R(41,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(40,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}_p(b)}jb=d+32|0;break a}a=P()|0;O()|0;_p(b);S(a|0);L()}return}if(b>>>0<c>>>0){aS(a,v[a>>2]+b|0)}}function z5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2055,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36151,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=b;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;b=qt(d,d+8|0);jb=d+16|0;a:{b=Uh(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[114578]=0;U(769,c|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;_d(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}vc(b);jb=e+32|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function GL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a=jb-16|0;jb=a;f=a,g=bc(c),v[f+8>>2]=g;f=a,g=cc(c),v[f>>2]=g;if(Jb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[114578]=0;Z(b|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;dx(c);Ab();L()}Ib(b+20|0);Ib(b+8|0);Xb(b);_d(a+8|0);if(Jb(a+8|0,a)){continue}break}}dx(c);jb=a+16|0;Xb(c)}}}function D5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2051,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35973,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function C5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2052,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36016,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function B5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2053,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36059,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function A5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2054,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36103,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function H4(a){a=a|0;var b=0,c=0,d=0;v[114578]=0;Z(2089,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[114578]=0;c=+la(d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37922,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F4(a){a=a|0;var b=0,c=0,d=0;v[114578]=0;Z(2089,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[114578]=0;c=+la(d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37887,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function D4(a){a=a|0;var b=0,c=0,d=0;v[114578]=0;Z(2089,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[114578]=0;c=+la(d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37853,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function kt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[fc(a,0)|0]&15)<<8|w[fc(a,1)|0];a:{if((d|0)==4095|!d){break a}e=108;while(1){f=x[(c<<1)+20848>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+20846>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[fc(a,2)|0];g=b,h=w[fc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[fc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[fc(a,3)|0],t[g+5|0]=h}function N6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Ai(C(C(Se(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Ai(C(C(b>>>0)*C(1.1892070770263672)));d=Ai(C(C(c>>>0)*C(1.1892070770263672)));g=Ai(C(C(d>>>0)*C(1.1892070770263672)));e=Ai(C(C(b+d>>>0)*C(.11546666920185089)));f=Ai(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;GI(a);EI(a)}function xN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{if(rj(a)){d=c+8|0;b=Pe(3848);e=v[c+12>>2];v[114578]=0;e=Q(1200,b|0,e|0)|0;f=v[114578];v[114578]=0;b:{if((f|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=e;W(1201,d|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){jb=b+16|0;break b}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;Xb(b);S(a|0);L()}Fs(a,c+8|0);wf(c+8|0);break a}EN(v[a>>2],b)}wN(a);jb=c+16|0}function n0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+16>>2];g=v[a+12>>2];if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g>>2;v[e+4>>2]=c-f;d=v[de(e+12|0,de(e+8|0,e+4|0))>>2];gi(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+(d<<2);f=d+f|0;b=(d<<2)+b|0;continue}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;f=f+1|0;b=b+4|0;continue}break}jb=e+16|0;return f|0}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=pi(a,b,c,d);v[a>>2]=79272;d=kk(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=Se(c),v[e+4232>>2]=f;v[114578]=0;Z(1640,a+4260|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;W(1641,a+44|0,2,2)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;Z(1642,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(d);bf(b);S(a|0);L()}function Ws(a){a=a|0;var b=0,c=0,d=0,e=0;pn(a);b=v[a>>2];c=Zn(a);a:{if(b-1>>>0<=268435455){b=b+208|0;Hma(c,0,b,0);c=mb?0:B(b,c);break a}c=0}b:{if(!c){break b}v[114578]=0;b=T(2827,c|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;b=0;if((d|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}if(!b){break b}e=Rb(b,0,c)- -64|0}v[a+20>>2]=e;if(!e){return 0}return Bj(a)|0}function IW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[114578]=0;a=Ja(2007,a|0,b|0,c|0,d|0)|0;b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;ja(2001,34641,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function Zt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-32|0;jb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=0;f=v[Lb(d+8|0,d+12|0)>>2];if((f|0)!=((i=a,j=Db(d+16|0),k=v[a+12>>2]+g|0,l=f,h=v[v[a>>2]+28>>2],nb[h](i|0,j|0,k|0,l|0)|0)|0)){break a}if(pd(d+16|0,b+g|0,f)){break a}e=v[d+12>>2]-f|0;v[d+12>>2]=e;g=f+g|0;if(e){continue}break}}Xc(a,c);e=1}jb=d+32|0;return e}function LA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;e=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(356,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(468,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;U(469,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;jC(e);S(a|0);L()}return a|0}function F6(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;a:{b:{if(!a){break b}a=qc(b+8|0,a);v[114578]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=T(1997,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1990,34236,0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}a=0}jb=b+16|0;return a|0}function Cga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=jb-48|0;jb=g;a:{b:{if(c>>>0>d>>>0){break b}if(Ce(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(mh(Ge(b,f))){h=bc(Ge(b,f));i=cc(Ge(b,f));f=NO(g,e);v[114578]=0;X(1032,g+24|0,h|0,i|0,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break a}ke(g+24|0);ke(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}MO(a,e);jb=g+48|0;return}a=P()|0;O()|0;ke(f);S(a|0);L()}function gU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,17);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function YT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if(!Df(a,7)){break b}c=0;if(!VA(a,12222)){break a}if(!Df(a,1)){break b}c=-1;if(!Xc(a,$p(a))){break a}d=jb-16|0;jb=d;f=e+8|0;Yt(d+8|0,f);c=a;g=Hb(d+8|0);h=ld(a,ac(d,d+8|0));if((g|0)==(h|0)){Xc(c,Hb(d+8|0))}jb=d+16|0;d=(g|0)==(h|0);if(!d){CA(f)}c=-1;if(!d){break a}c=0;if(!RA(e+8|0)){break a}c=df(a,b,QA(e+8|0),mb);break a}c=-1}jb=e+16|0;return c|0}function k0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;Xi(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Tb(c)+Fb(c)|0,v[d+44>>2]=e;Om(a,Tb(c),Tb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Fb(c);d=a,e=b+Tb(c)|0,v[d+44>>2]=e;Co(c,Kc(c));Nw(a,Tb(c),Tb(c)+Fb(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;Kr(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}Kr(a,b)}}function i6(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2019,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34986,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function f6(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2021,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35052,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Ed(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;pn(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Ub(d,18532);v[114578]=0;Q(372,a+43|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);eO(a);jb=d+16|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function CG(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;u[e+12>>1]=c;u[e+14>>1]=b;jg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=jb-16|0;jb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Vf(a)>>>0>=d>>>0){g=b,h=oc(a),v[g+8>>2]=h;Bz(v[a>>2],v[Lb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){gq(a,d-f|0,c);break a}Pn(a,v[a>>2]+(d<<1)|0);break a}YN(a);gz(a,Ri(a,d));gq(a,d,c)}jb=b+16|0;jb=e+16|0}function G3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114578]=0;c=Q(85,f|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,2);c=Rw(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function D3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114578]=0;c=Q(85,f|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,2);c=Qw(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function nQ(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function Jo(a,b,c){var d=0,e=0;a=tf(a);d=Fb(b);v[114578]=0;R(113,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){a:{if(Fb(b)){while(1){d=w[kc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[114578]=0;R(112,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break b}break a}v[114578]=0;R(112,a|0,65533);d=v[114578];v[114578]=0;if((d|0)==1){break a}}e=e+1|0;if(Fb(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Lc(a);S(b|0);L()}function nC(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return c}function m5(a,b){a=a|0;b=b|0;var c=0;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;b=Q(2069,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36599,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function l5(a,b){a=a|0;b=b|0;var c=0;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;b=Q(2070,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36632,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function dX(){var a=0,b=0,c=0,d=0,e=0,f=0;a=jb-48|0;jb=a;a:{b=v[115883];if(b){c=b+48|0;if(DD(c)){d=a;if(v[c>>2]==1126902529&v[c+4>>2]==1129074247){c=v[b+44>>2]}else{c=b+80|0}v[d+44>>2]=c;d=v[b>>2];b=v[d+4>>2];if(nb[v[v[17795]+16>>2]](71180,d,a+44|0)|0){break a}v[a+20>>2]=b;v[a+16>>2]=v[21295];L()}v[a+32>>2]=v[21295];L()}L()}c=v[21295];d=v[a+44>>2];e=a,f=nb[v[v[d>>2]+8>>2]](d)|0,v[e+8>>2]=f;v[a+4>>2]=b;v[a>>2]=c;L()}function bS(a,b){var c=0,d=0,e=0,f=0;a:{b:{if(!b){break b}if(!Qb(a,b)){break b}if(b>>>0<=3){c=jb-16|0;jb=c;c:{if(!b){break c}if(!Qb(a,b)){break c}while(1){t[c+11|0]=0;d:{if(b>>>0>d>>>0){Xf(a,c+11|0);e=t[c+11|0];f=e>>>31|0;break d}e=0-f|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24)}jb=c+16|0;a=d;break a}c=Cf(a);$b(a,b-4|0)}a=c}return a}function Qu(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=jb-16|0;jb=i;if((b^-1)-17>>>0>=c>>>0){j=Tb(a);a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Uk(v[bd(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=$h(k);if(e){xh(c,j,e)}if(g){xh(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){xh((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){pg(a,j,b)}Ff(a,c);Fg(a,k);b=a;a=d+(e+g|0)|0;we(b,a);t[i+7|0]=0;he(a+c|0,i+7|0);jb=i+16|0;return}Hg();L()}function KT(){var a=0,b=0;a=jb-16|0;jb=a;a:{if(Wa(a+12|0,a+8|0)|0){break a}b=od((v[a+12>>2]<<2)+4|0);v[115363]=b;if(!b){break a}b=od(v[a+8>>2]);if(b){v[v[115363]+(v[a+12>>2]<<2)>>2]=0;if(!(Va(v[115363],b|0)|0)){break a}}v[115363]=0}jb=a+16|0;b:{if(t[461432]&1){break b}if(!wd(461432)){break b}v[114578]=0;T(2312,461428)|0;a=v[114578];v[114578]=0;if((a|0)!=1){vd(461432);break b}a=P()|0;O()|0;pe(461432);S(a|0);L()}SK()}function fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(878,a+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(873,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(874,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;GQ(d);S(a|0);L()}return a|0}function cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(880,a+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(875,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(876,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;FQ(d);S(a|0);L()}return a|0}function Ux(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;v[a+1074372>>2]=b;XK(a+1074332|0,b);e=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(nb[v[v[b>>2]+132>>2]](b)|0){f=oJ(v[b+16>>2]);b=v[b+16>>2];c=C(C(c*C(y[b+480232>>2]))/C(z[f+8>>2]*z[oJ(b)+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((e|0)!=(a|0)){continue}break}}function U4(a){a=a|0;var b=0;v[114578]=0;Z(2089,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){nb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37293,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function JT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=bc(b);f=cc(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Jb(c+24|0,c+16|0)){break a}while(1){if((Gj(v[c+24>>2])|0)==v[v[c+8>>2]>>2]){break a}Gk(c+24|0);if(Jb(c+24|0,c+16|0)){continue}break}}jb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=cc(b),v[g>>2]=h;b:{if(Jb(d+8|0,d)){Ze(a,zb(v[d+8>>2]));break b}Xh(a)}jb=d+16|0}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function uw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Br(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}dc(a,32);return 0}ia(50614,50496,1549,50635);L()}function tK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;if((a|0)!=(b|0)){c=jb-16|0;jb=c;d=v[b>>2];e=v[b+4>>2];f=ot(d,e);a:{if(f>>>0<=yd(a)>>>0){v[c+12>>2]=e;if(Kb(a)>>>0<f>>>0){v[c+12>>2]=d;XQ(c+12|0,Kb(a));gf(d,v[c+12>>2],v[a>>2]);Ln(a,v[c+12>>2],e,f-Kb(a)|0);break a}UR(a,gf(d,e,v[a>>2]));break a}b=a;if(v[a>>2]){Ks(b);Re(zb(b),v[b>>2],yd(b));g=zb(b),h=0,v[g>>2]=h;v[b>>2]=0;v[b+4>>2]=0}sB(a,Be(a,f));Ln(a,d,e,f)}jb=c+16|0}}function q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;d=_E(a,e+12|0,d,le());a=mb;f=v[114552];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[114552]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}jb=e+16|0;mb=a;return d|0}function c6(a,b){a=a|0;b=+b;var c=0;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;b=+fb(2024,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[114578]=0;X(1990,35152,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function KZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;YD(a+16|0,c+12|0,c+8|0);e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(2552,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(2553,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;tE(d);S(a|0);L()}return a|0}function zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,15);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;jb=c+16|0}return a|0}function wka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;v[e+24>>2]=d;g=Mj(a,c);pf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(xd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=jb-16|0;jb=f;d=fd(f);v[114578]=0;aa(694,b|0,h|0,d|0,i|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){yb(d);jb=f+16|0;break b}a=P()|0;O()|0;yb(d);S(a|0);L()}}_i(a,g,c,e+16|0);jb=e+32|0}function AT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;f=e+8|0;g=b;if(qA(b,e+24|0)){d=e+28|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}ud(f,g,d);a=pA(a,e+24|0,e+8|0);Bb(e+8|0);a:{if(!c){break a}d=(d>>>0)%(c>>>0)|0;if(!d){break a}v[114578]=0;Q(340,b|0,c-d|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;hf(a);S(b|0);L()}jb=e+32|0}function h$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;le();d=jb-16|0;jb=d;Lv(d,a,e+12|0,0);f=mF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[114552];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114552]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return C(f)}function g6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2020,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35016,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function bH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]*.015625)}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function y5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2056,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36200,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function x5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2057,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36232,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function w5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2058,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36264,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function v5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2059,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36294,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function u5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2060,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36326,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function t5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2061,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,36361,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function e6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2022,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35084,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function R3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb+-64|0;jb=d;e=v[a>>2];f=v[a+4>>2];g=v[a+12>>2];a=v[a+8>>2];v[d+16>>2]=a;v[d+20>>2]=g;v[d+40>>2]=a;v[d+44>>2]=g;v[d+32>>2]=e;v[d+36>>2]=f;v[d+8>>2]=e;v[d+12>>2]=f;UH(d+48|0,d+8|0,0);a=Go(d+24|0,c);v[114578]=0;b=+xa(2162,d+48|0,+b,a|0);c=v[114578];v[114578]=0;if((c|0)!=1){Yc(a);Bb(d+48|0);jb=d- -64|0;return+b}c=P()|0;O()|0;Yc(a);Bb(d+48|0);S(c|0);L()}function K5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2045,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35764,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function J5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2046,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35797,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function I5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2047,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35830,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function H5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2048,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35863,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function G5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2049,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35898,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2050,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35929,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ns(a,Kl(b+16|0,Db(c),d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b|0,38633)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}jb=b+32|0;return a|0}L()}function qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=rP(b,c);v[114578]=0;e=Q(990,b+12|0,c+12|0)|0;a=v[114578];v[114578]=0;b:{c:{if((a|0)!=1){v[114578]=0;Q(991,b+24|0,c+24|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}a=v[c+40>>2];v[b+36>>2]=v[c+36>>2];v[b+40>>2]=a;u[b+52>>1]=x[c+52>>1];a=v[c+48>>2];v[b+44>>2]=v[c+44>>2];v[b+48>>2]=a;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;fe(e)}fe(d);S(a|0);L()}}function q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+28>>2];g=v[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Cg(t[b|0]),h=v[v[a>>2]+52>>2],nb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[de(e+12|0,e+8|0)>>2];xh(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}jb=e+16|0;return f|0}function d6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;c=+la(2023,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35116,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function b6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;c=+la(2025,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35188,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function L5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;c=+la(2044,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,35723,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Jq(a){var b=0,c=0;Cn(a,1,10879);v[114578]=0;b=da(228)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[114578]=0;b=da(229)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[a+16|0]=b;v[114578]=0;b=da(230)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[114578]=0;Z(231,a+20|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;yb(a);S(b|0);L()}function $G(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}jb=c+16|0;return(w[(v[a+32>>2]+B(b,896)|0)+1075073|0]&4)>>>2|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function sba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=jb-896|0;jb=d;b=Rb(a,0,66);v[b+72>>2]=0;v[b+76>>2]=0;v[b+68>>2]=256;u[b+66>>1]=65535;v[b+80>>2]=0;v[b+84>>2]=0;t[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=HL(a)+896|0;if((e|0)!=(a|0)){continue}break}d=Rb(d,0,896);e=HL(d);a=c;c=((a+229376|0)-a|0)/896|0;if((c|0)>=1){while(1){vs(a,e);a=a+896|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}jb=d+896|0;return b|0}function Lv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-160|0;jb=e;Rb(e+16|0,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;Bh(e+16|0,0,0);oF(e,e+16|0,d,1);d=v[e+8>>2];g=v[e+12>>2];h=v[e>>2];i=v[e+4>>2];if(c){j=c;f=b;b=v[e+20>>2]-v[e+24>>2]|0;k=b;c=b+v[e+136>>2]|0;b=v[e+140>>2]+(b>>31)|0;b=c>>>0<k>>>0?b+1|0:b;v[j>>2]=!(b|c)?f:f+c|0}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=g;jb=e+160|0}function H3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,1);c=Rw(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function E3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,1);c=Qw(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function T3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ns(a,Kl(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b|0,38633)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}jb=b+32|0;return a|0}L()}function lN(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1230,a+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(1224,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(1225,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;fN(d);S(a|0);L()}return a}function DG(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){dc(a,21);return-1}if(v[a+1396>>2]<=9){dk(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=kl(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>-1)){dc(a,21)}return c}ia(50824,50496,1778,50846);L()}function gQ(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)>>>0<512|(w[b|0]|w[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function ze(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=wo(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(vG(a,b)&3){case 0:c=wo(A[b>>3],A[b+8>>3]);break a;case 1:c=-xo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-wo(A[b>>3],A[b+8>>3]);break a;default:break b}}c=xo(A[b>>3],A[b+8>>3],1)}a=c;jb=b+16|0;return a}function z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,2);c=VH(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,4);c=VH(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function f$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;le();d=jb-16|0;jb=d;Lv(d,a,e+12|0,1);f=iw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[114552];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114552]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return+f}function B3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,2);c=WH(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function A3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2010,b|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}ni(a,b,4);c=WH(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Bi(e+24|0,e+16|0,c);v[114578]=0;U(872,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(668,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(518,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Xz(e+24|0,e+16|0,c);v[114578]=0;U(667,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(668,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(518,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;km(e+24|0,e+16|0,c);v[114578]=0;U(240,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function es(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function UL(){var a=0,b=0;a=jb-240|0;jb=a;a:{b:{if(t[85352]&1){break b}if(!wd(85352)){break b}v[114578]=0;da(102)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;R(103,a+120|0,85200);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;Q(104,85232,lc(a,a+120|0,120)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}vd(85352)}jb=a+240|0;return 85232}a=P()|0;O()|0;pe(85352);S(a|0);L()}function Pka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;km(e+24|0,e+16|0,c);v[114578]=0;U(224,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function My(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+8>>2]=c;g=f,h=nf(b),v[g+28>>2]=h;Me(f+8|0,b,v[Lb(f+8|0,f+28|0)>>2]);v[114578]=0;b=T(414,f+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[114578]=0;a=ea(442,a|0,b|0,c|0,d|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}Ec(f+8|0);jb=f+32|0;return a|0}a=P()|0;O()|0;Ec(f+8|0);S(a|0);L()}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;mO(e+24|0,e+16|0,c);v[114578]=0;U(77,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function lW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Bi(e+24|0,e+16|0,c);v[114578]=0;U(224,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function hU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;hu(e+24|0,e+16|0,c);v[114578]=0;U(446,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function EP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Mp(a);f=d,g=bc(b),v[f+8>>2]=g;f=d,g=cc(b),v[f>>2]=g;a:{if(Jb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=zb(a);v[114578]=0;R(601,e|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}}Gk(d+8|0);if(Jb(d+8|0,d)){continue}break}}jb=d+16|0;return}a=P()|0;O()|0;gd(e);S(a|0);L()}function hba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(yf(a)>>>0>=b>>>0){f=e,g=xc(a),v[f+8>>2]=g;Sh(v[a>>2],v[Lb(e+12|0,e+8|0)>>2],c);b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){Pp(a,b-d|0,c);break a}Cu(a,b+v[a>>2]|0);break a}d=a;if(v[d>>2]){xc(d);fC(d);tp(d);pg(zb(d),v[d>>2],yf(d));f=zb(d),g=0,v[f>>2]=g;v[d>>2]=0;v[d+4>>2]=0}Ip(a,Ki(a,b));Pp(a,b,c)}jb=e+16|0}function Bx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=ls(b);while(1){j=a;k=c;e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=ls(K(g*-152587890625e-16*d+1)*b);d=h*d;d=g*hi(d)/(d*i)}else{d=1}d=H(k*d+.5);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}u[j>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function hi(a){var b=0,c=0;b=jb-16|0;jb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=xo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(vG(a,b)&3){case 0:a=xo(A[b>>3],A[b+8>>3],1);break a;case 1:a=wo(A[b>>3],A[b+8>>3]);break a;case 2:a=-xo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-wo(A[b>>3],A[b+8>>3])}jb=b+16|0;return a}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;zb(a);v[c+12>>2]=214748364;v[114578]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){ed();L()}zb(a);c=b;if(c>>>0>214748364){Fc(15551);L()}c=sc(B(c,20),4);v[a>>2]=c;v[a+4>>2]=c;f=zb(a),g=c+B(b,20)|0,v[f>>2]=g;xp(a);xp(a)}function VT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;NA(e+24|0,c);v[114578]=0;U(224,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function q6(a){a=a|0;var b=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Xb(Qr(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34780,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function iH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=4?b<=0:1){d=ba(8)|0;v[114578]=0;c=Q(85,c|0,40593)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(d,c);v[114578]=0;U(2010,d|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=yk(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;To(v[a>>2]);jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function gH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=4?b<=0:1){d=ba(8)|0;v[114578]=0;c=Q(85,c|0,40614)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(d,c);v[114578]=0;U(2010,d|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=yk(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;To(v[a>>2]);jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=jb-16|0;jb=e;d=-1;a:{if(!Jj(a,e+8|0)){break a}b:{c:{c=e+8|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(Gj(14647)|0)){break c}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>259){break c}c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>255;break b}c=0}d=0;if(!c){break a}d=df(a,b,36,0)}c=d;jb=e+16|0;return c|0}function Cz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;lR(a,b);e=b+8|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);Qc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);kR(a,d);a:{b=b+32|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!Qc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}Bn(a,c);return}Rb(c,0,80)}function TF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;c=Ub(d,c);v[114578]=0;U(2359,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){v[114578]=0;Q(2360,a|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}yb(d+16|0);yb(c);v[a>>2]=58380;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;jb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+16|0)}yb(c);S(a|0);L()}function XG(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}a=v[a+32>>2]+B(b,896)|0;v[a+1075e3>>2]=0;v[a+1075060>>2]=0;jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function L7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=80596;v[114578]=0;W(1641,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1642,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);f=a,g=Db(w[b+2|0])|Db(w[b+3|0])<<8,u[f>>1]=g;Db(w[b+4|0]);Db(w[b+5|0]);f=a,g=Db(w[b+6|0])|Db(w[b+7|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;Db(w[b+7|0]);Db(w[b+6|0]);f=a,g=Db(w[b+5|0])|Db(w[b+4|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function mq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;e=v[a+4>>2];d=v[a>>2];t[c+12|0]=0;Xr(d,d+e|0,c+12|0);d=Tb(b);e=Tb(b);g=c,h=Fb(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;gf(d,e+v[Lb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Fb(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Lb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Xr(b+d|0,e+f|0,c+7|0);jb=c+16|0;return a|0}function k6(a,b){a=a|0;b=b|0;var c=0;v[114578]=0;Z(2016,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34929,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function cx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(Se(v[a+16>>2])>>>0);c=C(C(nb[v[v[a>>2]+200>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(nb[v[v[a>>2]+192>>2]](a))),z[d+4248>>2]=e;d=a,f=Lh(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(nb[v[v[a>>2]+204>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(nb[v[v[a>>2]+188>>2]](a)|0)){b=yG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function _8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[114578]=0;R(508,b+4|0,8);b=v[114578];v[114578]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(71204)|0;if((O()|0)==(ga(71204)|0)){_(b|0)|0;Es(v[a+20>>2]+4|0);$();return}S(b|0);L()}function M9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,52);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[114578]=0;U(1583,f|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d>>2]+52|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}vc(d);jb=e+16|0;return}a=P()|0;O()|0;vc(d);S(a|0);L()}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+(b<<5);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[114578]=0;U(1178,f|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d>>2]+32|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}vc(d);jb=e+16|0;return}a=P()|0;O()|0;vc(d);S(a|0);L()}function GF(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=jb-16|0;jb=c;b=ba(16)|0;a=jb-16|0;jb=a;a:{if(t[461444]&1){break a}if(!wd(461444)){break a}vd(461444)}Uc(a+8|0,1,85172);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;jb=a+16|0;v[114578]=0;W(2400,b|0,59056,c|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ha(b|0,59128,2401);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}}function _X(){var a=0;a:{if(t[462088]&1){break a}if(!wd(462088)){break a}a=461920;while(1){a=Wb(a)+12|0;if((a|0)!=462088){continue}break}vd(462088)}Mc(461920,69216);Mc(461932,69223);Mc(461944,69230);Mc(461956,69238);Mc(461968,69248);Mc(461980,69257);Mc(461992,69264);Mc(462004,69273);Mc(462016,69277);Mc(462028,69281);Mc(462040,69285);Mc(462052,69289);Mc(462064,69293);Mc(462076,69297)}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;hB(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function XX(){var a=0;a:{if(t[462264]&1){break a}if(!wd(462264)){break a}a=462096;while(1){a=tf(a)+12|0;if((a|0)!=462264){continue}break}vd(462264)}_c(462096,69304);_c(462108,69332);_c(462120,69360);_c(462132,69392);_c(462144,69432);_c(462156,69468);_c(462168,69496);_c(462180,69532);_c(462192,69548);_c(462204,69564);_c(462216,69580);_c(462228,69596);_c(462240,69612);_c(462252,69628)}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[114578]=0;U(707,f|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}vc(d);jb=e+16|0;return}a=P()|0;O()|0;vc(d);S(a|0);L()}function Via(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;a:{if(!d){break a}a=(e<<1)+a|0;e=c<<1;c=1;while(1){z[f+12>>2]=z[b>>2];ae(f+12|0,C(-1));g=C(z[f+12>>2]*C(32768));z[f+12>>2]=g;i=a;g=je(g);b:{if(C(D(g))<C(2147483648)){h=~~g;break b}h=-2147483648}j=i,k=Vc(h),u[j>>1]=k;if((c|0)==(d|0)){break a}b=b+4|0;a=a+e|0;c=c+1|0;continue}}jb=f+16|0}function Ny(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+8>>2]=c;f=e,g=nf(b),v[f+28>>2]=g;Me(e+8|0,b,v[Lb(e+8|0,e+28|0)>>2]);v[114578]=0;b=T(414,e+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[114578]=0;aa(1063,a|0,b|0,c|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}Ec(e+8|0);jb=e+32|0;return 1}a=P()|0;O()|0;Ec(e+8|0);S(a|0);L()}function l0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=v[a+24>>2];g=v[a+28>>2];if(f>>>0>=g>>>0){if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{v[d+12>>2]=g-f>>2;v[d+8>>2]=c-e;f=v[de(d+12|0,d+8|0)>>2];gi(v[a+24>>2],b,f);g=f<<2;v[a+24>>2]=g+v[a+24>>2];e=e+f|0;b=b+g|0}continue}break}jb=d+16|0;return e|0}function oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1234,a+8|0,d+12|0,d+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=jn(a+12|0);t[a+30|0]=c;u[a+28>>1]=0;v[a+24>>2]=b;v[114578]=0;R(1233,a|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;oe(d);eN(a);S(b|0);L()}function cN(a,b,c){var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[a+4>>2]=0;a:{if(b){b:{if(ft(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}zb(a);e=ez(d+16|0);v[114578]=0;f=Q(933,a|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}v[114578]=0;R(934,e|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break a}v[e+4>>2]=b;dz(a,e);ke(e)}vj(d,a);kq(d,b,w[c|0])}jb=d+32|0;return}a=P()|0;O()|0;ke(e);S(a|0);L()}function jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;e=-1;c=jb-16|0;jb=c;f=d+8|0;BK(c+8|0,f);g=Hb(c+8|0);h=ld(a,ac(c,c+8|0));if((g|0)==(h|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(g|0)==(h|0);if(!a){CK(f)}a:{if(!a){break a}e=0;if(!HK(d+8|0)){break a}if(b){a=d+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}e=1}jb=d+32|0;return e|0}function UE(a,b,c){var d=0,e=0,f=0,g=0,h=0;h=jb-16|0;jb=h;e=jb-16|0;jb=e;d=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){of(d,b);f=d;break b}g=tm(b)+1|0;f=sm(g);Ff(d,f);Fg(d,g);we(d,b)}g=f;c:{d:{d=b;if(b){v[114578]=0;ND(g,c,d);c=v[114578];v[114578]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}v[e+12>>2]=0;Te((b<<2)+f|0,e+12|0);jb=e+16|0;break a}Hg();L()}jb=h+16|0;return a}function zS(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function v1(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+40816>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+40816>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+40816>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+40816>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+40816>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function Pha(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!eA(a,b+16|0)){break a}c=0;if(!FP(b+16|0)){break a}c=-1;if(!Jj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+8|0;c=(c|0)==((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))&2139062143)}a=c;jb=b+32|0;return a|0}function sx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;a:{while(1){h=g&255;if(ux(b,c,h>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;Fy(a,f+15|0,f+14|0);break a}lh(b,d);lh(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(Ym(w[b|0])>>>0>Ym(w[d|0])>>>0){lh(b,d);lh(c,e)}t[f+11|0]=w[b|0];Fy(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}jb=f+16|0}function j6(a){a=a|0;var b=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34959,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function SS(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;return!(w[a|0]|w[a+1|0]<<8)}return 0}function FE(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=jb-16|0;jb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=_n(d,g+i|0,f+15|0);if(!d){break a}if(!Vm(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}jb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+24>>2]=b;a:{b=Xl(d+8|0,a+8|0,nA(b,c));if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];f=v[d+24>>2];v[114578]=0;U(522,c|0,e|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+2;te(d+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}vc(b);jb=d+32|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=Pe(64);v[114578]=0;f=T(1429,d|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){d=Rx(e+8|0,f);f=v[d>>2];v[114578]=0;b=W(1636,f|0,b|0,c|0)|0;c=v[114578];v[114578]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}Qx(a);break b}a=P()|0;O()|0;bg(d);break a}Gp(a,d)}bg(d);jb=e+16|0;return}a=P()|0;O()|0;Xb(d)}S(a|0);L()}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+(b<<11);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(1652,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+2048|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function l6(a){a=a|0;var b=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return Zd(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34891,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();return 0}return Zd(34181)|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,48);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(742,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+48|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,33);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(767,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+33|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;zP(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))!=1414807888){a=c+12|0}else{zP(a,c+11|0);t[b|0]=1;a=c+11|0}b=jb-16|0;jb=b;a:{b:{if(a){a=Ub(b,a);v[114578]=0;d=T(977,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}yb(a)}jb=b+16|0;break a}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=c+16|0;return d|0}function kp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=jb-16|0;jb=b;e=bc(a);f=cc(a);c=jb-16|0;jb=c;v[c>>2]=f;v[c+8>>2]=e;if(Jb(c+8|0,c)){while(1){d=A[v[c+8>>2]>>3]+d;vy(c+8|0);if(Jb(c+8|0,c)){continue}break}}jb=c+16|0;g=b,h=bc(a),v[g+8>>2]=h;g=b,h=cc(a),v[g>>2]=h;if(Jb(b+8|0,b)){d=-d;while(1){a=v[b+8>>2];d=A[a>>3]+d;A[a>>3]=d;vy(b+8|0);if(Jb(b+8|0,b)){continue}break}}jb=b+16|0}function H8(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+(b<<3);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(927,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+8|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function dy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,896)+a|0;v[c+1075680>>2]=0;d=c+1074992|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075072|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,896)+a|0;v[c+1075672>>2]=0;c=v[c+1075072>>2]}d=B(b,896)+a|0;v[d+1075072>>2]=c|2097152;xl(a,b,255,0);if(!(w[d+1075073|0]&2)){break a}a=a+1304392|0;if(!sd(a)){break a}yi(v[a>>2],b,0)}}function wP(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|(w[a+65|0]!=1?w[a+65|0]!=16:0))){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=jb-16|0;jb=c;d=mB(b,a);jb=c+16|0;a=d?a:b;return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function eH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=1?b<0:1){d=ba(8)|0;v[114578]=0;c=Q(85,c|0,40635)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(d,c);v[114578]=0;U(2010,d|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=yk(b*256);v[v[a+32>>2]+1074444>>2]=d;jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);f=a,g=Db(w[b+1|0])|Db(w[b+2|0])<<8,u[f>>1]=g;Db(w[b+3|0]);f=a,g=Db(w[b+4|0])|Db(w[b+5|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,6)|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;Db(w[b+5|0]);f=a,g=Db(w[b+4|0])|Db(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,6)|0}function ek(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=jb-32|0;jb=c;f=qc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Hc(c+8|0,c);jb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}jb=e+16|0;return a}function _S(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=89478485;v[114578]=0;v[b+8>>2]=2147483647;e=Q(33,b+12|0,b+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=Ml(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function ZJ(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=jb-16|0;jb=c;e=0;a:{if(!Gf(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Fi(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}ol(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;Lo(a,c+8|0);f=z[c+8>>2];g=Pb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Gf(v[v[a>>2]-12>>2]+a|0)}d=e;jb=c+16|0;return d}function YJ(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=jb-16|0;jb=c;e=0;a:{if(!Gf(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;xf(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}ol(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;Lo(a,c+8|0);f=z[c+8>>2];g=Pb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Gf(v[v[a>>2]-12>>2]+a|0)}a=e;jb=c+16|0;return a}function ll(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+50656|0]}if((a|0)<=511){return t[(a>>>5|0)+50656|0]+5|0}return t[(a>>>10|0)+50656|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+50656|0]+15|0}return t[(a>>>20|0)+50656|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+50656|0]+25|0}a=t[(a>>>30|0)+50656|0]+30|0}else{a=0}return a}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=jb-16|0;jb=e;c=e;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(b,20);a:{if(v[c+4>>2]!=v[c+8>>2]){while(1){b=zb(a);d=v[c+4>>2];v[114578]=0;R(881,b|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c+4>>2]+20|0;v[c+4>>2]=b;if((b|0)!=v[c+8>>2]){continue}break}}Mb(c);jb=e+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[c+12>>2]=477218588;v[114578]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){ed();L()}c=b;if(c>>>0>=477218589){Fc(17388);L()}c=sc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=zb(a),g=c+B(b,9)|0,v[f>>2]=g}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);Db(w[b+2|0]);Db(w[b+3|0]);Db(w[b+4|0]);Db(w[b+5|0]);f=a,g=Db(w[b+6|0])|Db(w[b+7|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+7|0]);Db(w[b+6|0]);Db(w[b+5|0]);Db(w[b+4|0]);Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function jH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-32>>>0>=481){a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40579)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function ar(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function HE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=v[hc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Pq((f|0)==2490?0:v[a>>2],d);if(g){if((f|0)!=2490){Nd(a)}v[e+4>>2]=2428;f=Rd(e+8|0,g,e+4|0);DE(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);jb=e+16|0;return}xv();L()}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-32|0;jb=b;a:{a=ns(a,Kl(b+24|0,Db(c),d),0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b+8|0,38633)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}jb=b+32|0;return a|0}L()}function cI(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=$e(e);if((f|0)==(Fb(c)|0)){v[114578]=0;c=ea(346,c|0,0,-1,e|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Ab();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}jb=d+16|0;return a}function ox(a,b,c){var d=0,e=0,f=0;f=jb-16|0;jb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{if(v[d+4>>2]!=v[d+8>>2]){while(1){b=zb(a);e=v[d+4>>2];v[114578]=0;U(1583,b|0,e|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d+4>>2]+52|0;v[d+4>>2]=b;if((b|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=f+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function bp(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+830|0]=w[b+830|0]&15|c<<4;break a}c=w[b+830|0]>>>4|0;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function b_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=v[hc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Pq((f|0)==2490?0:v[a>>2],d);if(g){if((f|0)!=2490){Nd(a)}v[e+4>>2]=2428;f=Rd(e+8|0,g,e+4|0);DE(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];jb=e+16|0;return}xv();L()}function Y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);v[a+4272>>2]=1065353216;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[a>>2]=81644;v[114578]=0;W(1641,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1642,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function kH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-1>>>0>=65535){a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40560)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2010,a|0,83440,2018);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074416>>2]=b;jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function zG(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function n6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34831,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function ym(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;Bc(d+8|0,b);v[114578]=0;b=T(2458,d+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;e=T(2468,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}v[c>>2]=e;v[114578]=0;R(2469,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(d+8|0);jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);S(a|0);L()}function fN(a){var b=0,c=0,d=0,e=0;a:{if(v[a>>2]){e=v[a>>2];b=a;c=v[a+4>>2];b:{while(1){if((c|0)==(e|0)){break b}d=zb(b);v[114578]=0;c=c-16|0;R(1232,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}break a}v[b+4>>2]=e;zb(a);b=v[a>>2];a=Yh(a);v[114578]=0;U(25,b|0,a<<4,8);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function uy(a){var b=0,c=0,d=0,e=0;a:{if(v[a>>2]){e=v[a>>2];b=a;c=v[a+4>>2];b:{while(1){if((c|0)==(e|0)){break b}d=zb(b);v[114578]=0;c=c-8|0;R(1229,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}break a}v[b+4>>2]=e;zb(a);b=v[a>>2];a=Vi(a);v[114578]=0;U(25,b|0,a<<3,8);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function hL(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,896)+a|0;d=w[c+1075797|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075799|0];if((c|0)>=0){aM(a,b,(d|0)==32,((w[(B(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0,c&255);return}aM(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function Is(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=d+8|0;b=jb-16|0;jb=b;v[114578]=0;c=a;T(1253,c+4|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)!=1){v[114578]=0;v[b+12>>2]=0;W(1254,c+8|0,b+12|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}break b}break b}g=c,h=hc(c),v[g>>2]=h;jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=d+16|0;return a}function Am(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;Bc(d+8|0,b);v[114578]=0;b=T(2424,d+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;e=T(2439,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}t[c|0]=e;v[114578]=0;R(2440,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(d+8|0);jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);S(a|0);L()}function pr(a,b,c,d){var e=0,f=0;e=jb-160|0;jb=e;lc(e+8|0,58064,144);a:{b:{if(b-1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=qG(e+8|0,c,d,2304,2305);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[114552]=61;a=-1}jb=e+160|0;return a}function ci(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(gj(a,f+8|0)){break b}g=4;h=bk(a);if(!Kg(d,2048,h)){break b}b=wm(d,h);while(1){c:{hl(a);b=b-48|0;if(!to(a,f+8|0)|(e|0)<2){break c}g=bk(a);if(!Kg(d,2048,g)){break a}e=e-1|0;b=wm(d,g)+B(b,10)|0;continue}break}g=2;if(!gj(a,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function bi(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(_j(a,f+8|0)){break b}g=4;h=fl(a);if(!$j(d,2048,h)){break b}b=vm(d,h);while(1){c:{Cm(a);b=b-48|0;if(!kr(a,f+8|0)|(e|0)<2){break c}g=fl(a);if(!$j(d,2048,g)){break a}e=e-1|0;b=vm(d,g)+B(b,10)|0;continue}break}g=2;if(!_j(a,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Mp(a);e=d,f=bc(b),v[e+8>>2]=f;e=d,f=cc(b),v[e>>2]=f;a:{if(Jb(d+8|0,d)){while(1){b=v[d+8>>2];if((Gj(b)|0)==(c|0)){b=zb(b);v[114578]=0;R(601,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}}Gk(d+8|0);if(Jb(d+8|0,d)){continue}break}}jb=d+16|0;return}b=P()|0;O()|0;gd(a);S(b|0);L()}function R6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=81848;v[114578]=0;W(1641,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1642,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function X0(a){a=a|0;a:{v[114578]=0;T(2318,460568)|0;a=v[114578];v[114578]=0;b:{if((a|0)==1){break b}v[114578]=0;T(2319,460652)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}v[114578]=0;T(2318,460904)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}v[114578]=0;T(2319,460988)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Ab();L()}}function TA(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=Hma(w[a+3|0],0,18,0);d=d+c|0;b=mb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}mb=a;return b}function tx(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=39;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=39;t[b|0]=w[d|0]}t[c|0]=0}}function X3(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;a=gh(a);v[114578]=0;R(2157,b+16|0,0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=bc(b+16|0);d=cc(b+16|0);e=v[Oc(b+8|0,a)>>2];v[114578]=0;W(2158,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}Cx(b+16|0);jb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;Cx(b+16|0)}kd(a);S(c|0);L()}function UP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=nb[a|0](b)|0;d=mb;f=d;if((d|0)<0){break b}if((nb[c|0](b,0,0,0)|0)<=-1){break a}if((nb[c|0](b,0,0,2)|0)<=-1){break a}d=nb[a|0](b)|0;a=mb;nb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=bR(d,a)}return g}nb[c|0](b,e,f,0)|0;return 0}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Db(w[b+1|0])+g|0)+(Db(w[b|0])<<8)|0;u[a>>1]=g;d=(Db(w[b+3|0])+d|0)+(Db(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<2}function jU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;c=-1;a:{if(!Df(a,7)){break a}c=0;if(!VA(a,12168)){break a}d=jb-16|0;jb=d;c=e;HA(d+8|0,e);f=a;g=Hb(d+8|0);h=ld(a,ac(d,d+8|0));if((g|0)==(h|0)){Xc(f,Hb(d+8|0))}jb=d+16|0;f=(g|0)==(h|0);if(!f){IA(c)}c=-1;if(!f){break a}c=0;if(!UA(e)){break a}c=df(a,b,TA(e),mb)}jb=e+16|0;return c|0}function eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=b;e=d,f=lz(a,b,c),v[e+24>>2]=f;a:{if(!Jb(d+24|0,d+16|0)){break a}v[d+8>>2]=v[d+24>>2];if(!Jb(te(d+8|0),d+16|0)){break a}while(1){if(x[v[d+8>>2]>>1]!=x[c>>1]){u[v[d+24>>2]>>1]=x[v[d+8>>2]>>1];te(d+24|0)}if(Jb(te(d+8|0),d+16|0)){continue}break}}jb=d+32|0;return v[d+24>>2]}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Db(w[b|0])+g|0)+(Db(w[b+1|0])<<8)|0;u[a>>1]=g;d=(Db(w[b+2|0])+d|0)+(Db(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<2}function $O(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if(w[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function o6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114578]=0;Z(2016,a|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1998;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34803,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Qd(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;hm(b);d=jb-16|0;jb=d;v[d+12>>2]=b;b=e+8|0;Te(b,d+12|0);jb=d+16|0;a:{a=a+16|0;if(Kb(a)>>>0<=c>>>0){v[114578]=0;R(2557,a|0,c+1|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}}if(v[Pb(a,c)>>2]){gm(v[Pb(a,c)>>2])}d=Nd(b);f=Pb(a,c),g=d,v[f>>2]=g;hE(b);jb=e+16|0;return}a=P()|0;O()|0;hE(b);S(a|0);L()}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=d;rz(a,c,d);d=0;e=v[a+16>>2];if(e>>>0>c>>>0){v[f+8>>2]=e-c;d=v[Lb(f+8|0,f+12|0)>>2];e=jb-32|0;jb=e;a=a+4|0;h=e,i=bc(a),v[h+24>>2]=i;g=cf(e+24|0,c);h=e,i=bc(a),v[h+8>>2]=i;h=e,i=cf(e+8|0,c),v[h+16>>2]=i;xj(g,cf(e+16|0,d),b);jb=e+32|0}jb=f+16|0;return d|0}function nX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Fb(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Lb(f+12|0,f)>>2],v[g+4>>2]=h;b=Vm(Tb(a)+b|0,d,v[Lb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}jb=f+16|0;return b|0}qm();L()}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{c=Xl(e,a+8|0,py(b,c));if(v[c>>2]!=v[c+4>>2]){while(1){d=v[a+16>>2];f=v[c>>2];v[114578]=0;U(1250,d|0,f|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[c>>2]+2|0;v[c>>2]=d;b=b+2|0;if((d|0)!=v[c+4>>2]){continue}break}}vc(c);jb=e+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function ZO(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>3999){break a}b=a+140|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;return(w[a|0]|w[a+1|0]<<8)==12800}return 0}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Mj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(xd(a,5)){break a}}f=v[a+28>>2];xB(b,v[e+24>>2]);if(v[e+24>>2]){while(1){GN(f,rc(b,g));g=g+1|0;if(g>>>0<y[e+24>>2]){continue}break}}}a=_i(a,d,c,e+16|0);jb=e+32|0;return a|0}function Ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=nM(b,c);if((e|0)!=-1){f=d,g=Dd(b),v[f+16>>2]=g;f=d,g=cf(d+16|0,e),v[f+24>>2]=g;f=d,g=cf(d+24|0,1),v[f+32>>2]=g;c=Md(d+40|0,d+32|0);f=d,g=sf(b),v[f>>2]=g;e=Md(d+8|0,d);ax(b,v[c>>2],v[e>>2]);break b}if(!Fb(b)){break b}if(tI(b,c)){break b}fd(a);break a}td(a,b)}jb=d+48|0}function g7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=nM(b,c);if((e|0)!=-1){f=d,g=Dd(b),v[f+16>>2]=g;f=d,g=cf(d+16|0,e),v[f+24>>2]=g;f=d,g=cf(d+24|0,1),v[f+32>>2]=g;c=Md(d+40|0,d+32|0);f=d,g=sf(b),v[f>>2]=g;e=Md(d+8|0,d);ax(b,v[c>>2],v[e>>2]);break b}if(!Fb(b)){break b}if(tI(b,c)){break b}Wb(a);break a}td(a,b)}jb=d+48|0}function ap(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+830|0];if(c){t[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function Z8(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((xc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}kJ(a,b)}es(a)}function On(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=b;a:{b:{c:{d:{if(Fe(a)){c=hk(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=w[a+11|0];if((b|0)!=10){break c}}Rl(a,c,1,c,c,0,0);b=e;if(Fe(a)){break b}}c=a;of(a,b+1|0);break a}c=v[a>>2];we(a,e+1|0);b=e}a=b+c|0;he(a,d+15|0);t[d+14|0]=0;he(a+1|0,d+14|0);jb=d+16|0}function Eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b|0])|Db(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(Db(w[b+2|0])|Db(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function Aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b+1|0])|Db(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(Db(w[b+3|0])|Db(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function mv(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function kX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(Fe(a)){c=hk(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=w[a+11|0];if((b|0)!=1){break c}}HD(a,c,1,c,c);b=e;if(Fe(a)){break b}}c=a;of(a,b+1|0);break a}c=v[a>>2];we(a,e+1|0);b=e}a=(b<<2)+c|0;Te(a,d+12|0);v[d+8>>2]=0;Te(a+4|0,d+8|0);jb=d+16|0}function NB(a){var b=0,c=0,d=0,e=0,f=0;a:{if(w[a+110|0]>64|((w[a|0]|w[a+1|0]<<8)!=20042?(w[a|0]|w[a+1|0]<<8)!=26217:0)|(t[a+112|0]<0|w[a+111|0]>128)){break a}while(1){e=0;d=a+c|0;b=t[d+113|0];f=(b|0)>-1;if(!((b&255)>>>0<254?f:1)){break a}b=w[d+241|0];if(!b&f|b>>>0>15|w[d+369|0]>=64){break a}e=1;c=c+1|0;if((c|0)!=128){continue}break}}return e}
function VP(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=Hma(w[a+30|0],0,37,0);c=mb;d=b;b=a+24|0;b=Hma(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=mb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}mb=a;return b}function fR(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=a;f=+(B(a,d)>>>0)*2500;a:{if(!(!c|b)){break a}b:{if(!(!b|!a)){Cc(e+12|0,10);a=w[v[e+12>>2]+15155|0];v[e+12>>2]=a;break b}if(a-1>>>0>9){break b}f=7338401.379310345/+(a>>>0);break a}f=+(a>>>0)*37878.78787878787}g=f;c:{if(f<4294967296&f>=0){a=~~g>>>0;break c}a=0}jb=e+16|0;return a}function YW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb+-64|0;jb=d;e=1;a:{if(kg(a,b,0)){break a}e=0;if(!b){break a}b=ov(b,71736,71784);e=0;if(!b){break a}Rb(d+8|4,0,52);v[d+56>>2]=1;v[d+20>>2]=-1;v[d+16>>2]=a;v[d+8>>2]=b;nb[v[v[b>>2]+28>>2]](b,d+8|0,v[c>>2],1);a=v[d+32>>2];if((a|0)==1){v[c>>2]=v[d+24>>2]}e=(a|0)==1}a=e;jb=d- -64|0;return a|0}function W3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Il(a);e=Il(b);a=jb-32|0;jb=a;v[a+24>>2]=c;a:{b:{if((d|0)!=(e|0)){while(1){b=Ub(a+8|0,v[d>>2]);v[114578]=0;Q(2209,a+24|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}yb(b);d=d+4|0;if((e|0)!=(d|0)){continue}break}c=v[a+24>>2]}jb=a+32|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}return c|0}function $g(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=e;e=0;i=e;f=c;c=0;e=Hma(h,e,f,c);j=mb;g=b;k=Hma(d,0,b,0);b=mb;d=Hma(d,l,f,c);c=b+d|0;b=mb;b=c>>>0<d>>>0?b+1|0:b;f=b;d=b+e|0;b=j;b=d>>>0<f>>>0?b+1|0:b;f=d;e=b;b=Hma(g,m,h,i)+c|0;d=mb;d=b>>>0<c>>>0?d+1|0:d;g=d;d=d+f|0;v[a+8>>2]=d;v[a+12>>2]=d>>>0<g>>>0?e+1|0:e;v[a>>2]=k;v[a+4>>2]=b}function bea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1177,a+8|0,c+12|0,c+8|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+16|0]=0;v[a+12>>2]=b;v[114578]=0;Z(1175,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Rs(a);S(b|0);L()}function _z(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;Cc(f+12|0,256);Cc(f+12|0,65535);h=x[f+12>>1];eg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Fj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0;return 1}function xV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-48|0;jb=e;bo(a);v[a>>2]=77128;g=uh(e+40|0);f=e+24|0;Oc(f,b);Oc(f+4|0,c);Oc(f+8|0,d);v[114578]=0;v[e+16>>2]=v[e+32>>2];b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;W(287,a+12|0,g|0,e+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=e+48|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function rz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(w[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;if(b>>>0<=y[a+16>>2]){break a}b=vz(b,4096);OQ(a,b-v[a+16>>2]|0);d=a,e=(g=a,h=wc(a+4|0,v[a+16>>2]),i=b-v[a+16>>2]|0,f=v[v[a>>2]+48>>2],nb[f](g|0,h|0,i|0)|0)+v[a+16>>2]|0,v[d+16>>2]=e;if(!(nb[v[v[a>>2]+44>>2]](a)|0)){break a}t[a+20|0]=1}}function _h(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function Rl(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;if(-17-b>>>0>=c>>>0){i=Tb(a);a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Uk(v[bd(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=$h(j);if(e){xh(c,i,e)}d=d-(e+f|0)|0;if(d){xh((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){pg(a,i,b)}Ff(a,c);Fg(a,j);jb=h+16|0;return}Hg();L()}function R1(a,b){a=a|0;b=b|0;var c=0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(ve(b,-1)){Om(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Er(b)|0}if(!(w[a+48|0]&16)){if(!ve(Km(b),t[v[a+12>>2]-1|0])){break a}}Om(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Km(b);t[v[a+12>>2]]=c;return b|0}return-1}function rN(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;a:{if(ft(a)>>>0<b>>>0){zb(a);d=ez(c+32|0);v[114578]=0;R(937,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}vj(c+16|0,a);wk(c+8|0,a);v[114578]=0;U(938,d|0,c+16|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}dz(a,d);ke(d)}jb=c+48|0;return}a=P()|0;O()|0;ke(d);S(a|0);L()}function tI(a,b){var c=0,d=0,e=0,f=0,g=0;e=Tb(a);c=Fb(a);a=Tb(b);b=Fb(b);if(!b|!c){a=-1}else{f=a+b|0;b=e;g=c+b|0;d=g;a:{if((b|0)==(d|0)){break a}while(1){c=a;if((c|0)!=(f|0)){while(1){if(nb[26](t[b|0],t[c|0])|0){break a}c=c+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}a=(b|0)==(g|0)?-1:b-e|0}return a}function hy(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e|0]=0;v[a>>2]=w[(b&15)+20832|0];t[a+4|0]=w[e|0];break a}t[e+15|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+15|0]=1;f=f<<1}Eb(e,b+1074312|0,66);if(!(!Cb(e)|!d)){v[e>>2]=0;Ei(a,e,e+15|0);break a}v[e>>2]=f<<4;Ei(a,e,e+15|0)}jb=e+16|0}function Ee(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Fb(a)|(c-b|0)<5){break a}qo(b,c);e=c-4|0;c=Tb(a);f=c+Fb(a)|0;b:{while(1){c:{a=t[c|0];if(b>>>0>=e>>>0){break c}if(!(v[b>>2]!=t[c|0]?(a|0)<1|(a|0)>=127:1)){break b}c=(f-c|0)>1?c+1|0:c;b=b+4|0;continue}break}if((a|0)<1|(a|0)>=127|t[c|0]>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function p3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=QM(a);a:{if(!v[b+4>>2]){break a}c=v[b+4>>2];v[114578]=0;R(2181,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[114578]=0;X(2182,a|0,c|0,e+f|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pC(d);S(a|0);L()}return a|0}function WF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;e=b+16|0;a:{while(1){c=v[a+36>>2];f=nb[v[v[c>>2]+20>>2]](c,v[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=v[b+4>>2]-(b+8|0)|0;if((d|0)!=($i(b+8|0,1,d,v[a+32>>2])|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}c=zr(v[a+32>>2])?-1:0}jb=b+16|0;return c|0}function bf(a){a=a|0;var b=0,c=0;v[a>>2]=79680;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;b=a+44|0;_r(b+36|0);_r(b+24|0);Zr(b+12|0);Zr(b);return a|0}function HD(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;if(1073741807-b>>>0>=c>>>0){g=Tb(a);a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=tm(v[bd(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=sm(h);if(e){gi(c,g,e)}d=d-e|0;if(d){e=e<<2;gi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){lo(g,b)}Ff(a,c);Fg(a,h);jb=f+16|0;return}Hg();L()}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Uh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(1606,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Uh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(413,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=at(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(571,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function Sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(w[a+40|0]){break a}e=v[a+28>>2];if(!e){t[a+40|0]=1;return 0}if(!c){break a}d=nb[e|0](v[a+24>>2],b,c)|0;b:{if(d){while(1){e=d+f|0;g=e>>>0<d>>>0?g+1|0:g;f=e;c=c-d|0;if(!c){break b}b=b+d|0;d=nb[v[a+28>>2]](v[a+24>>2],b,c)|0;if(d){continue}break}}t[a+40|0]=1}d=f}return d|0}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,9);b=v[c+4>>2];if((b|0)!=v[c+8>>2]){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=v[c+4>>2]+9|0;v[c+4>>2]=b;if(v[c+8>>2]!=(b|0)){continue}break}}Mb(c);jb=d+16|0}function EU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Xl(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(383,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function uI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Pe(12);b=v[b>>2];c=v[c>>2];v[114578]=0;c=W(2002,d|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2004,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return}a=P()|0;O()|0;Xb(d);S(a|0);L()}function rB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=qe(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(413,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+4|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function gq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Wh(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(383,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+2|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function WU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Mi(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(368,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+1|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Tz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Qp(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(707,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+6|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Pp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Mi(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(571,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+1|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=hN(a,c+8|0);a:{d=Dg(b);if(!d){break a}v[114578]=0;R(1221,a|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114578]=0;X(1222,a|0,b|0,e|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;uy(f);S(a|0);L()}jb=c+16|0;return a|0}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])|Db(w[b+1|0])<<8,u[f>>1]=g;f=a,g=Db(w[b+2|0])|Db(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function Bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;f=a,g=Db(w[b+3|0])|Db(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function wV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+24>>2]=b;Cq(v[d+24>>2]);v[d+16>>2]=v[c+8>>2];b=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=b;b=jb-16|0;jb=b;c=Sk(b+8|0,v[d+8>>2]);e=v[v[d+12>>2]>>2];f=v[v[d+16>>2]>>2];Kp(a);v[a>>2]=77168;Sk(a+4|0,c);v[a+16>>2]=f;v[a+12>>2]=e;Bb(c);jb=b+16|0;jb=d+32|0;return a|0}function $I(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=(Se(v[a+16>>2])|0)/5|0;b=Ac(b,b>>31);v[a+4272>>2]=b;v[114578]=0;v[c+12>>2]=0;U(1649,a+4256|0,b<<1,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;jb=c+16|0;return}S(b|0);L()}function uB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=nB(a,c+8|0);a:{d=Kb(b);if(!d){break a}v[114578]=0;R(406,a|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114578]=0;X(410,a|0,b|0,e|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ys(f);S(a|0);L()}jb=c+16|0;return a|0}function rP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=pP(a,c+8|0);a:{d=xc(b);if(!d){break a}v[114578]=0;R(563,a|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114578]=0;X(992,a|0,b|0,e|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pq(f);S(a|0);L()}jb=c+16|0;return a|0}function oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Le(b);v[d+12>>2]=0;a:{if(!Fi(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Wg(a,d+11|0)){break b}On(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}jb=d+16|0;return e|0}function UI(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Le(b);t[d+15|0]=0;a:{if(!Wg(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Wg(a,d+14|0)){break b}On(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}jb=d+16|0;return e|0}function QU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=ad(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){VB(a)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=11;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){Vl(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}Vl(a,b)}}function DS(a){a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>=10){break a}return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function mw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((nb[b|0](a,f)|0)>=0){if((nb[b|0](a,e)|0)>-1){break a}}j=f;f=(nb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}kG(g,h);jb=g+240|0}function WV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=Af(d,b);v[114578]=0;U(253,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){v[114578]=0;U(5,a|0,d+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}yb(d+16|0);yb(b);jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+16|0)}yb(b);S(a|0);L()}function Em(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Sr(a+60|0);v[a>>2]=76784;v[d>>2]=76804;v[114578]=0;e=a+8|0;W(175,a|0,76816,e|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){a:{v[a>>2]=76784;v[d>>2]=76804;v[114578]=0;W(176,e|0,b|0,c|8)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;ah(d);S(a|0);L()}function kG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=jb-256|0;jb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;lc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;lc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}jb=e+256|0}function AP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;f=d+8|0;g=b;if(qA(b,d+24|0)){e=bz(d+24|0)}ud(f,g,e);a=pA(a,d+24|0,d+8|0);Bb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}v[114578]=0;Q(340,b|0,c-e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;hf(a);S(b|0);L()}jb=d+32|0}function lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=RO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1238,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=Dd(b),v[g+8>>2]=h;b:{if(!Fb(b)){break b}if(w[kc(b,0)|0]!=43){if(w[kc(b,0)|0]!=45){break b}}lw(d+8|0);c=c+1|0}if(Fb(b)>>>0>=c>>>0){break a}e=Md(d,d+8|0);f=Fb(b);nw(b,v[e>>2],c-f|0,48)}td(a,b);jb=d+16|0}function PS(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=RO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1025,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function CK(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=mm(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1231,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+16|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=mD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(420,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=yq(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1228,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+8|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function sW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=mD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(216,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Uh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1623,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function qja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Uh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(822,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(829,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=qe(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1057,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Uh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(741,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Uh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(949,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Uh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1654,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function us(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;if(b){Eb(e+8|0,a+1074312|0,73);k=Cb(e+8|0)?c- -64|0:c;i=Zo(a);l=i^1;c=120;f=1;while(1){g=c>>>1|0;j=g+f|0;h=ag(a,j,k,d);a:{if(!((h|0)!=0&l|b>>>0<=h>>>0?(h>>>0<=b>>>0|i)==1:0)){f=j+1|0;c=(g^-1)+c|0;break a}c=g}if(c){continue}break}}jb=e+16|0;return f}function pU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(422,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function pB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=mm(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(420,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+16|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function oW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=at(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(218,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function lU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(427,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function XU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=at(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(367,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function W9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Qp(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1581,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+6|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function SW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(kg(a,v[b+8>>2],e)){lv(b,c,d);return}a:{if(!kg(a,v[b>>2],e)){break a}if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function Ria(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=qe(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(879,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Qp(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(569,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+6|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=at(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(38,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function NU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Uh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(373,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=C(0);c=jb-32|0;jb=c;Nj(a,c+24|0);f=c,g=hd(v[c+24>>2],v[c+28>>2]),v[f+16>>2]=g;v[c+12>>2]=256;ol(b,v[Lb(c+16|0,c+12|0)>>2]);if(Kb(b)){while(1){v[c+16>>2]=0;Lo(a,c+16|0);e=z[c+16>>2];f=Pb(b,d),h=e,z[f>>2]=h;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=c+32|0}function eB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Wh(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(422,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+2|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function dC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Mi(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(367,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function aN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;a:{if(oc(hp(a))>>>0<=b>>>0){break a}b:{c:{if(yc(a)>>>0>b>>>0){if(y[qd(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}ry(a,b,c,1);break b}ee(e+8|0,qd(a,b),c);f=Cb(e+8|0);if(f|!d){break a}ee(e+8|0,qd(a,b),c);ge(e+8|0,1);bN(a,b,c)}f=0}jb=e+16|0;return f|0}function _7(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=Se(v[a+16>>2]);b=Ac(Ima(Hma(b,b>>31,3840,0),mb,1e3,0),mb);v[a+4276>>2]=b;v[114578]=0;v[c+12>>2]=0;U(1649,a+4260|0,b|0,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4276>>2]=0;$()}jb=c+16|0;return}S(b|0);L()}function Px(a,b){var c=0,d=0,e=0;WQ(a);El(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[zb(b)>>2];d=zb(a),e=c,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function OV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=yq(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(270,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+8|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function MP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=qe(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(949,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function kS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Mi(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(38,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function _c(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=gF(b);e=jb-16|0;jb=e;c=Uq(a);a:{if(c>>>0>=b>>>0){f=Tb(a);g=f;c=b;b:{c:{if(b){v[114578]=0;MD(g,d,c);d=v[114578];v[114578]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Ab();L()}v[e+12>>2]=0;Te((b<<2)+f|0,e+12|0);Sg(a,b);break a}f=a;a=Fb(a);ID(f,c,b-c|0,a,0,a,b,d)}jb=e+16|0}function PB(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Xf(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=c+16|0;return d}function m6(a){a=a|0;var b=0;v[114578]=0;Z(2016,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,34861,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function MK(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+28|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=0}return c}function DI(a){var b=0;v[a+4116>>2]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;CI(a+4164|0);CI(a+4156|0);Wo(a+54060|0);Wo(a+62252|0);Wo(a+70444|0);Wo(a+78636|0);Rb(a+4332|0,0,32768);Oy(a+37100|0);Rb(a+37612|0,0,16384)}function T4(a){a=a|0;var b=0;v[114578]=0;Z(2089,a|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1990,37320,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=0;d=a;W(1199,a|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+530|0]=0;v[114578]=0;R(1198,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;wf(d);S(a|0);L()}function sn(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];f=v[d>>2];if(e|f){if(!b){break a}while(1){v[c>>2]=e-(((-2147483648-e>>>31|0)-1&255)+e>>8);v[d>>2]=v[d>>2]-(((-2147483648-f>>>31|0)-1&255)+f>>8);e=g<<3;v[e+a>>2]=v[c>>2];v[(e|4)+a>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=v[d>>2];e=v[c>>2];continue}}uO(a,b<<1)}}function WL(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Ik(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(1385,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+24|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Cy(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=$n(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(1178,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+32|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function jx(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=qe(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(1606,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+4|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;_s(a+8|0);jb=c+16|0;c=a;a:{if(!b){break a}v[114578]=0;R(1017,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(1018,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Sy(c);S(a|0);L()}return a|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);f=a,g=Db(w[b+2|0])|Db(w[b+3|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function bs(a){var b=0,c=0,d=0,e=0;b=Vg(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=vo(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Vg(c+d)*.5}A[e+4248>>3]=b}as(a)}function QN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:GN(a,b);return;default:break a}}d=jb-16|0;jb=d;v[d+12>>2]=c;u[d+10>>1]=0;v[d+4>>2]=2;Wk(a,d+10|0,v[Lb(d+12|0,d+4|0)>>2]);a=mb;if((a|0)>0?1:(a|0)>=0){v[d+4>>2]=2;Lb(d+12|0,d+4|0)}u[d+4>>1]=x[d+10>>1];u[b>>1]=w[d+4|0]|w[d+5|0]<<8;jb=d+16|0}function v6(){var a=0,b=0;v[114578]=0;a=da(2005)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1990,34568,0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function K6(){var a=0,b=0;v[114578]=0;a=da(1989)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1990,34128,0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function I6(){var a=0,b=0;v[114578]=0;a=da(1993)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1990,34156,0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function gma(a,b){a=a|0;b=b|0;var c=0;lt(a,b);wj(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function eia(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Df(a,8)){break a}c=0;if(!Zt(a,16628,8)){break a}c=-1;if(!Jj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=!((w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))&-2139062144)}a=c;jb=b+16|0;return a|0}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;_Q(c+8|0,f);g=Hb(c+8|0);d=a;h=ld(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){$Q(f)}d=-1;a:{if(!c){break a}d=0;if(!nR(e+8|0)){break a}d=df(a,b,mR(e+8|0),mb)}jb=e- -64|0;return d|0}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-112|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;GS(c+8|0,f);g=Hb(c+8|0);d=a;h=ld(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){HS(f)}d=-1;a:{if(!c){break a}d=0;if(!KS(e+8|0)){break a}d=df(a,b,JS(e+8|0),mb)}jb=e+112|0;return d|0}function JJ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[114578]=0;v[c+12>>2]=0;U(1649,a+4208|0,b<<1,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;jb=c+16|0;return}S(b|0);L()}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=jb-96|0;jb=d;qK(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=v[d+e>>2];e=v[(e|4)+d>>2];v[f>>2]=g;v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;jb=d+96|0;v[a+112>>2]=0;return a|0}function H$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=aF(a,d+8|0);e=Fb(b);f=Fb(c);b=Tb(b);v[114578]=0;X(195,a|0,b|0,e|0,e+f|0);b=v[114578];v[114578]=0;a:{if((b|0)!=1){b=Tb(c);v[114578]=0;W(196,a|0,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+16|0}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Qm(c,a);a=b;if(v[a>>2]){Id(a);yH(a);up(a);Xo(zb(a),v[a>>2],We(a));d=zb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}El(b,c);v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=v[zb(c)>>2];d=zb(b),e=a,v[d>>2]=e;d=zb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0;rf(c);jb=c+16|0}function HU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-512|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;HB(c+8|0,f);g=Hb(c+8|0);d=a;h=ld(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){IB(f)}d=-1;a:{if(!c){break a}d=0;if(!NB(e+8|0)){break a}d=df(a,b,MB(e+8|0),mb)}jb=e+512|0;return d|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);f=a,g=Db(w[b+1|0])|Db(w[b+2|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,3)|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,3)|0}function DU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;kB(c+8|0,f);g=Hb(c+8|0);d=a;h=ld(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){lB(f)}d=-1;a:{if(!c){break a}d=0;if(!EB(e+8|0)){break a}d=df(a,b,DB(e+8|0),mb)}jb=e+48|0;return d|0}function o_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=v[16163];v[g+24>>2]=v[16162];v[g+28>>2]=h;h=v[16161];v[g+16>>2]=v[16160];v[g+20>>2]=h;h=v[16159];v[g+8>>2]=v[16158];v[g+12>>2]=h;h=v[16157];v[g>>2]=v[16156];v[g+4>>2]=h;a=cj(a,b,c,d,e,f,g,g+32|0);jb=g+32|0;return a|0}function uY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[e>>2]=c;a=Av(f+12|0,0,b,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a-1|0;c=1;if(b>>>0>d-v[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=w[c|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;b=b-1|0;c=c+1|0;continue}break}c=0}jb=f+16|0;return c|0}function og(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);qf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;jb=d+16|0}function mL(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Pi(b,c);a:{if(e>>>0<=yf(a)>>>0){v[d+12>>2]=c;if(xc(a)>>>0<e>>>0){v[d+12>>2]=b;f=d,g=xc(a)+v[d+12>>2]|0,v[f+12>>2]=g;gf(b,v[d+12>>2],v[a>>2]);Yy(a,v[d+12>>2],c,e-xc(a)|0);break a}aS(a,gf(b,c,v[a>>2]));break a}MM(a);Ip(a,Ki(a,e));Yy(a,b,c,e)}jb=d+16|0}function PT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-1968|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;wA(c+8|0,f);g=Hb(c+8|0);d=a;h=ld(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){xA(f)}d=-1;a:{if(!c){break a}d=0;if(!BA(e+8|0)){break a}d=df(a,b,1024,0)}jb=e+1968|0;return d|0}function sca(a,b){a=a|0;b=b|0;var c=0,d=0;c=Pe(2500);v[114578]=0;d=W(92,c|0,b|0,0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=d;W(97,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return}a=P()|0;O()|0;Xb(c);S(a|0);L()}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])^128,t[f|0]=g;f=a,g=Db(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=Db(w[b|0])+g|0;t[a|0]=g;d=Db(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;Ok(c+16|0,c+40|0);b=Db(v[c+16>>2]);Ok(c+8|0,c+40|0);b=qi(c+24|0,b,Db(v[c+8>>2]+2|0));v[114578]=0;Q(1193,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function GD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=zw(a,d+8|0);e=$e(b);f=Fb(c);v[114578]=0;X(2837,a|0,b|0,e|0,e+f|0);b=v[114578];v[114578]=0;a:{if((b|0)!=1){b=Tb(c);v[114578]=0;W(2500,a|0,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+16|0}function q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=pi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=81236;v[114578]=0;W(1641,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1642,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function OQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;c=a+4|0;a:{if(xc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!xc(c)){Dk(c,vz(v[a+16>>2]+b|0,65536));break a}f=d,g=xc(c),v[f+12>>2]=g;e=MQ(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Dk(c,vz(a,65536));break a}f=d,g=xc(c),v[f+8>>2]=g;Dk(c,MQ(d+8|0))}jb=d+16|0}function iM(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+872|0]=w[b+872|0]|8;g=b;d=a?w[b+833|0]:0;h=(c|0)>-1?0-d|0:d;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+876>>2]=h+(d+v[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+833|0]=a^a+c}function eS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:yh(a,b);return;default:break a}}d=jb-32|0;jb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+20>>2]=1;Wk(a,d+27|0,v[Lb(d+28|0,d+20|0)>>2]);a=mb;if((a|0)>0?1:(a|0)>=0){v[d+16>>2]=1;Lb(d+28|0,d+16|0)}t[d+8|0]=w[d+27|0];t[b|0]=w[d+8|0];jb=d+32|0}
function Mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;b=-1;a:{if(!Df(a,1084)){break a}xk(a,1080);BQ(a,c+60|0);d=AQ(c+40|0);b=0;if(!zQ(c+60|0,d)){break a}xk(a,20);b=1;while(1){yQ(a,c+8|0);e=qz(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=y[d+4>>2]>=e>>>0}jb=c- -64|0;return b|0}function mz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=bc(a);c=cc(a);a=jb-16|0;jb=a;v[a>>2]=c;v[a+8>>2]=b;if(Jb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}te(a+8|0);if(Jb(a+8|0,a)){continue}break}}jb=a+16|0}jb=d+16|0}function eq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;Cc(f+12|0,256);Cc(f+12|0,65535);h=x[f+12>>1];eg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Fj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0}function RL(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(1383,b+14|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(1384,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){yp(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function PL(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(1388,b+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(1389,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){jt(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function In(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;Cc(f+12|0,128);Cc(f+12|0,65535);h=x[f+12>>1];eg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Fj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0}function hI(a){a=a|0;var b=0,c=0,d=0;b=Pe(1304568);v[114578]=0;c=T(2135,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2139,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return}a=P()|0;O()|0;Xb(b);S(a|0);L()}function eK(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-52|0;v[b+8>>2]=d;v[114578]=0;R(1440,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Mx(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/52|0)}}function VI(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=Pi(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){of(a,e);d=a;break a}g=Uk(e)+1|0;d=$h(g);Ff(a,d);Fg(a,g);we(a,e)}if((b|0)!=(c|0)){while(1){he(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;he(d,f+15|0);jb=f+16|0;return}Hg();L()}function yR(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-33|0;v[b+8>>2]=d;v[114578]=0;R(768,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){wR(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/33|0)}}function tY(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[114578]=0;b=aa(2573,0,0,4,b|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=v[a+8>>2];if(a){break b}a=1}return a|0}v[114578]=0;a=T(2574,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}return(a|0)==1|0}V(0)|0;O()|0;Ab();L()}function sP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-56|0;v[b+8>>2]=d;v[114578]=0;R(989,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){_y(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/56|0)}}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){g=Db(w[b|0])+d|0;d=g+Db(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function YR(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(729,b+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(732,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){sh(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function UJ(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(733,b+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(734,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){sh(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function QQ(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(824,b+14|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(825,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){yp(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function Kt(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-48|0;v[b+8>>2]=d;v[114578]=0;R(573,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){WS(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/48|0)}}function nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-608|0;jb=e;c=jb-16|0;jb=c;d=e;hP(c+8|0,e);g=Hb(c+8|0);f=a;h=ld(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){iP(d)}d=-1;a:{if(!f){break a}d=0;if(!kP(e)){break a}d=df(a,b,jP(e),mb)}jb=e+608|0;return d|0}function kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-576|0;jb=e;c=jb-16|0;jb=c;d=e;uS(c+8|0,e);g=Hb(c+8|0);f=a;h=ld(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){vS(d)}d=-1;a:{if(!f){break a}d=0;if(!zS(e)){break a}d=df(a,b,xS(e),mb)}jb=e+576|0;return d|0}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-192|0;jb=e;c=jb-16|0;jb=c;d=e;Zp(c+8|0,e);g=Hb(c+8|0);f=a;h=ld(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){QR(d)}d=-1;a:{if(!f){break a}d=0;if(!tS(e)){break a}d=df(a,b,sS(e),mb)}jb=e+192|0;return d|0}function _i(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=jb-48|0;jb=c;a:{if(!b){b=1;if(xd(a,5)){break a}b=uD(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;pf(c,v[a+28>>2]);yD(c+16|0,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[c+24>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}jb=c+48|0;return b|0}function ut(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-6|0;v[b+8>>2]=d;v[114578]=0;R(737,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Nt(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/6|0)}}function qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Bi(d+16|0,d+8|0,c);v[114578]=0;R(517,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(518,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function ds(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2048|0;v[b+8>>2]=d;v[114578]=0;R(1653,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){yJ(v[a+16>>2],v[a>>2],v[ec(a)>>2]-v[a>>2]>>11)}}function LD(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;d=Fb(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Tb(a);h=e;f=d;if(d){$l(c+e|0,e,f);b=b>>>0>=e>>>0?d+e>>>0>b>>>0?b+c|0:b:b}$l(h,b,c);b=c+d|0;Sg(a,b);t[g+15|0]=0;he(b+e|0,g+15|0);break a}Qu(a,f,(c+d|0)-f|0,d,0,0,c,b)}jb=g+16|0;return a}function Kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Xz(d+16|0,d+8|0,c);v[114578]=0;R(517,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(518,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Dba(a){a=a|0;var b=0,c=0,d=0;b=v[a+2496>>2];c=(b+1>>>0)%624|0;d=v[(c<<2)+a>>2];b=B(d&1,-1727483681)^(v[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|v[(b<<2)+a>>2]&-2147483648)>>>1);v[(v[a+2496>>2]<<2)+a>>2]=b;v[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function zm(a,b){var c=0,d=0;c=jb-16|0;jb=c;Bc(c+8|0,a);v[114578]=0;a=T(2457,c+8|0)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)==1){break b}v[114578]=0;aa(2471,a|0,64400,64426,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}Ob(c+8|0);jb=c+16|0;break a}a=P()|0;O()|0;Ob(c+8|0);S(a|0);L()}return b}function dh(a){var b=0,c=0,d=0;c=Sr(a+56|0);v[a>>2]=76600;v[c>>2]=76620;v[114578]=0;b=a+4|0;W(126,a|0,76632,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){a:{v[a>>2]=76600;v[c>>2]=76620;v[114578]=0;Q(127,b|0,16)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}return a}}a=P()|0;O()|0;ah(c);S(a|0);L()}function Uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=gn(w[b|0]),t[f|0]=g;f=a,g=gn(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function JC(a){a=a|0;var b=0,c=0;b=fd(a);v[114578]=0;T(277,a+12|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(278,a+28|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-80|0;jb=e;c=jb-16|0;jb=c;d=e;LR(c+8|0,e);g=Hb(c+8|0);f=a;h=ld(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){MR(d)}d=-1;a:{if(!f){break a}d=0;if(!LO(e)){break a}d=df(a,b,KO(e),mb)}jb=e+80|0;return d|0}function zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-128|0;jb=e;c=jb-16|0;jb=c;d=e;aQ(c+8|0,e);g=Hb(c+8|0);f=a;h=ld(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){bQ(d)}d=-1;a:{if(!f){break a}d=0;if(!gQ(e)){break a}d=df(a,b,256,0)}jb=e+128|0;return d|0}function YI(a,b,c){var d=0,e=0,f=0,g=0;g=(b|0)<1;if(C(D(a))<C(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!(g|(e|0)<0)){while(1){d=b-1|0;e=e<<1;if((b|0)<2){break a}b=d;if((e|0)>-1){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function Ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Bi(d+16|0,d+8|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function $P(a){var b=0,c=0,d=0,e=0,f=0;b=v[a>>2];a:{if(!b){break a}d=v[a+8>>2];if(!d){break a}e=v[a+12>>2];if(!e){break a}f=nb[e|0](b)|0;a=mb;if((a|0)<0){break a}c=0;b:{if((nb[d|0](b,0,0,0)|0)<0){break b}c=0;if((nb[d|0](b,0,0,2)|0)<0){break b}nb[e|0](b)|0;c=(mb|0)>-1}nb[d|0](b,f,a,0)|0}return c}function zU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;hu(d+16|0,d+8|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function yM(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}Ys(b,e,a);Eb(f+8|0,a+1074312|0,10);if(!Cb(f+8|0)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}jb=f+16|0}function wl(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=tM(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return sM(a,b,d)}e=sM(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=tM(a,b,d)}return e}function je(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function YV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;km(d+16|0,d+8|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Y2(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;a:{b:{if(mi(a)){Fo(b+24|0);break b}Qm(b+8|0,a);v[114578]=0;R(2176,b+24|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}rf(b+8|0)}if(mi(a)){a=a+36|0}else{a=v[b+24>>2]}a=Id(a);gk(b+24|0);jb=b+32|0;return a|0}a=P()|0;O()|0;rf(b+8|0);S(a|0);L()}function ry(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=hp(a);a:{if(oc(f)>>>0<=b>>>0){break a}if(sy(a,x[rc(f,b)>>1])>>>0<=c>>>0){break a}b:{if(yc(a)>>>0>b>>>0){if(y[qd(a,b)+4>>2]>c>>>0){break b}}qj(a,0);if(yc(a)>>>0<=b>>>0){break a}}ee(e+8|0,qd(a,b),c);ge(e+8|0,d);if(!d){break a}bN(a,b,c)}jb=e+16|0}function TI(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[114578]=0;v[c+12>>2]=0;U(1649,a+4208|0,b<<2,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;jb=c+16|0;return}S(b|0);L()}function OB(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Xf(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}jb=c+16|0;return d}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;dm(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;IN(h,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Aq(a,xe(a))}function KB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;Cc(d+12|0,128);Cc(d+12|0,65535);f=x[d+12>>1];eg(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}jb=d+16|0}function Jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Oh(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-24|0;qR(h,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Tt(a,Id(a))}function wE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;bj(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Dv(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,yc(a))}function o7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=Pi(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Fb(a);Rl(a,g,h,d,0,d,0)}d=Tb(a);if((b|0)!=(c|0)){while(1){he(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;he(d,e+15|0);Sg(a,f);jb=e+16|0;return a|0}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Vk(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-16|0;AH(h,e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];lm(a,nd(a))}function cka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=a;if(!w[b+8|0]){if(w[b+24|0]){t[b+24|0]=0;d=b+40|0;while(1){e=Ii(d,c),f=0,t[e+8|0]=f;c=c+1|0;if((c|0)!=16){continue}break}c=b+28|0;Dk(c,0);dS(c)}c=b+12|0;Dk(c,v[b+4>>2]);nb[v[v[b>>2]+44>>2]](b,v[c>>2],0,v[b+4>>2])|0;t[b+8|0]=1}return v[a+12>>2]}function XP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-8|0;v[b+8>>2]=d;v[114578]=0;R(924,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Lu(v[a+16>>2],v[a>>2],v[ec(a)>>2]-v[a>>2]>>3)}}function Tp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Oh(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-24|0;Up(h,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Tt(a,Id(a))}function DV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;dm(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;EC(h,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Aq(a,xe(a))}function BO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Fb(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=Vm(Tb(a),v[c+8>>2],v[Lb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}jb=c+16|0;return a|0}function uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;cQ(d+16|0,c);v[114578]=0;R(517,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(518,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b|0])|Db(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b+1|0])|Db(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function iT(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;a:{if(!Jb(d+24|0,d+16|0)){break a}while(1){a=v[d+24>>2];if(v[v[d+8>>2]>>2]==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}Gk(d+24|0);if(Jb(d+24|0,d+16|0)){continue}break}}jb=d+32|0;return v[d+24>>2]}function HQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!w[a+20|0]){if(!(nb[v[v[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){OQ(a,65536);c=a,d=(f=a,g=wc(b,v[a+16>>2]),h=65536,e=v[v[a>>2]+48>>2],nb[e](f|0,g|0,h|0)|0)+v[a+16>>2]|0,v[c+16>>2]=d;if(!(nb[v[v[a>>2]+44>>2]](a)|0)){continue}break}}t[a+20|0]=1}}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;vf(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-4|0;QJ(h,e-4|0,c);e=v[d>>2]-4|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mk(a,Kb(a))}function fG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=or(a);v[a+32>>2]=b;v[a>>2]=55956;rr(d+8|0,e);v[114578]=0;b=T(2316,d+8|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Ob(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Fm(b),t[g+44|0]=h;jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);il(e);S(a|0);L()}function eG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=NF(a);v[a+32>>2]=b;v[a>>2]=56060;rr(d+8|0,e);v[114578]=0;b=T(2317,d+8|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Ob(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Fm(b),t[g+44|0]=h;jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);uo(e);S(a|0);L()}function cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;NA(d+16|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Db(w[b|0])+d|0)+(Db(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Db(w[b+1|0])+d|0)+(Db(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function xK(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a-12|0;d:{if(c>>>0>28){break d}a=1;d=1<<c;if(d&270014517){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)-96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4)&1}function oV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=0;if(y[a+16>>2]>c>>>0){d=v[a+4>>2];f=v[a+12>>2];v[e+8>>2]=v[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=v[Lb(e+12|0,e+8|0)>>2],g=v[v[d>>2]+28>>2],nb[g](h|0,i|0,j|0,k|0)|0)}jb=e+16|0;return d|0}function RM(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){a=v[a>>2];v[114578]=0;c=T(1257,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(1258,a|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}}if(b){ny(b)}break a}V(0)|0;O()|0;Ab();L()}}}function Bm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);qf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;jb=c+16|0}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Vk(a);zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-16|0;cm(e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];lm(a,nd(a))}function kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;bj(a);zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Xy(e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,yc(a))}function dV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!sC(a,c+8|0)){break a}d=0;if(!nC(c+8|0)){break a}if(b){a=c+12|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(!v[b+4>>2]&y[b>>2]<(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))-8>>>0){break a}}d=1}jb=c+48|0;return d|0}function Sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[qh(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[qh(d+13|0,d+12|0)|0]}jb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{if(v[b>>2]){if(!Wc(c)){cv(c,58368)}e=v[b+4>>2];nb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[114578]=0;Q(1251,c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}yb(d)}td(a,c);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function l4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-48|0;jb=d;v[d+44>>2]=b;jj(d+8|0,0,c);b=d+24|0;v[b>>2]=v[d+44>>2];td(b+4|0,d+8|0);v[114578]=0;R(2127,a+4|0,d+24|0);a=v[114578];v[114578]=0;if((a|0)!=1){xt(d+24|0);yb(d+8|0);jb=d+48|0;return}a=P()|0;O()|0;xt(d+24|0);yb(d+8|0);S(a|0);L()}function i_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=jb-128|0;jb=c;v[c+12>>2]=c+116;ME(a+8|0,c+16|0,c+12|0,e,f,g);d=c+16|0;e=v[c+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((d|0)!=(e|0)){xF(a+8|0,t[d|0]);d=d+1|0;continue}break}jb=a+16|0;jb=c+128|0;return v[a+8>>2]}function uE(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;b=qe(d,a,b);c=v[b+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}_k(a);c=v[b+4>>2];v[114578]=0;_s(c);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[b+4>>2]+4|0;v[b+4>>2]=c;continue}break}a=P()|0;O()|0;Mb(b);S(a|0);L()}Mb(b);jb=d+16|0}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])|Db(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function ZE(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=ot(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){of(a,e);d=a;break a}g=tm(e)+1|0;d=sm(g);Ff(a,d);Fg(a,g);we(a,e)}while(1){if((b|0)!=(c|0)){Te(d,b);d=d+4|0;b=b+4|0;continue}break}v[f+12>>2]=0;Te(d,f+12|0);jb=f+16|0;return}Hg();L()}function $e(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function sS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function UT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Qb(a,120);a:{if(e){c=jb-16|0;jb=c;gc(d+8|0,b,120);jb=c+16|0;Bd(a,d+8|0);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+120|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function vU(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+16>>2]=b;v[c+24>>2]=a;a:{if(!Jb(c+24|0,c+16|0)){break a}v[c>>2]=v[c+24>>2];if(!Jb(te(c),c+16|0)){break a}while(1){if(mB(v[c+24>>2],v[c>>2])){v[c+24>>2]=v[c>>2]}if(Jb(te(c),c+16|0)){continue}break}}jb=c+32|0;return v[c+24>>2]}function Hy(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1167,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=255;return a}function Hr(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;v[b+12>>2]=12;v[b+8>>2]=32;a:{if(!v[Lb(b+12|0,b+8|0)>>2]){break a}d=15;while(1){e=_o(a);v[b+8>>2]=32;c=c^e;if(y[Lb(b+12|0,b+8|0)>>2]<=d>>>0){break a}c=c<<15;d=d+15|0;continue}}jb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function ur(a,b){var c=0,d=0;c=-1;a:{if((a|0)==-1){break a}d=v[b+76>>2]>=0;b:{c:{c=v[b+4>>2];d:{if(!c){gG(b);c=v[b+4>>2];if(!c){break d}}if(v[b+44>>2]-8>>>0<c>>>0){break c}}c=-1;if(d){break b}break a}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a;if(!d){break a}}}return c}function g8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[a+4>>2]=b;v[a>>2]=0;b=Qs(a+8|0,e);v[114578]=0;Q(1761,a+20|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&240|c|8;return a|0}a=P()|0;O()|0;Ib(b);S(a|0);L()}function aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(!v[a+300>>2]){return 0}if(!(!d|(nb[v[a+304>>2]](v[a+296>>2],c,0,0)|0)<0)){while(1){a:{c=nb[v[a+300>>2]](v[a+296>>2],b,d)|0;e=c+e|0;f=c>>>0>e>>>0?f+1|0:f;if(!c){break a}b=b+c|0;d=d-c|0;if(d){continue}}break}}return e|0}function Ud(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function zH(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-16|0;v[b+8>>2]=d;v[114578]=0;R(2207,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yi(v[a+16>>2],v[a>>2],ev(a))}}function xH(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(2208,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xo(v[a+16>>2],v[a>>2],Nl(a))}}function sD(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[b>>2]=0;t[c+15|0]=0;e=Wg(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;a:{f=d&3;if(!f){break a}d=1;while(1){t[c+15|0]=0;g=Wg(a,c+15|0);v[b>>2]=v[b>>2]|w[c+15|0]<<(d<<3)-2;e=e&g;if((d|0)==(f|0)){break a}d=d+1|0;continue}}jb=c+16|0}function kh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;g=Mj(a,c);pf(e+8|0,v[a+28>>2]);f=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!xd(a,5)){break b}break a}f=v[g+8>>2]}nb[d|0](v[a+28>>2],b,f)}a=_i(a,g,c,e+24|0);jb=e+32|0;return a|0}function bt(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(1024,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function VM(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(1237,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function SO(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(1023,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function Ps(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-32|0;v[b+8>>2]=d;v[114578]=0;R(1195,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){sh(v[a+16>>2],v[a>>2],Pu(a))}}function DK(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(1562,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],Nl(a))}}function uT(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(528,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],Nl(a))}}function uP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(985,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],Nl(a))}}function pR(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(770,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],Nl(a))}}function pD(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-16|0;v[b+8>>2]=d;v[114578]=0;R(217,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yi(v[a+16>>2],v[a>>2],ev(a))}}function lL(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1442,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function cs(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1655,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function Yr(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1764,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function Xq(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(206,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function VS(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(572,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],Nl(a))}}function TL(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-32|0;v[b+8>>2]=d;v[114578]=0;R(896,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){jt(v[a+16>>2],v[a>>2],Pu(a))}}function S1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;d=Go(f+8|0,d);v[114578]=0;ea(2015,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Yc(d);nH(a);b=mH(a+88|0);v[a>>2]=84152;v[b>>2]=84240;jb=f+16|0;return a|0}a=P()|0;O()|0;Yc(d);S(a|0);L()}function RK(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1526,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function PJ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1441,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function NS(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(604,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],Nl(a))}}function Hm(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=Kma(a,b,10,0);e=mb;f=e;e=Hma(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function Gs(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(350,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function Ft(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-16|0;v[b+8>>2]=d;v[114578]=0;R(428,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Yi(v[a+16>>2],v[a>>2],ev(a))}}function DO(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1060,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){yj(v[a+16>>2],v[a>>2],sg(a))}}function Bq(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-32|0;v[b+8>>2]=d;v[114578]=0;R(276,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){sh(v[a+16>>2],v[a>>2],Pu(a))}}function uq(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(351,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function om(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-1|0;v[b+8>>2]=d;v[114578]=0;R(215,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){pg(v[a+16>>2],v[a>>2],hA(a))}}function nk(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(107,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function e8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Dd(b);e=sf(b);f=Dd(b);c=jb-32|0;jb=c;v[c+16>>2]=e;v[c+24>>2]=d;v[c+8>>2]=f;if(Jb(c+24|0,c+16|0)){while(1){d=nb[117](t[v[c+24>>2]])|0;t[v[c+8>>2]]=d;qg(c+24|0);qg(c+8|0);if(Jb(c+24|0,c+16|0)){continue}break}}jb=c+32|0;td(a,b)}function cC(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(364,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Wn(v[a+16>>2],v[a>>2],Vn(a))}}function _A(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(424,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Pl(v[a+16>>2],v[a>>2],Vn(a))}}function Yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Yb(gn(w[b|0]),-64,63)<<1,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function YQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(819,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){yj(v[a+16>>2],v[a>>2],sg(a))}}function Wm(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(735,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function Vt(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(532,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Pl(v[a+16>>2],v[a>>2],Vn(a))}}function Vh(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(374,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){qu(v[a+16>>2],v[a>>2],sg(a))}}function Rg(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-1|0;v[b+8>>2]=d;v[114578]=0;R(363,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){pg(v[a+16>>2],v[a>>2],hA(a))}}function Rda(a,b){a=a|0;b=b|0;var c=0;c=jb-48|0;jb=c;t[c+40|0]=w[b|0];wq(c+16|0,c+40|0);b=Db(v[c+16>>2]);wq(c+8|0,c+40|0);b=qi(c+24|0,b,Db(v[c+8>>2]+1|0));v[114578]=0;Q(1193,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function RQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(826,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Pl(v[a+16>>2],v[a>>2],Vn(a))}}function NR(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(738,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){yj(v[a+16>>2],v[a>>2],sg(a))}}function GP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(950,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){yj(v[a+16>>2],v[a>>2],sg(a))}}function Ej(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(384,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Wn(v[a+16>>2],v[a>>2],Vn(a))}}function xl(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,896)+a|0)+1075640>>2];if(!f){break a}if(!zi(f)){break a}e=w[f+34|0];if(e-251>>>0<5|!e){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}nb[v[v[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,896)+a|0)+1075846>>1]=65535}}function mU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;if(!Qb(b,c)){c=nf(b)}v[a>>2]=c;d=v[b>>2];if(nb[v[v[d>>2]+16>>2]](d)|0){c=a;a=v[b>>2];e=c,f=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;return}d=a+8|0;Dk(d,v[a>>2]);if(!md(d)){xg(b,wc(d,0),c)}}function hC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;u[(v[a+1064>>2]<<1)+d>>1]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=ue(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function _p(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-1|0;v[b+8>>2]=d;v[114578]=0;R(32,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){pg(v[a+16>>2],v[a>>2],hA(a))}}function zJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-16|0;jb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Tb(d);qi(b,a,Fb(d)+a|0);break c}_J(e,c,d);v[114578]=0;U(115,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Lc(e)}jb=e+16|0;break a}a=P()|0;O()|0;Lc(e);S(a|0);L()}}function w7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=6){ae(d+12|0,C(0));c=z[d+12>>2];a:{if(!((b|0)!=1|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(je(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;cx(a)}jb=d+16|0}function a8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=6){ae(d+12|0,C(0));c=z[d+12>>2];a:{if(!((b|0)!=3|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(je(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;cx(a)}jb=d+16|0}function nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;if(v[c>>2]){yc(c);XM(c);ct(c);zh(zb(c),v[c>>2],lg(c));d=zb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}El(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[zb(b)>>2];d=zb(a),e=c,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Ui(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){c=v[a>>2];while(1){g=a;a:{if(c){d=v[a+4>>2];c=c-1|0;break a}v[a>>2]=8;c=v[a+12>>2];if((c|0)!=v[a+8>>2]){c=c-1|0;v[a+12>>2]=c}d=w[c|0];c=7}v[g>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function rA(a){var b=0,c=0,d=0,e=0;Oh(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(528,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Yf(zb(a),v[a>>2],We(a))}}function pw(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}nb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;nb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function lT(a){var b=0,c=0,d=0,e=0;Oh(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(572,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Yf(zb(a),v[a>>2],We(a))}}function dx(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(1764,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function bl(a){var b=0,c=0,d=0,e=0;bj(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-12|0;R(206,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;zh(zb(a),v[a>>2],lg(a))}}function bA(a){var b=0,c=0,d=0,e=0;Oh(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(604,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Yf(zb(a),v[a>>2],We(a))}}function TE(a,b){var c=0,d=0;c=jb-16|0;jb=c;Bc(c+8|0,a);v[114578]=0;a=T(21,c+8|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;a=Q(22,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}Ob(c+8|0);jb=c+16|0;return a}a=P()|0;O()|0;Ob(c+8|0);S(a|0);L()}function Sd(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function Hl(a){var b=0,c=0,d=0,e=0;dm(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-32|0;R(896,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;jt(zb(a),v[a>>2],th(a))}}function Gz(a){var b=0,c=0,d=0,e=0;Oh(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(770,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Yf(zb(a),v[a>>2],We(a))}}function Cx(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(1526,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function BP(a){var b=0,c=0,d=0,e=0;xP(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-56|0;R(989,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;_y(zb(a),v[a>>2],tn(a))}}function AL(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(1442,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function sX(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a=Uh(c,a+8|0,b);b=v[a>>2];a:{while(1){if(v[a+4>>2]==(b|0)){break a}b=v[a>>2];v[114578]=0;_s(b);b=v[114578];v[114578]=0;if((b|0)!=1){b=v[a>>2]+4|0;v[a>>2]=b;continue}break}b=P()|0;O()|0;vc(a);S(b|0);L()}vc(a);jb=c+16|0}function rC(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(351,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function nx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!jf(a)){break a}while(1){if(!mh(Ge(a,e))){break a}d=d+1|0;e=d&65535;if(jf(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=rg(a,d&65535,b)?d:-1}return c&65535}function kC(a){var b=0,c=0,d=0,e=0;Qk(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-2|0;R(364,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Wn(zb(a),v[a>>2],Vf(a))}}function uf(a,b){var c=0,d=0,e=0,f=0;c=Fb(a);a:{if((c|0)!=(Fb(b)|0)){break a}d=Tb(a);b=Tb(b);b:{if(!Fe(a)){if(c){break b}return 1}return!Vm(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function gC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;t[v[a+1064>>2]+d|0]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=ue(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function xo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-e*f)-b+e*.16666666666666632)}function N0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Cg(t[b|0]),e=v[v[a>>2]+52>>2],nb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=$i(b,1,c,v[a+32>>2])}return c|0}function kI(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-16|0;R(2207,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;Yi(zb(a),v[a>>2],Yh(a))}}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function pC(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-12|0;R(350,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;zh(zb(a),v[a>>2],lg(a))}}function c3(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function MQ(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;b=jb-16|0;jb=b;d=2;e=v[a>>2];if((e|0)!=1){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Lb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Lb(b+12|0,b+8|0)>>2]}jb=b+16|0;jb=c+16|0;return d}function FQ(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-20|0;R(885,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;yp(zb(a),v[a>>2],xp(a))}}function tS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148?(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function ss(a,b){var c=0,d=0;a:{if(b){ss(a,v[b>>2]);ss(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(1383,b+14|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1384,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}yp(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function mj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function jC(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-1|0;R(362,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;pg(zb(a),v[a>>2],yf(a))}}function cT(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-6|0;R(570,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;Nt(zb(a),v[a>>2],Li(a))}}function _D(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=0;v[d+4>>2]=4;Wk(a,d+8|0,v[Lb(d+12|0,d+4|0)>>2]);a=mb;if((a|0)>0?1:(a|0)>=0){v[d+4>>2]=4;Lb(d+12|0,d+4|0)}v[d+4>>2]=v[d+8>>2];a=d+4|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);jb=d+16|0}function Zx(a,b){var c=0,d=0;a:{if(b){Zx(a,v[b>>2]);Zx(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(1388,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1389,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}jt(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function WC(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-8|0;R(283,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;Lu(zb(a),v[a>>2],Vi(a))}}function GQ(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-4|0;R(884,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;yj(zb(a),v[a>>2],yd(a))}}function SF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=ba(16)|0;UF();a=Uc(c+8|0,a,85168);v[114578]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2361,d|0,c|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ha(d|0,58416,2362);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function EJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>2097151){Fc(32651);L()}f=sc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<11)+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function CJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){Fc(32651);L()}f=sc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function yE(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=64776;b=v[a+8>>2];v[114578]=0;c=da(2453)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[114578]=0;Pv(b);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Ab();L()}return a|0}function xz(a,b){var c=0,d=0;a:{if(b){xz(a,v[b>>2]);xz(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(824,b+14|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(825,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}yp(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){d=Db(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f|0}function Nz(a,b){var c=0,d=0;a:{if(b){Nz(a,v[b>>2]);Nz(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(733,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(734,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}sh(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function Lz(a,b){var c=0,d=0;a:{if(b){Lz(a,v[b>>2]);Lz(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(729,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(732,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}sh(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function $da(a){a=a|0;var b=0,c=0,d=0;c=jb-32|0;jb=c;b=255;a:{if(Mh(a)>>>0<=49){b=Ey(c,v[a+12>>2]);v[114578]=0;R(1179,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}Dl(b);mp(a,Mh(a)-1&255);b=Mh(a)-1|0}jb=c+32|0;return b&255}a=P()|0;O()|0;Dl(b);S(a|0);L()}function $ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=gn(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function dk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Cr(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function wH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Lh(C(d*C(65536)));if((e|0)==65536){break a}f=B(b,c);if(!f){break a}c=e;e=e>>31;b=1;while(1){g=v[a>>2];h=a,i=Ac(Ima(Hma(g,g>>31,c,e),mb,65536,0),mb),v[h>>2]=i;if((b|0)==(f|0)){break a}a=a+4|0;b=b+1|0;continue}}}function oy(a,b){var c=0,d=0;a:{if(b){oy(a,v[b>>2]);oy(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(1257,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1258,a|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}ny(b)}return}V(0)|0;O()|0;Ab();L()}function yv(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[114578]=0;c=da(2453)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[114578]=0;Pv(b);b=v[114578];v[114578]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Ab();L()}return a|0}function tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gu(a);a:{if(!b){break a}v[114578]=0;R(921,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(922,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bq(d);S(a|0);L()}return a|0}function VW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(kg(a,v[b+8>>2],0)){nv(b,c,d);return}e=v[a+12>>2];f=a+16|0;AD(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){AD(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function yU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jy(a);a:{if(!b){break a}v[114578]=0;R(406,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(407,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ys(d);S(a|0);L()}return a|0}function pS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Uz(a);a:{if(!b){break a}v[114578]=0;R(680,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(681,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;At(d);S(a|0);L()}return a|0}function m_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(2457,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);PE(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function l_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(2457,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);OE(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function lX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Uq(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);gi(d+(e<<2)|0,b,c);b=c+e|0;Sg(a,b);v[f+12>>2]=0;Te(d+(b<<2)|0,f+12|0);break a}ID(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function Qt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Du(a);a:{if(!b){break a}v[114578]=0;R(563,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(564,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pq(d);S(a|0);L()}return a|0}function Iba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-2496|0;jb=c;qK(b,c,c+2496|0);b=lc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}jb=c+2496|0;return a|0}function p0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;e=or(a);v[a>>2]=76704;f=zw(a+32|0,d+8|0);v[a+48>>2]=c;v[a+44>>2]=0;v[114578]=0;R(182,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){jb=d+16|0;return a|0}a=P()|0;O()|0;yb(f);il(e);S(a|0);L()}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=bc(a),v[e+8>>2]=f;b=b+(Vp(d+24|0,d+8|0)<<1)|0;if(Jb(d+24|0,d+16|0)){Pn(a,gf(b+(Vp(d+16|0,d+24|0)<<1)|0,v[a+4>>2],b))}a=Ng(b);jb=d+32|0;return a|0}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=bc(a),v[e+8>>2]=f;b=b+B(is(d+24|0,d+8|0),6)|0;if(Jb(d+24|0,d+16|0)){Sz(a,rx(b+B(is(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}a=Ng(b);jb=d+32|0;return a|0}function y$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function x7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gJ(a,b,c,d);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=81004;return a|0}function t_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(21,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);SE(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function r_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(21,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);RE(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function lp(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=uk(a,b);if((e|0)==255){break a}if(rj(a)){break a}b=Ii(a+314|0,e);e=vN(e);if(f=1,g=t[fc(b,10)|0]&1,h=d,h?f:g){hh(v[a>>2],e- -64&65535,uN(c,w[fc(b,2)|0]))}if(d){break a}hh(v[a>>2],e+67&65535,uN(c,w[fc(b,3)|0]))}}function bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;kL(d,b,c<<24>>24);jb=e+16|0;b=d;c=Tb(d);e=Fb(d);v[114578]=0;W(196,a|0,c|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);jb=d+16|0;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function rG(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=rG(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function QA(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}mb=a;return b}function Laa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;d=nd(a);e=b,f=bc(a),v[e+8>>2]=f;e=b,f=cc(a),v[e>>2]=f;if(Jb(b+8|0,b)){c=+(d>>>0);while(1){a=v[b+8>>2];A[a>>3]=A[a>>3]/c;A[a+8>>3]=A[a+8>>3]/c;Uf(b+8|0);if(Jb(b+8|0,b)){continue}break}}jb=b+16|0}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(!((c|0)!=-1?(c|0)!=4:0)){c=jb-16|0;jb=c;v[c+8>>2]=0;Lo(a,c+8|0);z[b>>2]=z[c+8>>2];jb=c+16|0;return}d=jb-16|0;jb=d;v[d+12>>2]=0;v[d+8>>2]=c;v[d+4>>2]=4;Wk(a,d+12|0,v[Lb(d+8|0,d+4|0)>>2]);v[b>>2]=0;jb=d+16|0}function jj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Tb(c);qi(b,a,Fb(c)+a|0);break c}KJ(d,c);v[114578]=0;U(115,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Lc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Lc(d);S(a|0);L()}}function fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,64);a:{if(d){mA(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b- -64|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,64);a:{if(d){mA(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b- -64|0;while(1){fu(b);b=b+2|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function B$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;lP(c+8|0,e);f=Hb(c+8|0);g=ld(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){mP(e)}if(a){d=wP(b+8|0)}jb=b+160|0;return d|0}function jma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-624|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;pT(c+8|0,e);f=Hb(c+8|0);g=ld(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){qT(e)}if(a){d=rT(b+8|0)}jb=b+624|0;return d|0}function sM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075072>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,27);a:{if(d){oN(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+27|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function $r(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Tb(c);qi(b,a,Fb(c)+a|0);break c}_J(d,b,c);v[114578]=0;R(116,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Lc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Lc(d);S(a|0);L()}}function zB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,16);a:{if(d){hB(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+16|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function gG(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){nb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;_t(c+8|0,e);f=Hb(c+8|0);g=ld(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){JA(e)}if(a){d=CR(b+8|0)}jb=b+16|0;return d|0}function Rz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Oi(a+8|0);v[114578]=0;d=T(332,b|0)|0;e=v[114578];v[114578]=0;b:{if((e|0)==1){break b}v[114578]=0;U(423,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;Pg(c);S(a|0);L()}}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;Gt(c+8|0,e);f=Hb(c+8|0);g=ld(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){PS(e)}if(a){d=SS(b+8|0)}jb=b+32|0;return d|0}function kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,6);a:{if(d){aA(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+6|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,2);a:{if(d){Ok(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+2|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function Qr(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[114578]=0;T(1405,c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){kd(a+68|0);rf(a+36|0);wf(a+32|0);Gh(b);Yc(a+4|0);Yc(a);return a}V(0)|0;O()|0;kd(a+68|0);rf(a+36|0);wf(a+32|0);Gh(b);Yc(a+4|0);Yc(a);Ab();L()}function Ima(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=b^d;h=e>>31;f=b>>31;a=a^f;i=a-f|0;g=b;b=b>>31;g=(g^b)-((a>>>0<f>>>0)+b|0)|0;a=d>>31;b=c^a;c=d>>31;e=e>>31;a=Kma(i,g,b-a|0,(c^d)-((a>>>0>b>>>0)+c|0)|0)^e;b=a-e|0;mb=(h^mb)-((a>>>0<e>>>0)+h|0)|0;return b}function Hx(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=mu(f,c);d=a+1074312|0;Eb(e+8|0,d,31);a=0;if(!Cb(e+8|0)){Eb(e,d,93);a=Cb(e)^1}if(!(t[$K(b,c)|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=md(f)^1}jb=e+16|0;return d}function vB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,3);a:{if(d){ju(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+3|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,1030);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,1030);jb=c+16|0}return a|0}function kz(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[fc(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function CT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,8);a:{if(d){Ju(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+8|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function vka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Mj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(xd(a,5)){break a}}fS(v[a+28>>2],b,v[e+24>>2],0)}_i(a,d,c,e+16|0);jb=e+32|0}function vga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jy(a);a:{if(!b){break a}v[114578]=0;R(406,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(1055,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ys(c);S(a|0);L()}return a|0}function k_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;Bc(a,d);v[114578]=0;b=T(2457,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(a);NE(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Ob(a);S(b|0);L()}function ZK(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(!b){break a}g=c;h=c>>31;c=1;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ac(Ima(Hma(d,d>>31,g,h),mb,256,0),mb);v[a+4>>2]=f-d;v[a>>2]=d+f;if((b|0)==(c|0)){break a}a=a+8|0;c=c+1|0;continue}}}function wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,274);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,274);jb=c+16|0}return a|0}function taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,225);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,225);jb=c+16|0}return a|0}function ria(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,106);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,106);jb=c+16|0}return a|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,326);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,326);jb=c+16|0}return a|0}function ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,422);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,422);jb=c+16|0}return a|0}function eo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Kc(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);xh(d+e|0,b,c);b=c+e|0;Sg(a,b);t[f+15|0]=0;he(b+d|0,f+15|0);break a}Qu(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,826);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,826);jb=c+16|0}return a|0}function Xj(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function NM(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=Db(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+85376|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function uU(a,b){a=a|0;b=b|0;var c=0,d=0;c=qB(a);a:{if(!b){break a}v[114578]=0;R(408,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(409,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;oB(c);S(a|0);L()}return a|0}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;Bc(a,d);v[114578]=0;b=T(21,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(a);QE(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Ob(a);S(b|0);L()}function qS(a,b){a=a|0;b=b|0;var c=0,d=0;c=Du(a);a:{if(!b){break a}v[114578]=0;R(563,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(669,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pq(c);S(a|0);L()}return a|0}function kR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,284);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,284);jb=c+16|0}return a|0}function Fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;if(!(!a|!b)){g=ws(a);f=jb-16|0;jb=f;d=ws(a);a=d;c=ws(b);if(c){while(1){a=c;c=(d>>>0)%(a>>>0)|0;d=a;if(c){continue}break}}jb=f+16|0;c=B(ws(b),(g|0)/(a|0)|0)}jb=e+16|0;return c|0}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,34);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,34);jb=c+16|0}return a|0}function waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,73);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,73);jb=c+16|0}return a|0}function vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,42);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,42);jb=c+16|0}return a|0}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,72);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,72);jb=c+16|0}return a|0}function nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;g=b;AS(c+8|0,b);e=Hb(c+8|0);f=ld(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(e|0)==(f|0);if(!a){BS(g)}if(a){d=DS(b)}jb=b+160|0;return d|0}function naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,60);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,60);jb=c+16|0}return a|0}function iga(a){a=a|0;var b=0,c=0,d=0,e=0;c=zO(a);if((c|0)!=(a|0)){while(1){b=0;e=a;cS(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Rb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function gL(a,b){var c=0,d=0,e=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}d=b;c=v[c>>2];b:{if(c){e=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[e+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[d>>2]=a}}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,91);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,91);jb=c+16|0}return a|0}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,71);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,71);jb=c+16|0}return a|0}function Ska(a,b){a=a|0;b=b|0;var c=0,d=0;c=dB(a);a:{if(!b){break a}v[114578]=0;R(36,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(37,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;KA(c);S(a|0);L()}return a|0}function Me(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Oi(a+8|0);v[114578]=0;U(423,a|0,b|0,c|0);c=v[114578];v[114578]=0;a:{if((c|0)!=1){a=v[a>>2];v[114578]=0;Q(340,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Pg(d);S(a|0);L()}}function K_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=Ah(e,e+12|0);v[114578]=0;a=W(2478,a|0,c|0,v[e+8>>2])|0;c=v[114578];v[114578]=0;if((c|0)!=1){Ie(b);jb=e+16|0;return a|0}a=P()|0;O()|0;Ie(b);S(a|0);L()}function IN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=KN(b,zb(c));v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];d=v[zb(c)>>2];e=zb(a),f=d,v[e>>2]=f;e=zb(c),f=0,v[e>>2]=f;v[c>>2]=0;v[c+4>>2]=0;td(b+12|0,c+12|0);u[b+28>>1]=x[c+28>>1];v[b+24>>2]=v[c+24>>2]}function C9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Mj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(xd(a,5)){break a}}XJ(v[a+28>>2],b,v[e+24>>2])}_i(a,d,c,e+16|0);jb=e+32|0}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-208|0;jb=b;d=-1;c=jb-16|0;jb=c;g=b;UO(c+8|0,b);e=Hb(c+8|0);f=ld(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(e|0)==(f|0);if(!a){VO(g)}if(a){d=ZO(b)}jb=b+208|0;return d|0}function wN(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(w[a+530|0]){while(1){d=c&65535;yi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;Sh(a+4|0,18,b+15|0);Bz(a+22|0,18,20106);t[b+14|0]=255;Sh(a+58|0,256,b+14|0);jb=b+16|0}function le(){var a=0,b=0;a:{b:{if(t[461636]&1){break b}if(!wd(461636)){break b}v[114578]=0;a=W(2455,2147483647,64693,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[115408]=a;vd(461636)}return v[115408]}a=P()|0;O()|0;pe(461636);S(a|0);L()}function Ila(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!eA(a,b+16|0)){break a}c=0;if(!US(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!Xc(a,4)){break a}}c=-1;if(!Jj(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}jb=b+32|0;return c|0}function IT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,50);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,50);jb=c+16|0}return a|0}function EC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;td(b,c);cm(b+12|0,c+12|0);a=jb-16|0;jb=a;c=c+28|0;d=a,e=Nd(c),v[d+12>>2]=e;v[114578]=0;W(282,b+28|0,a+12|0,c|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}}function wo(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function mba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){mL(e,v[d+4>>2],v[d+8>>2])}lc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-48|0;jb=b;d=-1;c=jb-16|0;jb=c;g=b;iB(c+8|0,b);e=Hb(c+8|0);f=ld(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(e|0)==(f|0);if(!a){jB(g)}if(a){d=BB(b)}jb=b+48|0;return d|0}function zd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}u[a+20>>1]=c-d}function Ty(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){Fc(17388);L()}f=sc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function KM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[bd(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=zM(c&255),v[e+44>>2]=f}jb=d+16|0}function xE(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){Fc(6863);L()}f=sc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function aL(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Lb(b+12|0,b+8|0)>>2]){c=15;while(1){d=_o(a);v[b+12>>2]=7;v[b+8>>2]=32;if(c>>>0<y[Lb(b+12|0,b+8|0)>>2]){c=c+15|0;continue}break}a=d&127}else{a=0}jb=b+16|0;return a}function YS(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>89478485){Fc(12706);L()}f=sc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,48)+f|0,v[g>>2]=h;jb=e+16|0;return a}function YE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){of(a,c);d=a;break a}f=Uk(d)+1|0;d=$h(f);Ff(a,d);Fg(a,f);we(a,c)}xh(d,b,c);t[e+15|0]=0;he(c+d|0,e+15|0);jb=e+16|0;return}Hg();L()}function CE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a:{a=Jb(d+24|0,d+16|0);if(!a){break a}if(!rl(v[d+24>>2],v[d+8>>2])){break a}_d(d+24|0);_d(d+8|0);continue}break}jb=d+32|0;return a^1}function hs(a,b,c){var d=0,e=0;d=jb-32|0;jb=d;a:{e=!b|!c;if(!e){b=Ub(d,b);v[114578]=0;U(1569,d+16|0,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}Gb(a+36|0,d+16|0);yb(d+16|0);yb(b)}jb=d+32|0;return!e}a=P()|0;O()|0;yb(b);S(a|0);L()}function y6(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;b=b+4|0;d=v[b+48>>2];a:{if(d&16){if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}qi(a,v[b+20>>2],v[b+44>>2]);break a}if(d&8){qi(a,v[b+8>>2],v[b+16>>2]);break a}zw(a,c+8|0)}jb=c+32|0}function QD(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-4;v[114578]=0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){TD(v[a+16>>2],v[a>>2],sg(a))}}function MD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function xT(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>2147483647){Fc(12489);L()}f=sc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<1)+f|0,v[g>>2]=h;jb=e+16|0;return a}function qC(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){Fc(11561);L()}f=sc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function jp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-Sd(A[Tk(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Ve(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function hJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){Fc(33245);L()}f=sc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Vga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(lg(a)>>>0<b>>>0){d=zb(a);b=Ty(c+8|0,b,yc(a),d);v[114578]=0;R(1016,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}bt(b)}jb=c+32|0;return}a=P()|0;O()|0;bt(b);S(a|0);L()}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(lg(a)>>>0<b>>>0){d=zb(a);b=PM(c+8|0,b,yc(a),d);v[114578]=0;R(1256,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Gs(b)}jb=c+32|0;return}a=P()|0;O()|0;Gs(b);S(a|0);L()}function $la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;ju(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;jb=c+16|0}return a|0}function uja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(Vf(a)>>>0<b>>>0){d=zb(a);b=fq(c+8|0,b,oc(a),d);v[114578]=0;R(382,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ej(b)}jb=c+32|0;return}a=P()|0;O()|0;Ej(b);S(a|0);L()}function lja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(yf(a)>>>0<b>>>0){d=zb(a);b=nh(c+8|0,b,xc(a),d);v[114578]=0;R(366,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Rg(b)}jb=c+32|0;return}a=P()|0;O()|0;Rg(b);S(a|0);L()}function i8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(yd(a)>>>0<b>>>0){d=zb(a);b=hJ(c+8|0,b,Kb(a),d);v[114578]=0;R(1760,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Yr(b)}jb=c+32|0;return}a=P()|0;O()|0;Yr(b);S(a|0);L()}function hV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(yd(a)>>>0<b>>>0){d=zb(a);b=qC(c+8|0,b,Kb(a),d);v[114578]=0;R(345,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}uq(b)}jb=c+32|0;return}a=P()|0;O()|0;uq(b);S(a|0);L()}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;AR(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-33|0,33)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];zk(a);Jl(a);Jl(a)}function Kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;XS(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Ni(a);Ml(a);Ml(a)}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=0;a:{if(!Kb(a)){break a}while(1){Af(d,v[Pb(a,e)>>2]+40|0);c=Hp(d,b);yb(d);if(c){c=v[Pb(a,e)>>2];break a}e=e+1|0;if(Kb(a)>>>0>e>>>0){continue}break}c=0}jb=d+16|0;return c|0}function c7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=12){ae(d+12|0,C(0));c=z[d+12>>2];if((b|0)==12){c=C(je(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}jb=d+16|0}function _1(a){a=a|0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<y[a+44>>2]){Om(a,v[a+8>>2],v[a+12>>2],v[a+44>>2])}if(y[a+12>>2]>=y[a+16>>2]){break a}return Cg(t[v[a+12>>2]])|0}return-1}function $7(a){a=a|0;var b=0;nb[v[v[a>>2]+124>>2]](a);cx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=nb[v[v[a>>2]+188>>2]](a)|0;v[a+4272>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4292>>2]=b;v[a+4288>>2]=b;v[a+4284>>2]=b;v[a+4280>>2]=b}function mg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function $ka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;a:{if(b){Ub(c,b);break a}Wb(c)}v[114578]=0;R(665,c+16|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){td(a,c+16|0);yb(c+16|0);yb(c);jb=c+32|0;return a|0}a=P()|0;O()|0;yb(c);S(a|0);L()}function K0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=$i(b,4,c,v[a+32>>2])}return c|0}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;b=JQ(d,b);e=jb-16|0;jb=e;b=JQ(e,b);f=jb-16|0;jb=f;Nq(d+8|0,v[b>>2],v[b>>2]+CQ(b)|0);jb=f+16|0;jb=e+16|0;Uu(a,d+8|0);v[a+12>>2]=c;v[a+8>>2]=0;jb=d+16|0;return a|0}function eD(){var a=0,b=0,c=0;b=jb-16|0;jb=b;a=Ub(b,10940);a:{if(!Fb(a)){break a}c=1;if((Zf(a,10946)|0)!=-1){break a}if((Zf(a,10948)|0)!=-1){break a}if((Zf(a,10952)|0)!=-1){break a}c=(Zf(a,10954)|0)!=-1}yb(a);jb=b+16|0;return c|0}function NL(a,b){a=a|0;b=b|0;IL(a);IL(a+368680|0);if(b){UK(a,1);return a|0}SK();gf(219584,285120,a+131112|0);gf(285120,350656,a+196648|0);gf(350656,416192,a+262184|0);gf(88496,219584,a+24|0);lc(a+327720|0,416192,40960);return a|0}function Kf(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Ve(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function EM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=jb-16|0;jb=a;d=v[b+104>>2];if(d){v[b+88>>2]=v[b+88>>2]&-131|128;d=v[d>>2];v[b+76>>2]=d;v[a+12>>2]=c<<8;v[a+8>>2]=d-1;c=d+(v[Lb(a+12|0,a+8|0)>>2]^-1)|0;v[b>>2]=0;v[b+4>>2]=c}jb=a+16|0}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;bj(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,yc(a))}function wd(a){var b=0,c=0,d=0;c=jb-16|0;jb=c;a=rv(c,a);d=jb-16|0;jb=d;if(!w[v[Oc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}jb=d+16|0;jb=c+16|0;return b}function oP(a,b){var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=RP(c+8|0,c);jb=c+32|0;return a}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Oh(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-24|0,24)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Tt(a,Id(a))}function rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=4896;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Jz(d,b);xg(a,v[d>>2],c);Jz(d,b);Rb(v[d>>2]+c|0,0,4896-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function _2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function Z2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=0;a:{if(!a){break a}e=a|-16;if(b>>>0>1?a>>>0<16&c:1){break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[qh(d+15|0,d+14|0)|0]}a=e;jb=d+16|0;return a&255}function Os(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;if(b){e=Kc(a);d=Fb(a);g=d+b|0;if(e-d>>>0<b>>>0){Rl(a,e,g-e|0,d,d,0,0)}e=d;d=Tb(a);yy(e+d|0,b,c);Sg(a,g);t[f+15|0]=0;he(d+g|0,f+15|0)}jb=f+16|0;return a|0}function MC(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;jb=b+16|0}function iE(){var a=0;a:{b:{if(t[461648]&1){break b}if(!wd(461648)){break b}v[114578]=0;da(2559)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115411]=461640;vd(461648)}return v[115411]}a=P()|0;O()|0;pe(461648);S(a|0);L()}function go(a,b){var c=0,d=0;c=b+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);a:{if(b>>>0>=xc(a)>>>0){break a}if(xc(a)>>>0<c>>>0){break a}d=c>>>0<=xc(a)-b>>>0}return d}function gI(a,b){a=a|0;b=b|0;var c=0;a:{c=Pe(8);ZH(c);v[c+4>>2]=b;v[c>>2]=83800;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2141,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}}function UY(){var a=0;a:{b:{if(t[461660]&1){break b}if(!wd(461660)){break b}v[114578]=0;da(2563)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115414]=461652;vd(461660)}return v[115414]}a=P()|0;O()|0;pe(461660);S(a|0);L()}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=263;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}EO(d,b);xg(a,v[d>>2],c);EO(d,b);Rb(v[d>>2]+c|0,0,263-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function sR(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=qe(d,a,1);a=zb(a);e=v[c+4>>2];v[114578]=0;U(769,a|0,e|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function os(a,b){var c=0;c=79244;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=79260;break a;case 2:c=79256;break a;case 1:break b;case 0:break c}}c=79252;break a}c=79248}v[a>>2]=v[c>>2]}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;v[e>>2]=83696;v[e>>2]=83652;v[114578]=0;a=aa(2156,a|0,b|0,c|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=d+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function US(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function F$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=pr(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=od(c);v[f>>2]=a;if(!a){break a}e=pr(a,c,b,v[d+12>>2])}jb=d+16|0;return e|0}function zg(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;c=Ub(b,11931);v[114578]=0;Q(380,a+9|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=b+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function wv(a,b){var c=0,d=0;c=jb-32|0;jb=c;a:{if(yf(a)>>>0<b>>>0){d=zb(a);b=nh(c+8|0,b,xc(a),d);v[114578]=0;R(209,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}om(b)}jb=c+32|0;return}a=P()|0;O()|0;om(b);S(a|0);L()}function b3(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function aba(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a+480180>>2]=b;DL(c,Vo(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;os(a+8|0,Vo(a));jb=c+16|0}function a3(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function _aa(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function JD(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<=1073741807){a:{if(c>>>0<=1){of(a,c);e=a;break a}f=tm(c)+1|0;e=sm(f);Ff(a,e);Fg(a,f);we(a,c)}gi(e,b,c);v[d+12>>2]=0;Te((c<<2)+e|0,d+12|0);jb=d+16|0;return}Hg();L()}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Ce(b);c=NO(d+8|0,c);v[114578]=0;fa(1031,a|0,b|0,0,e-1&65535,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){ke(c);jb=d+32|0;return}a=P()|0;O()|0;ke(c);S(a|0);L()}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=40;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}zz(d,b);xg(a,v[d>>2],c);zz(d,b);Rb(v[d>>2]+c|0,0,40-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function dN(a,b){var c=0,d=0;c=jb-32|0;jb=c;a:{if(yd(a)>>>0<b>>>0){d=zb(a);b=ks(c+8|0,b,Kb(a),d);v[114578]=0;R(96,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}nk(b)}jb=c+32|0;return}a=P()|0;O()|0;nk(b);S(a|0);L()}function IE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a=Jb(d+24|0,d+16|0);if(!(!a|w[v[d+24>>2]]!=w[v[d+8>>2]])){qg(d+24|0);qg(d+8|0);continue}break}jb=d+32|0;return a^1}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=22;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Gt(d,b);xg(a,v[d>>2],c);Gt(d,b);Rb(v[d>>2]+c|0,0,22-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function AA(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(Qb(a,512)){Xt(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;d=jb-16|0;jb=d;e=b+512|0;while(1){Wt(b);b=b+4|0;if((e|0)!=(b|0)){continue}break}jb=d+16|0;jb=a+16|0}jb=c+16|0}function yH(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-24|0;R(2208,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function v8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=33;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Ez(d,b);xg(a,v[d>>2],c);Ez(d,b);Rb(v[d>>2]+c|0,0,33-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function qX(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Et(b,70468)){GD(c,70481,b);a=Tb(c);v[114578]=0;R(2826,44,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=c+16|0;return a|0}L()}function nz(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-1024|0;jb=e;d=jb-16|0;jb=d;jz(d+8|0,e);f=Hb(d+8|0);g=nc(a,ac(d,d+8|0));if((f|0)==(g|0)){$b(a,Hb(d+8|0))}jb=d+16|0;if((f|0)==(g|0)){h=kz(e,c)>>>0<=b>>>0}jb=e+1024|0;return h}function YX(a){a=a|0;a:{b:{if(t[461744]&1){break b}if(!wd(461744)){break b}v[114578]=0;Y(2580);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115435]=462096;vd(461744)}return v[115435]}a=P()|0;O()|0;pe(461744);S(a|0);L()}function WO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-12|0;R(1024,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function VX(a){a=a|0;a:{b:{if(t[461752]&1){break b}if(!wd(461752)){break b}v[114578]=0;Y(2582);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115437]=462272;vd(461752)}return v[115437]}a=P()|0;O()|0;pe(461752);S(a|0);L()}function SX(a){a=a|0;a:{b:{if(t[461760]&1){break b}if(!wd(461760)){break b}v[114578]=0;Y(2584);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115439]=462576;vd(461760)}return v[115439]}a=P()|0;O()|0;pe(461760);S(a|0);L()}function PX(a){a=a|0;a:{b:{if(t[461768]&1){break b}if(!wd(461768)){break b}v[114578]=0;Y(2586);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115441]=462880;vd(461768)}return v[115441]}a=P()|0;O()|0;pe(461768);S(a|0);L()}function MX(a){a=a|0;a:{b:{if(t[461776]&1){break b}if(!wd(461776)){break b}v[114578]=0;Y(2588);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115443]=462912;vd(461776)}return v[115443]}a=P()|0;O()|0;pe(461776);S(a|0);L()}function GK(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-24|0;R(1562,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Cr(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!uw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Ae(a)}return b}ia(50578,50496,1563,50598);L()}function Co(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=Fb(a);if(c>>>0<b>>>0){Os(a,b-c|0,0);break a}c=jb-16|0;jb=c;b:{if(Fe(a)){d=v[a>>2];t[c+15|0]=0;he(b+d|0,c+15|0);we(a,b);break b}t[c+14|0]=0;he(a+b|0,c+14|0);of(a,b)}jb=c+16|0}}function $X(a){a=a|0;a:{b:{if(t[461736]&1){break b}if(!wd(461736)){break b}v[114578]=0;Y(2578);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115433]=461920;vd(461736)}return v[115433]}a=P()|0;O()|0;pe(461736);S(a|0);L()}function vP(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-24|0;R(985,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function fO(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;R(823,c|0,b+14|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){Yi(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function cP(a,b,c){var d=0;d=jb-16|0;jb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+20798>>1]-x[(c<<1)+20798>>1]|0)/5;a=w[pc(d+15|0,d+14|0)|0]}jb=d+16|0;return a&255}function ay(a,b){var c=0,d=0;c=B(b,896)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!oj(c+1074984|0)){break a}b=w[v[(B(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function YC(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-32|0;R(276,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function RS(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];c=QS(a);d=jb-16|0;jb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Jd(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}jb=d+16|0;return v[b>>2]}function KO(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function HO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-4|0;R(1060,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Aba(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function yT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-2|0;R(532,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function sY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Ah(e+8|0,e+12|0);v[114578]=0;a=dF(a,b,c);b=v[114578];v[114578]=0;if((b|0)!=1){Ie(d);jb=e+16|0;return a|0}a=P()|0;O()|0;Ie(d);S(a|0);L()}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Jz(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,4896);jb=c+16|0}return a|0}function Rba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(vo(b)+-4.8737671609324025),A[d+8>>3]=e;Rf(c+8|0,0,127);a=pt(A[c+8>>3]);jb=c+16|0;return a|0}function PQ(a){var b=0,c=0;a:{if(pd(a,15547,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function yN(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function nL(a,b){var c=0,d=0,e=0;d=a;c=jb-16|0;jb=c;Oc(c+8|0,b+116|0);v[114578]=0;b=Na(198,b|0)|0;O()|0;b=b|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}a=P()|0;O()|0;S(a|0);L()}v[d>>2]=b;_o(a);return a}function kL(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(b>>>0<=4294967279){a:{if(b>>>0<=10){of(a,b);e=a;break a}f=Uk(b)+1|0;e=$h(f);Ff(a,e);Fg(a,f);we(a,b)}yy(e,b,c);t[d+15|0]=0;he(b+e|0,d+15|0);jb=d+16|0;return}Hg();L()}function gp(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){of(a,c);e=a;break a}f=Uk(c)+1|0;e=$h(f);Ff(a,e);Fg(a,f);we(a,c)}xh(e,b,c);t[d+15|0]=0;he(c+e|0,d+15|0);jb=d+16|0;return}Hg();L()}function fP(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;u[a+34>>1]=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;c=a+43|0;f=c+22|0;while(1){ff(c);c=c+1|0;if((f|0)!=(c|0)){continue}break}jb=e+16|0;jb=d+16|0;v[a+20>>2]=0;Ed(a,b);return a|0}function Kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Jb(d+16|0,d+24|0)){while(1){v[d+12>>2]=v[v[d+16>>2]>>2];ly(a,d+12|0);_d(d+16|0);if(Jb(d+16|0,d+24|0)){continue}break}}jb=d+32|0}function Hda(a){a=a|0;var b=0;v[a>>2]=0;a:{if(t[87428]&1){break a}if(!wd(87428)){break a}v[114578]=0;T(1210,87424)|0;b=v[114578];v[114578]=0;if((b|0)!=1){vd(87428);break a}a=P()|0;O()|0;pe(87428);S(a|0);L()}return a|0}function uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;zz(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,40);jb=c+16|0}return a|0}function on(a){a=a|0;Cc(a+16|0,v[a>>2]);Cc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=al(e,a,d);a=zb(a);v[114578]=0;X(2183,a|0,b|0,c|0,d+4|0);a=v[114578];v[114578]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function m4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=mm(e,a,d);a=zb(a);v[114578]=0;X(2126,a|0,b|0,c|0,d+4|0);a=v[114578];v[114578]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function aD(a){var b=0,c=0;b=a+2|0;a:{if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+4|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<2147483649}return c}function Hma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;mb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function CB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,37);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;if((d|0)!=(e|0)){a=jb-16|0;jb=a;Rb(b,0,37);jb=a+16|0}}function zX(a){a=a|0;a:{b:{if(t[461872]&1){break b}if(!wd(461872)){break b}v[114578]=0;Q(2591,461860,65076)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461872)}return 461860}a=P()|0;O()|0;pe(461872);S(a|0);L()}function vw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Br(a)){break a}if(!(t[a+1375|0]&1)){continue}break}dc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function vX(a){a=a|0;a:{b:{if(t[461904]&1){break b}if(!wd(461904)){break b}v[114578]=0;Q(2591,461892,65172)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461904)}return 461892}a=P()|0;O()|0;pe(461904);S(a|0);L()}function q2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;bo(a);v[a>>2]=83720;d=uh(c+8|0);b=uh(b);v[114578]=0;W(2204,a+12|0,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function p2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;bo(a);v[a>>2]=83760;d=uh(c+8|0);b=uh(b);v[114578]=0;W(2206,a+12|0,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Op(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;mA(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,64);jb=c+16|0}return a|0}function HX(a){a=a|0;a:{b:{if(t[461808]&1){break b}if(!wd(461808)){break b}v[114578]=0;Q(2591,461796,64968)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461808)}return 461796}a=P()|0;O()|0;pe(461808);S(a|0);L()}function DX(a){a=a|0;a:{b:{if(t[461840]&1){break b}if(!wd(461840)){break b}v[114578]=0;Q(2591,461828,65016)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461840)}return 461828}a=P()|0;O()|0;pe(461840);S(a|0);L()}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;vf(a);e=v[b+4>>2];d=b+4|0;Nh(zb(a),v[a>>2],c,d);f=c;c=b+8|0;Kk(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mk(a,Kb(a));return e|0}function iN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Mt(a);e=v[b+4>>2];d=b+4|0;GR(zb(a),v[a>>2],c,d);f=c;c=b+8|0;rK(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Ot(a,cg(a));return e|0}function Ys(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;Eb(d+8|0,c+1074312|0,102);a:{if(!Cb(d+8|0)){break a}c=x[a+692>>1]+1|0;u[a+796>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+796>>1]=c|32768}v[a+692>>2]=b;jb=d+16|0}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Ol(a);e=v[b+4>>2];d=b+4|0;Nh(zb(a),v[a>>2],c,d);f=c;c=b+8|0;Kk(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];iA(a,xc(a));return e|0}function MV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;bo(a);v[a>>2]=76920;d=uh(c+8|0);b=uh(b);v[114578]=0;W(275,a+12|0,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Dda(a){a=a|0;var b=0,c=0,d=0,e=0;while(1){c=(b&255)<<24;d=1;while(1){e=c<<1;c=(c|0)>-1?e:e^79764919;if((d|0)!=8){d=d+1|0;continue}break}v[(b<<2)+87440>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}return a|0}function xX(a){a=a|0;a:{b:{if(t[461888]&1){break b}if(!wd(461888)){break b}v[114578]=0;Q(85,461876,65160)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461888)}return 461876}a=P()|0;O()|0;pe(461888);S(a|0);L()}function wT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Qk(a);e=v[b+4>>2];d=b+4|0;Nh(zb(a),v[a>>2],c,d);f=c;c=b+8|0;Kk(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Bu(a,oc(a));return e|0}function JX(a){a=a|0;a:{b:{if(t[461792]&1){break b}if(!wd(461792)){break b}v[114578]=0;Q(85,461780,64956)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461792)}return 461780}a=P()|0;O()|0;pe(461792);S(a|0);L()}function Im(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function Ig(a){var b=0;v[114578]=0;a=T(1401,a|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Ab();L()}function FX(a){a=a|0;a:{b:{if(t[461824]&1){break b}if(!wd(461824)){break b}v[114578]=0;Q(85,461812,65004)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461824)}return 461812}a=P()|0;O()|0;pe(461824);S(a|0);L()}function BX(a){a=a|0;a:{b:{if(t[461856]&1){break b}if(!wd(461856)){break b}v[114578]=0;Q(85,461844,65052)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461856)}return 461844}a=P()|0;O()|0;pe(461856);S(a|0);L()}function wF(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=nb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!ve(b,-1)){break a}v[a>>2]=0}return a|0}function pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;a=v[a+1304560>>2];a:{if(a){nb[v[v[a>>2]+8>>2]](a,b,c);break a}if(v[19056]<(b|0)){break a}EL(d+8|0,20495,20516,132);ZC(d+24|0,d+8|0,b,20486,c)}jb=d+32|0}function au(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function IM(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=c&15;if(e){t[b+844|0]=e}c=c&240;if(c){t[b+843|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Eb(d+8|0,a+1074312|0,80);if(!(!Cb(d+8|0)|!e)){t[b+844|0]=w[b+844|0]<<2}jb=d+16|0}function Lx(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}lc(a+24604|0,b,40);jL(a,c)}function Cn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(c){Ub(d,c);break a}Wb(d)}v[114578]=0;U(13,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function IV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=0;f=v[a+8>>2];if(f>>>0>c>>>0){v[e+8>>2]=f-c;d=Lb(e+8|0,e+12|0);a=v[a+4>>2]+c|0;d=v[d>>2];gf(a,a+d|0,b)}jb=e+16|0;return d|0}function BJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2048|0;R(1653,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function bC(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=2147483647;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function _v(a){a=a|0;var b=0;v[a>>2]=59048;v[114578]=0;R(2375,a|0,0);b=v[114578];v[114578]=0;if((b|0)!=1){Ob(a+28|0);Xb(v[a+32>>2]);Xb(v[a+36>>2]);Xb(v[a+48>>2]);Xb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Ab();L()}function Zm(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=1073741823;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e>>2]=c;v[e+8>>2]=b;if(Jb(e+8|0,e)){while(1){Mn(a,v[d>>2],v[e+8>>2]);te(e+8|0);v[d>>2]=v[d>>2]+2;if(Jb(e+8|0,e)){continue}break}}jb=e+16|0}function Kx(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;iL(a+24648|0);wL(a)}function zr(a){var b=0;if(a){if(v[a+76>>2]<=-1){return pw(a)}return pw(a)}if(v[21290]){b=zr(v[21290])}a=v[114557];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=pw(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function tT(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=178956970;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function sE(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=357913941;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function rm(a,b,c){var d=0,e=0;d=Jd(b,a);e=Jd(c,b);a:{b:{if(!d){d=0;if(!e){break a}Zb(b,c);d=1;if(!Jd(b,a)){break a}Zb(a,b);break b}if(e){Zb(a,c);return 1}Zb(a,b);d=1;if(!Jd(c,b)){break a}Zb(b,c)}d=2}return d}function oL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-52|0;R(1440,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function nv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function nh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=$h(b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=b+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;nb[g|0](a,b,e,d);jb=e+16|0}function h_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];a:{if((b|0)<=10){c=b+1|0;break a}e=a;b=378;while(1){JE(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}c=1}v[d+112>>2]=c;a=JE(a);return a|0}function fA(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=715827882;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function XL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-24|0;R(1382,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function WM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-12|0;R(1237,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function TO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-12|0;R(1023,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Nu(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=536870911;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function MN(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-32|0;R(1195,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Kq(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=268435455;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function GC(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=134217727;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function zV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;b=Sk(e+8|0,b);v[114578]=0;X(284,a|0,b|0,c|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){Bb(b);jb=e+16|0;return}a=P()|0;O()|0;Bb(b);S(a|0);L()}function xR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-33|0;R(768,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function xJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(1655,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function oD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-16|0;R(217,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function iK(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=82595524;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function bD(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1129474426&(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))==1634291279){a=a+8|0;a=(w[a|0]|w[a+1|0]<<8)==14}else{a=0}return a}function aT(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-48|0;R(573,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function XA(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-16|0;R(428,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Gaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=Ih(a),v[g>>2]=h;Ih(a);if(f>>>0>=60){$b(a,4)}g=e,h=Ih(a),v[g>>2]=h;$b(a,4);b=Ih(a);v[d>>2]=b;if((b|0)>=1){g=c,h=Ih(a),v[g>>2]=h}}function xx(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1561,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function wL(a){var b=0,c=0;b=jb-544|0;jb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){gN(b,Se(a));c=a+1304360|0;a=a+1074984|0;while(1){lc(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}jb=b+544|0}function rL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(107,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function qJ(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1743,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function pJ(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1744,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function lz(a,b,c){var d=0;d=jb-16|0;jb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Jb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}te(d+8|0);if(Jb(d+8|0,d)){continue}break}}jb=d+16|0;return v[d+8>>2]}function kk(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1595,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function jD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-1|0;R(215,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function jA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=d,f=iT(bc(b),cc(b),d+12|0),v[e+8>>2]=f;e=d,f=cc(b),v[e>>2]=f;a:{if(Jb(d+8|0,d)){Ze(a,zb(v[d+8>>2]));break a}Xh(a)}jb=d+16|0}function i7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;b=Ac(Ima(Hma(d,d>>31,b,b>>31),mb,1e3,0),mb);v[a+16>>2]=0;v[a+12>>2]=b+c;OI(a,e);b=v[a+12>>2];v[f+12>>2]=0;$J(a,b,f+12|0);jb=f+16|0}function eC(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-1|0;R(363,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function aB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2|0;R(424,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function ZQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(819,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function YP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-8|0;R(924,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function YB(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;if(!((f-1^e-1)>>>0<32?e:0)){g=v[a>>2];v[(f>>>0<33?g:(f-1>>>3&536870908)+g|0)>>2]=0}Tn(d+8|0,a,e);kq(d+8|0,b,c);jb=d+16|0}function VR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(735,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function UB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(374,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Tw(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(2132,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function Tla(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Yb(128/(B(v[zf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[qh(c+7|0,c+6|0)|0];jb=c+16|0;return a|b<<4&240}function SR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-6|0;R(737,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function SQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2|0;R(826,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function OR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(738,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function OK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){a=v[a>>2];v[114578]=0;R(1527,a|0,b+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}}if(b){QK(b)}break a}V(0)|0;O()|0;Ab();L()}}}function HP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(950,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function GB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2|0;R(384,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function vT(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-1|0;R(32,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function cz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(984,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function cq(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(418,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function XD(a){var b=0,c=0;b=jb-16|0;jb=b;_k(a);v[b+12>>2]=1073741823;v[114578]=0;v[b+8>>2]=2147483647;a=Lb(b+12|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function WD(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(207,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function ME(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){lh(g+13|0,g+14|0)}h=c,i=(Ua(b|0,EA(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;jb=g+16|0}function Jp(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(696,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function Hz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(762,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function Gv(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(203,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function vs(a,b){a=lc(a,b,88);v[a+88>>2]=v[b+88>>2];lc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];lc(a+672|0,b+672|0,52);ey(a+724|0,b+724|0);ey(a+736|0,b+736|0);ey(a+748|0,b+748|0);lc(a+760|0,b+760|0,135)}function h4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a=v[a+24>>2];$r(d,0,c);v[114578]=0;U(646,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function SK(){var a=0;a:{b:{if(t[457176]&1){break b}if(!wd(457176)){break b}v[114578]=0;Q(1525,88472,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(457176)}return}a=P()|0;O()|0;pe(457176);S(a|0);L()}function Cba(){var a=0;a:{b:{if(t[85228]&1){break b}if(!wd(85228)){break b}v[114578]=0;T(100,85200)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(85228)}return 85200}a=P()|0;O()|0;pe(85228);S(a|0);L()}function By(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){mn(d);zN(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function bO(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=Kc(a);a:{if(d>>>0>=c>>>0){d=Tb(a);$l(d,b,c);t[e+15|0]=0;he(c+d|0,e+15|0);Sg(a,c);break a}f=d;g=c-d|0;d=Fb(a);Qu(a,f,g,d,0,d,c,b)}jb=e+16|0;return a}function KC(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=FC(v[a+16>>2],b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<5)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Jf(a,b,c,d,e){var f=0;f=jb-256|0;jb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Rb(f,b&255,d?c:256);if(!d){while(1){Qe(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}Qe(a,f,c)}jb=f+256|0}function HN(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=LN(v[a+16>>2],b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<5)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=bc(b);e=cc(b);b=jb-16|0;jb=b;v[b+8>>2]=e;v[b>>2]=d;if(Jb(b,b+8|0)){while(1){pN(c,w[v[b>>2]]);qg(b);if(Jb(b,b+8|0)){continue}break}}jb=b+16|0;return a|0}function Bh(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function Ac(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=TQ(c+16|0,Az(c+24|0,c+8|0));jb=c+32|0;return v[a>>2]}function $p(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;b=jb-16|0;jb=b;wq(b+8|0,c+15|0);d=Hb(b+8|0);e=ld(a,ac(b,b+8|0));if((d|0)==(e|0)){Xc(a,Hb(b+8|0))}jb=b+16|0;jb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function xS(a){var b=0,c=0;b=a+36|0;c=Hma(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}mb=a;return b}function pK(a){var b=0,c=0,d=0;if(jf(a)){while(1){b=a;d=c&65535;if(jf(b)>>>0>d>>>0){b=Ge(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;vK(b);Le(b+36|0)}c=c+1|0;if(jf(a)>>>0>(c&65535)>>>0){continue}break}}}function gP(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;if((w[a|0]|w[a+1|0]<<8)!=2?(w[a|0]|w[a+1|0]<<8)!=1:0){break a}b=1}return b}function Td(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=od(b)}return c}function e2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;wH(b,c,d,z[a+28>>2]);vH(a,b,c,d);b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;jb=e+16|0}function ZS(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=-1;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function Hga(a,b){a=a|0;b=b|0;a:{a=jb-16|0;jb=a;v[b>>2]=0;v[b+4>>2]=0;v[114578]=0;v[a+12>>2]=0;W(1026,b+8|0,a+12|0,a+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}}function UN(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[a+16|0]=0;c=Ey(b,v[a+12>>2]);v[114578]=0;U(1176,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){Dl(c);jb=b+32|0;return}a=P()|0;O()|0;Dl(c);S(a|0);L()}function OP(a){var b=0,c=0,d=0,e=0;mb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function $ha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=RB(a);if(d>>>0>=b>>>0){a=ft(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[bd(c+12|0,c+8|0)>>2]}jb=c+16|0;return d|0}ed();L()}function xL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(nb[v[v[b>>2]+112>>2]](b)|0)){break a}nb[v[v[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function Yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-16|0;jb=c;xf(a,c+14|0);Vz(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Fi(a,Pb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}Ox(b);jb=c+16|0}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=v[a>>2];b=(f=d,g=v[a+8>>2],h=ac(c+8|0,b),e=v[v[d>>2]+32>>2],nb[e](f|0,g|0,h|0)|0);v[a+8>>2]=b+v[a+8>>2];jb=c+16|0;return b|0}function rY(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=a;a=Ah(b+8|0,b+12|0);v[114578]=0;c=cF();d=v[114578];v[114578]=0;if((d|0)!=1){Ie(a);jb=b+16|0;return c|0}b=P()|0;O()|0;Ie(a);S(b|0);L()}function Bg(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[114578]=0;T(354,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ha(a|0,77224,265);L()}function jN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function bE(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;e=Ah(f+8|0,f+12|0);v[114578]=0;a=so(a,b,c,d);b=v[114578];v[114578]=0;if((b|0)!=1){Ie(e);jb=f+16|0;return a}a=P()|0;O()|0;Ie(e);S(a|0);L()}function tr(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return gw(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=gw(a)}return a}function tM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,896)+a|0)+1075088>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function li(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function QM(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1260,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function LZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-16|0;jb=b;c=a;a:{if(!Fe(f)){v[c+8>>2]=v[f+8>>2];a=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=a;break a}JD(a,v[f>>2],v[f+4>>2])}jb=b+16|0}function $f(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb+-64|0;jb=c;d=px(c+8|0,a);v[114578]=0;U(1584,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){ul(d);jb=c- -64|0;return}a=P()|0;O()|0;ul(d);S(a|0);L()}function qB(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(419,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function j4(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a=v[a+24>>2];$r(c,0,b);v[114578]=0;U(646,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function ht(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(932,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function gu(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(411,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function ez(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[114578]=0;W(936,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Uz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(706,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fA(a)>>>0<b>>>0){ed();L()}zb(a);c=b;if(c>>>0>715827882){Fc(12706);L()}c=sc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+B(b,6)|0,v[d>>2]=e;Ot(a,0)}function PM(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=OM(b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Du(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(357,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Ad(a,b){var c=0;if(x[a+24>>1]!=(b&65535)){u[a+22>>1]=x[a+22>>1]-1&127;if(x[a+20>>1]<128){u[a+20>>1]=x[a+20>>1]+1}c=(x[a+22>>1]<<2)+a|0;u[c+28>>1]=0;u[c+26>>1]=b-x[a+24>>1];u[a+24>>1]=b}}function lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(RB(a)>>>0<b>>>0){ed();L()}zb(a);b=(b-1>>>5|0)+1|0;c=b;if(b>>>0>1073741823){Fc(11804);L()}c=sc(c<<2,4);v[a+4>>2]=0;v[a>>2]=c;d=zb(a),e=b,v[d>>2]=e}function jy(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(94,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function f3(a){a=a|0;var b=0;a=a+24|0;b=MH(v[a>>2]);if(sj(Vb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074436>>1]}b=x[rc(Vb(v[a>>2]+484360|0),b)>>1];return(Kn(v[a>>2]+484344|0,b)?b:-1)|0}function dB(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(31,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Yg(a,b){var c=0,d=0;a=v[a>>2];b=Kd(b);c=b;d=a+16|0;if(Kb(d)>>>0>b>>>0){c=v[Pb(d,c)>>2]!=0}else{c=0}if(!c){a=ba(4)|0;Rm(a);v[a>>2]=71628;ha(a|0,71688,2562);L()}return v[Pb(a+16|0,b)>>2]}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Zm(a)>>>0<b>>>0){ed();L()}zb(a);c=b;if(c>>>0>1073741823){Fc(15551);L()}c=sc(c<<2,1);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<2)|0,v[d>>2]=e;mk(a,0)}function MA(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=192;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Zp(d,b);xg(a,v[d>>2],c);Zp(d,b);Rb(v[d>>2]+c|0,0,192-c|0);$b(a,v[d+12>>2]);jb=d+16|0}function wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Nu(a)>>>0<b>>>0){ed();L()}zb(a);c=b;if(c>>>0>536870911){Fc(20113);L()}c=sc(c<<3,8);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<3)|0,v[d>>2]=e;Mu(a,0)}function sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kq(a)>>>0<b>>>0){ed();L()}zb(a);c=b;if(c>>>0>268435455){Fc(20113);L()}c=sc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<4)|0,v[d>>2]=e;lm(a,0)}function m9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<xc(a)>>>0){a=nm(d,wc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=iv(c,a);Ib(a);e=b^1}jb=d+16|0;return e|0}function lx(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=VJ(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function ks(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=EK(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function fq(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=FB(b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<1)+f|0,v[g>>2]=h;jb=e+16|0;return a}function ZN(a,b,c,d){var e=0;e=jb-16|0;jb=e;d=Wh(e,a,d);a=zb(a);v[114578]=0;X(1170,a|0,b|0,c|0,d+4|0);a=v[114578];v[114578]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Un(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=SB(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function S6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(86224);if(!d){return 0}v[114578]=0;a=aa(1966,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function QG(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;if((b|0)>=1){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function MS(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=YA(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<4)+f|0,v[g>>2]=h;jb=e+16|0;return a}function IR(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=JR(b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,6)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Av(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Ah(e+8|0,e+12|0);v[114578]=0;a=ck(a,b,c);b=v[114578];v[114578]=0;if((b|0)!=1){Ie(d);jb=e+16|0;return a}a=P()|0;O()|0;Ie(d);S(a|0);L()}function y7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4296);if(!d){return 0}v[114578]=0;a=aa(1880,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function r7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4228);if(!d){return 0}v[114578]=0;a=aa(1893,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function m7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=1){ae(d+12|0,C(0));c=z[d+12>>2];if((b|0)==1){c=je(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;PI(a)}jb=d+16|0}function hN(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(1226,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function h7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(5048);if(!d){return 0}v[114578]=0;a=aa(1916,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function fK(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(1593,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4268);if(!d){return 0}v[114578]=0;a=aa(1639,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function d8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4296);if(!d){return 0}v[114578]=0;a=aa(1776,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Z6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4276);if(!d){return 0}v[114578]=0;a=aa(1943,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function U7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4280);if(!d){return 0}v[114578]=0;a=aa(1809,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function PV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Nu(a)>>>0<b>>>0){ed();L()}zb(a);c=b;if(c>>>0>536870911){Fc(11120);L()}c=sc(c<<3,1);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<3)|0,v[d>>2]=e;Mu(a,0)}function M7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4276);if(!d){return 0}v[114578]=0;a=aa(1833,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function KN(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(1197,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4304);if(!d){return 0}v[114578]=0;a=aa(1702,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Ih(a){var b=0,c=0,d=0,e=0;e=Gd(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=Gd(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function F7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4268);if(!d){return 0}v[114578]=0;a=aa(1856,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function B7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=4){ae(d+12|0,C(0));c=z[d+12>>2];if((b|0)==4){c=je(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;UI(a)}jb=d+16|0}function vC(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){return(w[a+7|0]-9&255)>>>0<7}return 0}function uba(a){a=a|0;var b=0,c=0,d=0,e=0;v[a>>2]=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;b=a+9|0;e=b+20|0;while(1){ff(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}jb=d+16|0;jb=c+16|0;zg(a);return a|0}function pP(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(993,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function nB(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(421,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function KR(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function Fi(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=0;a=Wk(a,c+12|0,4);v[c+8>>2]=v[c+12>>2];d=b;b=c+8|0;v[d>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);jb=c+16|0;return!mb&(a|0)==4}function Af(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=a;a:{if(!Fe(b)){v[c+8>>2]=v[b+8>>2];e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;break a}gp(a,v[b>>2],v[b+4>>2])}jb=d+16|0;return a|0}function fx(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){b=_o(d)^b;if(a>>>0<=16){a=a+15|0;b=b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function SD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}_k(a);v[114578]=0;c=c-4|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function CO(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function yD(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function lF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function CV(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;bo(a);v[a>>2]=77024;v[114578]=0;W(281,a+12|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Aaa(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Jj(a,b+8|0)){break a}c=0;if(!KK(b+8|0)){break a}c=b;a=bP(a,b);if(!a){PR(c)}c=-1;if(!a){break a}c=JK(b)}jb=b+16|0;return c|0}function Vv(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Vd(a,b){var c=0;a:{c=$e(b);if((c|0)==(Fb(a)|0)){v[114578]=0;a=ea(346,a|0,0,-1,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Ab();L()}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((oh(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}lc(a+4260|0,c,oh(b));es(a)}}function S8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=jb-16|0;jb=d;e=d,f=C(C(nb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;ae(d+12|0,C(0));nb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);jb=d+16|0}function OY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(y[c>>2]>127){break b}if(!(x[mo()+(v[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function Ho(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Nd(b),v[d+12>>2]=e;v[114578]=0;W(2003,a|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function Go(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Nd(b),v[d+12>>2]=e;v[114578]=0;W(2163,a|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function qz(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;b=w[b|0]|w[b+1|0]<<8;a=a+22|0;a=w[a|0]|w[a+1|0]<<8;return c+(((b<<8|b>>>8)&65535)>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}function av(a){var b=0,c=0;a:{c=WD(Pe(12));b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(268,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}}function QY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=d;if(y[b>>2]<=127){e=x[mo()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;continue}break}return c|0}function Lh(a){var b=0;a=je(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Gp(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Nd(b),v[d+12>>2]=e;v[114578]=0;W(725,a|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function yz(a,b){var c=0;a:{if(b){yz(a,v[b>>2]);yz(a,v[b+4>>2]);a=hc(a);v[114578]=0;R(823,a|0,b+14|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}Yi(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function pl(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Kb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Kb(c)<<16)-65536>>16<(b|0)){break a}d=z[Pb(c,b-u[a+28>>1]|0)>>2]}return d}function ii(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function eu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;HA(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){IA(b)}return a|0}function et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;JP(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){KP(b)}return a|0}function bu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;_t(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){JA(b)}return a|0}function _C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;LC(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){MC(b)}return a|0}function PA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Yt(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){CA(b)}return a|0}function It(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;cA(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){TS(b)}return a|0}function I$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Ar(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;lc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function Gu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;tq(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){oC(b)}return a|0}function Bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;LR(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){MR(b)}return a|0}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;iB(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){jB(b)}return a|0}function $C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;NC(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){OC(b)}return a|0}function yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+8>>2]=b;d=c,e=bc(a),v[d>>2]=e;b=qt(c+8|0,c);b=v[a>>2]+(b<<2)|0;zu(a,gf(b+4|0,v[a+4>>2],b));a=Ng(b);jb=c+16|0;return a|0}function u6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=rI(f,b,c,d,0,0,0,0,e);jb=f+16|0;return a|0}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}ad(a,8,1,0,11);return}d=a;a=b+31|0;ad(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function AI(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=ze(31415.926535897932/+b);d=nn((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function tv(a,b,c,d,e){var f=0;f=uv(a,b,c,d);if(Jd(e,d)){Zb(d,e);if(!Jd(d,c)){return f+1|0}Zb(c,d);if(!Jd(c,b)){return f+2|0}Zb(b,c);if(!Jd(b,a)){return f+3|0}Zb(a,b);f=f+4|0}return f}function km(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=jb-16|0;jb=b;Zw(b,c);v[114578]=0;U(13,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function Yu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];b=(f=d,g=Db(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],nb[e](f|0,g|0,h|0,i|0)|0);v[a+8>>2]=b+v[a+8>>2];return b|0}function Sv(a,b,c,d,e,f,g,h,i){var j=0;j=jb-16|0;jb=j;_f(j,b,c,d,e,f,g,h,i^-2147483648);b=v[j+4>>2];v[a>>2]=v[j>>2];v[a+4>>2]=b;b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;jb=j+16|0}function pI(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114578]=0;T(2017,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(a|0,83324,2018);L()}function Yw(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114578]=0;T(2029,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(a|0,83336,2018);L()}function Sy(a){var b=0;if(v[a>>2]){we(a,v[a>>2]);b=v[a>>2];a=(v[zb(a)>>2]-v[a>>2]|0)/9|0;v[114578]=0;U(25,b|0,B(a,9)|0,1);a=v[114578];v[114578]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function Ab(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){a=v[115883];if(!a){break a}if(!DD(a+48|0)){break a}CD(v[a+12>>2]);L()}V(0)|0;O()|0;Ab();L()}CD(v[21294]);L()}function yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=nb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function wI(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=vI(f,b,c,d,e,0,0,0,0);jb=f+16|0;return+c}function um(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sE(a);if(d>>>0<=b>>>0){a=lg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function nK(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=iK(a);if(d>>>0<=b>>>0){a=lj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function em(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=GC(a);if(d>>>0<=b>>>0){a=th(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function Ri(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=bC(a);if(d>>>0<=b>>>0){a=Vf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function OX(){var a=0;a:{if(t[462904]&1){break a}if(!wd(462904)){break a}a=462880;while(1){a=Wb(a)+12|0;if((a|0)!=462904){continue}break}vd(462904)}Mc(462880,70296);Mc(462892,70299)}function Lq(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=Kq(a);if(d>>>0<=b>>>0){a=Yh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function LX(){var a=0;a:{if(t[462936]&1){break a}if(!wd(462936)){break a}a=462912;while(1){a=tf(a)+12|0;if((a|0)!=462936){continue}break}vd(462936)}_c(462912,70304);_c(462924,70316)}function LV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;Cq(v[d+8>>2]);b=jb-16|0;jb=b;v[b+8>>2]=v[d>>2];PC(a,wh(b,v[b+8>>2]));jb=b+16|0;jb=d+16|0;return a|0}function Ki(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ZS(a);if(d>>>0<=b>>>0){a=yf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function Iz(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=fA(a);if(d>>>0<=b>>>0){a=Li(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function Hk(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=tT(a);if(d>>>0<=b>>>0){a=We(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function Be(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=Zm(a);if(d>>>0<=b>>>0){a=yd(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}ed();L()}function $aa(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function tA(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(zq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}jb=b+16|0;return c|0}function i2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=v[d>>2];while(1){v[a>>2]=v[b>>2];Af(a+4|0,b+4|0);a=v[d>>2]+16|0;v[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function br(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Fb(b);if(d>>>0<c>>>0){qm();L()}b=Tb(b);v[e+4>>2]=d-c;gp(a,b+c|0,v[Lb(e+12|0,e+4|0)>>2]);jb=e+16|0}function _ka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Us(c,b);v[114578]=0;U(646,a|0,4,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function Jka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;iS(b,c,32);hS(a,c);jb=c+32|0}function JK(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function AD(a,b,c,d){var e=0,f=0,g=0,h=0;f=v[a+4>>2];a=v[a>>2];g=a;h=b;e=0;a:{if(!c){break a}b=f>>8;e=b;if(!(f&1)){break a}e=v[b+v[c>>2]>>2]}nb[v[v[a>>2]+28>>2]](g,h,e+c|0,f&2?d:2)}function vi(a){a=a|0;var b=0,c=0,d=0,e=0;while(1){c=a;e=d&65535;b=e;if(b>>>0<=126){zg(((b<<5)+c|0)+480280|0);qn((B(b,896)+c|0)+1074984|0,c,b)}d=d+1|0;if(e>>>0<126){continue}break}}function i$(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;jj(b,0,a);v[114578]=0;a=T(202,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);jb=b+16|0;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function TS(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;jb=b+16|0}function iz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;d=a,e=(g=a,h=v[a+12>>2],i=ac(c+8|0,b),f=v[v[a>>2]+32>>2],nb[f](g|0,h|0,i|0)|0)+v[a+12>>2]|0,v[d+12>>2]=e;jb=c+16|0}function IA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;jb=b+16|0}function v_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;a=dj(a,b,c,d,e,f,g+8|0,g+16|0);jb=g+16|0;return a|0}function qO(a,b){var c=0;c=w[a+822|0];a:{if(c){break a}c=Aj(w[a+819|0]-v[a+772>>2]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[fc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function Xk(a){var b=0,c=0;b=v[21296];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>ob()<<16>>>0){if(!(Qa(a|0)|0)){break a}}v[21296]=a;return b}v[114552]=48;return-1}function PY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(y[c>>2]>127){break a}if(!(x[mo()+(v[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function PP(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}return w[a+4|0]>95}return 0}function O$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=v[c+4>>2];c=v[c>>2];v[d>>2]=c;v[d+4>>2]=e;v[d+8>>2]=c;v[d+12>>2]=e;TF(a,d,b);v[a>>2]=59028;jb=d+16|0;return a|0}function xf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;u[c+14>>1]=0;a=Wk(a,c+14|0,2);u[c+12>>1]=x[c+14>>1];d=b;b=c+12|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;jb=c+16|0;return!mb&(a|0)==2}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;rz(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+8|0,d+12|0)>>2]}jb=d+16|0;return c|0}function hv(a,b){var c=0,d=0;c=jb-16|0;jb=c;u[b>>1]=0;t[c+15|0]=0;Wg(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Wg(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}jb=c+16|0}function fw(a,b){var c=0;c=Sr(a+4|0);v[a>>2]=58852;v[c>>2]=58872;v[114578]=0;R(2314,v[14710]+a|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){return}a=P()|0;O()|0;ah(c);S(a|0);L()}function ew(a,b){var c=0;c=bG(a+4|0);v[a>>2]=58900;v[c>>2]=58920;v[114578]=0;R(2315,v[14722]+a|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){return}a=P()|0;O()|0;ah(c);S(a|0);L()}function KS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(pd(a+44|0,12960,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Gb(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(Fe(a)){pg(a,v[a>>2],hk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;of(b,0);t[c+15|0]=0;he(b,c+15|0);jb=c+16|0}function F0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;nb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(ve(v[a+4>>2],v[c+4>>2])){a=v[a>>2]==v[c>>2]}else{a=0}jb=d+16|0;return a|0}function mK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!dg(a,b)){break a}c=nx(a,v[Ge(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=Ge(a,b);uK(Ge(a,c),b);d=c}return d|0}function jw(a,b,c){var d=0;a:{d=jb-16|0;jb=d;Vr(d,b,c);v[114578]=0;U(13,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function hr(a,b,c){var d=0;a:{d=jb-16|0;jb=d;Xw(d,b,c);v[114578]=0;U(13,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function ai(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(Fe(a)){lo(v[a>>2],hk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;of(b,0);v[c+12>>2]=0;Te(b,c+12|0);jb=c+16|0}function PK(a,b,c){a=jb-16|0;jb=a;Hh(a+8|0,c);v[114578]=0;b=Q(1530,b|0,a+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}return b>>>31|0}function Hs(a,b,c){a=jb-16|0;jb=a;Hh(a+8|0,c);v[114578]=0;b=Q(1061,b|0,a+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}return b>>>31|0}function $t(a,b,c){var d=0;a:{d=jb-16|0;jb=d;eI(d,b,c);v[114578]=0;U(13,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;wH(b,c,d,z[a+24>>2]);rH(a,b,c,d);v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;jb=e+16|0}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Kb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=bK(a,b,c,d+8|0);jb=d+16|0;return a|0}function Ax(a,b){a:{if(b){Ax(a,v[b>>2]);Ax(a,v[b+4>>2]);a=hc(a);v[114578]=0;R(1527,a|0,b+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}QK(b)}return}V(0)|0;O()|0;Ab();L()}function U6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=hn(C(C(C(Se(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;II(a);HI(a)}function Jy(a,b,c,d,e){var f=0;a:{if(!d){break a}f=1;while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;if((d|0)==(f|0)){break a}c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;continue}}}function uha(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=ad(d,w[a|0]&4?16:8,1,0,0);a:{b:{if(w[a|0]&8){break b}c=2;if(w[a|0]&16){break b}if(w[a|0]&127){break a}}Vl(b,c)}}function gE(a){a=a|0;var b=0,c=0;v[a>>2]=64704;b=a+16|0;while(1){if(Kb(b)>>>0>c>>>0){if(v[Pb(b,c)>>2]){gm(v[Pb(b,c)>>2])}c=c+1|0;continue}break}yb(a+176|0);vE(b);return a|0}function gD(a){var b=0;a:{if(!(y[a>>2]<=18285140|y[a>>2]>=18350592)){b=1;if(v[a>>2]!=18350080){break a}}a=v[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function bR(a,b){var c=0;c=jb-32|0;jb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=TQ(c+16|0,Az(c+24|0,c+8|0));jb=c+32|0;return v[a>>2]}function TH(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2170,a|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}
function yba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];c=v[a+8>>2];c=x[c>>1]|x[c+2>>1]<<16;u[b+4>>1]=0;u[b>>1]=c;u[b+2>>1]=c>>>16;jb=a+16|0}function yQ(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;mQ(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){nQ(b)}return a}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=c,e=iT(bc(a),cc(a),c+12|0),v[d+8>>2]=e;d=c,e=cc(a),v[d>>2]=e;a=Jb(c+8|0,c);jb=c+16|0;return a|0}function sC(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;tq(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){oC(b)}return a}function oz(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;kQ(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){lQ(b)}return a}function oT(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Lt(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){bT(b)}return a}function oG(a){var b=0,c=0,d=0;a:{if(!bh(t[v[a>>2]])){break a}while(1){c=v[a>>2];d=t[c|0];v[a>>2]=c+1;b=(b+d|0)-48|0;if(!bh(t[c+1|0])){break a}b=B(b,10);continue}}return b}function lR(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;_Q(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){$Q(b)}return a}function lA(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Lt(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){bT(b)}return a}function eA(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;cA(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){TS(b)}return a}function aP(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;ES(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){FS(b)}return a}function Zz(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;ES(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){FS(b)}return a}function SH(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2171,a|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function RH(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2172,a|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function QP(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;JP(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){KP(b)}return a}function Jj(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Ju(c+8|0,b);d=Hb(c+8|0);e=ld(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){AC(b)}return a}function Ep(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){xn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ug(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;xn(a,c)}function Dp(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){xn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ug(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;xn(a,c)}function $3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Uc(a+12|0,0,0);d=a+20|0;c=d;e=c+16|0;while(1){c=Ek(c)+4|0;if((e|0)!=(c|0)){continue}break}nL(d+16|0,b);v[a+40>>2]=1;return a|0}function jo(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=Hma(a,0,b,0);e=mb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=od(b);if(!(!a|!(w[a-4|0]&3))){Rb(a,0,b)}return a}function j0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Gf(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){lr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function W$(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Gf(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){FF(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function VL(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function M$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=oo(d,a);fE(a,c);v[114578]=0;R(2375,b|0,1);a=v[114578];v[114578]=0;if((a|0)==1){a=P()|0;O()|0;Ob(d);S(a|0);L()}}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=nb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pA(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;cm(a+8|0,c);return a}function n8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=0;d=c+12|0;t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;a=lJ(a,c+12|0);jb=c+16|0;return a|0}function Rx(a,b){var c=0;c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=b;W(1433,a|0,c+12|0,c+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function MY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Wq()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;continue}break}return c|0}function KY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Vq()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;continue}break}return c|0}function xM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];ly(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}jb=d+16|0}function nM(a,b){var c=0,d=0,e=0;c=Tb(a);a=Fb(a);d=Tb(b);e=Fb(b);a=a+c|0;b=-1;a:{while(1){if((a|0)==(c|0)){break a}a=a-1|0;if(_n(d,e,a)){continue}break}b=a-c|0}return b}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Oi(a+8|0);v[114578]=0;U(423,a|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Pg(d);S(a|0);L()}}function ye(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[hc(a)>>2];v[114578]=0;Z(a|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function eba(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[114578]=0;a=Q(1427,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function TU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;Zc(a+8|0,d+12|0,d+8|0);if(b){lq(a,b);YB(a,b,w[c|0])}jb=d+16|0;return a|0}function RG(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function N2(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((sj(Vb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[rc(Vb(v[a>>2]+484360|0),b)>>1]}return c|0}function Br(a){var b=0,c=0;b=a;a:{if((Ae(b)|0)!=79){break a}if((Ae(b)|0)!=103){break a}if((Ae(b)|0)!=103){break a}c=(Ae(b)|0)==83}if(!c){dc(a,30);return 0}return GG(a)}function wma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=zT(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function ui(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function pd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function U1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=v[d>>2];while(1){Mz(a,e,b);e=v[d>>2]+12|0;v[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=mt(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Js(c+12|0,c+8|0,32408)>>2],v[d+36>>2]=e;Mo(a);jb=c+16|0}function via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;rz(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function mV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function eU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=GA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function dU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=FA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function cU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=DA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function aq(a,b){var c=0;c=jb-16|0;jb=c;jb=c+16|0;return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function Qx(a){var b=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(1434,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function J6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}yI(a,i,h,g,e,f,b,c,d)}function Fo(a){var b=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2177,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function E8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=kj(a);if(a){a=(e=a,f=wh(c+8|0,b),d=v[v[a>>2]+72>>2],nb[d](e|0,f|0)|0)}else{a=1}jb=c+16|0;return a|0}function yO(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function b1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a=vr(Fa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);jb=e+16|0;mb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function GV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function FP(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function EY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=t[b|0];if((a|0)>=0){a=v[Wq()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;continue}break}return c|0}function CY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=t[b|0];if((a|0)>=0){a=v[Vq()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;continue}break}return c|0}function jl(a){a=a>>>1&1431655765|a<<1&-1431655766;a=a>>>2&858993459|a<<2&-858993460;a=a>>>4&252645135|a<<4&-252645136;return Lma(a>>>8&16711935|a<<8&-16711936,16)}function jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=Rp(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Zo(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(!(v[a+480208>>2]&16)){break a}Eb(b+8|0,a+1074312|0,7);if(!Cb(b+8|0)){break a}c=v[a+480180>>2]!=4}jb=b+16|0;return c}function UG(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Cg(b),d=v[v[a>>2]+52>>2],nb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Cg(b)}function Pe(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=od(a);if(b){break a}b=v[115885];if(b){nb[b|0]();continue}break}a=ba(4)|0;Yk(a);ha(a|0,71204,2009);L()}return b|0}function Jr(a,b,c,d){var e=0;a:{if(d==C(1)){break a}c=B(b,c);if(!c){break a}e=+d;b=1;while(1){A[a>>3]=A[a>>3]*e;if((b|0)==(c|0)){break a}a=a+8|0;b=b+1|0;continue}}}function EZ(){var a=0,b=0;a:{Ld(462992);v[115748]=64776;v[114578]=0;a=da(2453)|0;b=v[114578];v[114578]=0;if((b|0)!=1){v[115750]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=v[a>>2];a=(f=d,g=v[a+8>>2],h=ac(c+8|0,b),e=v[v[d>>2]+32>>2],nb[e](f|0,g|0,h|0)|0);jb=c+16|0;return a}function nP(a,b){var c=0,d=0,e=0;c=pP(a,zb(b));v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[zb(b)>>2];d=zb(c),e=a,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Zba(a){a=C(a);var b=0;a=je(a);b=65535;a:{if(!(a<C(65535))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function Xu(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c>>2]=v[b>>2];d=c,e=v[b>>2]+wC(b)|0,v[d+4>>2]=e;b=jb-16|0;jb=b;Nq(a,v[c>>2],v[c>>2]+wC(c)|0);jb=b+16|0;jb=c+16|0}function Pr(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Rb(a+32|0,0,40);Cv(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function HL(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;gN(a+112|0,48e3);v[a+668>>2]=0;Nx(a+724|0);Nx(a+736|0);Nx(a+748|0);Qh(a+810|0);return a}function Dca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jn(a);v[114578]=0;U(91,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;oe(d);S(a|0);L()}function $b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Qb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function rp(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function iX(a,b){a=a|0;b=b|0;Rm(a);v[a>>2]=71244;b=Tb(b);v[114578]=0;Q(2838,a+4|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function OW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=v[c>>2];a=nb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}jb=d+16|0;return a|0}function BB(a){var b=0,c=0;a:{if(pd(a,12061,3)){break a}b=a+3|0;if(w[b|0]<8|w[b|0]>14){break a}a=a+40|0;if(!(w[b|0]>9?w[a|0]<33?w[a|0]:0:1)){break a}c=1}return c}function tf(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;W(114,a|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Sm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function gia(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-80|0;jb=d;c=-1;a:{if(!oT(a,d+8|0)){break a}c=0;if(!WP(d+8|0)){break a}c=df(a,b,VP(d+8|0),mb)}jb=d+80|0;return c|0}function $q(a){a=a|0;var b=0;b=ba(8)|0;v[114578]=0;Q(2063,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ha(b|0,71532,265);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function z0(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){UF();c=85168;break a}b:{if(t[461436]&1){break b}if(!wd(461436)){break b}vd(461436)}c=85164}Uc(a,b,c)}function st(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!ug(a)){while(1){a=v[a+8>>2];if(!ug(a)){continue}break}}a=v[a+8>>2];break a}a=UQ(b)}v[c>>2]=a}function nJ(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Lb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);jb=c+16|0}function Wb(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;W(14,a|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Sm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Rd(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=b;v[114578]=0;ro(a,d+12|0,c);b=v[114578];v[114578]=0;if((b|0)!=1){jb=d+16|0;return a}V(0)|0;O()|0;Ab();L()}function Qn(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function zw(a,b){var c=0;c=jb-16|0;jb=c;v[114578]=0;W(150,a|0,c+8|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Sm(a);jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function tQ(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;mQ(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;if((d|0)!=(e|0)){nQ(b)}}function fd(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;W(1,a|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Sm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function aF(a,b){var c=0;c=jb-16|0;jb=c;v[114578]=0;W(197,a|0,c+8|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Sm(a);jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function Jma(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;Fma(e-d|0,(b^a)-((d>>>0>e>>>0)+a|0)|0,c,0);mb=lb;b=d^kb;c=b-d|0;mb=(a^mb)-((b>>>0<d>>>0)+a|0)|0;return c}function J2(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=Af(a,b);v[114578]=0;Q(120,a+12|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function GO(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;v[a>>2]=v[a>>2]+(b>>>3&536870908);break a}b=b+c|0;v[a>>2]=v[a>>2]+((b-31|0)/32<<2)}v[a+4>>2]=b&31}function Ct(a){var b=0;b=jb-16|0;jb=b;Uc(b+8|0,a,0);v[114578]=0;U(670,b+8|0,110,0);a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function w$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function Nla(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4}function HI(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function z$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function xg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];return(f=d,g=Db(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],nb[e](f|0,g|0,h|0,i|0)|0)|0}function n_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return cj(g,b,c,d,e,f,Tb(a),Tb(a)+(Fb(a)<<2)|0)|0}function jd(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}t[c+15|0]=0;Xf(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}jb=c+16|0;return d}function QB(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}t[c+15|0]=0;Xf(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}jb=c+16|0;return d}function O8(a,b){a=a|0;b=b|0;var c=0;AJ(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mf(a);jk(a);jk(a)}function uu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[pc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;jb=d+16|0}function tu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[pc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;jb=d+16|0}function Rka(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Qb(a,12);a:{if(d){cA(c+8|0,b);Bd(a,c+8|0);break a}t[c+7|0]=0;Sh(b,12,c+7|0)}jb=c+16|0;return d|0}function OC(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;jb=b+16|0}function tk(a,b){var c=0,d=0;a:{b=uk(a,b);if((b|0)==255){break a}if(rj(a)){break a}c=a+4|0;d=fc(c,b);t[d|0]=w[d|0]&223;hh(v[a>>2],Ms(b)|176,w[fc(c,b)|0])}}function pY(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[114578]=0;a=T(2574,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Ab();L()}function nV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function b$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=Ah(e,e+12|0);a=kF(a,c,v[e+8>>2]);Ie(b);jb=e+16|0;return a|0}function M2(a,b){a=a|0;b=b|0;var c=0;a:{if(!Nr(b)){break a}a=a+24|0;if(!dg(v[a>>2]+484344|0,b&65535)){break a}c=v[_b(v[a>>2]+484344|0,b)+12>>2]}return c|0}function JM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=ep(a,x[b+60>>1],v[b+48>>2],c,0)}return d|0}function Dh(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Cja(a,b){a=a|0;b=b|0;var c=0;a=oR(a,b);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;jb=c+16|0}return a|0}function Ai(a){var b=0;a=je(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function vl(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[a+1074400>>2];d=v[a+1074416>>2];v[b+12>>2]=1;a=v[bd(a+1074396|0,b+12|0)>>2];jb=b+16|0;return B(a,c+d|0)}function V6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=2){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];II(a)}jb=d+16|0}function Uo(a,b){var c=0;v[a>>2]=76544;v[a>>2]=76960;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;return a}function Q7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=5){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];aJ(a)}jb=d+16|0}function O6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=3){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];GI(a)}jb=d+16|0}function Lf(a,b,c){a:{switch(b-1|0){case 0:if(c){return xi(a,1)}return xi(a,0);case 1:if(c){return xi(a,3)}return xi(a,2);default:break a}}return xi(a,4)}function Ir(a){var b=0,c=0,d=0;b=Lma(v[a>>2],1)^270549120;c=v[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;v[a>>2]=d;b=a;a=B(Lma(d,16),5)+c|0;v[b+4>>2]=a;return a}function I7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=4){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];XI(a)}jb=d+16|0}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ED(a,b){a=a|0;b=b|0;Rm(a);v[a>>2]=71244;v[114578]=0;Q(2838,a+4|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=3){c=PB(a,b);break a}c=Cf(a);$b(a,b-4|0)}v[d>>2]=c}function Bw(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+43568>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=1){c=OB(a,1);break a}c=hg(a);$b(a,b-2|0)}u[d>>1]=c}function $i(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=jv(a,e,d);break a}a=jv(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function wp(a,b,c){var d=0;d=b;b=w[a|0]|w[a+1|0]<<8;if((d|0)<=((b<<8|b>>>8)&65535)){a=w[a|0]|w[a+1|0]<<8;a=((a<<8|a>>>8)&65535)<=(c|0)}else{a=0}return a}function Zi(a){var b=0;b=ba(8)|0;v[114578]=0;Q(214,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ha(b|0,71464,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function W0(a,b){a=a|0;b=b|0;var c=0,d=0;b=dw(b);v[a+36>>2]=b;c=a,d=$m(b),v[c+44>>2]=d;c=a,d=Fm(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){$q(55808);L()}}function S0(a,b){a=a|0;b=b|0;var c=0,d=0;b=cw(b);v[a+36>>2]=b;c=a,d=$m(b),v[c+44>>2]=d;c=a,d=Fm(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){$q(55808);L()}}function Jm(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=od(b)}return c}function Dm(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114578]=0;b=v[(b+c|0)+24>>2];c=v[114578];v[114578]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function zba(a,b){a=a|0;b=b|0;var c=0;dm(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Aq(a,xe(a))}function u_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return dj(g,b,c,d,e,f,Tb(a),Tb(a)+Fb(a)|0)|0}function tN(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function hia(a,b){a=a|0;b=b|0;var c=0;Dq(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Mu(a,Dg(a))}function eka(a,b){a=a|0;b=b|0;var c=0;Mt(a);c=b+4|0;GR(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Ot(a,cg(a))}function eZ(){var a=0;a:{Ld(463216);v[114578]=0;T(2558,463224)|0;a=v[114578];v[114578]=0;if((a|0)!=1){v[115804]=67580;break a}a=P()|0;O()|0;S(a|0);L()}}function cZ(){var a=0;a:{Ld(463232);v[114578]=0;T(2558,463240)|0;a=v[114578];v[114578]=0;if((a|0)!=1){v[115808]=67736;break a}a=P()|0;O()|0;S(a|0);L()}}function Qc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(nb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function HY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Fc(a){var b=0;b=ba(8)|0;v[114578]=0;Q(23,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ha(b|0,71412,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function vd(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;a=rv(b,a);c=jb-16|0;jb=c;d=v[Oc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;jb=c+16|0;jb=b+16|0}function rX(a,b){a=a|0;b=b|0;var c=0;jE(a);c=b+4|0;Nh(_k(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(Tq(a),ec(b));v[b>>2]=v[b+4>>2];UD(a,Kb(a))}function rW(a,b){a=a|0;b=b|0;var c=0;Vk(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];lm(a,nd(a))}function ku(a,b){a=a|0;b=b|0;var c=0;Qk(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Bu(a,oc(a))}function fh(a,b){a=a|0;b=b|0;var c=0;vf(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mk(a,Kb(a))}function du(a,b){a=a|0;b=b|0;var c=0;Ol(a);c=b+4|0;Nh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];iA(a,xc(a))}function Eh(a,b,c){v[b+12>>2]=v[b+12>>2]+c;v[b+8>>2]=v[b+8>>2]-c;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function zq(a,b){var c=0,d=0;c=jb-16|0;jb=c;vh(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function zY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function zL(a){if(v[a+480224>>2]==2){return+y[a+1074420>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))}function sia(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Cf(b);Cf(b);break a}a=hg(b);hg(b)}if(a){while(1){if(a&1){$b(b,260)}a=a>>>1|0;if(a){continue}break}}}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Rb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function r2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Rb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function oR(a,b){var c=0,d=0;c=jb-16|0;jb=c;aA(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(sE(a)>>>0<b>>>0){ed();L()}zb(a);c=OM(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=B(b,12)+c|0,v[d>>2]=e;po(a,0)}function nq(a,b){var c=0,d=0;c=jb-16|0;jb=c;Ok(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function ld(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a=(e=a,f=v[a+12>>2],g=ac(c+8|0,b),d=v[v[a>>2]+32>>2],nb[d](e|0,f|0,g|0)|0);jb=c+16|0;return a}function jX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=$e(b);d=Pe(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=lc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function bP(a,b){var c=0,d=0;c=jb-16|0;jb=c;vh(c+8|0,b);b=Hb(c+8|0);d=ld(a,ac(c,c+8|0));if((b|0)==(d|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function Xf(a,b){var c=0,d=0;c=jb-16|0;jb=c;wq(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function Rk(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114578]=0;b=T(27,b+c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Zm(a)>>>0<b>>>0){ed();L()}zb(a);c=IP(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;mk(a,0)}function Ku(a,b){var c=0,d=0;c=jb-16|0;jb=c;Ju(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function sB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Zm(a)>>>0<b>>>0){ed();L()}zb(a);c=EK(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;mk(a,0)}function qU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kq(a)>>>0<b>>>0){ed();L()}zb(a);c=YA(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<4)+c|0,v[d>>2]=e;lm(a,0)}function pQ(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878?(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165:0}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Kq(a)>>>0<b>>>0){ed();L()}zb(a);c=BH(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<4)+c|0,v[d>>2]=e;lm(a,0)}function iha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!QP(a,d)){break a}c=0;if(!gP(d)){break a}c=df(a,b,fP(d),mb)}jb=d+96|0;return c|0}function gz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(bC(a)>>>0<b>>>0){ed();L()}zb(a);c=FB(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<1)+c|0,v[d>>2]=e;Bu(a,0)}function gS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fA(a)>>>0<b>>>0){ed();L()}zb(a);c=JR(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=B(b,6)+c|0,v[d>>2]=e;Ot(a,0)}function bha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!aP(a,d)){break a}c=0;if(!$O(d)){break a}c=df(a,b,_O(d),mb)}jb=d+48|0;return c|0}function ZY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(XD(a)>>>0<b>>>0){ed();L()}c=VD(_k(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Tq(a),e=(b<<2)+c|0,v[d>>2]=e;UD(a,0)}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!QP(a,d)){break a}c=0;if(!PP(d)){break a}c=df(a,b,OP(d),mb)}jb=d+96|0;return c|0}function Wba(a){a=+a;var b=0;a=Sd(a);b=65535;a:{if(!(a<65535)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function Mm(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<1);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Le(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(Fe(a)){c=v[a>>2];t[b+15|0]=0;he(c,b+15|0);we(a,0);break a}t[b+14|0]=0;he(a,b+14|0);of(a,0)}jb=b+16|0}function Fga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!aP(a,d)){break a}c=0;if(!QO(d)){break a}c=df(a,b,PO(d),mb)}jb=d+48|0;return c|0}function Do(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<2);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function $L(a){var b=0;a=je(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function QW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(kg(a,v[b+8>>2],f)){mv(b,c,d,e);return}a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function Cv(a){var b=0,c=0;v[114578]=0;c=da(2564)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;hm(a);return}V(0)|0;O()|0;Ab();L()}function zy(a,b,c){var d=0,e=0,f=0;d=uk(a,b);if((d|0)!=255){e=dd(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=fc(a,b),f=255,t[e|0]=f;e=fc(a,c),f=d,t[e|0]=f}}function w0(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;nb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function u2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;gp(a,v[c+8>>2],v[c+12>>2]);jb=c+32|0;return a|0}function kw(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function H2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-32|0;jb=h;IH(h+8|0,b,c,d,e,f,g);td(a,h+20|0);kn(h+8|0);jb=h+32|0}function Baa(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){ad(a,8,1,0,11);return}c=a;a=b+14|0;ad(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function uv(a,b,c,d){var e=0;e=rm(a,b,c);if(Jd(d,c)){Zb(c,d);if(!Jd(c,b)){return e+1|0}Zb(b,c);if(!Jd(b,a)){return e+2|0}Zb(a,b);e=e+3|0}return e}function tD(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+256|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function hQ(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+512|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function PI(a){var b=0;b=(Se(v[a+16>>2])>>>0)/(Ai(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;Cc(a+4224|0,b)}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;wy(a,A[c>>3])}function I2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-32|0;jb=h;IH(h+8|0,b,c,d,e,f,g);td(a,h+8|0);kn(h+8|0);jb=h+32|0}function DM(a,b){var c=0,d=0;c=lc(a,b,602);a=0;while(1){d=B(a,896);vs((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function xba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];f=A[v[a+8>>2]>>3];v[b+8>>2]=0;A[b>>3]=f;jb=a+16|0}function gw(a){var b=0,c=0;b=jb-16|0;jb=b;c=-1;a:{if(gG(a)){break a}if((nb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}jb=b+16|0;return c}function ZP(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+32|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function Wg(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;t[c+15|0]=0;a=Wk(a,c+15|0,1);t[c+8|0]=w[c+15|0];t[b|0]=w[c+8|0];jb=c+16|0;return!mb&(a|0)==1}function Bo(a,b){var c=0;a:{if(!RG(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function wC(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(288,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function u0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;Pr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function pt(a){a=+a;var b=0;a=Sd(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function kv(a,b,c,d,e,f){var g=0,h=0,i=0;g=v[a+4>>2];h=g>>8;a=v[a>>2];i=a;if(g&1){h=v[v[d>>2]+h>>2]}nb[v[v[a>>2]+20>>2]](i,b,c,d+h|0,g&2?e:2,f)}function hp(a){var b=0,c=0,d=0;c=w[a+30|0];d=Mh(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Vb(b)}return Di(b,w[a+30|0])}function cha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;xu(d+8|0,a);vu(c,d+8|0);jb=d+16|0;a=uf(c,b);yb(c);jb=c+16|0;return a|0}
function ama(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;u[b+14>>1]=1;c=b,d=St(a),u[c+12>>1]=d;a=x[Si(b+14|0,b+12|0)>>1];jb=b+16|0;return a-1&65535}function Tm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function Ip(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(ZS(a)>>>0<b>>>0){ed();L()}zb(a);c=$h(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=b+c|0,v[d>>2]=e;iA(a,0)}function Fla(a,b){a=a|0;b=b|0;var c=0;a=ad(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(w[b|0]&64)){c=0;if(!(w[b|0]&2)){break a}}Vl(a,c)}if(w[b|0]&4){dA(a)}}function FR(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+4|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function CQ(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(883,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function yk(a){var b=0;a=Sd(a);b=-1;a:{if(!(a<4294967295)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function oh(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(29,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function mga(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24}function Hb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(34,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function BG(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function KI(a){a=a|0;var b=0,c=0;v[a>>2]=81440;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Sf(b);if((b|0)!=(c|0)){continue}break}bf(a);return a|0}function I0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;lc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function x8(a){a=a|0;var b=0;b=jb-16|0;jb=b;uJ(b+8|0,a,0);if(oh(b+8|0)){a=v[a+20>>2];v[a+148>>2]=-1;mL(a+4|0,v[b+8>>2],v[b+12>>2])}jb=b+16|0}function QL(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function MB(a){var b=0,c=0;c=Hma(w[a+111|0],0,1536,0);b=mb;a=Hma(w[a+110|0],0,25,0);c=c+a|0;b=mb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;mb=b;return a}function DP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=v[c>>2],g=b,h=Hb(c),d=v[v[a>>2]+28>>2],nb[d](e|0,f|0,g|0,h|0)|0)|0}function tj(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function as(a){var b=0;b=A[a+4248>>3]/+(Se(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function WP(a){a:{if(pd(a,16624,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}return w[a|0]!=0}return 0}function Qq(a,b,c,d,e){var f=0,g=0,h=0;f=v[a+4>>2];g=f>>8;a=v[a>>2];h=a;if(f&1){g=v[v[c>>2]+g>>2]}nb[v[v[a>>2]+24>>2]](h,b,c+g|0,f&2?d:2,e)}function yY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Lb(a+12|0,a+8|0);jb=a+16|0;return v[b>>2]}function o9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(!xd(a,4)){gv(a)}c=b,d=bc(a+44|0),v[c>>2]=d;a=v[Md(b+8|0,b)>>2];jb=b+16|0;return a|0}function n9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(!xd(a,4)){gv(a)}c=b,d=cc(a+44|0),v[c>>2]=d;a=v[Md(b+8|0,b)>>2];jb=b+16|0;return a|0}function hd(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=-1;v[c+4>>2]=0;a=su(c+8|0,c);jb=c+16|0;return v[a>>2]}function Lo(a,b){var c=0,d=0;c=jb-16|0;jb=c;vh(c+8|0,b);d=jb-16|0;jb=d;WJ(d+8|0,ac(d,c+8|0));yS(a,d+8|0);jb=d+16|0;vh(c,b);Hb(c);jb=c+16|0}function zM(a){a=50-(B(w[(a>>>4|0)+20368|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ac((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function yi(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((uk(a,b)|0)==255){break a}tk(a,b);lp(a,b,0,0);if(!c){break a}a=fc(a+58|0,b);t[a|0]=w[a|0]|128}}function sv(a,b){Rm(a);v[a>>2]=71224;v[114578]=0;Q(2838,a+4|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function iu(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(Qb(a,256)){d=jb-16|0;jb=d;gc(c+8|0,b,256);jb=d+16|0;Bd(a,c+8|0);break a}tD(b)}jb=c+16|0}function d1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+15&-16;v[c>>2]=b+16;d=a,e=iw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Vc(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[zf(b+8|0,de(b+12|0,b+4|0))>>1];jb=b+16|0;return a}function Ch(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function Aj(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[zf(b+8|0,de(b+12|0,b+4|0))|0];jb=b+16|0;return a|0}function tU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c>>2]=b;v[c+8>>2]=a;a=jb-16|0;jb=a;vv(v[c+8>>2],v[c>>2],a+8|0);jb=a+16|0;jb=c+16|0}function rma(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Vr(a,b,c);jb=c+32|0}function oja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];c=x[v[a+8>>2]>>1];u[b+2>>1]=0;u[b>>1]=c;jb=a+16|0}function lga(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;IQ(a,b,c);jb=c+32|0}function kha(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;$t(a,b,c);jb=c+32|0}function Wd(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=fm(c+8|0,b);UC(d,a);Bb(d);jb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function VF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function SY(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}nb[a|0](d)}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ow(a+8|0,b,c,d,2);if(a>>>0<16){a=w[a+32240|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function N1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ow(a+8|0,b,c,d,3);if(a>>>0<43){a=w[a+32192|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function K2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;JH(g+8|0,b,c,d,e,f);td(a,g+20|0);kn(g+8|0);jb=g+32|0}function Gka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;hr(a,b,c);jb=c+32|0}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=250){Zi(20452);L()}Eb(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function BI(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C(Vg(b-J(b+.5)))}else{c=C(0)}return c}function wz(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;IQ(a,b,c);jb=c+32|0}function nt(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;eI(a,b,c);jb=c+32|0}function mW(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;jw(a,b,c);jb=c+32|0}function dD(a){a=a|0;var b=0;a=fd(a);v[114578]=0;Q(238,a|0,7090)|0;b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;yb(a);S(b|0);L()}}function Xc(a,b){var c=0,d=0,e=0;c=Df(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function Wia(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;jw(a,b,c);jb=c+32|0}function WT(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;$t(a,b,c);jb=c+32|0}function Pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=43){Zi(20452);L()}Eb(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function Oba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=16){Zi(20452);L()}Pj(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=110){Zi(12352);L()}Eb(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function L2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;JH(g+8|0,b,c,d,e,f);td(a,g+8|0);kn(g+8|0);jb=g+32|0}function K$(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;hr(a,b,c);jb=c+32|0}function J$(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;hr(a,b,c);jb=c+32|0}function Ij(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function G9(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;hr(a,b,c);jb=c+32|0}function Dma(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;$t(a,b,c);jb=c+32|0}function AG(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}ia(52190,50496,1165,52205);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function $d(a,b){a=a|0;b=b|0;return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|0}function yr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function wla(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,6)){aA(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Sh(a,6,c+7|0)}jb=c+16|0}function nW(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;jw(a,b,c);jb=c+32|0}function fQ(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Qb(a,32);a:{if(d){_P(c+8|0,b);Bd(a,c+8|0);break a}ZP(b)}jb=c+16|0;return d|0}function Tha(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,5)){_t(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Sh(a,5,c+7|0)}jb=c+16|0}function hq(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,3)){ju(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Sh(a,3,c+7|0)}jb=c+16|0}function Sl(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,4)){vh(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Sh(a,4,c+7|0)}jb=c+16|0}function KD(a){var b=0,c=0,d=0;c=Tb(a);b=Fb(a);a=jb-16|0;jb=a;t[a+15|0]=0;d=-1;if(b){b=_n(c,b,a+15|0);d=b?b-c|0:-1}jb=a+16|0;return d}function EV(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;JC(b)}function Cf(a){var b=0,c=0;b=jb-16|0;jb=b;if(zq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=b+16|0;return c}function CA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;jb=b+16|0}function An(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Qb(a,4);a:{if(d){vh(c+8|0,b);Bd(a,c+8|0);break a}FR(b)}jb=c+16|0;return d|0}function A8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!be(c&255)|!d)){wJ(a,8,C(0))}a=kj(a);if(a){nb[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function af(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=Ah(f,f+12|0);a=pr(a,b,d,v[f+8>>2]);Ie(c);jb=f+16|0;return a}function wr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function dq(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,2)){Ok(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;gB(a,c+7|0)}jb=c+16|0}function bW(){var a=0,b=0;a=jb-16|0;jb=a;v[a+8>>2]=19468288;a:{if(gD(a+8|0)){break a}if(fD()){break a}b=eD()^1}jb=a+16|0;return b|0}function Yv(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Cg(t[b|0])|0}function Y3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];Pr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function nT(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179468868){return(w[a+4|0]-1&255)>>>0<10}return 0}function ho(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;b=wh(c,b);d=jb-16|0;jb=d;Nq(a,v[b>>2],v[b>>2]+oh(b)|0);jb=d+16|0;jb=c+16|0}function T8(a){a=a|0;a=jb-16|0;jb=a;v[a+12>>2]=1869112133;jb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function ZR(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];u[b>>1]=x[v[a+8>>2]>>1];fd(b+4|0);jb=a+16|0}function OU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=Lma(0-Lma(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function vu(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Tm(d,d+e|0,c+15|0);qi(a,v[b>>2],d);jb=c+16|0}function Xy(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=zb(b),d=0,v[c>>2]=d}function xw(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}lc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function wg(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;if(b>>>0>=110){Zi(12596);L()}Eb(c+8|0,a,b);ge(c+8|0,0);jb=c+16|0;return a|0}function tO(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=Hma(b,b>>31,a,a>>31)+5e5|0;a=mb;return Ac(Ima(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function sO(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=Hma(b,b>>31,a,a>>31)+5e5|0;a=mb;return Ac(Ima(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function qN(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){pN(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function oQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=Sk(c+8|0,b);UC(d,a);Bb(d);jb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function kj(a){var b=0,c=0;b=Ij(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function RE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=gr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function OE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=er(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function JY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function Bb(a){var b=0;a=v[a+4>>2];if(a){if(gm(a)){a:{b=a+8|0;if(v[b>>2]){if((Tu(b)|0)!=-1){break a}}nb[v[v[a>>2]+16>>2]](a)}}}}function fD(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Ub(a,10940);if(Fb(b)){c=(Zf(b,10950)|0)!=-1}else{c=0}yb(b);jb=a+16|0;return c|0}function Ie(a){a:{a=v[a>>2];if(a){v[114578]=0;Nv(a);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function FN(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){we(b,a)}if(c){we(c,a)}if(d){we(d,a)}if(e){we(e,a)}}function CD(a){v[114578]=0;Y(a|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;L()}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;L()}function BY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function xk(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(nb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function rk(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];Uc(a,c,v[Lb(d+12|0,d+8|0)>>2]);jb=d+16|0}function r0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Cg(t[a|0])|0}function qo(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Zb(a,b);a=a+4|0;continue}}}function Wj(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}lh(a,b);a=a+1|0;continue}}}function WW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(kg(a,v[b+8>>2],0)){nv(b,c,d);return}a=v[a+8>>2];nb[v[v[a>>2]+28>>2]](a,b,c,d)}function r1(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}nb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function or(a){v[a>>2]=58624;Cv(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function gi(a,b,c){a:{if(c){v[114578]=0;VF(a,b,c);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function _O(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;mb=c;return a}function Wp(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(nq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8;c=a<<8|a>>>8}jb=b+16|0;return c&65535}function Wf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Bg(d,a);return((Bg(d,a+1|0)<<8|e<<16|Bg(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function Sb(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function SE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=gr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function PE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=er(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function NF(a){v[a>>2]=58688;Cv(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function ML(a){a=a|0;v[a>>2]=0;Oi(a+4|0);v[a+152>>2]=0;v[a+156>>2]=0;v[a+144>>2]=0;v[a+148>>2]=0;Rb(a+16|0,0,128);return a|0}function KK(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){a=bz(a)>>>0>80}else{a=0}return a}function zh(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,12)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function yp(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,20)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function wR(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,33)|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function mt(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Lb(b+12|0,b+8|0)>>2];jb=b+16|0;return a|0}function ls(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function kK(a){a=a|0;var b=0,c=0;b=Ce(a);while(1){c=b;if(c&65535){b=c-1|0;if(!dg(a,b&65535)){continue}}break}return c&65535}function Xo(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,24)|0,8);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function WS(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,48)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Mx(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,52)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function v4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];td(b,v[a+8>>2]);Wb(b+12|0);jb=a+16|0}function rO(a){a=a|0;v[a+700>>2]=0;u[a+862>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function lK(a,b,c){var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function hz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function TK(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function Nt(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,6)|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function ND(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function ce(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function cM(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074312|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?25184:25248)>>2]}function bM(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074312|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?25248:25184)>>2]}function _x(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074312|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?26336:25312)>>2]}function Yn(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function Ev(a,b,c){c=v[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=v[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function B2(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=jb-16|0;jb=c;v[c+12>>2]=w[b|0];Zw(a,c+12|0);jb=c+16|0;jb=d+16|0}function $x(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074312|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?25312:26336)>>2]}function ok(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;yx(a,c)}function m0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function dO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){aO(a,1);aO(a,0)}}function cO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){$N(a,1);$N(a,0)}}function _U(a){a=a|0;var b=0;a:{if(!ve(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=TE(a,32);v[b+76>>2]=a}return a<<24>>24}function LO(a){var b=0;b=a+68|0;if(!(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>127)){return!pd(a,17965,17)}return 0}function AF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function yJ(a,b,c){a:{v[114578]=0;U(25,b|0,c<<11,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function rT(a){var b=0;a:{if(pd(a,12667,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}return t[a+47|0]>-1}return 0}function jba(a,b){a=a|0;b=b|0;if(b>>>0>255){return 20525}a=v[((b<<2)+a|0)+900380>>2];if(!a){return 20525}return a+492|0}function Xr(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Cd(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=83472;v[b+8>>2]=83576;v[a>>2]=v[b+12>>2];v[a+4>>2]=v[b+8>>2];jb=b+16|0}function CR(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1279544644){return w[a+4|0]<32}return 0}function yj(a,b,c){a:{v[114578]=0;U(25,b|0,c<<2,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function qu(a,b,c){a:{v[114578]=0;U(25,b|0,c<<2,2);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function jt(a,b,c){a:{v[114578]=0;U(25,b|0,c<<5,8);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function gA(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Lb(b+12|0,b+8|0)>>1];jb=b+16|0;return a|0}function aja(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(nq(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}jb=b+16|0;return c|0}function Wn(a,b,c){a:{v[114578]=0;U(25,b|0,c<<1,2);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function WJ(a,b){var c=0,d=0;c=jb-16|0;jb=c;b=ac(c,b);d=jb-16|0;jb=d;Nq(a,v[b>>2],v[b>>2]+Hb(b)|0);jb=d+16|0;jb=c+16|0}function Re(a,b,c){a:{v[114578]=0;U(25,b|0,c<<2,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Pl(a,b,c){a:{v[114578]=0;U(25,b|0,c<<1,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Lu(a,b,c){a:{v[114578]=0;U(25,b|0,c<<3,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ae(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function vA(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==810369604){return w[a+4|0]<4}return 0}function pg(a,b,c){a:{v[114578]=0;U(25,b|0,c|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function mc(a,b){var c=0;Rm(a);v[a+4>>2]=0;v[a>>2]=83428;c=a;a=od(Fb(b)+1|0);v[c+4>>2]=a;if(a){lc(a,Tb(b),Fb(b)+1|0)}}function dR(a){a=a|0;var b=0;b=jb-16|0;jb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[lf(b+14|0,b+12|0)|0];jb=b+16|0;return a|0}function bB(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){gc(a,c,v[b>>2]);return}b=b+8|0;if(!md(b)){Wi(a,b);return}Qf(a)}function DH(a,b){v[114578]=0;U(25,a|0,B(b,324)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=yq(e,a,d);Kk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function uk(a,b){a=a+58|0;if(t[fc(a,b)|0]<0){return 255}if(w[fc(a,b)|0]!=255){a=w[fc(a,b)|0]&127}else{a=255}return a}function tP(a,b){v[114578]=0;U(25,a|0,B(b,56)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function RC(a,b){v[114578]=0;U(25,a|0,B(b,24)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function rF(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function qx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Qp(e,a,d);rK(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function fo(a,b,c){var d=0;d=jb-16|0;jb=d;ho(d+8|0,wh(d,b));Uu(a,d+8|0);v[a+12>>2]=c;v[a+8>>2]=0;jb=d+16|0;return a}function Yy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Mi(e,a,d);Kk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function Nk(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Lb(b+12|0,b+8|0)|0];jb=b+16|0;return a|0}function Ln(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=qe(e,a,d);Kk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function JN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Wh(e,a,d);Kk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function s8(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function BT(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function xF(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!ve(UG(c,b),-1)){break a}v[a>>2]=0}return a|0}function sK(a){var b=0,c=0;if(v[a>>2]){vK(a);Nt(zb(a),v[a>>2],Li(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function qk(a,b){var c=0;c=b&15;if(c){t[a+844|0]=c<<2}b=b&240;if(b){t[a+843|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function h9(a,b){a=a|0;b=b|0;var c=0;a:{if(Kb(a)>>>0>511){break a}if(!sd(b)){break a}c=v[b>>2];RJ(a,b)}return c|0}function YN(a){var b=0,c=0;if(v[a>>2]){Xp(a);Wn(zb(a),v[a>>2],Vf(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function X8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=$L(C(c*C(255))),t[d|0]=e;es(a)}}function WQ(a){var b=0,c=0;if(v[a>>2]){uR(a);qu(zb(a),v[a>>2],yd(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function WI(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function Oj(a,b,c){var d=0;d=a+24|0;a=jb-16|0;jb=a;if(b>>>0>=12){Zi(6934);L()}Pj(a+8|0,d,b);ge(a+8|0,c);jb=a+16|0}function MM(a){var b=0,c=0;if(v[a>>2]){Es(a);pg(zb(a),v[a>>2],yf(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function HM(a,b){var c=0;c=b&15;if(c){t[a+847|0]=c<<2}b=b&240;if(b){t[a+846|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function Eaa(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function uG(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function lo(a,b){a:{v[114578]=0;dv(a,b<<2,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function sA(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;b=a;a=Ub(c,v[c+12>>2]);Ky(b,a);yb(a);jb=c+16|0}function pp(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+(b<<2);jb=c+16|0;return v[c+8>>2]}function lD(a,b){v[114578]=0;U(25,a|0,b<<4,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function YH(a){var b=0;a:{while(1){if(!v[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function Xg(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function O0(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=dw(b);v[a+36>>2]=b;c=a,d=Fm(b),t[c+44|0]=d}function L0(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=cw(b);v[a+36>>2]=b;c=a,d=Fm(b),t[c+44|0]=d}function Gj(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function Ds(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function DC(a,b){v[114578]=0;U(25,a|0,b<<5,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function p6(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=Ub(b,38128);mc(a,c);yb(c);v[a>>2]=83388;jb=b+16|0;return a|0}function kg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!ii(v[a+4>>2],v[b+4>>2])}function ge(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function cK(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Lb(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function _5(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=Ub(b,38147);mc(a,c);yb(c);v[a>>2]=83408;jb=b+16|0;return a|0}function Ts(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Jb(c+8|0,c);jb=c+16|0;return a}function Pt(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=(B(a,b)>>>0)/255;ce(c+12|0,0,15);jb=c+16|0;return w[c+12|0]}function y4(a,b){a=a|0;b=b|0;if(a){b=nb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=Zd(b);break a}b=Zd(34181)}v[a>>2]=b}}function uQ(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function ae(a,b){var c=C(0);a:{if(b>C(1)){break a}c=z[a>>2];if(!(c<b)){b=C(1);if(c<=C(1)){break a}}z[a>>2]=b}}function Ym(a){var b=0;while(1){if(w[b+32256|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function Yd(a){a=a|0;var b=0;b=v[19157];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19160];Mr(a+4|0);ah(a+56|0);return a|0}function If(a){a=a|0;var b=0;b=v[19203];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19206];Mr(a+8|0);ah(a+60|0);return a|0}function $K(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function np(a,b){a=a|0;b=b|0;if(oc(a)>>>0>b>>>0){a=dg(v[a+24>>2]+484344|0,x[Fj(a,b)>>1])}else{a=0}return a|0}function mo(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;if((a|0)!=1){return v[15131]}V(0)|0;O()|0;Ab();L()}function hR(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;if((St(a)|0)!=65535){OA(a,c+14|0)}jb=c+16|0}function Wq(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;if((a|0)!=1){return v[15324]}V(0)|0;O()|0;Ab();L()}function Vq(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;if((a|0)!=1){return v[15712]}V(0)|0;O()|0;Ab();L()}function QE(a,b,c,d,e){b=ci(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function NE(a,b,c,d,e){b=bi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function HF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return Cg(t[b|0])}function ny(a){v[114578]=0;U(25,a|0,40,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function eh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Dc(c,(b>>31&a)+b|0)>>2]}function QK(a){v[114578]=0;U(25,a|0,28,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function NG(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function Js(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(!Yp(a,b)){b=Yp(c,a)?c:a}jb=d+16|0;return b|0}function $R(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){XR(c+52|0);yb(c+40|0);Sf(c+16|0);Sf(c+4|0);Xb(c)}}}function pX(a){a=a|0;a=jb-16|0;jb=a;if(Ta(a+12|0,4)|0){SF(v[114552],70510);L()}jb=a+16|0;return v[a+12>>2]}function nja(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Jj(a,b+8|0)){c=PQ(b+8|0)}jb=b+16|0;return c|0}function mu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function ema(a,b){a=a|0;b=b|0;var c=0;b=jb-80|0;jb=b;c=-1;if(oT(a,b+8|0)){c=nT(b+8|0)}jb=b+80|0;return c|0}function cf(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+b;jb=c+16|0;return v[c+8>>2]}function _o(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=Db(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function VG(a){var b=0;b=v[(w[a+2|0]&12)+42468>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function TD(a,b,c){v[114578]=0;RD(a,b,c);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function Ew(a,b){var c=0;c=(B(B(Cw(a),Dw(a)),125)>>>0)/(VG(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function px(a,b){Uz(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Yx(a+24|0);Wb(a+36|0);v[a+48>>2]=b;return a}function lt(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Sl(c+8|0,a);v[c+4>>2]=v[c+8>>2];kt(c+4|0,b);jb=c+16|0}function lV(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Jj(a,b+8|0)){c=vC(b+8|0)}jb=b+16|0;return c|0}function hg(a){var b=0,c=0;b=jb-16|0;jb=b;if(nq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}jb=b+16|0;return c}function dE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function NT(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Jj(a,b+8|0)){c=vA(b+8|0)}jb=b+16|0;return c|0}function BF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function zN(a){u[a+70>>1]=w[((x[v[a+4>>2]+22>>1]<<4|x[v[a+4>>2]+20>>1]>>>6)&65535)+19968|0]>>>x[a+68>>1]}function ig(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];mb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Jh(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];Bl(a,d*e-f*g,e*f+d*g)}function g0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function d0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function co(a,b,c){var d=0;d=jb-16|0;jb=d;a=Qf(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;jb=d+16|0}function a0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function Zb(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];jb=c+16|0}function Z$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function YK(a,b){var c=0;c=jb-16|0;jb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];jb=c+16|0}function S$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function JO(a,b){var c=0;c=y[b>>2]>y[a>>2];a=v[a+4>>2];b=v[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function eO(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function Nv(a){a=a|0;var b=0;b=v[21203];if(a){v[21203]=(a|0)==-1?458288:a}return((b|0)==458288?-1:b)|0}function BQ(a,b){var c=0;c=jb-16|0;jb=c;a:{if(Df(a,4)){vh(c+8|0,b);iz(a,c+8|0);break a}FR(b)}jb=c+16|0}function sy(a,b){if(dg(v[a+24>>2]+484344|0,b)){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function L3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;ho(d+8|0,wh(d,b));fo(a,d+8|0,c);jb=d+16|0}function Dw(a){var b=0;b=w[a+1|0];return w[(B(b>>>1&3,15)+B(b>>>3&1,45)+(w[a+2|0]>>>4)|0)+42465|0]<<1}function bm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function JA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;jb=b+16|0}function td(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];Sm(b);return a}function ru(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function Y8(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function Rf(a,b,c){var d=0;a:{if(b>c){break a}d=A[a>>3];if(!(d<b)){b=c;if(d<=b){break a}}A[a>>3]=b}}function DB(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}mb=a;return b}function wW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return nb[a|0](b,c,d,e,f,g)|0}function w4(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Tb(b);if(c){nb[c|0](b,v[a+8>>2]);return}Wr(b,a)}function vg(a){var b=0;b=a+44|0;Vk(b);if(v[b>>2]){oD(b,v[b>>2]);Yi(zb(b),v[b>>2],Yh(b))}CC(a+32|0)}function ou(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Xf(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function V9(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;Qh(b)}function RY(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[mo()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function Fia(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(eA(a,b)){c=pQ(b)}jb=b+16|0;return c|0}function Bja(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;Bz(a+236|0,128,c+14|0);jb=c+16|0}function yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=rw(A[b>>3]);e=hi(c);Bl(a,d*ze(c),d*e)}function y8(a,b,c){a=a|0;b=b|0;c=c|0;a=kj(a);if(!a){return 0}return nb[v[v[a>>2]+96>>2]](a,b,c)|0}function lh(a,b){var c=0;c=jb-16|0;jb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];jb=c+16|0}function lf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Xn(c+8|0,b,a);jb=c+16|0;return(d?b:a)|0}function jJ(a){a=a|0;var b=0;b=v[a>>2];if(b){nb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Es(a);dS(a)}function Si(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Xn(c+8|0,a,b);jb=c+16|0;return(d?b:a)|0}function I3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;nb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;oo(d,a);fE(a,c)}function Hka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;XB(c,a);a=uf(c,b);yb(c);jb=c+16|0;return a|0}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;v[b+8>>2]=v[c+8>>2]}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;Te(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function wK(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];oS(c+8|0,b);jb=c+16|0;return v[c+8>>2]}function eQ(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function VU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;xu(c+8|0,a);mq(c+8|0,b);jb=c+16|0;return a|0}function RU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;WB(c+8|0,a);mq(c+8|0,b);jb=c+16|0;return a|0}function PO(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}mb=a;return b}function P3(a,b){a=a|0;b=b|0;or(a);v[a>>2]=76704;Wb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function FU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;JB(c+8|0,a);mq(c+8|0,b);jb=c+16|0;return a|0}function pla(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function pka(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=zq(a,b+8|0);jb=b+16|0;return C(a?z[b+8>>2]:C(0))}function cu(a,b){a=a|0;b=b|0;var c=0;a=nq(a,b);if(!a){c=jb-16|0;jb=c;fu(b);jb=c+16|0}return a|0}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function Ro(a,b,c){a=v[a>>2]+1074984|0;return v[(a+B(b,896)|0)+680>>2]>v[(a+B(c,896)|0)+680>>2]}function PW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(kg(a,v[b+8>>2],f)){mv(b,c,d,e)}}function Nka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;mS(c,b);td(a,c);yb(c);jb=c+16|0;return a|0}function KU(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Xf(a,b+8|0)){c=w[b+8|0]}jb=b+16|0;return c|0}function JG(a){var b=0;b=+((a&2097151)>>>0);return C(_h(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function Haa(a,b){a=a|0;b=b|0;Ih(a);Ih(a);a:{if(b>>>0>=60){$b(a,4);break a}Ih(a)}return Ih(a)|0}function w8(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;Wi(b,v[a+20>>2]+4|0);tJ(a,Od(b+8|0,b),0);jb=b+16|0}function nA(a,b){var c=0;c=jb-16|0;jb=c;v[c>>2]=b;v[c+8>>2]=a;a=Vp(c,c+8|0);jb=c+16|0;return a}function hT(a,b){return(Yb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((B(a&15,b)>>>0)/15|0,1,15))&255}function Wr(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;v[b>>2]=a;a=v[13922];nG(a,34267,b);zr(a);jb=b+16|0}function W8(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Se(v[a+16>>2]),v[b+4232>>2]=c;es(a);JJ(a)}function Vs(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=yk(Vg(b)*+(c>>>0)),v[d+24>>2]=e}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=td(c,b);Ky(d,a);yb(a);jb=c+16|0}function A7(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Se(v[a+16>>2]),v[b+4256>>2]=c;UI(a);TI(a)}function Vj(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Tb(a)+(Fb(a)<<2)|0)>>2];jb=b+16|0;return a}function U$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[v[v[a>>2]+16>>2]](a,b,c,d,e)|0}function T$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0}function RO(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function E0(a,b,c){a=a|0;b=b|0;c=c|0;if(ve(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function BW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=nb[a|0](b,c,d,e)|0;qa(mb|0);return a|0}function mD(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function lG(a){var b=0;b=Gma(v[a>>2]-1|0);if(!b){a=Gma(v[a+4>>2]);return a?a+32|0:0}return b}function gF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function eE(a){a=a|0;var b=0;v[a>>2]=64724;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Xb(b)}return a|0}function Yo(a,b,c){a=vl(a)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function Xl(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function Wk(a,b,c){var d=0;d=jb-16|0;jb=d;gc(d+8|0,Db(b),c);a=yS(a,d+8|0);jb=d+16|0;return a}function Up(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;cm(b+8|0,c+8|0)}function Uh(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function R$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return nb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function Nia(a,b){a=a|0;b=b|0;var c=0;a=jb-16|0;jb=a;c=b;b=Xh(a);NQ(c,b,0,0);Bb(b);jb=a+16|0}function zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Yp(a,b);jb=c+16|0;return(d?b:a)|0}function w6(a,b,c){a=a|0;b=b|0;c=c|0;Vw(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=83356;return a|0}function uC(a){a=a|0;var b=0;b=v[a>>2];return Db((nb[v[v[b>>2]+20>>2]](b)|0)+v[a+8>>2]|0)|0}function tma(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;yg(c,1,a);aC(c,b);jb=c+16|0;return a|0}function su(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=ru(b,a);jb=c+16|0;return(d?b:a)|0}function sma(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Ut(c,1,a);aC(c,b);jb=c+16|0;return a|0}function rK(a,b,c,d){a=c-b|0;if((a|0)>=1){lc(v[d>>2],b,a);v[d>>2]=v[d>>2]+B((a>>>0)/6|0,6)}}function qh(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=rD(a,b);jb=c+16|0;return(d?b:a)|0}function qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;gp(a,b,c);jb=d+16|0;return a|0}function pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=rD(b,a);jb=c+16|0;return(d?b:a)|0}function mia(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Ku(a,b+8|0);jb=b+16|0;return+(a?A[b+8>>3]:0)}function hu(a,b,c){a=a|0;b=b|0;c=c|0;b=jb-16|0;jb=b;t[b+15|0]=w[c|0];mI(a,b+15|0);jb=b+16|0}function gy(a){var b=0;v[a+72>>2]=0;v[a+76>>2]=0;b=v[a+68>>2];v[a+80>>2]=b;v[a+84>>2]=b<<12}function de(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Yp(b,a);jb=c+16|0;return(d?b:a)|0}function bd(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Jd(a,b);jb=c+16|0;return(d?b:a)|0}function Qb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return nb[v[v[c>>2]+36>>2]](c,v[a+8>>2],b)|0}function OI(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function Lb(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Jd(b,a);jb=c+16|0;return(d?b:a)|0}function IL(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function Hp(a,b){var c=0;c=Fb(a);if((c|0)==(Fb(b)|0)){a=Vm(Tb(a),Tb(b),c)}else{a=1}return!a}function CC(a){var b=0;Ol(a);b=a;if(v[b>>2]){jD(b,v[b>>2]);pg(zb(b),v[b>>2],yf(b))}return a}function x6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;yI(a,b,c,d,e,0,0,f,g)}function tF(a){var b=0;b=v[a>>2];if(b){if(!ve(HF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function sF(a){var b=0;b=v[a>>2];if(b){if(!ve(BF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function qi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;VI(a,b,c);jb=d+16|0;return a|0}function qaa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;ad(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function laa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;ad(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function Wi(a,b){a=a|0;b=b|0;var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+xc(b)|0,v[c+4>>2]=d}function Uk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function PC(a,b){var c=0,d=0;Kp(a);v[a>>2]=76960;v[a+4>>2]=v[b>>2];c=a,d=oh(b),v[c+8>>2]=d}function Hj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;kL(a,b,c);jb=d+16|0;return a|0}function GR(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){lc(c,b,a)}}function xd(a,b){var c=0;c=jb-16|0;jb=c;Pj(c+8|0,a+24|0,b);a=Cb(c+8|0);jb=c+16|0;return a}function vJ(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];A[a+4256>>3]=b-J(b)}function jG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function bw(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;a=pr(a,b,c,d);jb=e+16|0;return a}function X9(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){Fi(a,b);return}_D(a,b,c)}function Ww(a){a=a|0;var b=0;v[a>>2]=83428;b=v[a+4>>2];if(b){Xb(b);v[a+4>>2]=0}return a|0}function VD(a,b){a:{if(!(w[a+112|0]|b>>>0>28)){t[a+112|0]=1;break a}a=sc(b<<2,4)}return a}function P$(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){aw(a,c);return}Ub(a,58945)}function Ou(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0>4){b=1085}else{b=v[(b<<2)+76228>>2]}Ub(a,b)}function Lma(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function EW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;nb[a|0](b,c,d,e,f,g)}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kj(a);if(a){nb[v[v[a>>2]+76>>2]](a,b,c,d)}}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kj(a);if(a){nb[v[v[a>>2]+80>>2]](a,b,c,d)}}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kj(a);if(a){nb[v[v[a>>2]+84>>2]](a,b,c,d)}}function sf(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Tb(a)+Fb(a)|0)>>2];jb=b+16|0;return a}function qR(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];u[b+4>>1]=x[c+4>>1];cm(b+8|0,c+8|0)}function Gd(a){var b=0;b=jb-16|0;jb=b;a=Xf(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)&255}function Bz(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function wh(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+oh(b)|0,v[c+4>>2]=d;return a}function rR(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function pV(a){a=a|0;var b=0;b=v[a+4>>2];return(nb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function pN(a,b){var c=0;b=Db(b);c=a;a=v[a>>2];v[c>>2]=a<<8^v[((b^a>>>24)<<2)+87440>>2]}function o8(a,b,c){a=a|0;b=b|0;c=c|0;Od(a,b);b=v[c+4>>2];v[a+8>>2]=v[c>>2];v[a+12>>2]=b}function ms(a,b){if(!(v[a+480180>>2]==8?t[b+872|0]&1:0)){Gx(a,b,0);Gx(a,b,1);Gx(a,b,2)}}function hM(a,b){var c=0;c=w[a+872|0];if(c&1){t[a+872|0]=c|8;v[a+876>>2]=v[a+876>>2]+b}}function hF(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a=kF(a,64656,b);jb=c+16|0;return a}function gm(a){var b=0;b=Tu(a+4|0);if((b|0)==-1){nb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function at(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function ac(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+Hb(b)|0,v[c+4>>2]=d;return a}function Ze(a,b){var c=0;Sk(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function Qh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function JQ(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+CQ(b)|0,v[c+4>>2]=d;return a}function F8(a,b){a=a|0;b=b|0;a=kj(a);if(!a){return 1}return nb[v[v[a>>2]+68>>2]](a,b)|0}function zv(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;JD(a,b,gF(b));jb=c+16|0;return a|0}function yA(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+12336|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function uN(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function pe(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[rv(b,a)+8>>2],d=0,t[c|0]=d;jb=b+16|0}function jm(a){var b=0;b=a+36|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function hD(a){var b=0;b=a+48|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function ef(a){var b=0;b=a+24|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function YO(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function Ub(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;gp(a,b,$e(b));jb=c+16|0;return a|0}function Sh(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function RD(a,b,c){a=a|0;b=b|0;c=c|0;if((a|0)==(b|0)){t[a+112|0]=0;return}dv(b,c<<2,4)}function LL(a){fd(a);fd(a+12|0);fd(a+24|0);fd(a+36|0);fd(a+48|0);v[a+60>>2]=0;return a}function tm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function tba(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=v[nL(b+8|0,a)>>2];jb=b+16|0;return a|0}function j1(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function i1(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function dt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function c_(a,b,c){a=a|0;b=b|0;c=c|0;c=Yv(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function ZX(a){a=a|0;a=462088;while(1){a=yb(a-12|0);if((a|0)!=461920){continue}break}}function WX(a){a=a|0;a=462264;while(1){a=Lc(a-12|0);if((a|0)!=462096){continue}break}}function TX(a){a=a|0;a=462560;while(1){a=yb(a-12|0);if((a|0)!=462272){continue}break}}function S2(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;JB(c+8|0,b);vu(a,c+8|0);jb=c+16|0}function QX(a){a=a|0;a=462864;while(1){a=Lc(a-12|0);if((a|0)!=462576){continue}break}}function NX(a){a=a|0;a=462904;while(1){a=yb(a-12|0);if((a|0)!=462880){continue}break}}function KX(a){a=a|0;a=462936;while(1){a=Lc(a-12|0);if((a|0)!=462912){continue}break}}function nf(a){a=a|0;var b=0;b=v[a>>2];return(nb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Ph(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Qh(a)}function FY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Wq()+((b&255)<<2)>>2]}return b<<24>>24}function DY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Vq()+((b&255)<<2)>>2]}return b<<24>>24}function yW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nb[a|0](b,c,d)|0;qa(mb|0);return a|0}function rf(a){var b=0;Oh(a);b=a;if(v[b>>2]){yH(b);Xo(zb(b),v[b>>2],We(b))}return a}function r6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return qI(a,b,c,d,0,0,0,0,e)|0}function fm(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function WE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function VE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function uh(a){var b=0,c=0;b=jb-16|0;jb=b;c=b+8|0;QC(c,a);jb=b+16|0;return v[c>>2]}function nU(a){a=a|0;var b=0;b=jb-16|0;jb=b;cB(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function ey(a,b){var c=0;t[a|0]=w[b|0];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c}function aR(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,v[a>>2])>>2];jb=b+16|0;return a}function KG(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function GM(a,b){var c=0;c=b&15;if(c){t[a+850|0]=c}b=b&240;if(b){t[a+849|0]=b>>>4}}function Fj(a,b){a=a|0;b=b|0;if(oc(a)>>>0<=b>>>0){hG();L()}return v[a>>2]+(b<<1)|0}function yC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);sh(v[a>>2],b,v[a+4>>2])}}function sI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){nb[v[v[c>>2]+4>>2]](c)}}}function oA(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8;t[b|0]=a;t[b+1|0]=a>>>8}function al(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function TC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);Yf(v[a>>2],b,v[a+4>>2])}}function Ry(a,b){a=lc(a,b,34);u[a+34>>1]=x[b+34>>1];lc(a+36|0,b+36|0,68);return a}function Iu(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){hm(a)}}function Ik(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,24);return a}function IC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);Yi(v[a>>2],b,v[a+4>>2])}}function FH(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);_y(v[a>>2],b,v[a+4>>2])}}function $S(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function zj(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,hc(a))>>2];jb=b+16|0;return a}function yq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function vn(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,aR(a))>>2];jb=b+16|0;return a}function qe(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function mm(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function Wh(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Qp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function Hi(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,zj(a))>>2];jb=b+16|0;return a}function Dd(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Tb(a))>>2];jb=b+16|0;return a}function $n(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function xW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[a|0](b,c,d,e,f)}function x$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-16|0;jb=b;ZE(a,c,d);jb=b+16|0}function OS(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function x1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return YG(a-88|0,b,c,d,e)|0}function nG(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;qG(a,b,c,0,0);jb=d+16|0}function gt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function cm(a,b){var c=0;fm(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Xs(a,b){return yk(Vg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function Kga(a,b){a=a|0;b=b|0;bj(b);if(v[b>>2]){WO(b);zh(zb(b),v[b>>2],lg(b))}}function C0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,58216);return}aw(a,c)}function AW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[a|0](b,c,d,e)|0}function A0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,58295);return}aw(a,c)}function kba(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:20525)|0}function ji(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Xb(b)}function d7(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function d2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Jr(b,c,d,z[a+28>>2]);uH(a,b,c,d)}function a2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Jr(b,c,d,z[a+28>>2]);sH(a,b,c,d)}function Z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Jr(b,c,d,z[a+24>>2]);qH(a,b,c,d)}function XW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(kg(a,v[b+8>>2],0)){nv(b,c,d)}}function X1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Jr(b,c,d,z[a+24>>2]);oH(a,b,c,d)}function Sk(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){hm(b)}return a}function ud(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];$b(b,c);Vu(a,b,d,c)}function nl(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=iJ(b,a);jb=c+16|0;return d?b:a}function n7(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function ex(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=iJ(a,b);jb=c+16|0;return d?b:a}function bz(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function b8(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function Xi(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){a=bO(a,Tb(b),Fb(b))}return a|0}function XH(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function W6(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function UF(){a:{if(t[461440]&1){break a}if(!wd(461440)){break a}vd(461440)}}function TQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=JO(a,b);jb=c+16|0;return d?b:a}function SM(a){var b=0;b=jb-16|0;jb=b;QC(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function R7(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function P6(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function Nh(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){lc(c,b,a)}}function Ng(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,a)>>2];jb=b+16|0;return a}function Kk(a,b,c,d){a=c-b|0;if((a|0)>=1){lc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function J7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function Il(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0;return v[b+8>>2]}function DE(a,b){var c=0,d=0;ye(a,Nd(b));b=v[hc(b)>>2];c=hc(a),d=b,v[c>>2]=d}function C7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function Az(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=JO(b,a);jb=c+16|0;return d?b:a}function zK(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function zA(a,b){a=a|0;b=b|0;a=v[a>>2];return nb[v[v[a>>2]+36>>2]](a,0,b)|0}function yK(a,b){a=a|0;b=b|0;return(b>>>0<=42?t[v[a+84>>2]+b|0]:63)<<24>>24}function qr(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function dW(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;km(a,c+8|0,b);jb=c+16|0}function cD(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Bi(a,c+8|0,b);jb=c+16|0}function ZF(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function UQ(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function QO(a){if((w[a+14|0]-49&255)>>>0<=3){return!pd(a,17504,14)}return 0}function NO(a,b){qP(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Mi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function rv(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function fg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function dg(a,b){a=a|0;b=b|0;if(Kn(a,b)){a=mh(Ge(a,b))}else{a=0}return a|0}function Um(a,b){a=v[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function UM(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;GO(a,c)}function Og(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function NY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Wq()+(b<<2)>>2]}return b|0}function LY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Vq()+(b<<2)>>2]}return b|0}function vW(a,b,c){a=a|0;b=b|0;c=c|0;a=nb[a|0](b,c)|0;qa(mb|0);return a|0}function vQ(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function pk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function haa(a,b){a=a|0;b=b|0;return(b>>>0<=42?w[v[a+84>>2]+b|0]!=63:0)|0}function ad(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function aaa(a,b,c){a=a|0;b=b|0;c=c|0;if(Fb(b)>>>0>c>>>0){Co(b,c)}td(a,b)}function XB(a,b){var c=0;c=jb-16|0;jb=c;WB(c+8|0,b);vu(a,c+8|0);jb=c+16|0}function X$(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+32>>2]](a,b,c)|0}function Wl(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+48>>2]](a,b,c)|0}function $j(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+12>>2]](a,b,c)|0}function r8(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function mB(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function jS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=bS(a,b),v[d>>2]=e}function QF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Og(a,-1,-1)}function Kz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,v[b>>2],Kb(b)<<2);jb=c+16|0}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=bS(a,b),t[d|0]=e}function AK(a,b){a=a|0;b=b|0;return(b>>>0<=15?w[v[a+88>>2]+b|0]!=63:0)|0}function $A(a,b){var c=0;c=jb-16|0;jb=c;gc(a,v[b>>2],oc(b)<<1);jb=c+16|0}function wn(a){AR(a);if(v[a>>2]){xR(a,v[a>>2]);wR(zb(a),v[a>>2],Jl(a))}}function vN(a){if(a>>>0<=8){return w[a+20096|0]}return w[a+20087|0]|256}function uD(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function tw(a){return((Lg(a)+(Lg(a)<<8)|0)+(Lg(a)<<16)|0)+(Lg(a)<<24)|0}function sw(a,b){a=a|0;b=b|0;nb[b|0](v[v[a>>2]-12>>2]+a|0)|0;return a|0}function qc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=$e(b),v[c+4>>2]=d;return a}function gR(a){Qk(a);if(v[a>>2]){SQ(a,v[a>>2]);Pl(zb(a),v[a>>2],Vf(a))}}function fH(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function dQ(a){Dq(a);if(v[a>>2]){YP(a,v[a>>2]);Lu(zb(a),v[a>>2],Vi(a))}}function cR(a){vf(a);if(v[a>>2]){ZQ(a,v[a>>2]);yj(zb(a),v[a>>2],yd(a))}}function XO(a){bj(a);if(v[a>>2]){TO(a,v[a>>2]);zh(zb(a),v[a>>2],lg(a))}}function Kg(a,b,c){return(c|0)>=0?(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function Ji(a){vf(a);if(v[a>>2]){OR(a,v[a>>2]);yj(zb(a),v[a>>2],yd(a))}}function EN(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Cj(a){Qk(a);if(v[a>>2]){aB(a,v[a>>2]);Pl(zb(a),v[a>>2],Vf(a))}}function Bv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function AQ(a){v[a+8>>2]=0;v[a>>2]=0;v[a+4>>2]=40;u[a+12>>1]=0;return a}function yx(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function yS(a,b){ak(a,Db(v[b>>2]),Hb(b));a=v[a+4>>2];mb=a>>31;return a}function tC(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function lv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function i0(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){Ba();L()}}function hK(a,b){if(b>>>0>82595524){Fc(32335);L()}return sc(B(b,52),4)}function Tj(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function FL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){wf(c);Xb(c)}}}function Dc(a,b){if(Kb(a)>>>0<=b>>>0){hG();L()}return v[a>>2]+(b<<2)|0}function _V(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;iD(a,b);jb=c+16|0}function Tr(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;cQ(a,b);jb=c+16|0}function OM(a){if(a>>>0>357913941){Fc(20272);L()}return sc(B(a,12),4)}function NW(a){a=a|0;if(!a){return 0}return(ov(a,71736,71880)|0)!=0|0}function GH(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){DH(b,v[hc(a)+4>>2])}}function DD(a){return(v[a>>2]&-256)==1126902528&v[a+4>>2]==1129074247}function Ci(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[a|0](b,c,d)|0}function rx(a,b,c){b=b-a|0;if(b){aj(c,a,b)}return B((b|0)/6|0,6)+c|0}function io(a,b,c,d,e){b=La(a|0,b|0,c|0,d|0,e|0)|0;mb=O()|0;return b}function dz(a,b){Zb(a,b);Zb(a+4|0,b+4|0);Zb(zb(a),zb(b));zb(a);zb(b)}function cl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function XC(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(CC(c))}}}function TY(a){a=a|0;var b=0;b=v[115416]+1|0;v[115416]=b;v[a+4>>2]=b}function MZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Af(a,f)}function LN(a,b){if(b>>>0>134217727){Fc(18648);L()}return sc(b<<5,4)}function JR(a){if(a>>>0>715827882){Fc(14480);L()}return sc(B(a,6),1)}function FC(a,b){if(b>>>0>134217727){Fc(11120);L()}return sc(b<<5,4)}function Ey(a,b){Ql(a);fd(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function AH(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];td(b+4|0,c+4|0)}function $0(a,b){a=a|0;b=b|0;if(!v[114578]){v[114579]=b;v[114578]=a}}function xD(a,b,c,d,e,f,g){return Ka(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function sm(a){if(a>>>0>1073741823){Fc(70328);L()}return sc(a<<2,4)}function ro(a,b,c){a=a|0;b=b|0;c=c|0;Te(a,b);Te(a+4|0,c);return a|0}function o1(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function VJ(a){if(a>>>0>1073741823){Fc(32462);L()}return sc(a<<2,4)}function SB(a){if(a>>>0>1073741823){Fc(11804);L()}return sc(a<<2,2)}function IP(a){if(a>>>0>1073741823){Fc(16711);L()}return sc(a<<2,1)}function FB(a){if(a>>>0>2147483647){Fc(11932);L()}return sc(a<<1,2)}function EL(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function BV(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a);v[a>>2]=77064;return a|0}function $y(a){a=a|0;v[a>>2]=76256;Pg(a+28|0);Pg(a+12|0);return a|0}function rn(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<2)|0}function pn(a){var b=0;b=v[a+20>>2];if(b){Xb(b+-64|0)}v[a+20>>2]=0}function gk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Xb(rf(b))}}}function gM(a,b){v[a+876>>2]=v[a+876>>2]+b;t[a+872|0]=w[a+872|0]|8}function bF(a,b,c){a=a|0;b=b|0;c=c|0;return so(0,a,b,c?c:461468)|0}function YD(a,b,c){a=a|0;b=b|0;c=c|0;_s(a);t[a+128|0]=0;return a|0}function YA(a){if(a>>>0>268435455){Fc(12065);L()}return sc(a<<4,4)}function Xe(a,b,c){a=a|0;b=b|0;c=c|0;return Nc(a,B(lk(a),b)+c|0)|0}function SL(a){if(a>>>0>134217727){Fc(20384);L()}return sc(a<<5,8)}function Qla(a){a=a|0;return v[a+16>>2]+(v[a+8>>2]-v[a+20>>2]|0)|0}function Nm(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function MO(a,b){Xy(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function IY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function EK(a){if(a>>>0>1073741823){Fc(1447);L()}return sc(a<<2,4)}function BH(a){if(a>>>0>268435455){Fc(39501);L()}return sc(a<<4,4)}function uj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function rV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+12>>2]](a)|0}function qV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+16>>2]](a)|0}function oB(a){if(v[a>>2]){XA(a,v[a>>2]);Yi(zb(a),v[a>>2],Yh(a))}}function jP(a){a=a+34|0;a=Hma(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function dH(a){a=a|0;return+(+v[v[a+32>>2]+1074444>>2]*.00390625)}function LP(a){if(v[a>>2]){HP(a,v[a>>2]);yj(zb(a),v[a>>2],yd(a))}}function JS(a){mb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function Cw(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function Ah(a,b){var c=0,d=0;c=a,d=Nv(v[b>>2]),v[c>>2]=d;return a}function tX(a){a=a|0;var b=0,c=0;b=a,c=le(),v[b>>2]=c;return a|0}function sV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function sJ(a){a=a|0;v[a>>2]=79476;Pg(a+4208|0);bf(a);return a|0}function rs(a){yb(a+48|0);yb(a+36|0);yb(a+24|0);yb(a+12|0);yb(a)}function qy(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(c)}}}function gn(a){var b=0;b=jb-16|0;jb=b;jb=b+16|0;return a<<24>>24}function bx(a){a=a|0;v[a>>2]=80160;Sf(a+4260|0);bf(a);return a|0}function _I(a){a=a|0;v[a>>2]=80392;Sf(a+4256|0);bf(a);return a|0}function SI(a){a=a|0;v[a>>2]=80800;Sf(a+4208|0);bf(a);return a|0}function IJ(a){a=a|0;v[a>>2]=79272;Sf(a+4208|0);bf(a);return a|0}function Eda(a,b){a=a|0;b=b|0;qN(a,v[b>>2],v[b+4>>2]);return a|0}function Db(a){a=a|0;var b=0;b=jb-16|0;jb=b;jb=b+16|0;return a|0}function z6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function xj(a,b,c){a=a|0;b=b|0;c=c|0;return Dz(Il(a),Il(b),c)|0}function un(a){vf(a);if(v[a>>2]){tR(a);qu(zb(a),v[a>>2],yd(a))}}function sl(a){Oh(a);if(v[a>>2]){GK(a);Yf(zb(a),v[a>>2],We(a))}}function me(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function mN(a,b){b=1/(564505.8718779281/b+1);jN(a,b,0,0,b+-1,0)}function ir(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+44>>2]](a,b)|0}function eN(a){bj(a);if(v[a>>2]){XM(a);zh(zb(a),v[a>>2],lg(a))}}function dJ(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function _r(a){vf(a);if(v[a>>2]){DJ(a);Re(zb(a),v[a>>2],yd(a))}}function Zr(a){AJ(a);if(v[a>>2]){GJ(a);yJ(zb(a),v[a>>2],jk(a))}}function Wx(a){XS(a);if(v[a>>2]){kT(a);WS(zb(a),v[a>>2],Ml(a))}}function Vx(a){qL(a);if(v[a>>2]){pL(a);Mx(zb(a),v[a>>2],lj(a))}}function Sx(a){dm(a);if(v[a>>2]){YC(a);sh(zb(a),v[a>>2],th(a))}}function Sf(a){vf(a);if(v[a>>2]){WR(a);Re(zb(a),v[a>>2],yd(a))}}function Rs(a){dm(a);if(v[a>>2]){NN(a);sh(zb(a),v[a>>2],th(a))}}function Qv(a,b){a=a|0;b=b|0;return(bh(a)|0)!=0|(a|32)-97>>>0<6}function NQ(a,b,c,d){Ze(a,b);u[a+18>>1]=d;u[a+16>>1]=c;return a}function Lk(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+28>>2]](a,b)|0}function Lj(a){a=a|0;a=v[a>>2];return nb[v[v[a>>2]+24>>2]](a)|0}function Jv(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+12>>2]](a,b)|0}function Io(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function IO(a){vf(a);if(v[a>>2]){HO(a);yj(zb(a),v[a>>2],yd(a))}}function Gl(a){Oh(a);if(v[a>>2]){vP(a);Yf(zb(a),v[a>>2],We(a))}}function EB(a){if(!pd(a,12035,25)){return w[a+34|0]<65}return 0}function DW(a,b){a=a|0;b=b|0;a=nb[a|0](b)|0;qa(mb|0);return a|0}function DT(a){Qk(a);if(v[a>>2]){yT(a);Pl(zb(a),v[a>>2],Vf(a))}}function BM(a){Oh(a);if(v[a>>2]){YL(a);Xo(zb(a),v[a>>2],We(a))}}function wA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,1954);jb=c+16|0}function vq(a){a=a|0;a=v[a>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function oq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function oba(a,b){a=a|0;b=b|0;sv(a,b);v[a>>2]=71324;return a|0}function jz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,1024);jb=c+16|0}function iI(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function XZ(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,AF(v[b>>2]),v[b>>2])}function Mr(a){a=a|0;v[a>>2]=76704;yb(a+32|0);il(a);return a|0}function Jz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,4896);jb=c+16|0}function Ef(a,b){a=a|0;b=b|0;a=Ku(a,b);if(!a){AC(b)}return a|0}function Df(a,b){return nb[v[v[a>>2]+36>>2]](a,v[a+12>>2],b)|0}function CS(a){a=a|0;a=w[a|0];return be(a)^1|(a-49&255)>>>0<36}function Bt(a,b){a=a|0;b=b|0;a=zq(a,b);if(!a){PR(b)}return a|0}function wD(a,b,c){b=Ha(2079,a|0,b|0,c|0)|0;mb=O()|0;return b}function vz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function uV(a){a=a|0;var b=0;b=jb-16|0;jb=b;DC(a,1);jb=b+16|0}function uS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,576);jb=c+16|0}function tW(a,b){a=a|0;b=b|0;sv(a,b);v[a>>2]=71432;return a|0}function sja(a,b,c){a=a|0;b=b|0;c=c|0;td(a,LD(c,Tb(b),Fb(b)))}function qW(a,b){a=a|0;b=b|0;sv(a,b);v[a>>2]=71380;return a|0}function pm(a,b){if(Fb(a)>>>0<=b>>>0){qm();L()}return kc(a,b)}function pT(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,610);jb=c+16|0}function mp(a,b){a=a|0;b=b|0;if(xe(a)>>>0>b>>>0){t[a+16|0]=b}}function m2(a){a=a|0;var b=0;b=jb-16|0;jb=b;DH(a,1);jb=b+16|0}function lP(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,146);jb=c+16|0}function kQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,130);jb=c+16|0}function j2(a){a=a|0;var b=0;b=jb-16|0;jb=b;tP(a,1);jb=b+16|0}function iQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,600);jb=c+16|0}function hP(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,608);jb=c+16|0}function g4(a,b,c){a=a|0;b=b|0;c=c|0;zJ(a,0,Qz(v[b+24>>2]),c)}function aQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,126);jb=c+16|0}function _M(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function Zp(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,192);jb=c+16|0}function Xt(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,512);jb=c+16|0}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1186)|0}function Wda(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1187)|0}function UO(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,204);jb=c+16|0}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1192)|0}function Sq(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function RR(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,674);jb=c+16|0}function Od(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function KV(a){a=a|0;var b=0;b=jb-16|0;jb=b;RC(a,1);jb=b+16|0}function HB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,497);jb=c+16|0}function ER(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,128);jb=c+16|0}function EO(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,263);jb=c+16|0}function AV(a){a=a|0;var b=0;b=jb-16|0;jb=b;lD(a,1);jb=b+16|0}function AS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,157);jb=c+16|0}function zz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,40);jb=c+16|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1616)|0}function yka(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,710)|0}function y9(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1617)|0}function xv(){var a=0;a=ba(4)|0;Yk(a);ha(a|0,71204,2009);L()}function xA(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,1954);jb=b+16|0}function tq(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,36);jb=c+16|0}function oN(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,27);jb=c+16|0}function mQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,30);jb=c+16|0}function mA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,64);jb=c+16|0}function kB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,38);jb=c+16|0}function iB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,41);jb=c+16|0}function hH(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function hB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,16);jb=c+16|0}function gx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function cA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,12);jb=c+16|0}function _n(a,b,c){if(!b){return 0}return Ar(a,Cg(t[c|0]),b)}function _Q(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,52);jb=c+16|0}function _P(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,32);jb=c+16|0}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1580)|0}function Sc(a){return(a|0)<-32768?-32768:(a|0)>32767?32767:a}function NC(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,10);jb=c+16|0}function Lt(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,66);jb=c+16|0}function LR(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,80);jb=c+16|0}function LC(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,14);jb=c+16|0}function JP(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,96);jb=c+16|0}function HA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,11);jb=c+16|0}function Gt(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,22);jb=c+16|0}function GS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,98);jb=c+16|0}function Ez(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,33);jb=c+16|0}function ES(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,48);jb=c+16|0}function BK(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,24);jb=c+16|0}function z8(a){a=a|0;a=kj(a);if(a){nb[v[v[a>>2]+92>>2]](a)}}function wq(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,1);jb=c+16|0}function vh(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,4);jb=c+16|0}function vS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,576);jb=b+16|0}function qT(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,610);jb=b+16|0}function mP(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,146);jb=b+16|0}function lQ(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,130);jb=b+16|0}function ju(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,3);jb=c+16|0}function jQ(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,600);jb=b+16|0}function iP(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,608);jb=b+16|0}function bQ(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,126);jb=b+16|0}function aA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,6);jb=c+16|0}function _t(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,5);jb=c+16|0}function Yt(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,7);jb=c+16|0}function VO(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,204);jb=b+16|0}function Tu(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function QR(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,192);jb=b+16|0}function Ok(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,2);jb=c+16|0}function Ju(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,8);jb=c+16|0}function IB(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,497);jb=b+16|0}function Cq(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0}function BS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,157);jb=b+16|0}function AY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function oC(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,36);jb=b+16|0}function lB(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,38);jb=b+16|0}function jB(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,41);jb=b+16|0}function h3(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function f4(a){a=a|0;jI(a,2,100);mp(v[a+24>>2]+484360|0,0)}function bT(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,66);jb=b+16|0}function Z0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb=0;return 0}function Pf(a,b){a=Ima(v[a>>2],v[a+4>>2],b,b>>31);return a}function Om(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function MR(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,80);jb=b+16|0}function KP(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,96);jb=b+16|0}function HS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,98);jb=b+16|0}function Fb(a){if(Fe(a)){return v[a+4>>2]}return w[a+11|0]}function FS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,48);jb=b+16|0}function CW(a,b,c){a=a|0;b=b|0;c=c|0;return nb[a|0](b,c)|0}function BD(a){a=v[a>>2]-12|0;if((Tu(a+8|0)|0)<=-1){Xb(a)}}function $Q(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,52);jb=b+16|0}function yw(a,b){return v[((a>>>24^b)<<2)+457184>>2]^a<<8}function ys(a){if(v[a>>2]){CL(a);Re(zb(a),v[a>>2],yd(a))}}function tE(a){if(v[a>>2]){rE(a);TD(_k(a),v[a>>2],Zk(a))}}function pq(a){if(v[a>>2]){fC(a);pg(zb(a),v[a>>2],yf(a))}}function oj(a){a=v[a+656>>2];if(!a){return 0}return zi(a)}function ke(a){if(v[a>>2]){Re(zb(a),v[a>>2],v[zb(a)>>2])}}function ee(a,b,c){Uc(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function ch(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function bq(a){if(v[a>>2]){fB(a);Wn(zb(a),v[a>>2],Vf(a))}}function aV(a){a=a|0;VC(a,11650);v[a>>2]=77244;return a|0}function X2(a){a=a|0;return sj(Vb(v[a+24>>2]+484360|0))|0}function Tn(a,b,c){Uc(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function Of(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Nw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function NV(a){a=a|0;VC(a,11072);v[a>>2]=76900;return a|0}function Lm(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function KA(a){if(v[a>>2]){ET(a);pg(zb(a),v[a>>2],yf(a))}}function IG(a){while(1){if((Cr(a)|0)!=-1){continue}break}}function De(a){if(!v[a+20>>2]){return 0}return v[a>>2]!=0}function At(a){if(v[a>>2]){TR(a);Nt(zb(a),v[a>>2],Li(a))}}function zka(a,b){a=a|0;b=b|0;Ub(a,b?b:14548);return a|0}function xC(a){a=a|0;v[a>>2]=77128;Hu(a+12|0);return a|0}function wy(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function wS(a){a=a|0;if(!w[a|0]){return 1}return Tf(a)|0}function vD(a,b,c){b=Da(a|0,b|0,c|0)|0;mb=O()|0;return b}function u1(a,b,c){a=a|0;b=b|0;c=c|0;return od(B(b,c))|0}function rt(a){un(a+88|0);un(a+68|0);un(a+48|0);return a}function p4(a,b,c){a=a|0;b=b|0;c=c|0;td(a,LD(c,b,$e(b)))}function oha(a,b){a=a|0;b=b|0;return KF(a,Tb(b),Fb(b))|0}function ki(a){return Ae(a)|Ae(a)<<8|Ae(a)<<16|Ae(a)<<24}function fV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Vu(a,b,c,d)}function fE(a,b){hm(v[b>>2]);gm(v[a>>2]);v[a>>2]=v[b>>2]}function aE(a){a=a|0;v[a>>2]=64824;yb(a+12|0);return a|0}function _l(a,b,c){a=Ima(v[a>>2],v[a+4>>2],b,c);return a}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;return Ar(a,b,c)|0}function Yla(a,b,c){a=a|0;b=b|0;c=c|0;return FA(a,b,c)|0}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;return DA(a,b,c)|0}function Wt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function QV(a,b,c){a=a|0;b=b|0;c=c|0;Vu(a,b,v[b+8>>2],c)}function PF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Og(a,-1,-1)}function LB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ye(a,c,d,b)}function EH(a){a=a|0;v[a>>2]=83720;$y(a+12|0);return a|0}function CH(a){a=a|0;v[a>>2]=83760;Zy(a+12|0);return a|0}function $D(a){a=a|0;v[a>>2]=64864;yb(a+16|0);return a|0}function uo(a){a=a|0;v[a>>2]=58688;Ob(a+4|0);return a|0}function uA(a,b,c){a=a|0;b=b|0;c=c|0;return zT(a,b,c)|0}function qv(a){a=a|0;v[a>>2]=71224;BD(a+4|0);return a|0}function l7(a){a=a|0;PI(a);t[a+4202|0]=1;v[a+4224>>2]=0}function il(a){a=a|0;v[a>>2]=58624;Ob(a+4|0);return a|0}function iF(a){return(a|0)!=0&(a|0)!=60368&(a|0)!=60392}function hE(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){gm(b)}}function cr(a,b,c){return FE(Tb(a),Fb(a),Tb(b),c,Fb(b))}function _E(a,b,c,d){a=$E(a,b,c,0,-2147483648);return a}function Zy(a){a=a|0;v[a>>2]=76312;Pg(a+4|0);return a|0}function Zc(a,b,c){a=a|0;b=b|0;c=c|0;Te(a,b);return a|0}function Wz(a,b,c){a=a|0;b=b|0;c=c|0;return GA(a,b,c)|0}function TG(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function Rr(a){a=a|0;v[a>>2]=83592;Sw(a+4|0);return a|0}function Rq(a){a=a|0;v[a>>2]=71244;BD(a+4|0);return a|0}function RA(a){if(w[a+1|0]==2){return w[a|0]<3}return 0}function PN(a,b,c){a=a|0;b=b|0;c=c|0;return Os(a,b,c)|0}function Nba(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function MI(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function LI(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function Kc(a){if(Fe(a)){a=hk(a)-1|0}else{a=10}return a}function Jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pA(b,c,d)}function Hu(a){a=a|0;v[a>>2]=77168;Bb(a+4|0);return a|0}function Fd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function Dz(a,b,c){b=b-a|0;if(b){aj(c,a,b)}return b+c|0}function zF(a){a=a|0;return jr(v[v[a>>2]-12>>2]+a|0)|0}function u3(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function ng(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+20>>2]](a,b)}function fj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function e0(a){a=a|0;return If(v[v[a>>2]-12>>2]+a|0)|0}function bJ(a){a=a|0;return Ai(C(z[a+4224>>2]*C(4)))|0}function _g(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+24>>2]](a,b)}function Zg(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+28>>2]](a,b)}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Uq(a){if(Fe(a)){a=hk(a)-1|0}else{a=1}return a}function Taa(a){a=a|0;z[a+12>>2]=1;XK(a,4);return a|0}
function MF(a){a=a|0;return mr(v[v[a>>2]-12>>2]+a|0)|0}function Lg(a){var b=0;b=Cr(a);v[a+1396>>2]=0;return b}function Fu(a,b){a=Hma(v[a>>2],v[a+4>>2],b,0);return a}function Ao(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function AN(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;Ay(a)}function A$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;qi(a,c,d)}function $2(a){a=a|0;return Yd(v[v[a>>2]-12>>2]+a|0)|0}function yma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function yb(a){if(Fe(a)){pg(a,v[a>>2],hk(a))}return a}function wm(a,b){return nb[v[v[a>>2]+36>>2]](a,b,0)|0}function vm(a,b){return nb[v[v[a>>2]+52>>2]](a,b,0)|0}function vO(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function uc(a,b,c){a=a|0;b=b|0;c=c|0;_s(a);return a|0}function iW(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+48}function hO(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function ei(a){a=a|0;return nb[v[v[a>>2]+12>>2]](a)|0}function di(a){a=a|0;return nb[v[v[a>>2]+16>>2]](a)|0}function Ye(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function W2(a){a=a|0;return kK(v[a+24>>2]+484344|0)|0}function V8(a,b,c){a=a|0;b=b|0;c=c|0;Kl(a,b+4260|0,8)}function V1(a,b){a=a|0;b=b|0;TM(v[a>>2],b);return a|0}function PR(a){var b=0;b=jb-16|0;jb=b;Wt(a);jb=b+16|0}function Kn(a,b){a=a|0;b=b|0;return Ce(a)>>>0>b>>>0|0}function HC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function AC(a){var b=0;b=jb-16|0;jb=b;bm(a);jb=b+16|0}function $m(a){a=a|0;return nb[v[v[a>>2]+24>>2]](a)|0}function $V(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function t4(a){a=a|0;a=v[a+4>>2];return(a?a:38169)|0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function jia(a,b){a=a|0;b=b|0;return KF(a,b,$e(b))|0}function i3(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function hla(a){a=a|0;return xK(w[a+3|0],w[a+5|0])|0}function e3(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function cJ(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function ao(a){a=a|0;a=a+12|0;nb[v[v[a>>2]>>2]](a)|0}function _m(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function V7(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function Mn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function Gma(a){if(a){return 31-E(a-1^a)|0}return 32}function G8(a){a=a|0;t[a+4202|0]=1;as(a);fx(a);vJ(a)}function zC(a,b,c){Sk(a,b);v[a+12>>2]=c;v[a+8>>2]=0}function z1(a,b,c){a=a|0;b=b|0;c=c|0;_G(a-88|0,b,c)}function vr(a){if(!a){return 0}v[114552]=a;return-1}function tda(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0}function t3(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function s7(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function oo(a,b){b=v[b>>2];v[a>>2]=b;hm(b);return a}function ml(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function kN(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function iy(a){a=a|0;return zs(w[a+2|0],w[a+4|0])|0}function im(a,b){Ze(a,b);Rb(a+16|0,0,1040);return a}function d3(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function baa(a,b){a=a|0;b=b|0;Xi(a+36|0,b);return 1}function Y9(a,b){a=a|0;b=b|0;a=a+24|0;tK(a,b);Ox(a)}function Vm(a,b,c){if(!c){return 0}return pd(a,b,c)}function Or(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function Nd(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function Mc(a,b){a=a|0;b=b|0;return bO(a,b,$e(b))|0}function Ly(a,b){a=a|0;b=b|0;return eo(a,b,$e(b))|0}function Lc(a){if(Fe(a)){lo(v[a>>2],hk(a))}return a}function Kl(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function Eo(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function Eb(a,b,c){Uc(a,(c>>>3&536870908)+b|0,1<<c)}function C1(a,b,c){a=a|0;b=b|0;c=c|0;aH(a-88|0,b,c)}function Bs(a){a=a|0;return zs(w[a+3|0],w[a+5|0])|0}function Bba(a){a=a|0;wf(85224);wf(85216);yb(85204)}function yl(a){wi(a+724|0);wi(a+736|0);wi(a+748|0)}function y1(a,b){a=a|0;b=b|0;return ZG(a-88|0,b)|0}function vha(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,24,b)}function rba(a,b){a=a|0;b=b|0;return lc(a,b,116)|0}function iq(a,b,c){a=a|0;b=b|0;c=c|0;td(a,SN(b,c))}function iG(a,b){cG(a,74);v[a+4>>2]=v[a+4>>2]|b&74}function Sja(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,16,b)}function Rp(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function Qy(a,b,c){a=a|0;b=b|0;c=c|0;GO(Od(a,b),c)}function Oz(a,b,c){Kl(a,v[b+28>>2]+(c<<12)|0,4096)}function Mq(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function Lp(a){return(v[a+480180>>2]&740327453)!=0}function FO(a,b,c){a=a|0;b=b|0;c=c|0;td(a,Ly(b,c))}function FM(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function Ei(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function E1(a,b,c){a=a|0;b=b|0;c=+c;cH(a-88|0,b,c)}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,33,b)}function B1(a,b){a=a|0;b=b|0;return $G(a-88|0,b)|0}function $z(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function yu(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,26,b)}function yg(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,32,b)}function xp(a){return(v[zb(a)>>2]-v[a>>2]|0)/20|0}function xG(a,b){hw(v[v[a>>2]-12>>2]+a|0,v[b>>2])}function ve(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function tn(a){return(v[zb(a)>>2]-v[a>>2]|0)/56|0}function sG(a,b){if(!a){return 0}return ck(a,b,0)}function no(a){return(v[ec(a)>>2]-v[a>>2]|0)/12|0}function nga(a,b){a=a|0;b=b|0;return nb[b|0](a)|0}function lj(a){return(v[zb(a)>>2]-v[a>>2]|0)/52|0}function lg(a){return(v[zb(a)>>2]-v[a>>2]|0)/12|0}function Zf(a,b){return FE(Tb(a),Fb(a),b,0,$e(b))}function We(a){return(v[zb(a)>>2]-v[a>>2]|0)/24|0}function Ut(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,64,b)}function Uc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function Tl(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,22,b)}function Sg(a,b){if(Fe(a)){we(a,b);return}of(a,b)}function Pja(a,b){a=a|0;b=b|0;return hs(a,b,17)|0}function Nl(a){return(v[ec(a)>>2]-v[a>>2]|0)/24|0}function Ml(a){return(v[zb(a)>>2]-v[a>>2]|0)/48|0}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,9,b)}function Jl(a){return(v[zb(a)>>2]-v[a>>2]|0)/33|0}function IS(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,40,b)}function Ht(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,28,b)}function Hn(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,20,b)}function HT(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,30,b)}function Fk(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,12,b)}function EF(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function Bl(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function sT(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function rh(a){return(mf(a)|0)!=(0-mf(a+12|0)|0)}function hS(a,b){a=a|0;b=b|0;return hs(a,b,32)|0}function gO(a,b){Oc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function dv(a,b,c){a=a|0;b=b|0;c=c|0;kD(c);Xb(a)}function ala(a,b){a=a|0;b=b|0;return Ul(a,b,3)|0}function aU(a,b){a=a|0;b=b|0;return hs(a,b,11)|0}function Tb(a){if(Fe(a)){return v[a>>2]}return a}function Sm(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Nx(a){v[a+4>>2]=0;v[a+8>>2]=-1;t[a|0]=0}function Lla(a,b,c){a=a|0;b=b|0;c=c|0;lc(b,c,48)}function Li(a){return(v[zb(a)>>2]-v[a>>2]|0)/6|0}function Kh(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function Fy(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function D1(a,b){a=a|0;b=b|0;return+bH(a-88|0,b)}function Cp(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function Cia(a,b){a=a|0;b=b|0;return Ul(a,b,2)|0}function Ay(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function zk(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function zZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461724))}function yc(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function yZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461488))}function xZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461496))}function wZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461504))}function vk(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function vZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461512))}function u7(a){a=a|0;return z[a+4212>>2]<C(1)|0}function tZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461552))}function sZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461560))}function rZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461568))}function qZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461576))}function ph(a,b){a=a|0;b=b|0;return Ul(a,b,4)|0}function nZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461584))}function lw(a){var b=0;b=v[a>>2];qg(a);return b}function lZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461592))}function jf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function jZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461600))}function hZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461608))}function gZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461520))}function fZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461528))}function dZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461536))}function bk(a){a=a|0;return HF(v[a>>2])<<24>>24}function bZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461544))}function _Y(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461624))}function X7(a){a=a|0;return z[a+4220>>2]<C(1)|0}function TP(a,b){a=a|0;b=b|0;return Ul(a,b,8)|0}function S9(a,b){a=a|0;b=b|0;return hs(a,b,1)|0}function Rn(a,b){a=a|0;b=b|0;return Xe(a,b,0)|0}function Qs(a,b){a=a|0;b=b|0;Af(a,b);return a|0}function Qj(a){return nb[v[v[a>>2]+36>>2]](a)|0}function Ns(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Ni(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function N9(a,b){a=a|0;b=b|0;uB(a,b);return a|0}function Mv(a,b,c,d){a=$E(a,b,c,-1,-1);return a}function KW(a){a=a|0;a=jb-a&-16;jb=a;return a|0}function JZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461472))}function JU(a,b){a=a|0;b=b|0;On(a,b);return a|0}function Id(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function IZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461480))}function HZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461676))}function GZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461668))}function Fp(a,b,c){b=b-a|0;if(b){aj(c-b|0,a,b)}}function Fm(a){return nb[v[v[a>>2]+28>>2]](a)|0}function FZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461684))}function DZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461692))}function Cl(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function CZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461700))}function BZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461708))}function Ag(a,b){a=a|0;b=b|0;GF(a,v[a+16>>2]|b)}function AZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461716))}function $Y(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461616))}function vp(a,b){return(B(b,104)+a|0)+484380|0}function sN(a){rN(a);Rb(a+27|0,0,255);return a}function lS(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function is(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function gc(a,b,c){a=a|0;b=b|0;c=c|0;Kl(a,b,c)}function fk(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function cg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function bo(a){SC(a);v[a+8>>2]=0;v[a>>2]=70608}function b7(a){a=a|0;NI(a);_w(a);t[a+4202|0]=1}function Qe(a,b,c){if(!(w[a|0]&32)){jv(b,c,a)}}function QS(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function P7(a){a=a|0;t[a+4202|0]=1;$I(a);aJ(a)}function Ms(a){return(a>>>0<9?a:a-9|256)&65535}function H7(a){a=a|0;t[a+4202|0]=1;XI(a);WI(a)}function G0(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,c,b)}function DN(a,b){yN(v[a>>2],b);yN(v[a+4>>2],b)}function Ak(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function zi(a){return(w[a+31|0]-1&255)>>>0<17}function zE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function yF(a){a=a|0;Wv(v[v[a>>2]-12>>2]+a|0)}function to(a,b){a=a|0;b=b|0;return IF(a,b)^1}function sla(a,b,c){a=a|0;b=b|0;c=c|0;Ze(b,c)}function qA(a,b){a=a|0;b=b|0;return Ku(a,b)|0}function pu(a,b){a=a|0;b=b|0;return mu(a,b)|0}function kr(a,b){a=a|0;b=b|0;return CF(a,b)^1}function jk(a){return v[zb(a)>>2]-v[a>>2]>>11}function jga(a){a=a|0;Oy(a+288|0);sp(a+800|0)}function jg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function gj(a,b){a=a|0;b=b|0;return IF(a,b)|0}function fT(a){t[a+12|0]=w[a+12|0]|2;return a}function cv(a,b){a=a|0;b=b|0;return Ly(a,b)|0}function _j(a,b){a=a|0;b=b|0;return CF(a,b)|0}function Zs(a,b){a=a|0;b=b|0;return SN(a,b)|0}function Y$(a){a=a|0;JF(v[v[a>>2]-12>>2]+a|0)}function Vw(a){a=a|0;v[a>>2]=83460;return a|0}function U2(a){a=a|0;NH(v[v[a>>2]-12>>2]+a|0)}function Ti(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function RN(a,b){a=a|0;b=b|0;return qd(a,b)|0}function Qf(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Pi(a,b){a=a|0;b=b|0;return EA(a,b)|0}function LM(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function LF(a){a=a|0;Zv(v[v[a>>2]-12>>2]+a|0)}function Kma(a,b,c,d){a=Fma(a,b,c,d);return a}function Jb(a,b){a=a|0;b=b|0;return rl(a,b)^1}function Gi(a,b){a=a|0;b=b|0;return Jb(a,b)|0}function Eia(a){a=a|0;HQ(a);return v[a+16>>2]}function DR(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Cc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function CM(a){BM(a+20|0);ZL(a+8|0);wf(a+4|0)}function yd(a){return v[zb(a)>>2]-v[a>>2]>>2}function ug(a){return v[v[a+8>>2]>>2]==(a|0)}function th(a){return v[zb(a)>>2]-v[a>>2]>>5}function sg(a){return v[ec(a)>>2]-v[a>>2]>>2}function ika(a,b){a=a|0;b=b|0;Sp(Rb(b,0,48))}function hx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function g3(a){a=a|0;return MH(v[a+24>>2])|0}function ev(a){return v[ec(a)>>2]-v[a>>2]>>4}function c1(a){a=a|0;return _a(v[a+60>>2])|0}function Zk(a){return v[Tq(a)>>2]-v[a>>2]>>2}function Yh(a){return v[zb(a)>>2]-v[a>>2]>>4}function Xz(a,b,c){a=a|0;b=b|0;c=c|0;oI(a,c)}function Vn(a){return v[ec(a)>>2]-v[a>>2]>>1}function Vi(a){return v[zb(a)>>2]-v[a>>2]>>3}function Vf(a){return v[zb(a)>>2]-v[a>>2]>>1}function QJ(a,b,c){a=a|0;b=b|0;c=c|0;Gp(b,c)}function Pu(a){return v[ec(a)>>2]-v[a>>2]>>5}function Mz(a,b,c){a=a|0;b=b|0;c=c|0;Af(b,c)}function Jia(a){a=a|0;HQ(a);return v[a+4>>2]}function Dv(a,b,c){a=a|0;b=b|0;c=c|0;td(b,c)}function Bi(a,b,c){a=a|0;b=b|0;c=c|0;Us(a,c)}function $w(a){return C(C(a*C(7900))+C(100))}function zI(a){return Lh(C(BI(a)*C(32768)))}function yf(a){return v[zb(a)>>2]-v[a>>2]|0}function vL(a){return a>>>0<=255&a>>>0>=251}function t7(a){a=a|0;return C(z[a+4220>>2])}function si(a,b){a=a|0;b=b|0;return C(C(0))}function oZ(a,b){a=a|0;b=b|0;return $h(b)|0}function mf(a){return v[a+4>>2]-v[a>>2]>>11}function hl(a){a=a|0;Yv(v[a>>2]);return a|0}function hA(a){return v[ec(a)>>2]-v[a>>2]|0}function h1(a){a=a|0;cG(a,16384);return a|0}function g1(a){a=a|0;hw(a,16384);return a|0}function fJ(a){a=a|0;nb[v[v[a>>2]+4>>2]](a)}function f1(a,b){a=a|0;b=b|0;return bh(a)|0}function eJ(a){a=a|0;return C(z[a+4208>>2])}function cG(a,b){v[a+4>>2]=v[a+4>>2]&(b^-1)}function bG(a){QH(a);v[a>>2]=59220;return a}function W7(a){a=a|0;return C(z[a+4212>>2])}function VY(){oo(461652,iE());return 461652}function Ue(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function Sr(a){QH(a);v[a>>2]=59148;return a}function PD(a,b){a=a|0;b=b|0;return sm(b)|0}function Gg(a,b,c){return Ma(a|0,b|0,c|0)|0}function Cm(a){a=a|0;AF(v[a>>2]);return a|0}function CN(a,b){u[a+22>>1]=b&7;Ay(a);By(a)}function xe(a){return v[a+4>>2]-v[a>>2]>>5}function ul(a){yb(a+36|0);oe(a+24|0);Ll(a)}function qt(a,b){return v[a>>2]-v[b>>2]>>2}function oc(a){return v[a+4>>2]-v[a>>2]>>1}function nu(a){a=a|0;return Yg(a,461676)|0}function nd(a){return v[a+4>>2]-v[a>>2]>>4}function nI(a,b){a=a|0;b=b|0;Uv(a,v[b>>2])}function m8(a,b,c){a=a|0;b=b|0;c=c|0;Qf(a)}function j3(a){a=a|0;return+zL(v[a+24>>2])}function hk(a){return v[a+8>>2]&2147483647}function h0(a){a=a|0;return Yg(a,461488)|0}function dw(a){a=a|0;return Yg(a,461684)|0}function cw(a){a=a|0;return Yg(a,461692)|0}function cba(a,b){a=a|0;b=b|0;Xi(a+40|0,b)}function cF(){return(v[v[21203]>>2]?4:1)|0}function az(a){ke(a+24|0);fe(a+12|0);fe(a)}function Yq(a,b){nb[v[v[b>>2]+40>>2]](a,b)}function Xv(a){a=a|0;return Yg(a,461668)|0}function Vp(a,b){return v[a>>2]-v[b>>2]>>1}function V$(a){a=a|0;return Yg(a,461504)|0}function Sj(a,b){nb[v[v[b>>2]+44>>2]](a,b)}function Ru(a){Eq(a+28|0);Bb(a+12|0);yb(a)}function Rj(a,b){nb[v[v[b>>2]+32>>2]](a,b)}function R8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function Nr(a){return(a|0)<=65535&(a|0)>=0}function Kv(a){a=a|0;return Yg(a,461716)|0}function Kb(a){return v[a+4>>2]-v[a>>2]>>2}function JV(a){a=a|0;return v[a+4>>2]!=0|0}function Hv(a){a=a|0;return Yg(a,461724)|0}function FI(a){return C(C(a*C(96))+C(-96))}function E5(a,b){a=a|0;b=b|0;Uv(a,x[b>>1])}function E2(a,b){a=a|0;b=b|0;return b-a>>3}function Dg(a){return v[a+4>>2]-v[a>>2]>>3}function Bma(a,b){a=a|0;b=b|0;Xi(a+12|0,b)}function BN(a,b){t[a+21|0]=b&3;Ay(a);By(a)}function xc(a){return v[a+4>>2]-v[a>>2]|0}function w1(a,b){a=a|0;b=b|0;XG(a-88|0,b)}function uz(a,b){return v[a>>2]+B(b,20)|0}function te(a){v[a>>2]=v[a>>2]+2;return a}function qd(a,b){return v[a>>2]+B(b,12)|0}function p1(a){a=a|0;if(a){MG(a);Xd(a,a)}}function nm(a,b,c){qi(a,b,b+c|0);return a}function mr(a){a=a|0;ah(a+8|0);return a|0}function lC(a){return(w[a+24|0]&16)>>>4|0}function jr(a){a=a|0;ah(a+4|0);return a|0}function hn(a,b,c){return a<b?b:C(F(a,c))}function h6(a,b){a=a|0;b=b|0;Uv(a,w[b|0])}function fs(a,b,c){return u[b>>1]<u[c>>1]}function fl(a){a=a|0;return BF(v[a>>2])|0}function eY(a,b){a=a|0;b=b|0;Af(a,b+16|0)}function am(a,b){return v[a>>2]-v[b>>2]|0}function _d(a){v[a>>2]=v[a>>2]+4;return a}function Zl(a,b){return v[a>>2]+(b<<11)|0}function YM(a){v[a>>2]=v[a>>2]-4;return a}function Xn(a,b,c){return x[b>>1]<x[c>>1]}function Xm(a){return v[v[a+48>>2]+12>>2]}function SN(a,b){return eo(a,Tb(b),Fb(b))}function Rc(a,b){return v[a>>2]+B(b,24)|0}function R9(a,b){a=a|0;b=b|0;Af(a,b+36|0)}function ON(a){v[a>>2]=v[a>>2]-2;return a}function NK(a,b){Bl(a,A[b>>3],-A[b+8>>3])}function Md(a,b){v[a>>2]=v[b>>2];return a}function M8(a,b){a=a|0;b=b|0;Rb(b,0,2048)}function M1(a,b){a=a|0;b=b|0;kH(a-88|0,b)}function LH(a,b){a=a|0;b=b|0;Af(a,b+12|0)}function L1(a,b){a=a|0;b=b|0;jH(a-88|0,b)}function Gw(a){a=a|0;Qr(a+8|0);return a|0}function Ge(a,b){return v[a>>2]+B(b,52)|0}function Fl(a,b){return v[a>>2]+B(b,56)|0}function En(a){return x[a+480190>>1]<3999}function EI(a){a=a|0;Rb(a+4296|0,0,81928)}function Bc(a,b){a=a|0;b=b|0;oo(a,b+28|0)}function BR(a,b){return v[a>>2]+B(b,33)|0}function tt(a){a=a|0;return v[a>>2]+14|0}function tc(a,b){return v[a>>2]+(b<<4)|0}function rl(a,b){return v[a>>2]==v[b>>2]}function rc(a,b){return v[a>>2]+(b<<1)|0}function pE(){Ld(463120);v[115780]=67864}function oE(){Ld(463152);v[115788]=68360}function nE(){Ld(463160);v[115790]=68524}function mma(a,b){a=a|0;b=b|0;Uc(a,b,44)}function md(a){return v[a>>2]==v[a+4>>2]}function mJ(a){return(w[a+24|0]&8)>>>3|0}function mE(){Ld(463168);v[115792]=68688}function lu(a,b){return v[a>>2]+(b<<5)|0}function lk(a){return x[Xm(a)+480188>>1]}function lE(){Ld(463176);v[115794]=68852}function l1(a){a=a|0;iG(a,2);return a|0}
function kE(){Ld(463248);v[115812]=69016}function fn(a){a=a|0;return AM(w[a|0])|0}function el(a){return(a|0)==32|a-9>>>0<5}function dY(a,b){a=a|0;b=b|0;Ub(a,64896)}function dI(a){return(Tb(a)+Fb(a)|0)-1|0}function d9(a){a=a|0;BT(a,80,150,80,255)}function cY(a,b){a=a|0;b=b|0;zv(a,64904)}function bY(a,b){a=a|0;b=b|0;Ub(a,64924)}function aY(a,b){a=a|0;b=b|0;zv(a,64932)}function Zn(a){return B(sq(a),ue(a))&255}function UC(a,b){Zb(a,b);Zb(a+4|0,b+4|0)}function Tk(a,b){return v[a>>2]+(b<<3)|0}function Tf(a){a=a|0;return be(w[a|0])|0}function SC(a){v[a+4>>2]=0;v[a>>2]=70552}function Q1(a){a=a|0;return Gw(a-88|0)|0}function Pb(a,b){return v[a>>2]+(b<<2)|0}function Nc(a,b){return v[a>>2]+B(b,6)|0}function Mb(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function Kr(a,b){v[a+24>>2]=v[a+24>>2]+b}function K1(a,b){a=a|0;b=+b;iH(a-88|0,b)}function Jha(a,b){a=a|0;b=b|0;Uc(a,b,10)}function I1(a,b){a=a|0;b=+b;gH(a-88|0,b)}function Hja(a,b){a=a|0;b=b|0;Uc(a,b,17)}function Gf(a){a=a|0;return!v[a+16>>2]|0}function G1(a,b){a=a|0;b=+b;eH(a-88|0,b)}function Fg(a,b){v[a+8>>2]=b|-2147483648}function $6(a){a=a|0;return v[a+4260>>2]}function yy(a,b,c){if(b){Rb(a,Cg(c),b)}}function yB(a,b){a=a|0;b=b|0;return b|0}function xu(a,b){a=a|0;b=b|0;Uc(a,b,32)}function wi(a){v[a+4>>2]=0;v[a+8>>2]=-1}function vM(a,b){return(uk(a,b)|0)!=255}function sha(a,b){a=a|0;b=b|0;Uc(a,b,5)}function qda(a,b){a=a|0;b=b|0;Bl(b,0,0)}function oS(a,b){v[a>>2]=v[a>>2]+B(b,6)}function k1(a){a=a|0;iG(a,8);return a|0}function iJ(a,b){return z[a>>2]<z[b>>2]}function Yp(a,b){return v[a>>2]<v[b>>2]}function Xd(a,b){if(!v[a+80>>2]){Xb(b)}}function XQ(a,b){v[a>>2]=v[a>>2]+(b<<2)}function St(a){a=a|0;return gA(oc(a))|0}function QT(a,b){a=a|0;b=b|0;Uc(a,b,11)}function Q8(a){a=a|0;return w[a+4201|0]}function P8(a){a=a|0;return w[a+4202|0]}function OL(a,b){return A[a>>3]<A[b>>3]}function LE(a,b){a=a|0;b=b|0;Hj(a,1,45)}function KE(a,b){a=a|0;b=b|0;UE(a,1,45)}function Jd(a,b){return y[a>>2]<y[b>>2]}function Fh(a,b,c){td(a,b);td(a+12|0,c)}function E6(a){a=a|0;return(a|0)==277|0}function ws(a){return(a|0)<=-1?0-a|0:a}function vc(a){v[v[a+8>>2]>>2]=v[a>>2]}function v0(a){a=a|0;return v[a+20>>2]}function ue(a){return w[a+34|0]&64?2:1}function ts(a){a=a|0;return 2147483647}function s3(a){a=a|0;return+A[a+16>>3]}function oU(a,b){a=a|0;b=b|0;u[b>>1]=0}function mS(a,b){a=a|0;b=b|0;$r(a,0,b)}function ky(a,b,c){return a<b?b:F(a,c)}function kga(a){a=a|0;AO(a);return a|0}function ij(a,b){return Tb(a)+(b<<2)|0}function hw(a,b){v[a+4>>2]=v[a+4>>2]|b}function be(a){return(a-1&255)>>>0<120}function Yha(a){a=a|0;return w[a+40|0]}function W1(a){a=a|0;return v[a+16>>2]}function VN(a,b){v[a+4>>2]=b;v[a>>2]=b}function VC(a,b){ED(a,b);v[a>>2]=71484}function UU(a){a=a|0;return v[a+12>>2]}function RB(a){zb(a);return 2147483647}function M6(a){a=a|0;return-2013527448}function LU(a){a=a|0;return v[a+24>>2]}function J1(a){a=a|0;return+hH(a-88|0)}function HH(a){return a?(a|0)==2?3:2:1}function H1(a){a=a|0;return+fH(a-88|0)}function F1(a){a=a|0;return+dH(a-88|0)}function Bj(a){return B(v[a>>2],Zn(a))}function zt(a){a=a|0;return v[a+4>>2]}function z7(a){a=a|0;return-281111764}function xI(a,b){a=a|0;b=b|0;return 0}function wu(a){return w[a+21|0]>>>7|0}function vt(a){a=a|0;return Qb(a,1)^1}function v7(a){a=a|0;return-271958638}function uF(a){a=a|0;$v(a);return a|0}function t8(a){a=a|0;return 542066252}function sq(a){return t[a+34|0]&1?2:1}function rD(a,b){return w[a|0]<w[b|0]}function nr(a,b){a=a|0;b=b|0;return-1}function mH(a){v[a>>2]=84408;return a}function kma(a,b){a=a|0;b=b|0;Ss(a,b)}function k7(a){a=a|0;return-620920304}function jO(a){a=a|0;ZP(a);return a|0}function ix(a,b){a=a|0;b=b|0;return 1}function gka(a){a=a|0;return w[a+8|0]}function ah(a){a=a|0;_v(a);return a|0}function a7(a){a=a|0;return-275227023}function ZB(a){return w[a+22|0]>>>7|0}function Y7(a){a=a|0;return-270114148}function Vb(a){return lu(a,w[a+16|0])}function V0(a){a=a|0;return $F(a,0)|0}function U0(a){a=a|0;return $F(a,1)|0}function T6(a){a=a|0;return 302837129}function R0(a){a=a|0;return XF(a,0)|0}function Qz(a){return v[a+1304496>>2]}function Q0(a){a=a|0;return XF(a,1)|0}function Pv(a){a=a|0;if(iF(a)){Xb(a)}}function O7(a){a=a|0;return-285139079}function Ne(a,b){v[a+4>>2]=b;return a}function MH(a){return x[a+1074438>>1]}function Jt(a){return(w[a+16|0]&5)!=0}function IF(a,b){return tF(a)^tF(b)^1}function G7(a){a=a|0;return-284078960}function Fz(a){a=a|0;return v[a+8>>2]}function Fn(a,b){u[a+8>>1]=b;return a}function Fe(a){return w[a+11|0]>>>7|0}function Ck(a){a=a|0;Dt(a);return a|0}function CF(a,b){return sF(a)^sF(b)^1}function Bp(a){a=a|0;st(a);return a|0}function B6(a,b){a=a|0;b=b|0;return 3}function A6(a,b){a=a|0;b=b|0;return 2}function $v(a){a=a|0;Rq(a);return a|0}function zu(a,b){Kb(a);UB(a,b);Qg(a)}function zma(a){a=a|0;return vq(a)|0}function xka(a){a=a|0;return Qz(a)|0}function oK(a,b){jf(a);oL(a,b);jK(a)}function mx(a,b){Kb(a);VR(a,b);Qg(a)}function l8(a,b,c){a=a|0;b=b|0;c=c|0}function id(a,b){return Zl(a+12|0,b)}function hm(a){v[a+4>>2]=v[a+4>>2]+1}function h8(a,b){a=a|0;b=b|0;Qs(a,b)}function gY(a){a=a|0;return t[a+8|0]}function ft(a){return v[zb(a)>>2]<<5}function fY(a){a=a|0;return t[a+9|0]}function cB(a,b){a=a|0;b=b|0;bB(a,b)}function ada(a){a=a|0;return Lj(a)|0}function aS(a,b){xc(a);vT(a,b);tp(a)}function Us(a,b){a=a|0;b=b|0;Af(a,b)}function UR(a,b){Kb(a);rL(a,b);Qg(a)}function Tg(a){return v[a+4>>2]-32|0}function TN(a,b){xe(a);MN(a,b);Wu(a)}function Sz(a,b){cg(a);SR(a,b);HR(a)}function Rt(a){return v[a+4>>2]-24|0}function RV(a){a=a|0;return Cf(a)|0}
function Pn(a,b){oc(a);GB(a,b);Nn(a)}function OH(a){return v[a+4>>2]-48|0}function Kaa(a){a=a|0;return Ih(a)|0}function KH(a){return v[a+4>>2]-12|0}function Cu(a,b){xc(a);eC(a,b);tp(a)}function CP(a){return v[a+4>>2]-56|0}function CI(a){v[a>>2]=0;v[a+4>>2]=0}function AM(a){return(a+5&255)>>>0<2}function yt(a){a=a|0;return jh(a)|0}function yn(a,b,c){return Xn(a,b,c)}function xs(a){return _o(a)<<24>>24}function xq(a){a=a|0;return Gd(a)|0}function xh(a,b,c){if(c){lc(a,b,c)}}function ww(a){return!pd(a,84484,6)}function wc(a,b){return v[a>>2]+b|0}function tz(a,b){return cf(a,0-b|0)}function rha(a,b){a=a|0;b=b|0;az(b)}function qD(a){a=a|0;return v[a>>2]}function pj(a){return v[a+4>>2]-4|0}function oX(a){a=a|0;return Pe(a)|0}function mda(a,b){a=a|0;b=b|0;ke(b)}function lO(a,b){return pp(a,0-b|0)}function jda(a,b){a=a|0;b=b|0;ht(b)}function j7(a){a=a|0;v[a+4224>>2]=0}function iC(a){a=a|0;return hg(a)|0}function gf(a,b,c){return Dz(a,b,c)}function fW(a){a=a|0;return _F(a)|0}function eR(a){a=a|0;return tt(a)|0}function cda(a,b){a=a|0;b=b|0;kn(b)}function cc(a){return Ng(v[a+4>>2])}function _B(a){return w[a+22|0]&127}function Waa(a,b){a=a|0;b=b|0;ul(b)}function Vaa(a,b){a=a|0;b=b|0;bg(b)}function TB(a){t[a+2|0]=0;u[a>>1]=0}function Se(a){return v[a+24620>>2]}function Oda(a,b){a=a|0;b=b|0;Dl(b)}function Oc(a,b){v[a>>2]=b;return a}function Kja(a,b){a=a|0;b=b|0;vR(b)}function Ii(a,b){return B(b,12)+a|0}function H0(a){a=a|0;return Jt(a)|0}function $l(a,b,c){if(c){aj(a,b,c)}}function $B(a){return w[a+21|0]&127}function xi(a,b){return(b<<13)+a|0}function wt(a,b){a=a|0;b=b|0;Wt(b)}function wk(a,b){Tn(a,b,v[b+4>>2])}function t1(a,b){a=a|0;b=b|0;Xb(b)}function ri(a){a=a|0;t[a+4202|0]=0}function pW(a,b){a=a|0;b=b|0;uD(b)}function mi(a){return md(a+36|0)^1}function kU(a,b){a=a|0;b=b|0;Xh(b)}function jh(a){return v[a>>2]+16|0}function gW(a){a=a|0;Cn(a,1,10956)}function fu(a){t[a|0]=0;t[a+1|0]=0}function cE(a,b){a=a|0;b=b|0;Ib(b)}function _N(a,b){t[v[a>>2]]=w[b|0]}function Zq(a,b){a=a|0;b=b|0;tf(a)}function ZA(a,b){a=a|0;b=b|0;fu(b)}function Yk(a){Rm(a);v[a>>2]=71116}function WA(a,b){a=a|0;b=b|0;Bb(b)}function Uy(a,b){a=a|0;b=b|0;ff(b)}function Uj(a,b){a=a|0;b=b|0;Wb(a)}function Tc(a,b){_s(a);Oc(a+4|0,b)}function Pz(a,b){a=a|0;b=b|0;xt(b)}function Py(a,b){a=a|0;b=b|0;_s(b)}function Pm(a,b){v[a+1304560>>2]=b}function MU(a,b){a=a|0;b=b|0;TB(b)}function Ld(a){SC(a);v[a>>2]=65252}function Jn(a,b){a=a|0;b=b|0;hf(b)}function Jg(a,b){v[a>>2]=v[a>>2]|b}function Hh(a,b){Uc(a,Tb(b),Fb(b))}function GE(a){return Yg(a,461560)}function Fw(a){a=a|0;t[a+6152|0]=0}function FV(a,b){a=a|0;b=b|0;Ru(b)}function Er(a){return ve(a,-1)?0:a}function EE(a){return Yg(a,461552)}function BE(a){return Yg(a,461576)}function BC(a,b){a=a|0;b=b|0;bm(b)}function AE(a){return Yg(a,461568)}function zn(a){v[a>>2]=v[a>>2]+12}function wQ(a,b){return Ul(a,b,5)}function ty(a){v[a>>2]=v[a>>2]+52}function qQ(a,b){return(b<<4)+a|0}function oJ(a){return a+1074332|0}function mha(a){a=a|0;$y(a);Xb(a)}function kc(a,b){return Tb(a)+b|0}function gha(a){a=a|0;Zy(a);Xb(a)}function eP(a,b){return Zt(a,b,4)}function dd(a,b){return(b<<1)+a|0}function cn(a){return a+1074328|0}function bh(a){return a-48>>>0<10}function bc(a){return Ng(v[a>>2])}function bX(a){a=a|0;return 71091}function an(a){Pg(a+4|0);return a}function aX(a){a=a|0;return 71128}function ZW(a){a=a|0;return 71640}function Ve(a,b){return(b<<2)+a|0}function VA(a,b){return Zt(a,b,7)}function Uw(a,b){return TK(a,b)^1}function Uf(a){v[a>>2]=v[a>>2]+16}function UA(a){return w[a+1|0]==1}function Th(a){v[a>>2]=1;return a}function SA(a,b){return Ul(a,b,7)}function Q$(a){a=a|0;return 58936}function Pw(a){return a+1304500|0}function Ky(a,b){td(a,b);return a}function Ke(a){return v[hc(a)>>2]}function Jk(a,b){Ze(a,b);return a}function Gn(a){v[a>>2]=2;return a}function Gk(a){v[a>>2]=v[a>>2]+24}function Gha(a){a=a|0;hR(a,65535)}function Eu(a){return t[a+24|0]&1}function Et(a,b){return Vd(a,b)^1}function Ek(a){v[a>>2]=0;return a}function Dy(a){v[a>>2]=v[a>>2]+32}function D0(a){a=a|0;return 58208}function Ce(a){return jf(a)&65535}function B0(a){a=a|0;return 58288}function Al(a){u[a>>1]=0;return a}function xP(a){tn(a);vk(a);tn(a)}function x4(a){a=a|0;Vw(a);Xb(a)}function vy(a){v[a>>2]=v[a>>2]+8}function vf(a){yd(a);Kb(a);yd(a)}function vK(a){cg(a);TR(a);HR(a)}function uR(a){Kb(a);tR(a);Qg(a)}function ti(a){Kb(a);WR(a);Qg(a)}function sd(a){return v[a>>2]!=0}function qg(a){v[a>>2]=v[a>>2]+1}function qL(a){lj(a);jf(a);lj(a)}function pv(a){a=a|0;qv(a);Xb(a)}function my(a){t[a|0]=0;return a}function lI(a){a=a|0;Ww(a);Xb(a)}function kA(a){Ni(a);kT(a);jT(a)}function js(a){return vL(w[a|0])}function jE(a){Zk(a);Kb(a);Zk(a)}function ik(a){a=a|0;bf(a);Xb(a)}function iR(a,b){lc(a,b+4|0,256)}function fX(a,b){a=a|0;b=b|0;L()}function dm(a){th(a);xe(a);th(a)}function dP(a){return w[a|0]<129}function bj(a){lg(a);yc(a);lg(a)}function aG(a){a=a|0;il(a);Xb(a)}function YF(a){a=a|0;uo(a);Xb(a)}function Xp(a){oc(a);fB(a);Nn(a)}function XS(a){Ml(a);Ni(a);Ml(a)}function Vk(a){Yh(a);nd(a);Yh(a)}function Te(a,b){v[a>>2]=v[b>>2]}function Su(a){a=a|0;Rq(a);Xb(a)}function Sp(a){return Rb(a,0,48)}function Qk(a){Vf(a);oc(a);Vf(a)}function QI(a){a=a|0;bx(a);Xb(a)}function Ol(a){yf(a);xc(a);yf(a)}function Oh(a){We(a);Id(a);We(a)}function OJ(a){mf(a);GJ(a);FJ(a)}function Mt(a){Li(a);cg(a);Li(a)}function MJ(a){Kb(a);DJ(a);Qg(a)}function LQ(a){xp(a);xp(a);FQ(a)}function Ks(a){Kb(a);CL(a);Qg(a)}function GT(a){oc(a);yT(a);Nn(a)}function Fq(a){xe(a);YC(a);Wu(a)}function Es(a){xc(a);ET(a);tp(a)}function Dq(a){Vi(a);Dg(a);Vi(a)}function Dj(a){v[a>>2]=v[a>>2]+6}function AR(a){Jl(a);zk(a);Jl(a)}function AJ(a){jk(a);mf(a);jk(a)}function yX(a){a=a|0;Lc(461860)}function wX(a){a=a|0;yb(461876)}function uX(a){a=a|0;Lc(461892)}function ot(a,b){return VQ(a,b)}function nn(a){return tj(Sd(a))}function nj(a){return!v[a+4>>2]}function kn(a){yb(a+12|0);yb(a)}function jq(a,b){return OB(a,b)}function iv(a,b){return uf(a,b)}function ie(a){a=a|0;return a|0}function cL(a,b){return $K(a,b)}function _q(a){a=a|0;return 127}function _e(a){yb(a+20|0);yb(a)}function _b(a,b){return Ge(a,b)}function Zh(a,b){return a>>>b&1}function So(a){u[a+480214>>1]=0}function RP(a,b){return Ci(b,a)}function Qi(a,b,c){Ye(a,c,13,b)}function Pj(a,b,c){Uc(a,b,1<<c)}function Pd(a,b){return Zl(a,b)}function P1(a){a=a|0;lH(a-88|0)}function Mk(a,b){return PB(a,b)}function Mh(a){return xe(a)&255}function Km(a){return a<<24>>24}function Je(a,b){return Xf(a,b)}function IX(a){a=a|0;yb(461780)}function GX(a){a=a|0;Lc(461796)}function EX(a){a=a|0;yb(461812)}function Dl(a){yb(a+12|0);kf(a)}function Di(a,b){return lu(a,b)}function CX(a){a=a|0;Lc(461828)}function AX(a){a=a|0;yb(461844)}function $o(a){oe(a+12|0);eN(a)}function zs(a,b){return a<<8|b}function zO(a){return a+4896|0}function xY(a){a=a|0;Xb(yE(a))}function x0(a){a=a|0;Xb($v(a))}function vV(a){a=a|0;Xb(xC(a))}function u4(a){a=a|0;Xb(Ww(a))}function tV(a){a=a|0;Xb(Hu(a))}function t2(a){a=a|0;Xb(Rr(a))}function t0(a){a=a|0;Xb(il(a))}function rJ(a){a=a|0;Xb(sJ(a))}function py(a,b){return b-a>>1}function o0(a){a=a|0;Xb(uo(a))}function nS(a){return a+2466|0}function n2(a){a=a|0;Xb(EH(a))}function lH(a){a=a|0;Xb(Gw(a))}function kD(a){return a>>>0>16}function k2(a){a=a|0;Xb(CH(a))}function iY(a){a=a|0;Xb(aE(a))}function he(a,b){t[a|0]=w[b|0]}function hY(a){a=a|0;Xb($D(a))}function gs(a){return a>>>27^a}function dc(a,b){v[a+100>>2]=b}function bL(a,b,c){ry(a,b,c,1)}function _W(a){a=a|0;Xb(Rq(a))}function _6(a){a=a|0;return 13}function Zv(a){a=a|0;Xb(mr(a))}function ZI(a){a=a|0;Xb(_I(a))}function ZD(a){a=a|0;Xb(yv(a))}function Z7(a){a=a|0;Xb(bx(a))}function Wv(a){a=a|0;Xb(jr(a))}function WY(a){a=a|0;Xb(gE(a))}function VQ(a,b){return b-a>>2}function Rga(a){a=a|0;return 9}function RI(a){a=a|0;Xb(SI(a))}function RF(a){a=a|0;Xb(ah(a))}function NH(a){a=a|0;Xb(Yd(a))}function N$(a){a=a|0;Xb(uF(a))}function L$(a){a=a|0;Xb(_v(a))}function JI(a){a=a|0;Xb(KI(a))}function JF(a){a=a|0;Xb(If(a))}function HJ(a){a=a|0;Xb(IJ(a))}function GY(a){a=a|0;Xb(eE(a))}function FD(){return(Sa()|0)>0}function F2(a){a=a|0;Xb(Mr(a))}function $W(a){a=a|0;Xb(qv(a))}function uO(a,b){Rb(a,0,b<<2)}function tl(a,b){v[a+32>>2]=b}function sr(a,b){v[a+72>>2]=b}function se(a){a=a|0;return 1}function rq(a){Du(a);return a}function rj(a){return sd(a)^1}function re(a){a=a|0;return 2}function r4(){return 19468288}function mh(a){return md(a)^1}function ln(a,b){v[a+36>>2]=b}function jn(a){jy(a);return a}function jR(a){a=a|0;return 7}function ic(a){a=a|0;return 0}function gh(a){QM(a);return a}function fc(a,b){return a+b|0}function Yx(a){jn(a);return a}function Xx(a){tC(a);return a}function UV(a){a=a|0;return 3}function Sn(a){return a>>>0<5}function Ql(a){gu(a);return a}function Pk(a){return!v[a>>2]}function Oi(a){dB(a);return a}function Oe(a,b){u[a+28>>1]=b}function OF(a){a=a|0;return-1}function N7(a){a=a|0;return 6}function Mp(a){qB(a);return a}function IK(a){a=a|0;return 5}function Gq(a){a=a|0;return 4}function EA(a,b){return b-a|0}function Dt(a){Ek(a);return a}function $s(a){return a+256|0}function $h(a){return sc(a,1)}function zc(a,b){a=a|0;b=b|0}function yP(a,b){Ye(a,b,8,2)}function xn(a,b){v[a+8>>2]=b}function we(a,b){v[a+4>>2]=b}function tR(a){UB(a,v[a>>2])}function rr(a,b){oo(a,b+4|0)}function rE(a){SD(a,v[a>>2])}function po(a,b){lg(a);lg(a)}function pL(a){oL(a,v[a>>2])}function of(a,b){t[a+11|0]=b}function nH(a){v[a>>2]=84384}function mk(a,b){yd(a);yd(a)}function lm(a,b){Yh(a);Yh(a)}function kT(a){aT(a,v[a>>2])}function iA(a,b){yf(a);yf(a)}function gK(a,b){lj(a);lj(a)}function fC(a){eC(a,v[a>>2])}function fB(a){GB(a,v[a>>2])}function ec(a){return a+12|0}function _k(a){return a+32|0}function ZH(a){v[a>>2]=83632}function YL(a){XL(a,v[a>>2])}function XN(a,b){VN(a,cc(b))}function XM(a){WM(a,v[a>>2])}function WR(a){VR(a,v[a>>2])}function WN(a,b){VN(a,bc(b))}function Ug(a){return a+20|0}function UD(a,b){Zk(a);Zk(a)}function Tt(a,b){We(a);We(a)}function Tq(a){return a+16|0}function TR(a){SR(a,v[a>>2])}function Rm(a){v[a>>2]=71152}function Qo(a,b){z[a+8>>2]=b}function QH(a){v[a>>2]=59048}function Ot(a,b){Li(a);Li(a)}function Oo(a,b){z[a+4>>2]=b}function Nq(a,b,c){Uc(a,b,c)}function No(a,b){t[a+36|0]=b}function NN(a){MN(a,v[a>>2])}function Mu(a,b){Vi(a);Vi(a)}function Lr(a){v[a>>2]=83912}function Kp(a){v[a>>2]=76544}function IQ(a,b,c){Xw(a,b,c)}function GJ(a){BJ(a,v[a>>2])}function Fs(a,b){qy(a,Nd(b))}function Ex(a,b){t[a+37|0]=b}function El(a,b){zb(b);zb(a)}function ET(a){vT(a,v[a>>2])}function Dx(a,b){t[a+38|0]=b}function DJ(a){xJ(a,v[a>>2])}function CL(a){rL(a,v[a>>2])}function Bu(a,b){Vf(a);Vf(a)}function BL(a){return a+80|0}function Aq(a,b){th(a);th(a)}function $u(a,b){XC(a,Nd(b))}function zb(a){return a+8|0}function tG(){return 458208}function sp(a){Rb(a,0,4096)}function s4(){return 327689}function qm(){Zi(70684);L()}function hc(a){return a+4|0}function hG(){Zi(55692);L()}function ed(){Fc(55692);L()}function eX(){return 463532}function cd(a){return a+1|0}function Wo(a){Rb(a,0,8192)}function Wc(a){return!Fb(a)}function WB(a,b){Uc(a,b,22)}function Vy(a){v[a+12>>2]=0}function Vl(a,b){t[a+3|0]=b}function Rh(a){return a+3|0}function Mla(){return 65535}function KL(a){Rb(a,0,1024)}function JB(a,b){Uc(a,b,20)}function Hha(){return 65534}function Hg(){Fc(70684);L()}function Cg(a){return a&255}function Bf(a){return a+2|0}function zp(a){xz(a,Ke(a))}function wM(a){Zx(a,Ke(a))}function vj(a,b){Tn(a,b,0)}function vE(a){jE(a);tE(a)}function up(a){We(a);Id(a)}function tp(a){yf(a);xc(a)}function sk(a){oy(a,Ke(a))}function sh(a,b,c){DC(b,c)}function qq(a){Ol(a);jC(a)}function qE(a){Zk(a);Kb(a)}function oe(a){vf(a);ys(a)}function nD(a){Yh(a);nd(a)}function kf(a){Qk(a);bq(a)}function kd(a){bj(a);pC(a)}function jT(a){Ml(a);Ni(a)}function jK(a){lj(a);jf(a)}function ip(a){Vk(a);fN(a)}function gd(a){Vk(a);oB(a)}function gB(a,b){Sh(a,2,b)}function fe(a){Ol(a);pq(a)}function eT(a){Mt(a);cT(a)}function ct(a){lg(a);yc(a)}function cS(a){t[a+31|0]=0}function _y(a,b,c){tP(b,c)}function _R(a){Lz(a,Ke(a))}function Zu(a){Dq(a);WC(a)}function ZL(a){ss(a,Ke(a))}function Yi(a,b,c){lD(b,c)}function Yf(a,b,c){RC(b,c)}function XR(a){Nz(a,Ke(a))}function Wu(a){th(a);xe(a)}function VK(a){Ax(a,Ke(a))}function Sw(a){Vk(a);kI(a)}function Qg(a){yd(a);Kb(a)}function Po(a,b){z[a>>2]=b}function Pg(a){Ol(a);KA(a)}function Pc(a){a=a|0;Xb(a)}function Oy(a){Rb(a,0,512)}function Ob(a){gm(v[a>>2])}function Nn(a){Vf(a);oc(a)}function NP(a){vf(a);LP(a)}function Mf(a){Dq(a);uy(a)}function Ll(a){Mt(a);At(a)}function KQ(a){vf(a);GQ(a)}function Jc(a){v[a+8>>2]=0}function Iq(a){a=a|0;Jq(a)}function HR(a){Li(a);cg(a)}function Ff(a,b){v[a>>2]=b}function FJ(a){jk(a);mf(a)}function E$(){return 60524}function D$(){return 61296}function C$(){return 62848}function Ap(a){yz(a,Ke(a))}function vR(a){Rb(a,0,33)}function vF(a){Rb(a,0,44)}function dG(a){hw(a,8192)}function VB(a){t[a+1|0]=3}function S3(){return 2048}function MW(){return jb|0}function LW(a){a=a|0;jb=a}function yh(a,b){Wg(a,b)}function xt(a){yb(a+4|0)}function ih(a){a=a|0;L()}function hf(a){Bb(a+8|0)}function dA(a){t[a|0]=16}function cQ(a,b){Zw(a,b)}function _s(a){v[a>>2]=0}function ZM(a,b){WN(a,b)}function QC(a,b){Oc(a,b)}function NA(a,b){mI(a,b)}function GN(a,b){xf(a,b)}function Ec(a){Pg(a+8|0)}function Dn(a,b){GF(a,b)}function ff(a){t[a|0]=0}function wf(a){qy(a,0)}function qs(a){GL(a,0)}function ps(a){FL(a,0)}function iL(a){UK(a,0)}function bg(a){$R(a,0)}function Yc(a){sI(a,0)}function Gh(a){fI(a,0)}function Gc(a){ye(a,0)}function Eq(a){XC(a,0)}function tB(a){_d(a)}function Ib(a){yb(a)}function He(a){a=a|0}function uZ(){pE()}function pZ(){oE()}function mZ(){nE()}function kZ(){mE()}function iZ(){lE()}function aZ(){kE()}function cX(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var nb=c([null,Cl,Ub,iq,Af,Ema,Cn,Wia,jia,jj,oha,nga,Iea,$r,Cl,j0,_U,Yl,Ag,i0,$,nu,Lk,qW,qv,dv,ve,LU,Wl,Pi,oZ,uc,zc,Lb,Pi,Ska,Ip,kS,Uy,nh,du,Oga,$y,ih,se,se,gka,cka,zt,Wja,DP,Cha,yha,cX,Zy,ih,se,ic,se,Jia,Eia,Aia,via,pia,mha,aia,gha,Yha,Sha,ie,ih,vO,zea,Ss,RN,Zs,PN,mO,hO,Ns,xda,Ba,pda,Zc,Zc,Ub,qX,ly,Dca,sca,Zc,Kba,Iba,xM,uc,_m,fh,Zc,pX,Dba,Ada,Bba,Cba,wba,rba,He,H9,zc,Xaa,xM,On,Ss,kX,mX,Cl,u9,u8,Io,On,o7,Af,g7,iE,L6,D6,y6,Y3,P3,M$,I3,h6,Z5,E5,nI,nI,j5,_4,Vr,iq,Ur,i4,d4,Ur,l1,k1,h1,g1,Ur,Ur,Co,Cl,Yd,NH,$2,U2,jr,Wv,zF,yF,Mr,F2,zc,Cl,v2,c2,ic,ic,s0,_1,r0,R1,q0,A1,c0,H0,u0,p0,f0,$$,_$,sw,b0,k0,If,JF,e0,Y$,mr,Zv,MF,LF,K$,Zs,J$,H$,YE,eo,Cl,h_,br,Us,H_,s_,uc,Dv,wE,cE,uc,uc,du,Mq,sW,rW,oW,tW,zc,pW,zc,Uy,Qfa,nW,mW,lW,kW,Bi,iW,u$,i$,hW,fD,eD,gW,br,fW,dW,cv,Iq,Xi,Mc,aW,km,$V,_V,bW,ZV,YV,eW,Ffa,cW,dD,XV,WV,cD,VV,Ef,Lj,Qc,Yu,Qb,QV,Kj,Yu,PV,OV,NV,Rq,EV,DV,Zc,uc,BC,qD,zV,MV,Eg,LV,FV,Xh,Zc,CV,Eg,BV,Zc,zc,yV,xV,Eg,wV,Pi,Su,zt,ie,Pc,ao,xI,KV,Pc,JV,se,se,zt,Fz,IV,DP,HV,GV,ie,Pc,ao,AV,Pc,ic,se,se,ic,ic,HC,xC,vV,ao,uV,Hu,tV,sV,rV,qV,pV,W1,oV,nV,mV,fv,nf,Lb,hV,Haa,gV,Gaa,fV,vq,$b,Kaa,JC,ud,eV,fh,nX,uc,_m,EC,cE,zc,uC,bV,aV,Su,uc,uc,uc,iC,ZU,YU,zc,zc,zc,XU,du,Uy,Mq,NU,fh,VU,RU,MU,zc,iC,pu,KU,ou,JU,FU,EU,ku,Mn,zc,zU,xB,yU,Ed,xq,wB,xU,RV,pc,bd,wU,vU,uU,vB,uB,tU,sU,tg,$f,rg,rU,sB,rB,qU,pB,Ln,uc,pU,_m,nU,Db,LB,Ic,uc,uc,kU,uc,oU,mU,zc,lU,ku,ZA,WA,hU,gU,fU,eU,dU,zg,cU,bU,aU,$T,nw,zJ,Db,xO,_T,dg,ZT,hu,PA,hd,Hd,Xi,mj,WT,VT,Si,qh,sL,UT,TT,bu,Ac,_u,ST,OA,de,eu,Ws,Db,Ip,WU,QT,mq,Xe,dq,LT,JT,$C,vi,lf,Nb,wg,Dma,uA,Cma,Mc,Wp,$da,Bma,Ama,mp,zma,IT,HT,xma,tA,wma,baa,Rn,Qn,ql,sx,xK,vma,CT,jJ,uma,tma,sma,Dk,sA,rma,qma,xu,AT,pma,oma,wT,vO,nma,mma,uc,oA,oA,lma,kma,RN,Zs,PN,Jn,Up,Tp,uc,zc,Ns,hma,gma,fma,cma,qA,bma,jA,ama,$la,_la,St,Zla,np,My,Yla,Xla,Wla,Vla,zf,Tf,Ula,Tla,Sla,Lla,Kla,Jla,Tp,Pla,Ola,Ip,Pp,dT,Qla,uc,uc,Nla,zc,Mq,Jn,zc,wj,Op,Gla,Ht,Fla,Cla,JT,Np,Bla,It,Ny,IT,Ala,Tl,zla,yla,RS,gg,xla,wla,jG,Sl,kt,vla,nea,AT,ula,tla,xg,LS,Jn,Up,Tp,uc,sla,rla,LS,CS,AK,haa,vx,wS,ila,hla,ph,ela,dla,aba,ala,$ka,_ka,Zka,yu,Yka,Xka,Wka,Ef,PU,Vka,iga,jga,Uka,Tka,gla,Bn,SU,Rka,op,QU,rS,Qka,Pka,pba,bd,Oka,Nka,qS,Mka,IU,Lka,Kka,Jka,pS,Ika,Wy,Hka,Gka,OU,mT,fla,Fka,mS,Eka,Xz,hO,dC,kq,Dka,Cka,Em,Yaa,Bka,Aka,jS,jS,Wz,gS,Tz,$k,zka,uW,yka,xka,wka,vka,kh,Zda,kh,P9,uka,p9,fS,uc,jka,Wi,Bd,An,pka,hka,cB,ho,qi,uc,KR,fka,eka,eS,tka,ska,xf,rka,Gi,yt,q9,dba,h9,qka,iq,oka,nka,mka,Zc,Ck,Zc,Mz,ie,ZR,Eg,Pz,ie,Pz,zc,lka,zc,zc,kka,fh,wt,ika,$ja,_ja,Zja,yg,Hn,Yja,Xja,_C,Vja,hd,Nk,Uja,Tja,Sja,Rja,Qja,Pja,Oja,Nja,uc,Ija,Hja,Mja,Lja,Kja,zc,rR,Jn,qR,Jja,uc,kR,Bn,Eja,Dja,Cja,Bja,jea,Ef,Aja,zja,yja,xja,IS,iO,Jb,tt,Cz,_z,ou,wja,vja,hR,uja,Bt,gA,tja,Hj,sja,iq,Ef,cu,Ef,Gu,hq,rja,Gi,eR,cea,nx,dR,Bp,uc,Ck,Zc,uc,zc,qja,fh,wt,zc,ie,zc,zc,pja,ku,ZA,oja,Eg,lja,kja,Wi,jja,ija,wz,nt,hja,gja,fja,eja,dja,cja,AB,bja,aja,Db,$ia,_ia,Zia,Yia,hga,gda,HC,Xia,Db,mt,m1,Rz,n1,mt,Via,Uia,o1,p1,Zaa,Tia,iS,hS,nO,Bi,Sia,Ria,Qia,Pia,Oia,uc,wt,uc,Nia,Mq,Pi,zc,WA,Qt,lt,Aj,qi,Ef,Op,Cia,Bia,Lia,vt,zc,xia,PA,LA,wia,_aa,uia,tia,mK,An,sia,fQ,ria,qia,uu,tu,it,Rba,oia,nia,Vs,mia,Kn,lia,kia,gz,gq,uc,zc,iia,hia,BC,Ef,cia,eg,bia,Zc,$ha,_ha,SP,Zc,lq,Zha,Vha,Uha,Fk,on,it,Tha,gaa,Rha,MP,uc,wt,zc,Qha,fh,Nha,Mha,jA,TP,EP,eu,Lha,Kha,Jha,Iha,Mla,Hha,Gha,Fha,et,Eha,Dha,et,Bha,zA,AP,Aha,TU,uc,tha,qha,pha,Op,wha,vha,uha,uc,Jn,sha,Up,Tp,rha,rP,qP,Yy,uc,kha,Bn,jha,fha,AO,fQ,Bn,ida,hda,cha,Zga,Yga,_u,Xga,Wga,Vga,Uga,Tga,pt,Sga,Qga,Pga,Nga,Mga,Lga,uc,Jga,Iga,Gga,Kga,zc,Hga,uc,uc,FO,Dga,fz,Cga,Bga,dea,yga,xga,Daa,wga,vga,uga,Baa,tga,Caa,Eaa,sga,rga,qga,jW,iD,gea,mz,iba,gba,Qy,pga,oga,uc,Py,mga,fh,zc,BO,lga,gga,fga,ega,dga,cga,bga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Pfa,Ofa,Nfa,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,Efa,Dfa,Cfa,Bfa,Afa,zfa,yfa,xfa,wfa,vfa,ufa,tfa,sfa,rfa,qfa,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,Kea,Jea,Hea,Gea,Fea,Eea,Dea,Cea,Bea,Aea,yea,xea,wea,vea,uea,tea,sea,rea,qea,pea,oea,mea,lea,iea,jO,kea,Ck,Zc,uc,Mn,Eg,Pda,Fj,eea,fea,eB,UN,aea,uc,Nda,_da,IN,Mda,Yda,Xda,Wda,Vda,Uda,QN,Tda,Sda,Rda,Qda,eS,Qs,Lda,Oda,JN,uc,xN,Zc,Kda,Zc,Ida,Hda,Gda,qN,Fda,bB,Eda,qD,Dda,nN,Paa,Cda,Bda,ls,Naa,zda,Maa,Laa,yda,wda,vda,uda,sda,rda,uc,uc,tda,zc,uc,qda,zc,qj,uc,lda,kda,mda,jda,Fw,q1,Js,fda,eba,xj,hea,Gy,eda,wT,Mn,Mn,Zs,cD,Ck,Zc,Dv,wE,ie,cda,Eg,uc,lS,$d,zB,$U,Me,RT,bda,ada,Db,Rla,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Qba,oda,Pba,Oba,Nba,aN,$M,Mba,Lba,fn,Bs,iy,Jba,KM,Ys,ep,JM,fL,tL,Jx,dp,As,cp,Hba,EM,oO,rO,Gba,Fba,Gi,yt,Bp,wN,xy,yi,Gi,eR,Eba,Bp,nda,uc,Aba,zba,Ck,Zc,Zc,Ck,Zc,uc,zc,ie,zc,VL,yba,Eg,ie,zc,xba,Eg,uba,bea,kga,ML,UL,tba,Taa,sba,JL,Pe,Zc,Zc,uc,qba,oba,TV,lV,jV,dV,mba,cV,kV,SV,iV,k8,lba,Ux,Faa,uc,Jda,uc,_m,fh,Zc,hba,fba,F9,K9,cba,I9,E9,Zc,Zc,Ly,bba,kO,uc,uc,Waa,Vaa,zc,Aga,zga,cla,bla,iha,hha,bha,aha,Gja,Fja,gia,fia,bka,aka,NT,MT,qla,ola,jU,iU,YT,XT,eia,dia,nha,lha,Fga,Ega,ema,dma,Ila,Hla,DU,CU,BU,AU,Pha,Oha,zha,xha,zia,yia,dka,DR,nla,lla,kla,jla,jma,ima,Ela,Dla,Xha,Wha,Aaa,zaa,jaa,iaa,Fia,Dia,eha,dha,$ga,_ga,Mia,Hia,Gia,HU,GU,PT,OT,nja,mja,Kia,Iia,Raa,uc,_m,fh,Qaa,Ck,Zc,NL,zc,cE,Mz,Eg,BO,Oaa,zx,Os,Iaa,Jaa,TM,yaa,xaa,jA,waa,Ut,vaa,EP,uaa,taa,saa,Op,raa,qaa,Ef,paa,oaa,naa,maa,laa,AP,kaa,v1,s1,r1,uc,Jn,Up,Tp,faa,eaa,daa,KR,aaa,W9,kh,_9,Z9,kh,Vz,Y9,Gf,Wg,gl,X9,V9,U9,O9,T9,caa,S9,M9,L9,Q9,$9,N9,qx,uc,dK,uc,Ck,Zc,t9,fh,r9,kx,Gi,yt,G9,e8,s9,C9,B9,kh,A9,z9,y9,bK,J9,Mo,QN,x9,xf,aK,v9,Nj,Wg,Py,ZR,Eg,o9,n9,m9,l9,k9,j9,_i,i9,RJ,w9,D9,QJ,g9,e9,d9,c9,s8,b9,a9,EJ,O8,CJ,fh,$J,N8,L8,M8,zc,Py,zc,IJ,HJ,HJ,T8,ic,He,ic,ic,ic,zc,Gq,X8,Y8,_8,Z8,$8,si,ix,ix,hx,hx,hx,yma,He,DR,S8,R8,Q8,P8,W8,ri,JJ,r8,ic,ic,se,gx,re,re,se,V8,U8,zc,He,zc,He,J8,v8,sJ,rJ,rJ,t8,ic,He,ic,ic,ic,zc,Rga,wJ,H8,x8,w8,I8,si,F8,E8,D8,C8,B8,A8,z8,y8,G8,ri,vJ,ic,ic,se,re,re,se,uJ,tJ,o8,n8,lJ,uc,uc,bf,ih,p8,kJ,q8,ic,m8,l8,j8,Us,i8,h8,g8,f8,Zc,fh,Qs,uc,_m,zc,d8,U7,M7,F7,y7,r7,h7,Z6,S6,f9,K8,gJ,bx,Z7,fJ,Y7,ic,He,ic,ic,ic,zc,jR,a8,b8,c8,si,$7,ri,_7,ic,ic,se,re,re,zc,He,eJ,X7,W7,dJ,V7,cJ,bJ,T7,_I,ZI,ZI,O7,ic,He,ic,ic,ic,zc,N7,Q7,R7,S7,si,P7,ri,$I,ic,ic,se,re,re,L7,ik,ik,G7,ic,He,ic,ic,ic,zc,IK,I7,J7,K7,si,H7,ri,WI,ic,ic,se,re,re,E7,SI,RI,RI,z7,ic,He,ic,ic,ic,zc,IK,B7,C7,D7,si,A7,ri,TI,ic,ic,se,re,re,x7,QI,QI,v7,jR,w7,eJ,u7,t7,dJ,s7,cJ,bJ,q7,ik,ik,k7,ic,He,ic,ic,ic,zc,re,m7,n7,p7,si,l7,ri,j7,ic,ic,se,re,re,f7,i7,KI,JI,JI,a7,ic,He,ic,ic,$6,zc,_6,c7,d7,e7,si,b7,ri,_w,ic,ic,se,re,re,zc,He,Y6,ik,ik,T6,ic,He,ic,ic,ic,zc,UV,V6,W6,X6,si,U6,ri,HI,ic,ic,se,re,re,R6,ik,ik,M6,ic,He,ic,ic,ic,zc,Gq,O6,P6,Q6,si,N6,ri,EI,ic,ic,se,re,re,s4,J6,z4,j4,r4,q4,X3,cv,V3,Wr,uI,R3,x6,w6,Zc,Zc,S3,Q3,O3,N3,ie,ha,t6,s6,uI,M3,K3,pI,p6,Ww,PH,Fz,u3,t3,x3,r3,s3,v3,Yw,J3,_5,jI,H3,G3,F3,E3,D3,C3,B3,A3,z3,y3,q3,Yw,k3,j3,i3,h3,g3,f3,e3,d3,c3,b3,a3,_2,Z2,Y2,Eo,X2,W2,ml,Or,V2,ED,T2,R2,Q2,P2,O2,N2,M2,Ow,L2,K2,I2,H2,G2,D2,C2,A2,y2,w2,a4,bI,aI,$H,_H,T1,S1,pI,Yw,R4,Q4,P4,O4,N4,M4,L4,K4,J4,I4,H4,G4,F4,E4,D4,C4,B4,A4,y4,v4,Vw,x4,w4,lI,t4,lI,u4,ZC,Tr,p4,dda,Hq,n4,m4,uc,i2,k4,AH,h2,Cs,e4,uc,VL,g2,vba,$3,GD,FO,Zc,Zc,Zc,B2,u2,z2,x2,nba,c4,o4,h4,Ou,Gi,yt,Bp,su,Z3,Uaa,Saa,W3,hI,gI,T3,U3,Zc,q2,p2,b4,UH,_3,f4,Zc,Zc,Zc,Db,gc,L3,w3,Zc,Zc,yL,p3,o3,n3,U1,jba,kba,g4,$aa,m3,l3,Qm,LH,R9,S2,sj,kK,J2,Xe,uL,zK,yK,E2,uc,Eg,o2,Eg,l2,Pz,zc,V1,uc,ih,Rr,t2,l4,ie,ih,ie,Pc,s2,r2,ih,EH,n2,ao,m2,CH,k2,ao,j2,Pc,f2,ie,Pc,e2,d2,Pc,vH,uH,ih,Pc,b2,a2,Pc,tH,sH,Pc,$1,Z1,Pc,rH,qH,Pc,Y1,X1,Pc,pH,oH,Gw,lH,O1,N1,kH,jH,iH,hH,gH,fH,eH,dH,cH,bH,aH,$G,_G,ZG,YG,XG,Q1,P1,M1,L1,K1,J1,I1,H1,G1,F1,E1,D1,C1,B1,z1,y1,x1,w1,ie,ih,ie,ih,u1,t1,j1,i1,e1,d1,c1,a1,b1,_0,ic,Z0,Y0,X0,Pr,Pr,dw,cw,lr,FF,il,aG,W0,QF,PF,V0,U0,T0,nr,uo,YF,S0,Cl,QF,PF,ic,ic,n0,R0,Q0,P0,l0,nr,aG,O0,WF,OF,nr,N0,M0,YF,L0,WF,OF,m0,nr,K0,J0,I0,y0,iX,TF,$v,ie,Pc,D0,G0,F0,E0,C0,Pc,B0,z0,A0,x0,w0,VF,$m,h0,d0,v0,g0,a0,S$,Z$,Yv,X$,pla,mla,OS,W$,$m,Ag,V$,U$,T$,S$,R$,xF,He,O$,uF,t0,o0,zc,mr,Zv,MF,LF,jr,Wv,zF,yF,Pc,Q$,P$,N$,_v,L$,ah,RF,ah,RF,I$,Kv,_g,Zg,gr,Xb,xv,to,gj,bk,Jv,hl,ro,Zj,s$,Ee,di,ng,q$,o$,XE,XE,k$,fr,h$,WE,ei,f$,d$,Bc,le,b$,G$,Nv,Xv,Hv,_g,Zg,er,kr,_j,fl,Lk,Cm,Yj,di,ng,dr,VE,ei,P_,Wj,K_,J_,ro,F$,Qv,f1,wF,D_,ir,qo,Wl,y_,xm,ro,Ov,He,e_,$q,d_,c_,IE,b_,HE,ro,$Z,eo,ZZ,YZ,$j,XZ,CE,HE,VZ,lX,TZ,SZ,PZ,OZ,Pv,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,nZ,mZ,lZ,kZ,jZ,iZ,hZ,gZ,fZ,eZ,dZ,cZ,bZ,aZ,$Y,_Y,ZY,uE,YD,Py,TY,XY,tX,YY,sX,rX,ie,VY,UY,SY,E$,D$,C$,fF,ck,eF,so,sY,rY,dF,cF,bF,_X,ZX,XX,WX,UX,TX,RX,QX,OX,NX,LX,KX,IX,zv,GX,EX,CX,AX,yX,wX,uX,RD,zc,gE,WY,fJ,eE,GY,FY,EY,DY,CY,yB,BY,AY,zY,yE,xY,wY,vY,uY,tY,ic,qY,pY,aE,iY,gY,fY,LH,dY,bY,$D,hY,Fz,UU,eY,cY,aY,ie,Pc,Pc,RY,QY,PY,OY,NY,MY,LY,KY,yB,JY,IY,HY,Pc,dE,dE,Bv,se,se,yY,se,Pc,oY,nY,Bv,ic,ic,mY,Gq,Pc,lY,kY,Bv,ic,ic,jY,Gq,ie,Pc,B$,A$,z$,ie,Pc,y$,x$,w$,Pc,v$,t$,r$,p$,n$,m$,l$,j$,g$,e$,c$,Pc,a$,$_,__,Z_,Y_,X_,W_,V_,U_,T_,S_,Pc,R_,Q_,O_,N_,M_,L_,I_,G_,Pc,F_,E_,C_,B_,A_,z_,x_,w_,ie,Pc,re,v_,u_,t_,r_,q_,p_,$X,VX,PX,BX,xX,JX,FX,ie,Pc,re,o_,n_,m_,l_,k_,j_,YX,SX,MX,zX,vX,HX,DX,yv,ZD,i_,yv,ZD,g_,Pc,_q,_q,Uj,Uj,Uj,LE,ic,Tj,Tj,Pc,_q,_q,Uj,Uj,Uj,LE,ic,Tj,Tj,Pc,ts,ts,Uj,Zq,Zq,KE,ic,Tj,Tj,Pc,ts,ts,Uj,Zq,Zq,KE,ic,Tj,Tj,Pc,f_,a_,Pc,_Z,WZ,Pc,UZ,RZ,Pc,QZ,NZ,Pc,zE,MZ,zc,Pc,zE,LZ,zc,SF,oX,ie,ih,ih,ic,ic,ic,MD,ND,PD,YE,jX,Ra,tG,hX,gX,dX,eX,fX,Pc,aX,Pc,bX,$W,zt,_W,pv,pv,pv,Su,Pc,ZW,ie,Pc,He,He,YW,PW,SW,XW,Pc,QW,TW,WW,Pc,RW,UW,VW]);function ob(){return s.byteLength/65536|0}function tb(ub){ub=ub|0;var pb=ob()|0;var qb=pb+ub|0;if(pb<qb&&qb<65536){var rb=new ArrayBuffer(B(qb,65536));var sb=new Int8Array(rb);sb.set(t);t=new Int8Array(rb);u=new Int16Array(rb);v=new Int32Array(rb);w=new Uint8Array(rb);x=new Uint16Array(rb);y=new Uint32Array(rb);z=new Float32Array(rb);A=new Float64Array(rb);s=rb;r.buffer=s;e=w}return pb}return{"ya":KT,"za":nb,"Aa":K6,"Ba":I6,"Ca":Pc,"Da":Xb,"Ea":H6,"Fa":G6,"Ga":F6,"Ha":Wr,"Ia":zc,"Ja":E6,"Ka":C6,"La":B6,"Ma":ix,"Na":A6,"Oa":xI,"Pa":z6,"Qa":ie,"Ra":wI,"Sa":vI,"Ta":wI,"Ua":v6,"Va":JW,"Wa":IW,"Xa":HW,"Ya":u6,"Za":rI,"_a":r6,"$a":qI,"ab":q6,"bb":o6,"cb":n6,"db":m6,"eb":l6,"fb":k6,"gb":j6,"hb":i6,"ib":g6,"jb":f6,"kb":e6,"lb":d6,"mb":c6,"nb":b6,"ob":a6,"pb":$5,"qb":Y5,"rb":X5,"sb":W5,"tb":V5,"ub":U5,"vb":T5,"wb":S5,"xb":R5,"yb":Q5,"zb":P5,"Ab":O5,"Bb":N5,"Cb":M5,"Db":L5,"Eb":K5,"Fb":J5,"Gb":I5,"Hb":H5,"Ib":G5,"Jb":F5,"Kb":D5,"Lb":C5,"Mb":B5,"Nb":A5,"Ob":z5,"Pb":y5,"Qb":x5,"Rb":w5,"Sb":v5,"Tb":u5,"Ub":t5,"Vb":s5,"Wb":r5,"Xb":q5,"Yb":p5,"Zb":o5,"_b":n5,"$b":m5,"ac":l5,"bc":k5,"cc":i5,"dc":h5,"ec":g5,"fc":f5,"gc":e5,"hc":d5,"ic":c5,"jc":GW,"kc":b5,"lc":a5,"mc":$4,"nc":Z4,"oc":FW,"pc":Y4,"qc":X4,"rc":W4,"sc":V4,"tc":U4,"uc":T4,"vc":S4,"wc":od,"xc":tG,"yc":MW,"zc":LW,"Ac":KW,"Bc":$0,"Cc":OW,"Dc":NW,"Ec":EW,"Fc":DW,"Gc":CW,"Hc":BW,"Ic":wW,"Jc":AW,"Kc":zW,"Lc":yW,"Mc":xW,"Nc":wW,"Oc":vW}}return vb(xb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


